/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.51 from the
 * contents of Const.xs. Do not edit this file, edit Const.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

#line 1 "lib/OpenGL/Modern/Const.xs"
#define PERL_NO_GET_CONTEXT
#include "EXTERN.h"
#include "perl.h"
#include "XSUB.h"

#include "ppport.h"

#include <GL/glew.h>

#include "gl_errors.h"
#include "oglm.h"

#define OGL_CONST_i(test) newCONSTSUB(stash, #test, newSViv((IV)test));

#line 25 "lib/OpenGL/Modern/Const.c"
#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif

#line 169 "lib/OpenGL/Modern/Const.c"

/* INCLUDE:  Including '../../../auto-xs-enums.inc' from 'Const.xs' */


XS_EUPXS(XS_OpenGL__Modern_enum2name); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_enum2name)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "g, e");
    {
	char *	g = (char *)SvPV_nolen(ST(0))
;
	GLenum	e = (int)SvIV(ST(1))
;
	char *	RETVAL;
	dXSTARG;
#line 6 "lib/OpenGL/Modern/../../../auto-xs-enums.inc"
  RETVAL = NULL;
  if (!strcmp(g, "AccumOp")) {
    switch (e) {
      case GL_ACCUM: RETVAL = "GL_ACCUM"; break;
      case GL_ADD: RETVAL = "GL_ADD"; break;
      case GL_LOAD: RETVAL = "GL_LOAD"; break;
      case GL_MULT: RETVAL = "GL_MULT"; break;
      case GL_RETURN: RETVAL = "GL_RETURN"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "AlphaFunction")) {
    switch (e) {
      case GL_ALWAYS: RETVAL = "GL_ALWAYS"; break;
      case GL_EQUAL: RETVAL = "GL_EQUAL"; break;
      case GL_GEQUAL: RETVAL = "GL_GEQUAL"; break;
      case GL_GREATER: RETVAL = "GL_GREATER"; break;
      case GL_LEQUAL: RETVAL = "GL_LEQUAL"; break;
      case GL_LESS: RETVAL = "GL_LESS"; break;
      case GL_NEVER: RETVAL = "GL_NEVER"; break;
      case GL_NOTEQUAL: RETVAL = "GL_NOTEQUAL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ArrayObjectPNameATI")) {
    switch (e) {
      case GL_OBJECT_BUFFER_SIZE_ATI: RETVAL = "GL_OBJECT_BUFFER_SIZE_ATI"; break;
      case GL_OBJECT_BUFFER_USAGE_ATI: RETVAL = "GL_OBJECT_BUFFER_USAGE_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ArrayObjectUsageATI")) {
    switch (e) {
      case GL_DYNAMIC_ATI: RETVAL = "GL_DYNAMIC_ATI"; break;
      case GL_STATIC_ATI: RETVAL = "GL_STATIC_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "AtomicCounterBufferPName")) {
    switch (e) {
      case GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS"; break;
      case GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTER_INDICES: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTER_INDICES"; break;
      case GL_ATOMIC_COUNTER_BUFFER_BINDING: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_BINDING"; break;
      case GL_ATOMIC_COUNTER_BUFFER_DATA_SIZE: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_DATA_SIZE"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_COMPUTE_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_COMPUTE_SHADER"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_FRAGMENT_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_FRAGMENT_SHADER"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_GEOMETRY_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_GEOMETRY_SHADER"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_CONTROL_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_CONTROL_SHADER"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_EVALUATION_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_EVALUATION_SHADER"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_VERTEX_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_VERTEX_SHADER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "AttribMask")) {
    switch (e) {
      case GL_ACCUM_BUFFER_BIT: RETVAL = "GL_ACCUM_BUFFER_BIT"; break;
      case GL_ALL_ATTRIB_BITS: RETVAL = "GL_ALL_ATTRIB_BITS"; break;
      case GL_COLOR_BUFFER_BIT: RETVAL = "GL_COLOR_BUFFER_BIT"; break;
      case GL_CURRENT_BIT: RETVAL = "GL_CURRENT_BIT"; break;
      case GL_DEPTH_BUFFER_BIT: RETVAL = "GL_DEPTH_BUFFER_BIT"; break;
      case GL_ENABLE_BIT: RETVAL = "GL_ENABLE_BIT"; break;
      case GL_EVAL_BIT: RETVAL = "GL_EVAL_BIT"; break;
      case GL_FOG_BIT: RETVAL = "GL_FOG_BIT"; break;
      case GL_HINT_BIT: RETVAL = "GL_HINT_BIT"; break;
      case GL_LIGHTING_BIT: RETVAL = "GL_LIGHTING_BIT"; break;
      case GL_LINE_BIT: RETVAL = "GL_LINE_BIT"; break;
      case GL_LIST_BIT: RETVAL = "GL_LIST_BIT"; break;
      case GL_MULTISAMPLE_BIT: RETVAL = "GL_MULTISAMPLE_BIT"; break;
      case GL_PIXEL_MODE_BIT: RETVAL = "GL_PIXEL_MODE_BIT"; break;
      case GL_POINT_BIT: RETVAL = "GL_POINT_BIT"; break;
      case GL_POLYGON_BIT: RETVAL = "GL_POLYGON_BIT"; break;
      case GL_POLYGON_STIPPLE_BIT: RETVAL = "GL_POLYGON_STIPPLE_BIT"; break;
      case GL_SCISSOR_BIT: RETVAL = "GL_SCISSOR_BIT"; break;
      case GL_STENCIL_BUFFER_BIT: RETVAL = "GL_STENCIL_BUFFER_BIT"; break;
      case GL_TEXTURE_BIT: RETVAL = "GL_TEXTURE_BIT"; break;
      case GL_TRANSFORM_BIT: RETVAL = "GL_TRANSFORM_BIT"; break;
      case GL_VIEWPORT_BIT: RETVAL = "GL_VIEWPORT_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "AttributeType")) {
    switch (e) {
      case GL_BOOL: RETVAL = "GL_BOOL"; break;
      case GL_BOOL_VEC2: RETVAL = "GL_BOOL_VEC2"; break;
      case GL_BOOL_VEC3: RETVAL = "GL_BOOL_VEC3"; break;
      case GL_BOOL_VEC4: RETVAL = "GL_BOOL_VEC4"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_DOUBLE_MAT2: RETVAL = "GL_DOUBLE_MAT2"; break;
      case GL_DOUBLE_MAT2x3: RETVAL = "GL_DOUBLE_MAT2x3"; break;
      case GL_DOUBLE_MAT2x4: RETVAL = "GL_DOUBLE_MAT2x4"; break;
      case GL_DOUBLE_MAT3: RETVAL = "GL_DOUBLE_MAT3"; break;
      case GL_DOUBLE_MAT3x2: RETVAL = "GL_DOUBLE_MAT3x2"; break;
      case GL_DOUBLE_MAT3x4: RETVAL = "GL_DOUBLE_MAT3x4"; break;
      case GL_DOUBLE_MAT4: RETVAL = "GL_DOUBLE_MAT4"; break;
      case GL_DOUBLE_MAT4x2: RETVAL = "GL_DOUBLE_MAT4x2"; break;
      case GL_DOUBLE_MAT4x3: RETVAL = "GL_DOUBLE_MAT4x3"; break;
      case GL_DOUBLE_VEC2: RETVAL = "GL_DOUBLE_VEC2"; break;
      case GL_DOUBLE_VEC3: RETVAL = "GL_DOUBLE_VEC3"; break;
      case GL_DOUBLE_VEC4: RETVAL = "GL_DOUBLE_VEC4"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_FLOAT_MAT2: RETVAL = "GL_FLOAT_MAT2"; break;
      case GL_FLOAT_MAT2x3: RETVAL = "GL_FLOAT_MAT2x3"; break;
      case GL_FLOAT_MAT2x4: RETVAL = "GL_FLOAT_MAT2x4"; break;
      case GL_FLOAT_MAT3: RETVAL = "GL_FLOAT_MAT3"; break;
      case GL_FLOAT_MAT3x2: RETVAL = "GL_FLOAT_MAT3x2"; break;
      case GL_FLOAT_MAT3x4: RETVAL = "GL_FLOAT_MAT3x4"; break;
      case GL_FLOAT_MAT4: RETVAL = "GL_FLOAT_MAT4"; break;
      case GL_FLOAT_MAT4x2: RETVAL = "GL_FLOAT_MAT4x2"; break;
      case GL_FLOAT_MAT4x3: RETVAL = "GL_FLOAT_MAT4x3"; break;
      case GL_FLOAT_VEC2: RETVAL = "GL_FLOAT_VEC2"; break;
      case GL_FLOAT_VEC3: RETVAL = "GL_FLOAT_VEC3"; break;
      case GL_FLOAT_VEC4: RETVAL = "GL_FLOAT_VEC4"; break;
      case GL_IMAGE_1D: RETVAL = "GL_IMAGE_1D"; break;
      case GL_IMAGE_1D_ARRAY: RETVAL = "GL_IMAGE_1D_ARRAY"; break;
      case GL_IMAGE_2D: RETVAL = "GL_IMAGE_2D"; break;
      case GL_IMAGE_2D_ARRAY: RETVAL = "GL_IMAGE_2D_ARRAY"; break;
      case GL_IMAGE_2D_MULTISAMPLE: RETVAL = "GL_IMAGE_2D_MULTISAMPLE"; break;
      case GL_IMAGE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_IMAGE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_IMAGE_2D_RECT: RETVAL = "GL_IMAGE_2D_RECT"; break;
      case GL_IMAGE_3D: RETVAL = "GL_IMAGE_3D"; break;
      case GL_IMAGE_BUFFER: RETVAL = "GL_IMAGE_BUFFER"; break;
      case GL_IMAGE_CUBE: RETVAL = "GL_IMAGE_CUBE"; break;
      case GL_IMAGE_CUBE_MAP_ARRAY: RETVAL = "GL_IMAGE_CUBE_MAP_ARRAY"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_INT64_NV: RETVAL = "GL_INT64_NV"; break;
      case GL_INT64_VEC2_ARB: RETVAL = "GL_INT64_VEC2_ARB"; break;
      case GL_INT64_VEC3_ARB: RETVAL = "GL_INT64_VEC3_ARB"; break;
      case GL_INT64_VEC4_ARB: RETVAL = "GL_INT64_VEC4_ARB"; break;
      case GL_INT_IMAGE_1D: RETVAL = "GL_INT_IMAGE_1D"; break;
      case GL_INT_IMAGE_1D_ARRAY: RETVAL = "GL_INT_IMAGE_1D_ARRAY"; break;
      case GL_INT_IMAGE_2D: RETVAL = "GL_INT_IMAGE_2D"; break;
      case GL_INT_IMAGE_2D_ARRAY: RETVAL = "GL_INT_IMAGE_2D_ARRAY"; break;
      case GL_INT_IMAGE_2D_MULTISAMPLE: RETVAL = "GL_INT_IMAGE_2D_MULTISAMPLE"; break;
      case GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_INT_IMAGE_2D_RECT: RETVAL = "GL_INT_IMAGE_2D_RECT"; break;
      case GL_INT_IMAGE_3D: RETVAL = "GL_INT_IMAGE_3D"; break;
      case GL_INT_IMAGE_BUFFER: RETVAL = "GL_INT_IMAGE_BUFFER"; break;
      case GL_INT_IMAGE_CUBE: RETVAL = "GL_INT_IMAGE_CUBE"; break;
      case GL_INT_IMAGE_CUBE_MAP_ARRAY: RETVAL = "GL_INT_IMAGE_CUBE_MAP_ARRAY"; break;
      case GL_INT_SAMPLER_1D: RETVAL = "GL_INT_SAMPLER_1D"; break;
      case GL_INT_SAMPLER_1D_ARRAY: RETVAL = "GL_INT_SAMPLER_1D_ARRAY"; break;
      case GL_INT_SAMPLER_2D: RETVAL = "GL_INT_SAMPLER_2D"; break;
      case GL_INT_SAMPLER_2D_ARRAY: RETVAL = "GL_INT_SAMPLER_2D_ARRAY"; break;
      case GL_INT_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_INT_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_INT_SAMPLER_2D_RECT: RETVAL = "GL_INT_SAMPLER_2D_RECT"; break;
      case GL_INT_SAMPLER_3D: RETVAL = "GL_INT_SAMPLER_3D"; break;
      case GL_INT_SAMPLER_BUFFER: RETVAL = "GL_INT_SAMPLER_BUFFER"; break;
      case GL_INT_SAMPLER_CUBE: RETVAL = "GL_INT_SAMPLER_CUBE"; break;
      case GL_INT_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_INT_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_INT_VEC2: RETVAL = "GL_INT_VEC2"; break;
      case GL_INT_VEC3: RETVAL = "GL_INT_VEC3"; break;
      case GL_INT_VEC4: RETVAL = "GL_INT_VEC4"; break;
      case GL_SAMPLER_1D: RETVAL = "GL_SAMPLER_1D"; break;
      case GL_SAMPLER_1D_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_1D_ARRAY_SHADOW"; break;
      case GL_SAMPLER_1D_SHADOW: RETVAL = "GL_SAMPLER_1D_SHADOW"; break;
      case GL_SAMPLER_2D: RETVAL = "GL_SAMPLER_2D"; break;
      case GL_SAMPLER_2D_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_2D_ARRAY_SHADOW"; break;
      case GL_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_SAMPLER_2D_RECT: RETVAL = "GL_SAMPLER_2D_RECT"; break;
      case GL_SAMPLER_2D_RECT_SHADOW: RETVAL = "GL_SAMPLER_2D_RECT_SHADOW"; break;
      case GL_SAMPLER_2D_SHADOW: RETVAL = "GL_SAMPLER_2D_SHADOW"; break;
      case GL_SAMPLER_3D: RETVAL = "GL_SAMPLER_3D"; break;
      case GL_SAMPLER_BUFFER: RETVAL = "GL_SAMPLER_BUFFER"; break;
      case GL_SAMPLER_CUBE: RETVAL = "GL_SAMPLER_CUBE"; break;
      case GL_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW"; break;
      case GL_SAMPLER_CUBE_SHADOW: RETVAL = "GL_SAMPLER_CUBE_SHADOW"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_INT64_NV: RETVAL = "GL_UNSIGNED_INT64_NV"; break;
      case GL_UNSIGNED_INT64_VEC2_ARB: RETVAL = "GL_UNSIGNED_INT64_VEC2_ARB"; break;
      case GL_UNSIGNED_INT64_VEC3_ARB: RETVAL = "GL_UNSIGNED_INT64_VEC3_ARB"; break;
      case GL_UNSIGNED_INT64_VEC4_ARB: RETVAL = "GL_UNSIGNED_INT64_VEC4_ARB"; break;
      case GL_UNSIGNED_INT_IMAGE_1D: RETVAL = "GL_UNSIGNED_INT_IMAGE_1D"; break;
      case GL_UNSIGNED_INT_IMAGE_1D_ARRAY: RETVAL = "GL_UNSIGNED_INT_IMAGE_1D_ARRAY"; break;
      case GL_UNSIGNED_INT_IMAGE_2D: RETVAL = "GL_UNSIGNED_INT_IMAGE_2D"; break;
      case GL_UNSIGNED_INT_IMAGE_2D_ARRAY: RETVAL = "GL_UNSIGNED_INT_IMAGE_2D_ARRAY"; break;
      case GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE: RETVAL = "GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE"; break;
      case GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_UNSIGNED_INT_IMAGE_2D_RECT: RETVAL = "GL_UNSIGNED_INT_IMAGE_2D_RECT"; break;
      case GL_UNSIGNED_INT_IMAGE_3D: RETVAL = "GL_UNSIGNED_INT_IMAGE_3D"; break;
      case GL_UNSIGNED_INT_IMAGE_BUFFER: RETVAL = "GL_UNSIGNED_INT_IMAGE_BUFFER"; break;
      case GL_UNSIGNED_INT_IMAGE_CUBE: RETVAL = "GL_UNSIGNED_INT_IMAGE_CUBE"; break;
      case GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY: RETVAL = "GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_1D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_1D"; break;
      case GL_UNSIGNED_INT_SAMPLER_1D_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_1D_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_RECT: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_RECT"; break;
      case GL_UNSIGNED_INT_SAMPLER_3D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_3D"; break;
      case GL_UNSIGNED_INT_SAMPLER_BUFFER: RETVAL = "GL_UNSIGNED_INT_SAMPLER_BUFFER"; break;
      case GL_UNSIGNED_INT_SAMPLER_CUBE: RETVAL = "GL_UNSIGNED_INT_SAMPLER_CUBE"; break;
      case GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_UNSIGNED_INT_VEC2: RETVAL = "GL_UNSIGNED_INT_VEC2"; break;
      case GL_UNSIGNED_INT_VEC3: RETVAL = "GL_UNSIGNED_INT_VEC3"; break;
      case GL_UNSIGNED_INT_VEC4: RETVAL = "GL_UNSIGNED_INT_VEC4"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BindTransformFeedbackTarget")) {
    switch (e) {
      case GL_TRANSFORM_FEEDBACK: RETVAL = "GL_TRANSFORM_FEEDBACK"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BinormalPointerTypeEXT")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BlendEquationModeEXT")) {
    switch (e) {
      case GL_ALPHA_MAX_SGIX: RETVAL = "GL_ALPHA_MAX_SGIX"; break;
      case GL_ALPHA_MIN_SGIX: RETVAL = "GL_ALPHA_MIN_SGIX"; break;
      case GL_FUNC_ADD: RETVAL = "GL_FUNC_ADD"; break;
      case GL_FUNC_REVERSE_SUBTRACT: RETVAL = "GL_FUNC_REVERSE_SUBTRACT"; break;
      case GL_FUNC_SUBTRACT: RETVAL = "GL_FUNC_SUBTRACT"; break;
      case GL_MAX: RETVAL = "GL_MAX"; break;
      case GL_MIN: RETVAL = "GL_MIN"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BlendingFactor")) {
    switch (e) {
      case GL_CONSTANT_ALPHA: RETVAL = "GL_CONSTANT_ALPHA"; break;
      case GL_CONSTANT_COLOR: RETVAL = "GL_CONSTANT_COLOR"; break;
      case GL_DST_ALPHA: RETVAL = "GL_DST_ALPHA"; break;
      case GL_DST_COLOR: RETVAL = "GL_DST_COLOR"; break;
      case GL_ONE: RETVAL = "GL_ONE"; break;
      case GL_ONE_MINUS_CONSTANT_ALPHA: RETVAL = "GL_ONE_MINUS_CONSTANT_ALPHA"; break;
      case GL_ONE_MINUS_CONSTANT_COLOR: RETVAL = "GL_ONE_MINUS_CONSTANT_COLOR"; break;
      case GL_ONE_MINUS_DST_ALPHA: RETVAL = "GL_ONE_MINUS_DST_ALPHA"; break;
      case GL_ONE_MINUS_DST_COLOR: RETVAL = "GL_ONE_MINUS_DST_COLOR"; break;
      case GL_ONE_MINUS_SRC1_ALPHA: RETVAL = "GL_ONE_MINUS_SRC1_ALPHA"; break;
      case GL_ONE_MINUS_SRC1_COLOR: RETVAL = "GL_ONE_MINUS_SRC1_COLOR"; break;
      case GL_ONE_MINUS_SRC_ALPHA: RETVAL = "GL_ONE_MINUS_SRC_ALPHA"; break;
      case GL_ONE_MINUS_SRC_COLOR: RETVAL = "GL_ONE_MINUS_SRC_COLOR"; break;
      case GL_SRC1_ALPHA: RETVAL = "GL_SRC1_ALPHA"; break;
      case GL_SRC1_COLOR: RETVAL = "GL_SRC1_COLOR"; break;
      case GL_SRC_ALPHA: RETVAL = "GL_SRC_ALPHA"; break;
      case GL_SRC_ALPHA_SATURATE: RETVAL = "GL_SRC_ALPHA_SATURATE"; break;
      case GL_SRC_COLOR: RETVAL = "GL_SRC_COLOR"; break;
      case GL_ZERO: RETVAL = "GL_ZERO"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BlitFramebufferFilter")) {
    switch (e) {
      case GL_LINEAR: RETVAL = "GL_LINEAR"; break;
      case GL_NEAREST: RETVAL = "GL_NEAREST"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "Boolean")) {
    switch (e) {
      case GL_FALSE: RETVAL = "GL_FALSE"; break;
      case GL_TRUE: RETVAL = "GL_TRUE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "Buffer")) {
    switch (e) {
      case GL_COLOR: RETVAL = "GL_COLOR"; break;
      case GL_DEPTH: RETVAL = "GL_DEPTH"; break;
      case GL_STENCIL: RETVAL = "GL_STENCIL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferAccessARB")) {
    switch (e) {
      case GL_READ_ONLY: RETVAL = "GL_READ_ONLY"; break;
      case GL_READ_WRITE: RETVAL = "GL_READ_WRITE"; break;
      case GL_WRITE_ONLY: RETVAL = "GL_WRITE_ONLY"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferBitQCOM")) {
    switch (e) {
      case GL_COLOR_BUFFER_BIT0_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT0_QCOM"; break;
      case GL_COLOR_BUFFER_BIT1_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT1_QCOM"; break;
      case GL_COLOR_BUFFER_BIT2_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT2_QCOM"; break;
      case GL_COLOR_BUFFER_BIT3_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT3_QCOM"; break;
      case GL_COLOR_BUFFER_BIT4_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT4_QCOM"; break;
      case GL_COLOR_BUFFER_BIT5_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT5_QCOM"; break;
      case GL_COLOR_BUFFER_BIT6_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT6_QCOM"; break;
      case GL_COLOR_BUFFER_BIT7_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT7_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT0_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT0_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT1_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT1_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT2_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT2_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT3_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT3_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT4_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT4_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT5_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT5_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT6_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT6_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT7_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT7_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT0_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT0_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT1_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT1_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT2_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT2_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT3_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT3_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT4_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT4_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT5_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT5_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT6_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT6_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT7_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT7_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT0_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT0_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT1_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT1_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT2_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT2_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT3_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT3_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT4_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT4_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT5_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT5_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT6_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT6_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT7_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT7_QCOM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferPNameARB")) {
    switch (e) {
      case GL_BUFFER_ACCESS: RETVAL = "GL_BUFFER_ACCESS"; break;
      case GL_BUFFER_ACCESS_FLAGS: RETVAL = "GL_BUFFER_ACCESS_FLAGS"; break;
      case GL_BUFFER_IMMUTABLE_STORAGE: RETVAL = "GL_BUFFER_IMMUTABLE_STORAGE"; break;
      case GL_BUFFER_MAPPED: RETVAL = "GL_BUFFER_MAPPED"; break;
      case GL_BUFFER_MAP_LENGTH: RETVAL = "GL_BUFFER_MAP_LENGTH"; break;
      case GL_BUFFER_MAP_OFFSET: RETVAL = "GL_BUFFER_MAP_OFFSET"; break;
      case GL_BUFFER_SIZE: RETVAL = "GL_BUFFER_SIZE"; break;
      case GL_BUFFER_STORAGE_FLAGS: RETVAL = "GL_BUFFER_STORAGE_FLAGS"; break;
      case GL_BUFFER_USAGE: RETVAL = "GL_BUFFER_USAGE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferPointerNameARB")) {
    switch (e) {
      case GL_BUFFER_MAP_POINTER: RETVAL = "GL_BUFFER_MAP_POINTER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferStorageMask")) {
    switch (e) {
      case GL_CLIENT_STORAGE_BIT: RETVAL = "GL_CLIENT_STORAGE_BIT"; break;
      case GL_DYNAMIC_STORAGE_BIT: RETVAL = "GL_DYNAMIC_STORAGE_BIT"; break;
      case GL_MAP_COHERENT_BIT: RETVAL = "GL_MAP_COHERENT_BIT"; break;
      case GL_MAP_PERSISTENT_BIT: RETVAL = "GL_MAP_PERSISTENT_BIT"; break;
      case GL_MAP_READ_BIT: RETVAL = "GL_MAP_READ_BIT"; break;
      case GL_MAP_WRITE_BIT: RETVAL = "GL_MAP_WRITE_BIT"; break;
      case GL_PER_GPU_STORAGE_BIT_NV: RETVAL = "GL_PER_GPU_STORAGE_BIT_NV"; break;
      case GL_SPARSE_STORAGE_BIT_ARB: RETVAL = "GL_SPARSE_STORAGE_BIT_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferStorageTarget")) {
    switch (e) {
      case GL_ARRAY_BUFFER: RETVAL = "GL_ARRAY_BUFFER"; break;
      case GL_ATOMIC_COUNTER_BUFFER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER"; break;
      case GL_COPY_READ_BUFFER: RETVAL = "GL_COPY_READ_BUFFER"; break;
      case GL_COPY_WRITE_BUFFER: RETVAL = "GL_COPY_WRITE_BUFFER"; break;
      case GL_DISPATCH_INDIRECT_BUFFER: RETVAL = "GL_DISPATCH_INDIRECT_BUFFER"; break;
      case GL_DRAW_INDIRECT_BUFFER: RETVAL = "GL_DRAW_INDIRECT_BUFFER"; break;
      case GL_ELEMENT_ARRAY_BUFFER: RETVAL = "GL_ELEMENT_ARRAY_BUFFER"; break;
      case GL_PIXEL_PACK_BUFFER: RETVAL = "GL_PIXEL_PACK_BUFFER"; break;
      case GL_PIXEL_UNPACK_BUFFER: RETVAL = "GL_PIXEL_UNPACK_BUFFER"; break;
      case GL_QUERY_BUFFER: RETVAL = "GL_QUERY_BUFFER"; break;
      case GL_SHADER_STORAGE_BUFFER: RETVAL = "GL_SHADER_STORAGE_BUFFER"; break;
      case GL_TEXTURE_BUFFER: RETVAL = "GL_TEXTURE_BUFFER"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER"; break;
      case GL_UNIFORM_BUFFER: RETVAL = "GL_UNIFORM_BUFFER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferTargetARB")) {
    switch (e) {
      case GL_ARRAY_BUFFER: RETVAL = "GL_ARRAY_BUFFER"; break;
      case GL_ATOMIC_COUNTER_BUFFER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER"; break;
      case GL_COPY_READ_BUFFER: RETVAL = "GL_COPY_READ_BUFFER"; break;
      case GL_COPY_WRITE_BUFFER: RETVAL = "GL_COPY_WRITE_BUFFER"; break;
      case GL_DISPATCH_INDIRECT_BUFFER: RETVAL = "GL_DISPATCH_INDIRECT_BUFFER"; break;
      case GL_DRAW_INDIRECT_BUFFER: RETVAL = "GL_DRAW_INDIRECT_BUFFER"; break;
      case GL_ELEMENT_ARRAY_BUFFER: RETVAL = "GL_ELEMENT_ARRAY_BUFFER"; break;
      case GL_PARAMETER_BUFFER: RETVAL = "GL_PARAMETER_BUFFER"; break;
      case GL_PIXEL_PACK_BUFFER: RETVAL = "GL_PIXEL_PACK_BUFFER"; break;
      case GL_PIXEL_UNPACK_BUFFER: RETVAL = "GL_PIXEL_UNPACK_BUFFER"; break;
      case GL_QUERY_BUFFER: RETVAL = "GL_QUERY_BUFFER"; break;
      case GL_SHADER_STORAGE_BUFFER: RETVAL = "GL_SHADER_STORAGE_BUFFER"; break;
      case GL_TEXTURE_BUFFER: RETVAL = "GL_TEXTURE_BUFFER"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER"; break;
      case GL_UNIFORM_BUFFER: RETVAL = "GL_UNIFORM_BUFFER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferUsageARB")) {
    switch (e) {
      case GL_DYNAMIC_COPY: RETVAL = "GL_DYNAMIC_COPY"; break;
      case GL_DYNAMIC_DRAW: RETVAL = "GL_DYNAMIC_DRAW"; break;
      case GL_DYNAMIC_READ: RETVAL = "GL_DYNAMIC_READ"; break;
      case GL_STATIC_COPY: RETVAL = "GL_STATIC_COPY"; break;
      case GL_STATIC_DRAW: RETVAL = "GL_STATIC_DRAW"; break;
      case GL_STATIC_READ: RETVAL = "GL_STATIC_READ"; break;
      case GL_STREAM_COPY: RETVAL = "GL_STREAM_COPY"; break;
      case GL_STREAM_DRAW: RETVAL = "GL_STREAM_DRAW"; break;
      case GL_STREAM_READ: RETVAL = "GL_STREAM_READ"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClampColorModeARB")) {
    switch (e) {
      case GL_FALSE: RETVAL = "GL_FALSE"; break;
      case GL_FIXED_ONLY: RETVAL = "GL_FIXED_ONLY"; break;
      case GL_TRUE: RETVAL = "GL_TRUE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClampColorTargetARB")) {
    switch (e) {
      case GL_CLAMP_FRAGMENT_COLOR_ARB: RETVAL = "GL_CLAMP_FRAGMENT_COLOR_ARB"; break;
      case GL_CLAMP_READ_COLOR: RETVAL = "GL_CLAMP_READ_COLOR"; break;
      case GL_CLAMP_VERTEX_COLOR_ARB: RETVAL = "GL_CLAMP_VERTEX_COLOR_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClearBufferMask")) {
    switch (e) {
      case GL_ACCUM_BUFFER_BIT: RETVAL = "GL_ACCUM_BUFFER_BIT"; break;
      case GL_COLOR_BUFFER_BIT: RETVAL = "GL_COLOR_BUFFER_BIT"; break;
      case GL_DEPTH_BUFFER_BIT: RETVAL = "GL_DEPTH_BUFFER_BIT"; break;
      case GL_STENCIL_BUFFER_BIT: RETVAL = "GL_STENCIL_BUFFER_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClientAttribMask")) {
    switch (e) {
      case GL_CLIENT_ALL_ATTRIB_BITS: RETVAL = "GL_CLIENT_ALL_ATTRIB_BITS"; break;
      case GL_CLIENT_PIXEL_STORE_BIT: RETVAL = "GL_CLIENT_PIXEL_STORE_BIT"; break;
      case GL_CLIENT_VERTEX_ARRAY_BIT: RETVAL = "GL_CLIENT_VERTEX_ARRAY_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClipControlDepth")) {
    switch (e) {
      case GL_NEGATIVE_ONE_TO_ONE: RETVAL = "GL_NEGATIVE_ONE_TO_ONE"; break;
      case GL_ZERO_TO_ONE: RETVAL = "GL_ZERO_TO_ONE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClipControlOrigin")) {
    switch (e) {
      case GL_LOWER_LEFT: RETVAL = "GL_LOWER_LEFT"; break;
      case GL_UPPER_LEFT: RETVAL = "GL_UPPER_LEFT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClipPlaneName")) {
    switch (e) {
      case GL_CLIP_PLANE0: RETVAL = "GL_CLIP_PLANE0"; break;
      case GL_CLIP_PLANE1: RETVAL = "GL_CLIP_PLANE1"; break;
      case GL_CLIP_PLANE2: RETVAL = "GL_CLIP_PLANE2"; break;
      case GL_CLIP_PLANE3: RETVAL = "GL_CLIP_PLANE3"; break;
      case GL_CLIP_PLANE4: RETVAL = "GL_CLIP_PLANE4"; break;
      case GL_CLIP_PLANE5: RETVAL = "GL_CLIP_PLANE5"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorBuffer")) {
    switch (e) {
      case GL_BACK: RETVAL = "GL_BACK"; break;
      case GL_BACK_LEFT: RETVAL = "GL_BACK_LEFT"; break;
      case GL_BACK_RIGHT: RETVAL = "GL_BACK_RIGHT"; break;
      case GL_COLOR_ATTACHMENT0: RETVAL = "GL_COLOR_ATTACHMENT0"; break;
      case GL_COLOR_ATTACHMENT1: RETVAL = "GL_COLOR_ATTACHMENT1"; break;
      case GL_COLOR_ATTACHMENT10: RETVAL = "GL_COLOR_ATTACHMENT10"; break;
      case GL_COLOR_ATTACHMENT11: RETVAL = "GL_COLOR_ATTACHMENT11"; break;
      case GL_COLOR_ATTACHMENT12: RETVAL = "GL_COLOR_ATTACHMENT12"; break;
      case GL_COLOR_ATTACHMENT13: RETVAL = "GL_COLOR_ATTACHMENT13"; break;
      case GL_COLOR_ATTACHMENT14: RETVAL = "GL_COLOR_ATTACHMENT14"; break;
      case GL_COLOR_ATTACHMENT15: RETVAL = "GL_COLOR_ATTACHMENT15"; break;
      case GL_COLOR_ATTACHMENT2: RETVAL = "GL_COLOR_ATTACHMENT2"; break;
      case GL_COLOR_ATTACHMENT3: RETVAL = "GL_COLOR_ATTACHMENT3"; break;
      case GL_COLOR_ATTACHMENT4: RETVAL = "GL_COLOR_ATTACHMENT4"; break;
      case GL_COLOR_ATTACHMENT5: RETVAL = "GL_COLOR_ATTACHMENT5"; break;
      case GL_COLOR_ATTACHMENT6: RETVAL = "GL_COLOR_ATTACHMENT6"; break;
      case GL_COLOR_ATTACHMENT7: RETVAL = "GL_COLOR_ATTACHMENT7"; break;
      case GL_COLOR_ATTACHMENT8: RETVAL = "GL_COLOR_ATTACHMENT8"; break;
      case GL_COLOR_ATTACHMENT9: RETVAL = "GL_COLOR_ATTACHMENT9"; break;
      case GL_FRONT: RETVAL = "GL_FRONT"; break;
      case GL_FRONT_AND_BACK: RETVAL = "GL_FRONT_AND_BACK"; break;
      case GL_FRONT_LEFT: RETVAL = "GL_FRONT_LEFT"; break;
      case GL_FRONT_RIGHT: RETVAL = "GL_FRONT_RIGHT"; break;
      case GL_LEFT: RETVAL = "GL_LEFT"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RIGHT: RETVAL = "GL_RIGHT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorMaterialParameter")) {
    switch (e) {
      case GL_AMBIENT: RETVAL = "GL_AMBIENT"; break;
      case GL_AMBIENT_AND_DIFFUSE: RETVAL = "GL_AMBIENT_AND_DIFFUSE"; break;
      case GL_DIFFUSE: RETVAL = "GL_DIFFUSE"; break;
      case GL_EMISSION: RETVAL = "GL_EMISSION"; break;
      case GL_SPECULAR: RETVAL = "GL_SPECULAR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorPointerType")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorTableParameterPName")) {
    switch (e) {
      case GL_COLOR_TABLE_ALPHA_SIZE: RETVAL = "GL_COLOR_TABLE_ALPHA_SIZE"; break;
      case GL_COLOR_TABLE_BIAS: RETVAL = "GL_COLOR_TABLE_BIAS"; break;
      case GL_COLOR_TABLE_BLUE_SIZE: RETVAL = "GL_COLOR_TABLE_BLUE_SIZE"; break;
      case GL_COLOR_TABLE_FORMAT: RETVAL = "GL_COLOR_TABLE_FORMAT"; break;
      case GL_COLOR_TABLE_GREEN_SIZE: RETVAL = "GL_COLOR_TABLE_GREEN_SIZE"; break;
      case GL_COLOR_TABLE_INTENSITY_SIZE: RETVAL = "GL_COLOR_TABLE_INTENSITY_SIZE"; break;
      case GL_COLOR_TABLE_LUMINANCE_SIZE: RETVAL = "GL_COLOR_TABLE_LUMINANCE_SIZE"; break;
      case GL_COLOR_TABLE_RED_SIZE: RETVAL = "GL_COLOR_TABLE_RED_SIZE"; break;
      case GL_COLOR_TABLE_SCALE: RETVAL = "GL_COLOR_TABLE_SCALE"; break;
      case GL_COLOR_TABLE_WIDTH: RETVAL = "GL_COLOR_TABLE_WIDTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorTableTarget")) {
    switch (e) {
      case GL_COLOR_TABLE: RETVAL = "GL_COLOR_TABLE"; break;
      case GL_POST_COLOR_MATRIX_COLOR_TABLE: RETVAL = "GL_POST_COLOR_MATRIX_COLOR_TABLE"; break;
      case GL_POST_CONVOLUTION_COLOR_TABLE: RETVAL = "GL_POST_CONVOLUTION_COLOR_TABLE"; break;
      case GL_PROXY_COLOR_TABLE: RETVAL = "GL_PROXY_COLOR_TABLE"; break;
      case GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE: RETVAL = "GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE"; break;
      case GL_PROXY_POST_CONVOLUTION_COLOR_TABLE: RETVAL = "GL_PROXY_POST_CONVOLUTION_COLOR_TABLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorTableTargetSGI")) {
    switch (e) {
      case GL_COLOR_TABLE: RETVAL = "GL_COLOR_TABLE"; break;
      case GL_POST_COLOR_MATRIX_COLOR_TABLE: RETVAL = "GL_POST_COLOR_MATRIX_COLOR_TABLE"; break;
      case GL_POST_CONVOLUTION_COLOR_TABLE: RETVAL = "GL_POST_CONVOLUTION_COLOR_TABLE"; break;
      case GL_PROXY_COLOR_TABLE: RETVAL = "GL_PROXY_COLOR_TABLE"; break;
      case GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE: RETVAL = "GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE"; break;
      case GL_PROXY_POST_CONVOLUTION_COLOR_TABLE: RETVAL = "GL_PROXY_POST_CONVOLUTION_COLOR_TABLE"; break;
      case GL_PROXY_TEXTURE_COLOR_TABLE_SGI: RETVAL = "GL_PROXY_TEXTURE_COLOR_TABLE_SGI"; break;
      case GL_TEXTURE_COLOR_TABLE_SGI: RETVAL = "GL_TEXTURE_COLOR_TABLE_SGI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerBiasNV")) {
    switch (e) {
      case GL_BIAS_BY_NEGATIVE_ONE_HALF_NV: RETVAL = "GL_BIAS_BY_NEGATIVE_ONE_HALF_NV"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerComponentUsageNV")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_BLUE: RETVAL = "GL_BLUE"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerMappingNV")) {
    switch (e) {
      case GL_EXPAND_NEGATE_NV: RETVAL = "GL_EXPAND_NEGATE_NV"; break;
      case GL_EXPAND_NORMAL_NV: RETVAL = "GL_EXPAND_NORMAL_NV"; break;
      case GL_HALF_BIAS_NEGATE_NV: RETVAL = "GL_HALF_BIAS_NEGATE_NV"; break;
      case GL_HALF_BIAS_NORMAL_NV: RETVAL = "GL_HALF_BIAS_NORMAL_NV"; break;
      case GL_SIGNED_IDENTITY_NV: RETVAL = "GL_SIGNED_IDENTITY_NV"; break;
      case GL_SIGNED_NEGATE_NV: RETVAL = "GL_SIGNED_NEGATE_NV"; break;
      case GL_UNSIGNED_IDENTITY_NV: RETVAL = "GL_UNSIGNED_IDENTITY_NV"; break;
      case GL_UNSIGNED_INVERT_NV: RETVAL = "GL_UNSIGNED_INVERT_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerParameterNV")) {
    switch (e) {
      case GL_COMBINER_COMPONENT_USAGE_NV: RETVAL = "GL_COMBINER_COMPONENT_USAGE_NV"; break;
      case GL_COMBINER_INPUT_NV: RETVAL = "GL_COMBINER_INPUT_NV"; break;
      case GL_COMBINER_MAPPING_NV: RETVAL = "GL_COMBINER_MAPPING_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerPortionNV")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerRegisterNV")) {
    switch (e) {
      case GL_DISCARD_NV: RETVAL = "GL_DISCARD_NV"; break;
      case GL_PRIMARY_COLOR_NV: RETVAL = "GL_PRIMARY_COLOR_NV"; break;
      case GL_SECONDARY_COLOR_NV: RETVAL = "GL_SECONDARY_COLOR_NV"; break;
      case GL_SPARE0_NV: RETVAL = "GL_SPARE0_NV"; break;
      case GL_SPARE1_NV: RETVAL = "GL_SPARE1_NV"; break;
      case GL_TEXTURE0_ARB: RETVAL = "GL_TEXTURE0_ARB"; break;
      case GL_TEXTURE1_ARB: RETVAL = "GL_TEXTURE1_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerScaleNV")) {
    switch (e) {
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_SCALE_BY_FOUR_NV: RETVAL = "GL_SCALE_BY_FOUR_NV"; break;
      case GL_SCALE_BY_ONE_HALF_NV: RETVAL = "GL_SCALE_BY_ONE_HALF_NV"; break;
      case GL_SCALE_BY_TWO_NV: RETVAL = "GL_SCALE_BY_TWO_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerStageNV")) {
    switch (e) {
      case GL_COMBINER0_NV: RETVAL = "GL_COMBINER0_NV"; break;
      case GL_COMBINER1_NV: RETVAL = "GL_COMBINER1_NV"; break;
      case GL_COMBINER2_NV: RETVAL = "GL_COMBINER2_NV"; break;
      case GL_COMBINER3_NV: RETVAL = "GL_COMBINER3_NV"; break;
      case GL_COMBINER4_NV: RETVAL = "GL_COMBINER4_NV"; break;
      case GL_COMBINER5_NV: RETVAL = "GL_COMBINER5_NV"; break;
      case GL_COMBINER6_NV: RETVAL = "GL_COMBINER6_NV"; break;
      case GL_COMBINER7_NV: RETVAL = "GL_COMBINER7_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerVariableNV")) {
    switch (e) {
      case GL_VARIABLE_A_NV: RETVAL = "GL_VARIABLE_A_NV"; break;
      case GL_VARIABLE_B_NV: RETVAL = "GL_VARIABLE_B_NV"; break;
      case GL_VARIABLE_C_NV: RETVAL = "GL_VARIABLE_C_NV"; break;
      case GL_VARIABLE_D_NV: RETVAL = "GL_VARIABLE_D_NV"; break;
      case GL_VARIABLE_E_NV: RETVAL = "GL_VARIABLE_E_NV"; break;
      case GL_VARIABLE_F_NV: RETVAL = "GL_VARIABLE_F_NV"; break;
      case GL_VARIABLE_G_NV: RETVAL = "GL_VARIABLE_G_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CommandOpcodesNV")) {
    switch (e) {
      case GL_ALPHA_REF_COMMAND_NV: RETVAL = "GL_ALPHA_REF_COMMAND_NV"; break;
      case GL_ATTRIBUTE_ADDRESS_COMMAND_NV: RETVAL = "GL_ATTRIBUTE_ADDRESS_COMMAND_NV"; break;
      case GL_BLEND_COLOR_COMMAND_NV: RETVAL = "GL_BLEND_COLOR_COMMAND_NV"; break;
      case GL_DRAW_ARRAYS_COMMAND_NV: RETVAL = "GL_DRAW_ARRAYS_COMMAND_NV"; break;
      case GL_DRAW_ARRAYS_INSTANCED_COMMAND_NV: RETVAL = "GL_DRAW_ARRAYS_INSTANCED_COMMAND_NV"; break;
      case GL_DRAW_ARRAYS_STRIP_COMMAND_NV: RETVAL = "GL_DRAW_ARRAYS_STRIP_COMMAND_NV"; break;
      case GL_DRAW_ELEMENTS_COMMAND_NV: RETVAL = "GL_DRAW_ELEMENTS_COMMAND_NV"; break;
      case GL_DRAW_ELEMENTS_INSTANCED_COMMAND_NV: RETVAL = "GL_DRAW_ELEMENTS_INSTANCED_COMMAND_NV"; break;
      case GL_DRAW_ELEMENTS_STRIP_COMMAND_NV: RETVAL = "GL_DRAW_ELEMENTS_STRIP_COMMAND_NV"; break;
      case GL_ELEMENT_ADDRESS_COMMAND_NV: RETVAL = "GL_ELEMENT_ADDRESS_COMMAND_NV"; break;
      case GL_FRONT_FACE_COMMAND_NV: RETVAL = "GL_FRONT_FACE_COMMAND_NV"; break;
      case GL_LINE_WIDTH_COMMAND_NV: RETVAL = "GL_LINE_WIDTH_COMMAND_NV"; break;
      case GL_NOP_COMMAND_NV: RETVAL = "GL_NOP_COMMAND_NV"; break;
      case GL_POLYGON_OFFSET_COMMAND_NV: RETVAL = "GL_POLYGON_OFFSET_COMMAND_NV"; break;
      case GL_SCISSOR_COMMAND_NV: RETVAL = "GL_SCISSOR_COMMAND_NV"; break;
      case GL_STENCIL_REF_COMMAND_NV: RETVAL = "GL_STENCIL_REF_COMMAND_NV"; break;
      case GL_TERMINATE_SEQUENCE_COMMAND_NV: RETVAL = "GL_TERMINATE_SEQUENCE_COMMAND_NV"; break;
      case GL_UNIFORM_ADDRESS_COMMAND_NV: RETVAL = "GL_UNIFORM_ADDRESS_COMMAND_NV"; break;
      case GL_VIEWPORT_COMMAND_NV: RETVAL = "GL_VIEWPORT_COMMAND_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ConditionalRenderMode")) {
    switch (e) {
      case GL_QUERY_BY_REGION_NO_WAIT: RETVAL = "GL_QUERY_BY_REGION_NO_WAIT"; break;
      case GL_QUERY_BY_REGION_NO_WAIT_INVERTED: RETVAL = "GL_QUERY_BY_REGION_NO_WAIT_INVERTED"; break;
      case GL_QUERY_BY_REGION_WAIT: RETVAL = "GL_QUERY_BY_REGION_WAIT"; break;
      case GL_QUERY_BY_REGION_WAIT_INVERTED: RETVAL = "GL_QUERY_BY_REGION_WAIT_INVERTED"; break;
      case GL_QUERY_NO_WAIT: RETVAL = "GL_QUERY_NO_WAIT"; break;
      case GL_QUERY_NO_WAIT_INVERTED: RETVAL = "GL_QUERY_NO_WAIT_INVERTED"; break;
      case GL_QUERY_WAIT: RETVAL = "GL_QUERY_WAIT"; break;
      case GL_QUERY_WAIT_INVERTED: RETVAL = "GL_QUERY_WAIT_INVERTED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ContainerType")) {
    switch (e) {
      case GL_PROGRAM_OBJECT_ARB: RETVAL = "GL_PROGRAM_OBJECT_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ContextFlagMask")) {
    switch (e) {
      case GL_CONTEXT_FLAG_DEBUG_BIT: RETVAL = "GL_CONTEXT_FLAG_DEBUG_BIT"; break;
      case GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT: RETVAL = "GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT"; break;
      case GL_CONTEXT_FLAG_NO_ERROR_BIT: RETVAL = "GL_CONTEXT_FLAG_NO_ERROR_BIT"; break;
      case GL_CONTEXT_FLAG_PROTECTED_CONTENT_BIT_EXT: RETVAL = "GL_CONTEXT_FLAG_PROTECTED_CONTENT_BIT_EXT"; break;
      case GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT: RETVAL = "GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ContextProfileMask")) {
    switch (e) {
      case GL_CONTEXT_COMPATIBILITY_PROFILE_BIT: RETVAL = "GL_CONTEXT_COMPATIBILITY_PROFILE_BIT"; break;
      case GL_CONTEXT_CORE_PROFILE_BIT: RETVAL = "GL_CONTEXT_CORE_PROFILE_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ConvolutionBorderModeEXT")) {
    switch (e) {
      case GL_REDUCE: RETVAL = "GL_REDUCE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ConvolutionParameter")) {
    switch (e) {
      case GL_CONVOLUTION_BORDER_COLOR: RETVAL = "GL_CONVOLUTION_BORDER_COLOR"; break;
      case GL_CONVOLUTION_BORDER_MODE: RETVAL = "GL_CONVOLUTION_BORDER_MODE"; break;
      case GL_CONVOLUTION_FILTER_BIAS: RETVAL = "GL_CONVOLUTION_FILTER_BIAS"; break;
      case GL_CONVOLUTION_FILTER_SCALE: RETVAL = "GL_CONVOLUTION_FILTER_SCALE"; break;
      case GL_CONVOLUTION_FORMAT: RETVAL = "GL_CONVOLUTION_FORMAT"; break;
      case GL_CONVOLUTION_HEIGHT: RETVAL = "GL_CONVOLUTION_HEIGHT"; break;
      case GL_CONVOLUTION_WIDTH: RETVAL = "GL_CONVOLUTION_WIDTH"; break;
      case GL_MAX_CONVOLUTION_HEIGHT: RETVAL = "GL_MAX_CONVOLUTION_HEIGHT"; break;
      case GL_MAX_CONVOLUTION_WIDTH: RETVAL = "GL_MAX_CONVOLUTION_WIDTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ConvolutionTarget")) {
    switch (e) {
      case GL_CONVOLUTION_1D: RETVAL = "GL_CONVOLUTION_1D"; break;
      case GL_CONVOLUTION_2D: RETVAL = "GL_CONVOLUTION_2D"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ConvolutionTargetEXT")) {
    switch (e) {
      case GL_CONVOLUTION_1D: RETVAL = "GL_CONVOLUTION_1D"; break;
      case GL_CONVOLUTION_2D: RETVAL = "GL_CONVOLUTION_2D"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CopyBufferSubDataTarget")) {
    switch (e) {
      case GL_ARRAY_BUFFER: RETVAL = "GL_ARRAY_BUFFER"; break;
      case GL_ATOMIC_COUNTER_BUFFER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER"; break;
      case GL_COPY_READ_BUFFER: RETVAL = "GL_COPY_READ_BUFFER"; break;
      case GL_COPY_WRITE_BUFFER: RETVAL = "GL_COPY_WRITE_BUFFER"; break;
      case GL_DISPATCH_INDIRECT_BUFFER: RETVAL = "GL_DISPATCH_INDIRECT_BUFFER"; break;
      case GL_DRAW_INDIRECT_BUFFER: RETVAL = "GL_DRAW_INDIRECT_BUFFER"; break;
      case GL_ELEMENT_ARRAY_BUFFER: RETVAL = "GL_ELEMENT_ARRAY_BUFFER"; break;
      case GL_PIXEL_PACK_BUFFER: RETVAL = "GL_PIXEL_PACK_BUFFER"; break;
      case GL_PIXEL_UNPACK_BUFFER: RETVAL = "GL_PIXEL_UNPACK_BUFFER"; break;
      case GL_QUERY_BUFFER: RETVAL = "GL_QUERY_BUFFER"; break;
      case GL_SHADER_STORAGE_BUFFER: RETVAL = "GL_SHADER_STORAGE_BUFFER"; break;
      case GL_TEXTURE_BUFFER: RETVAL = "GL_TEXTURE_BUFFER"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER"; break;
      case GL_UNIFORM_BUFFER: RETVAL = "GL_UNIFORM_BUFFER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CopyImageSubDataTarget")) {
    switch (e) {
      case GL_RENDERBUFFER: RETVAL = "GL_RENDERBUFFER"; break;
      case GL_TEXTURE_1D: RETVAL = "GL_TEXTURE_1D"; break;
      case GL_TEXTURE_1D_ARRAY: RETVAL = "GL_TEXTURE_1D_ARRAY"; break;
      case GL_TEXTURE_2D: RETVAL = "GL_TEXTURE_2D"; break;
      case GL_TEXTURE_2D_ARRAY: RETVAL = "GL_TEXTURE_2D_ARRAY"; break;
      case GL_TEXTURE_2D_MULTISAMPLE: RETVAL = "GL_TEXTURE_2D_MULTISAMPLE"; break;
      case GL_TEXTURE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_TEXTURE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_TEXTURE_3D: RETVAL = "GL_TEXTURE_3D"; break;
      case GL_TEXTURE_CUBE_MAP: RETVAL = "GL_TEXTURE_CUBE_MAP"; break;
      case GL_TEXTURE_CUBE_MAP_ARRAY: RETVAL = "GL_TEXTURE_CUBE_MAP_ARRAY"; break;
      case GL_TEXTURE_RECTANGLE: RETVAL = "GL_TEXTURE_RECTANGLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CullParameterEXT")) {
    switch (e) {
      case GL_CULL_VERTEX_EYE_POSITION_EXT: RETVAL = "GL_CULL_VERTEX_EYE_POSITION_EXT"; break;
      case GL_CULL_VERTEX_OBJECT_POSITION_EXT: RETVAL = "GL_CULL_VERTEX_OBJECT_POSITION_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DataTypeEXT")) {
    switch (e) {
      case GL_MATRIX_EXT: RETVAL = "GL_MATRIX_EXT"; break;
      case GL_SCALAR_EXT: RETVAL = "GL_SCALAR_EXT"; break;
      case GL_VECTOR_EXT: RETVAL = "GL_VECTOR_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DebugSeverity")) {
    switch (e) {
      case GL_DEBUG_SEVERITY_HIGH: RETVAL = "GL_DEBUG_SEVERITY_HIGH"; break;
      case GL_DEBUG_SEVERITY_LOW: RETVAL = "GL_DEBUG_SEVERITY_LOW"; break;
      case GL_DEBUG_SEVERITY_MEDIUM: RETVAL = "GL_DEBUG_SEVERITY_MEDIUM"; break;
      case GL_DEBUG_SEVERITY_NOTIFICATION: RETVAL = "GL_DEBUG_SEVERITY_NOTIFICATION"; break;
      case GL_DONT_CARE: RETVAL = "GL_DONT_CARE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DebugSource")) {
    switch (e) {
      case GL_DEBUG_SOURCE_API: RETVAL = "GL_DEBUG_SOURCE_API"; break;
      case GL_DEBUG_SOURCE_APPLICATION: RETVAL = "GL_DEBUG_SOURCE_APPLICATION"; break;
      case GL_DEBUG_SOURCE_OTHER: RETVAL = "GL_DEBUG_SOURCE_OTHER"; break;
      case GL_DEBUG_SOURCE_SHADER_COMPILER: RETVAL = "GL_DEBUG_SOURCE_SHADER_COMPILER"; break;
      case GL_DEBUG_SOURCE_THIRD_PARTY: RETVAL = "GL_DEBUG_SOURCE_THIRD_PARTY"; break;
      case GL_DEBUG_SOURCE_WINDOW_SYSTEM: RETVAL = "GL_DEBUG_SOURCE_WINDOW_SYSTEM"; break;
      case GL_DONT_CARE: RETVAL = "GL_DONT_CARE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DebugType")) {
    switch (e) {
      case GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR: RETVAL = "GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR"; break;
      case GL_DEBUG_TYPE_ERROR: RETVAL = "GL_DEBUG_TYPE_ERROR"; break;
      case GL_DEBUG_TYPE_MARKER: RETVAL = "GL_DEBUG_TYPE_MARKER"; break;
      case GL_DEBUG_TYPE_OTHER: RETVAL = "GL_DEBUG_TYPE_OTHER"; break;
      case GL_DEBUG_TYPE_PERFORMANCE: RETVAL = "GL_DEBUG_TYPE_PERFORMANCE"; break;
      case GL_DEBUG_TYPE_POP_GROUP: RETVAL = "GL_DEBUG_TYPE_POP_GROUP"; break;
      case GL_DEBUG_TYPE_PORTABILITY: RETVAL = "GL_DEBUG_TYPE_PORTABILITY"; break;
      case GL_DEBUG_TYPE_PUSH_GROUP: RETVAL = "GL_DEBUG_TYPE_PUSH_GROUP"; break;
      case GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR: RETVAL = "GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR"; break;
      case GL_DONT_CARE: RETVAL = "GL_DONT_CARE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DepthFunction")) {
    switch (e) {
      case GL_ALWAYS: RETVAL = "GL_ALWAYS"; break;
      case GL_EQUAL: RETVAL = "GL_EQUAL"; break;
      case GL_GEQUAL: RETVAL = "GL_GEQUAL"; break;
      case GL_GREATER: RETVAL = "GL_GREATER"; break;
      case GL_LEQUAL: RETVAL = "GL_LEQUAL"; break;
      case GL_LESS: RETVAL = "GL_LESS"; break;
      case GL_NEVER: RETVAL = "GL_NEVER"; break;
      case GL_NOTEQUAL: RETVAL = "GL_NOTEQUAL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DepthStencilTextureMode")) {
    switch (e) {
      case GL_DEPTH_COMPONENT: RETVAL = "GL_DEPTH_COMPONENT"; break;
      case GL_STENCIL_INDEX: RETVAL = "GL_STENCIL_INDEX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DrawBufferMode")) {
    switch (e) {
      case GL_AUX0: RETVAL = "GL_AUX0"; break;
      case GL_AUX1: RETVAL = "GL_AUX1"; break;
      case GL_AUX2: RETVAL = "GL_AUX2"; break;
      case GL_AUX3: RETVAL = "GL_AUX3"; break;
      case GL_BACK: RETVAL = "GL_BACK"; break;
      case GL_BACK_LEFT: RETVAL = "GL_BACK_LEFT"; break;
      case GL_BACK_RIGHT: RETVAL = "GL_BACK_RIGHT"; break;
      case GL_COLOR_ATTACHMENT0: RETVAL = "GL_COLOR_ATTACHMENT0"; break;
      case GL_COLOR_ATTACHMENT1: RETVAL = "GL_COLOR_ATTACHMENT1"; break;
      case GL_COLOR_ATTACHMENT10: RETVAL = "GL_COLOR_ATTACHMENT10"; break;
      case GL_COLOR_ATTACHMENT11: RETVAL = "GL_COLOR_ATTACHMENT11"; break;
      case GL_COLOR_ATTACHMENT12: RETVAL = "GL_COLOR_ATTACHMENT12"; break;
      case GL_COLOR_ATTACHMENT13: RETVAL = "GL_COLOR_ATTACHMENT13"; break;
      case GL_COLOR_ATTACHMENT14: RETVAL = "GL_COLOR_ATTACHMENT14"; break;
      case GL_COLOR_ATTACHMENT15: RETVAL = "GL_COLOR_ATTACHMENT15"; break;
      case GL_COLOR_ATTACHMENT2: RETVAL = "GL_COLOR_ATTACHMENT2"; break;
      case GL_COLOR_ATTACHMENT3: RETVAL = "GL_COLOR_ATTACHMENT3"; break;
      case GL_COLOR_ATTACHMENT4: RETVAL = "GL_COLOR_ATTACHMENT4"; break;
      case GL_COLOR_ATTACHMENT5: RETVAL = "GL_COLOR_ATTACHMENT5"; break;
      case GL_COLOR_ATTACHMENT6: RETVAL = "GL_COLOR_ATTACHMENT6"; break;
      case GL_COLOR_ATTACHMENT7: RETVAL = "GL_COLOR_ATTACHMENT7"; break;
      case GL_COLOR_ATTACHMENT8: RETVAL = "GL_COLOR_ATTACHMENT8"; break;
      case GL_COLOR_ATTACHMENT9: RETVAL = "GL_COLOR_ATTACHMENT9"; break;
      case GL_FRONT: RETVAL = "GL_FRONT"; break;
      case GL_FRONT_AND_BACK: RETVAL = "GL_FRONT_AND_BACK"; break;
      case GL_FRONT_LEFT: RETVAL = "GL_FRONT_LEFT"; break;
      case GL_FRONT_RIGHT: RETVAL = "GL_FRONT_RIGHT"; break;
      case GL_LEFT: RETVAL = "GL_LEFT"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RIGHT: RETVAL = "GL_RIGHT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DrawElementsType")) {
    switch (e) {
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ElementPointerTypeATI")) {
    switch (e) {
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "EnableCap")) {
    switch (e) {
      case GL_ALPHA_TEST: RETVAL = "GL_ALPHA_TEST"; break;
      case GL_ASYNC_DRAW_PIXELS_SGIX: RETVAL = "GL_ASYNC_DRAW_PIXELS_SGIX"; break;
      case GL_ASYNC_HISTOGRAM_SGIX: RETVAL = "GL_ASYNC_HISTOGRAM_SGIX"; break;
      case GL_ASYNC_READ_PIXELS_SGIX: RETVAL = "GL_ASYNC_READ_PIXELS_SGIX"; break;
      case GL_ASYNC_TEX_IMAGE_SGIX: RETVAL = "GL_ASYNC_TEX_IMAGE_SGIX"; break;
      case GL_AUTO_NORMAL: RETVAL = "GL_AUTO_NORMAL"; break;
      case GL_BLEND: RETVAL = "GL_BLEND"; break;
      case GL_CLIP_PLANE0: RETVAL = "GL_CLIP_PLANE0"; break;
      case GL_CLIP_PLANE1: RETVAL = "GL_CLIP_PLANE1"; break;
      case GL_CLIP_PLANE2: RETVAL = "GL_CLIP_PLANE2"; break;
      case GL_CLIP_PLANE3: RETVAL = "GL_CLIP_PLANE3"; break;
      case GL_CLIP_PLANE4: RETVAL = "GL_CLIP_PLANE4"; break;
      case GL_CLIP_PLANE5: RETVAL = "GL_CLIP_PLANE5"; break;
      case GL_COLOR_ARRAY: RETVAL = "GL_COLOR_ARRAY"; break;
      case GL_COLOR_LOGIC_OP: RETVAL = "GL_COLOR_LOGIC_OP"; break;
      case GL_COLOR_MATERIAL: RETVAL = "GL_COLOR_MATERIAL"; break;
      case GL_COLOR_TABLE: RETVAL = "GL_COLOR_TABLE"; break;
      case GL_CONVOLUTION_1D_EXT: RETVAL = "GL_CONVOLUTION_1D_EXT"; break;
      case GL_CONVOLUTION_2D_EXT: RETVAL = "GL_CONVOLUTION_2D_EXT"; break;
      case GL_CULL_FACE: RETVAL = "GL_CULL_FACE"; break;
      case GL_DEBUG_OUTPUT: RETVAL = "GL_DEBUG_OUTPUT"; break;
      case GL_DEBUG_OUTPUT_SYNCHRONOUS: RETVAL = "GL_DEBUG_OUTPUT_SYNCHRONOUS"; break;
      case GL_DEPTH_CLAMP: RETVAL = "GL_DEPTH_CLAMP"; break;
      case GL_DEPTH_TEST: RETVAL = "GL_DEPTH_TEST"; break;
      case GL_DITHER: RETVAL = "GL_DITHER"; break;
      case GL_EDGE_FLAG_ARRAY: RETVAL = "GL_EDGE_FLAG_ARRAY"; break;
      case GL_FETCH_PER_SAMPLE_ARM: RETVAL = "GL_FETCH_PER_SAMPLE_ARM"; break;
      case GL_FOG: RETVAL = "GL_FOG"; break;
      case GL_FOG_OFFSET_SGIX: RETVAL = "GL_FOG_OFFSET_SGIX"; break;
      case GL_FRAMEBUFFER_FETCH_NONCOHERENT_QCOM: RETVAL = "GL_FRAMEBUFFER_FETCH_NONCOHERENT_QCOM"; break;
      case GL_FRAMEBUFFER_SRGB: RETVAL = "GL_FRAMEBUFFER_SRGB"; break;
      case GL_HISTOGRAM_EXT: RETVAL = "GL_HISTOGRAM_EXT"; break;
      case GL_INDEX_ARRAY: RETVAL = "GL_INDEX_ARRAY"; break;
      case GL_INDEX_LOGIC_OP: RETVAL = "GL_INDEX_LOGIC_OP"; break;
      case GL_INTERLACE_SGIX: RETVAL = "GL_INTERLACE_SGIX"; break;
      case GL_LIGHT0: RETVAL = "GL_LIGHT0"; break;
      case GL_LIGHT1: RETVAL = "GL_LIGHT1"; break;
      case GL_LIGHT2: RETVAL = "GL_LIGHT2"; break;
      case GL_LIGHT3: RETVAL = "GL_LIGHT3"; break;
      case GL_LIGHT4: RETVAL = "GL_LIGHT4"; break;
      case GL_LIGHT5: RETVAL = "GL_LIGHT5"; break;
      case GL_LIGHT6: RETVAL = "GL_LIGHT6"; break;
      case GL_LIGHT7: RETVAL = "GL_LIGHT7"; break;
      case GL_LIGHTING: RETVAL = "GL_LIGHTING"; break;
      case GL_LINE_SMOOTH: RETVAL = "GL_LINE_SMOOTH"; break;
      case GL_LINE_STIPPLE: RETVAL = "GL_LINE_STIPPLE"; break;
      case GL_MAP1_COLOR_4: RETVAL = "GL_MAP1_COLOR_4"; break;
      case GL_MAP1_INDEX: RETVAL = "GL_MAP1_INDEX"; break;
      case GL_MAP1_NORMAL: RETVAL = "GL_MAP1_NORMAL"; break;
      case GL_MAP1_TEXTURE_COORD_1: RETVAL = "GL_MAP1_TEXTURE_COORD_1"; break;
      case GL_MAP1_TEXTURE_COORD_2: RETVAL = "GL_MAP1_TEXTURE_COORD_2"; break;
      case GL_MAP1_TEXTURE_COORD_3: RETVAL = "GL_MAP1_TEXTURE_COORD_3"; break;
      case GL_MAP1_TEXTURE_COORD_4: RETVAL = "GL_MAP1_TEXTURE_COORD_4"; break;
      case GL_MAP1_VERTEX_3: RETVAL = "GL_MAP1_VERTEX_3"; break;
      case GL_MAP1_VERTEX_4: RETVAL = "GL_MAP1_VERTEX_4"; break;
      case GL_MAP2_COLOR_4: RETVAL = "GL_MAP2_COLOR_4"; break;
      case GL_MAP2_INDEX: RETVAL = "GL_MAP2_INDEX"; break;
      case GL_MAP2_NORMAL: RETVAL = "GL_MAP2_NORMAL"; break;
      case GL_MAP2_TEXTURE_COORD_1: RETVAL = "GL_MAP2_TEXTURE_COORD_1"; break;
      case GL_MAP2_TEXTURE_COORD_2: RETVAL = "GL_MAP2_TEXTURE_COORD_2"; break;
      case GL_MAP2_TEXTURE_COORD_3: RETVAL = "GL_MAP2_TEXTURE_COORD_3"; break;
      case GL_MAP2_TEXTURE_COORD_4: RETVAL = "GL_MAP2_TEXTURE_COORD_4"; break;
      case GL_MAP2_VERTEX_3: RETVAL = "GL_MAP2_VERTEX_3"; break;
      case GL_MAP2_VERTEX_4: RETVAL = "GL_MAP2_VERTEX_4"; break;
      case GL_MINMAX_EXT: RETVAL = "GL_MINMAX_EXT"; break;
      case GL_MULTISAMPLE: RETVAL = "GL_MULTISAMPLE"; break;
      case GL_NORMALIZE: RETVAL = "GL_NORMALIZE"; break;
      case GL_NORMAL_ARRAY: RETVAL = "GL_NORMAL_ARRAY"; break;
      case GL_POINT_SMOOTH: RETVAL = "GL_POINT_SMOOTH"; break;
      case GL_POLYGON_OFFSET_FILL: RETVAL = "GL_POLYGON_OFFSET_FILL"; break;
      case GL_POLYGON_OFFSET_LINE: RETVAL = "GL_POLYGON_OFFSET_LINE"; break;
      case GL_POLYGON_OFFSET_POINT: RETVAL = "GL_POLYGON_OFFSET_POINT"; break;
      case GL_POLYGON_SMOOTH: RETVAL = "GL_POLYGON_SMOOTH"; break;
      case GL_POLYGON_STIPPLE: RETVAL = "GL_POLYGON_STIPPLE"; break;
      case GL_POST_COLOR_MATRIX_COLOR_TABLE: RETVAL = "GL_POST_COLOR_MATRIX_COLOR_TABLE"; break;
      case GL_POST_CONVOLUTION_COLOR_TABLE: RETVAL = "GL_POST_CONVOLUTION_COLOR_TABLE"; break;
      case GL_PRIMITIVE_RESTART: RETVAL = "GL_PRIMITIVE_RESTART"; break;
      case GL_PRIMITIVE_RESTART_FIXED_INDEX: RETVAL = "GL_PRIMITIVE_RESTART_FIXED_INDEX"; break;
      case GL_PROGRAM_POINT_SIZE: RETVAL = "GL_PROGRAM_POINT_SIZE"; break;
      case GL_RASTERIZER_DISCARD: RETVAL = "GL_RASTERIZER_DISCARD"; break;
      case GL_RESCALE_NORMAL_EXT: RETVAL = "GL_RESCALE_NORMAL_EXT"; break;
      case GL_SAMPLE_ALPHA_TO_COVERAGE: RETVAL = "GL_SAMPLE_ALPHA_TO_COVERAGE"; break;
      case GL_SAMPLE_ALPHA_TO_ONE: RETVAL = "GL_SAMPLE_ALPHA_TO_ONE"; break;
      case GL_SAMPLE_COVERAGE: RETVAL = "GL_SAMPLE_COVERAGE"; break;
      case GL_SAMPLE_MASK: RETVAL = "GL_SAMPLE_MASK"; break;
      case GL_SAMPLE_SHADING: RETVAL = "GL_SAMPLE_SHADING"; break;
      case GL_SCISSOR_TEST: RETVAL = "GL_SCISSOR_TEST"; break;
      case GL_SEPARABLE_2D_EXT: RETVAL = "GL_SEPARABLE_2D_EXT"; break;
      case GL_SHADING_RATE_IMAGE_PER_PRIMITIVE_NV: RETVAL = "GL_SHADING_RATE_IMAGE_PER_PRIMITIVE_NV"; break;
      case GL_SHADING_RATE_PRESERVE_ASPECT_RATIO_QCOM: RETVAL = "GL_SHADING_RATE_PRESERVE_ASPECT_RATIO_QCOM"; break;
      case GL_SHARED_TEXTURE_PALETTE_EXT: RETVAL = "GL_SHARED_TEXTURE_PALETTE_EXT"; break;
      case GL_STENCIL_TEST: RETVAL = "GL_STENCIL_TEST"; break;
      case GL_TEXTURE_1D: RETVAL = "GL_TEXTURE_1D"; break;
      case GL_TEXTURE_2D: RETVAL = "GL_TEXTURE_2D"; break;
      case GL_TEXTURE_3D_EXT: RETVAL = "GL_TEXTURE_3D_EXT"; break;
      case GL_TEXTURE_COLOR_TABLE_SGI: RETVAL = "GL_TEXTURE_COLOR_TABLE_SGI"; break;
      case GL_TEXTURE_COORD_ARRAY: RETVAL = "GL_TEXTURE_COORD_ARRAY"; break;
      case GL_TEXTURE_CUBE_MAP: RETVAL = "GL_TEXTURE_CUBE_MAP"; break;
      case GL_TEXTURE_CUBE_MAP_SEAMLESS: RETVAL = "GL_TEXTURE_CUBE_MAP_SEAMLESS"; break;
      case GL_TEXTURE_GEN_Q: RETVAL = "GL_TEXTURE_GEN_Q"; break;
      case GL_TEXTURE_GEN_R: RETVAL = "GL_TEXTURE_GEN_R"; break;
      case GL_TEXTURE_GEN_S: RETVAL = "GL_TEXTURE_GEN_S"; break;
      case GL_TEXTURE_GEN_T: RETVAL = "GL_TEXTURE_GEN_T"; break;
      case GL_TEXTURE_RECTANGLE: RETVAL = "GL_TEXTURE_RECTANGLE"; break;
      case GL_VERTEX_ARRAY: RETVAL = "GL_VERTEX_ARRAY"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ErrorCode")) {
    switch (e) {
      case GL_INVALID_ENUM: RETVAL = "GL_INVALID_ENUM"; break;
      case GL_INVALID_FRAMEBUFFER_OPERATION: RETVAL = "GL_INVALID_FRAMEBUFFER_OPERATION"; break;
      case GL_INVALID_OPERATION: RETVAL = "GL_INVALID_OPERATION"; break;
      case GL_INVALID_VALUE: RETVAL = "GL_INVALID_VALUE"; break;
      case GL_NO_ERROR: RETVAL = "GL_NO_ERROR"; break;
      case GL_OUT_OF_MEMORY: RETVAL = "GL_OUT_OF_MEMORY"; break;
      case GL_STACK_OVERFLOW: RETVAL = "GL_STACK_OVERFLOW"; break;
      case GL_STACK_UNDERFLOW: RETVAL = "GL_STACK_UNDERFLOW"; break;
      case GL_TABLE_TOO_LARGE: RETVAL = "GL_TABLE_TOO_LARGE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "EvalMapsModeNV")) {
    switch (e) {
      case GL_FILL_NV: RETVAL = "GL_FILL_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "EvalTargetNV")) {
    switch (e) {
      case GL_EVAL_2D_NV: RETVAL = "GL_EVAL_2D_NV"; break;
      case GL_EVAL_TRIANGULAR_2D_NV: RETVAL = "GL_EVAL_TRIANGULAR_2D_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ExternalHandleType")) {
    switch (e) {
      case GL_HANDLE_TYPE_D3D11_IMAGE_EXT: RETVAL = "GL_HANDLE_TYPE_D3D11_IMAGE_EXT"; break;
      case GL_HANDLE_TYPE_D3D11_IMAGE_KMT_EXT: RETVAL = "GL_HANDLE_TYPE_D3D11_IMAGE_KMT_EXT"; break;
      case GL_HANDLE_TYPE_D3D12_FENCE_EXT: RETVAL = "GL_HANDLE_TYPE_D3D12_FENCE_EXT"; break;
      case GL_HANDLE_TYPE_D3D12_RESOURCE_EXT: RETVAL = "GL_HANDLE_TYPE_D3D12_RESOURCE_EXT"; break;
      case GL_HANDLE_TYPE_D3D12_TILEPOOL_EXT: RETVAL = "GL_HANDLE_TYPE_D3D12_TILEPOOL_EXT"; break;
      case GL_HANDLE_TYPE_OPAQUE_FD_EXT: RETVAL = "GL_HANDLE_TYPE_OPAQUE_FD_EXT"; break;
      case GL_HANDLE_TYPE_OPAQUE_WIN32_EXT: RETVAL = "GL_HANDLE_TYPE_OPAQUE_WIN32_EXT"; break;
      case GL_HANDLE_TYPE_OPAQUE_WIN32_KMT_EXT: RETVAL = "GL_HANDLE_TYPE_OPAQUE_WIN32_KMT_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FeedBackToken")) {
    switch (e) {
      case GL_BITMAP_TOKEN: RETVAL = "GL_BITMAP_TOKEN"; break;
      case GL_COPY_PIXEL_TOKEN: RETVAL = "GL_COPY_PIXEL_TOKEN"; break;
      case GL_DRAW_PIXEL_TOKEN: RETVAL = "GL_DRAW_PIXEL_TOKEN"; break;
      case GL_LINE_RESET_TOKEN: RETVAL = "GL_LINE_RESET_TOKEN"; break;
      case GL_LINE_TOKEN: RETVAL = "GL_LINE_TOKEN"; break;
      case GL_PASS_THROUGH_TOKEN: RETVAL = "GL_PASS_THROUGH_TOKEN"; break;
      case GL_POINT_TOKEN: RETVAL = "GL_POINT_TOKEN"; break;
      case GL_POLYGON_TOKEN: RETVAL = "GL_POLYGON_TOKEN"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FeedbackType")) {
    switch (e) {
      case GL_2D: RETVAL = "GL_2D"; break;
      case GL_3D: RETVAL = "GL_3D"; break;
      case GL_3D_COLOR: RETVAL = "GL_3D_COLOR"; break;
      case GL_3D_COLOR_TEXTURE: RETVAL = "GL_3D_COLOR_TEXTURE"; break;
      case GL_4D_COLOR_TEXTURE: RETVAL = "GL_4D_COLOR_TEXTURE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FenceConditionNV")) {
    switch (e) {
      case GL_ALL_COMPLETED_NV: RETVAL = "GL_ALL_COMPLETED_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FenceParameterNameNV")) {
    switch (e) {
      case GL_FENCE_CONDITION_NV: RETVAL = "GL_FENCE_CONDITION_NV"; break;
      case GL_FENCE_STATUS_NV: RETVAL = "GL_FENCE_STATUS_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FfdMaskSGIX")) {
    switch (e) {
      case GL_GEOMETRY_DEFORMATION_BIT_SGIX: RETVAL = "GL_GEOMETRY_DEFORMATION_BIT_SGIX"; break;
      case GL_TEXTURE_DEFORMATION_BIT_SGIX: RETVAL = "GL_TEXTURE_DEFORMATION_BIT_SGIX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogCoordSrc")) {
    switch (e) {
      case GL_FOG_COORD: RETVAL = "GL_FOG_COORD"; break;
      case GL_FRAGMENT_DEPTH: RETVAL = "GL_FRAGMENT_DEPTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogCoordinatePointerType")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogMode")) {
    switch (e) {
      case GL_EXP: RETVAL = "GL_EXP"; break;
      case GL_EXP2: RETVAL = "GL_EXP2"; break;
      case GL_LINEAR: RETVAL = "GL_LINEAR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogPName")) {
    switch (e) {
      case GL_FOG_COORD_SRC: RETVAL = "GL_FOG_COORD_SRC"; break;
      case GL_FOG_DENSITY: RETVAL = "GL_FOG_DENSITY"; break;
      case GL_FOG_END: RETVAL = "GL_FOG_END"; break;
      case GL_FOG_INDEX: RETVAL = "GL_FOG_INDEX"; break;
      case GL_FOG_MODE: RETVAL = "GL_FOG_MODE"; break;
      case GL_FOG_START: RETVAL = "GL_FOG_START"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogParameter")) {
    switch (e) {
      case GL_FOG_COLOR: RETVAL = "GL_FOG_COLOR"; break;
      case GL_FOG_DENSITY: RETVAL = "GL_FOG_DENSITY"; break;
      case GL_FOG_END: RETVAL = "GL_FOG_END"; break;
      case GL_FOG_INDEX: RETVAL = "GL_FOG_INDEX"; break;
      case GL_FOG_MODE: RETVAL = "GL_FOG_MODE"; break;
      case GL_FOG_OFFSET_VALUE_SGIX: RETVAL = "GL_FOG_OFFSET_VALUE_SGIX"; break;
      case GL_FOG_START: RETVAL = "GL_FOG_START"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogPointerTypeEXT")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogPointerTypeIBM")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FoveationConfigBitQCOM")) {
    switch (e) {
      case GL_FOVEATION_ENABLE_BIT_QCOM: RETVAL = "GL_FOVEATION_ENABLE_BIT_QCOM"; break;
      case GL_FOVEATION_SCALED_BIN_METHOD_BIT_QCOM: RETVAL = "GL_FOVEATION_SCALED_BIN_METHOD_BIT_QCOM"; break;
      case GL_FOVEATION_SUBSAMPLED_LAYOUT_METHOD_BIT_QCOM: RETVAL = "GL_FOVEATION_SUBSAMPLED_LAYOUT_METHOD_BIT_QCOM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentLightParameterSGIX")) {
    switch (e) {
      case GL_AMBIENT: RETVAL = "GL_AMBIENT"; break;
      case GL_CONSTANT_ATTENUATION: RETVAL = "GL_CONSTANT_ATTENUATION"; break;
      case GL_DIFFUSE: RETVAL = "GL_DIFFUSE"; break;
      case GL_LINEAR_ATTENUATION: RETVAL = "GL_LINEAR_ATTENUATION"; break;
      case GL_POSITION: RETVAL = "GL_POSITION"; break;
      case GL_QUADRATIC_ATTENUATION: RETVAL = "GL_QUADRATIC_ATTENUATION"; break;
      case GL_SPECULAR: RETVAL = "GL_SPECULAR"; break;
      case GL_SPOT_CUTOFF: RETVAL = "GL_SPOT_CUTOFF"; break;
      case GL_SPOT_DIRECTION: RETVAL = "GL_SPOT_DIRECTION"; break;
      case GL_SPOT_EXPONENT: RETVAL = "GL_SPOT_EXPONENT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentOp1ATI")) {
    switch (e) {
      case GL_MOV_ATI: RETVAL = "GL_MOV_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentOp2ATI")) {
    switch (e) {
      case GL_ADD_ATI: RETVAL = "GL_ADD_ATI"; break;
      case GL_DOT3_ATI: RETVAL = "GL_DOT3_ATI"; break;
      case GL_DOT4_ATI: RETVAL = "GL_DOT4_ATI"; break;
      case GL_MUL_ATI: RETVAL = "GL_MUL_ATI"; break;
      case GL_SUB_ATI: RETVAL = "GL_SUB_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentOp3ATI")) {
    switch (e) {
      case GL_CND0_ATI: RETVAL = "GL_CND0_ATI"; break;
      case GL_CND_ATI: RETVAL = "GL_CND_ATI"; break;
      case GL_DOT2_ADD_ATI: RETVAL = "GL_DOT2_ADD_ATI"; break;
      case GL_LERP_ATI: RETVAL = "GL_LERP_ATI"; break;
      case GL_MAD_ATI: RETVAL = "GL_MAD_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderColorModMaskATI")) {
    switch (e) {
      case GL_2X_BIT_ATI: RETVAL = "GL_2X_BIT_ATI"; break;
      case GL_BIAS_BIT_ATI: RETVAL = "GL_BIAS_BIT_ATI"; break;
      case GL_COMP_BIT_ATI: RETVAL = "GL_COMP_BIT_ATI"; break;
      case GL_NEGATE_BIT_ATI: RETVAL = "GL_NEGATE_BIT_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderConATI")) {
    switch (e) {
      case GL_CON_0_ATI: RETVAL = "GL_CON_0_ATI"; break;
      case GL_CON_1_ATI: RETVAL = "GL_CON_1_ATI"; break;
      case GL_CON_2_ATI: RETVAL = "GL_CON_2_ATI"; break;
      case GL_CON_3_ATI: RETVAL = "GL_CON_3_ATI"; break;
      case GL_CON_4_ATI: RETVAL = "GL_CON_4_ATI"; break;
      case GL_CON_5_ATI: RETVAL = "GL_CON_5_ATI"; break;
      case GL_CON_6_ATI: RETVAL = "GL_CON_6_ATI"; break;
      case GL_CON_7_ATI: RETVAL = "GL_CON_7_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderDestMaskATI")) {
    switch (e) {
      case GL_BLUE_BIT_ATI: RETVAL = "GL_BLUE_BIT_ATI"; break;
      case GL_GREEN_BIT_ATI: RETVAL = "GL_GREEN_BIT_ATI"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RED_BIT_ATI: RETVAL = "GL_RED_BIT_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderDestModMaskATI")) {
    switch (e) {
      case GL_2X_BIT_ATI: RETVAL = "GL_2X_BIT_ATI"; break;
      case GL_4X_BIT_ATI: RETVAL = "GL_4X_BIT_ATI"; break;
      case GL_8X_BIT_ATI: RETVAL = "GL_8X_BIT_ATI"; break;
      case GL_EIGHTH_BIT_ATI: RETVAL = "GL_EIGHTH_BIT_ATI"; break;
      case GL_HALF_BIT_ATI: RETVAL = "GL_HALF_BIT_ATI"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_QUARTER_BIT_ATI: RETVAL = "GL_QUARTER_BIT_ATI"; break;
      case GL_SATURATE_BIT_ATI: RETVAL = "GL_SATURATE_BIT_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderGenericSourceATI")) {
    switch (e) {
      case GL_CON_0_ATI: RETVAL = "GL_CON_0_ATI"; break;
      case GL_CON_1_ATI: RETVAL = "GL_CON_1_ATI"; break;
      case GL_CON_2_ATI: RETVAL = "GL_CON_2_ATI"; break;
      case GL_CON_3_ATI: RETVAL = "GL_CON_3_ATI"; break;
      case GL_CON_4_ATI: RETVAL = "GL_CON_4_ATI"; break;
      case GL_CON_5_ATI: RETVAL = "GL_CON_5_ATI"; break;
      case GL_CON_6_ATI: RETVAL = "GL_CON_6_ATI"; break;
      case GL_CON_7_ATI: RETVAL = "GL_CON_7_ATI"; break;
      case GL_ONE: RETVAL = "GL_ONE"; break;
      case GL_PRIMARY_COLOR: RETVAL = "GL_PRIMARY_COLOR"; break;
      case GL_REG_0_ATI: RETVAL = "GL_REG_0_ATI"; break;
      case GL_REG_1_ATI: RETVAL = "GL_REG_1_ATI"; break;
      case GL_REG_2_ATI: RETVAL = "GL_REG_2_ATI"; break;
      case GL_REG_3_ATI: RETVAL = "GL_REG_3_ATI"; break;
      case GL_REG_4_ATI: RETVAL = "GL_REG_4_ATI"; break;
      case GL_REG_5_ATI: RETVAL = "GL_REG_5_ATI"; break;
      case GL_SECONDARY_INTERPOLATOR_ATI: RETVAL = "GL_SECONDARY_INTERPOLATOR_ATI"; break;
      case GL_ZERO: RETVAL = "GL_ZERO"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderRegATI")) {
    switch (e) {
      case GL_REG_0_ATI: RETVAL = "GL_REG_0_ATI"; break;
      case GL_REG_1_ATI: RETVAL = "GL_REG_1_ATI"; break;
      case GL_REG_2_ATI: RETVAL = "GL_REG_2_ATI"; break;
      case GL_REG_3_ATI: RETVAL = "GL_REG_3_ATI"; break;
      case GL_REG_4_ATI: RETVAL = "GL_REG_4_ATI"; break;
      case GL_REG_5_ATI: RETVAL = "GL_REG_5_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderTextureSourceATI")) {
    switch (e) {
      case GL_REG_0_ATI: RETVAL = "GL_REG_0_ATI"; break;
      case GL_REG_1_ATI: RETVAL = "GL_REG_1_ATI"; break;
      case GL_REG_2_ATI: RETVAL = "GL_REG_2_ATI"; break;
      case GL_REG_3_ATI: RETVAL = "GL_REG_3_ATI"; break;
      case GL_REG_4_ATI: RETVAL = "GL_REG_4_ATI"; break;
      case GL_REG_5_ATI: RETVAL = "GL_REG_5_ATI"; break;
      case GL_TEXTURE0: RETVAL = "GL_TEXTURE0"; break;
      case GL_TEXTURE1: RETVAL = "GL_TEXTURE1"; break;
      case GL_TEXTURE10: RETVAL = "GL_TEXTURE10"; break;
      case GL_TEXTURE11: RETVAL = "GL_TEXTURE11"; break;
      case GL_TEXTURE12: RETVAL = "GL_TEXTURE12"; break;
      case GL_TEXTURE13: RETVAL = "GL_TEXTURE13"; break;
      case GL_TEXTURE14: RETVAL = "GL_TEXTURE14"; break;
      case GL_TEXTURE15: RETVAL = "GL_TEXTURE15"; break;
      case GL_TEXTURE16: RETVAL = "GL_TEXTURE16"; break;
      case GL_TEXTURE17: RETVAL = "GL_TEXTURE17"; break;
      case GL_TEXTURE18: RETVAL = "GL_TEXTURE18"; break;
      case GL_TEXTURE19: RETVAL = "GL_TEXTURE19"; break;
      case GL_TEXTURE2: RETVAL = "GL_TEXTURE2"; break;
      case GL_TEXTURE20: RETVAL = "GL_TEXTURE20"; break;
      case GL_TEXTURE21: RETVAL = "GL_TEXTURE21"; break;
      case GL_TEXTURE22: RETVAL = "GL_TEXTURE22"; break;
      case GL_TEXTURE23: RETVAL = "GL_TEXTURE23"; break;
      case GL_TEXTURE24: RETVAL = "GL_TEXTURE24"; break;
      case GL_TEXTURE25: RETVAL = "GL_TEXTURE25"; break;
      case GL_TEXTURE26: RETVAL = "GL_TEXTURE26"; break;
      case GL_TEXTURE27: RETVAL = "GL_TEXTURE27"; break;
      case GL_TEXTURE28: RETVAL = "GL_TEXTURE28"; break;
      case GL_TEXTURE29: RETVAL = "GL_TEXTURE29"; break;
      case GL_TEXTURE3: RETVAL = "GL_TEXTURE3"; break;
      case GL_TEXTURE30: RETVAL = "GL_TEXTURE30"; break;
      case GL_TEXTURE31: RETVAL = "GL_TEXTURE31"; break;
      case GL_TEXTURE4: RETVAL = "GL_TEXTURE4"; break;
      case GL_TEXTURE5: RETVAL = "GL_TEXTURE5"; break;
      case GL_TEXTURE6: RETVAL = "GL_TEXTURE6"; break;
      case GL_TEXTURE7: RETVAL = "GL_TEXTURE7"; break;
      case GL_TEXTURE8: RETVAL = "GL_TEXTURE8"; break;
      case GL_TEXTURE9: RETVAL = "GL_TEXTURE9"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderValueRepATI")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_BLUE: RETVAL = "GL_BLUE"; break;
      case GL_GREEN: RETVAL = "GL_GREEN"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RED: RETVAL = "GL_RED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FramebufferAttachment")) {
    switch (e) {
      case GL_COLOR_ATTACHMENT0: RETVAL = "GL_COLOR_ATTACHMENT0"; break;
      case GL_COLOR_ATTACHMENT1: RETVAL = "GL_COLOR_ATTACHMENT1"; break;
      case GL_COLOR_ATTACHMENT10: RETVAL = "GL_COLOR_ATTACHMENT10"; break;
      case GL_COLOR_ATTACHMENT11: RETVAL = "GL_COLOR_ATTACHMENT11"; break;
      case GL_COLOR_ATTACHMENT12: RETVAL = "GL_COLOR_ATTACHMENT12"; break;
      case GL_COLOR_ATTACHMENT13: RETVAL = "GL_COLOR_ATTACHMENT13"; break;
      case GL_COLOR_ATTACHMENT14: RETVAL = "GL_COLOR_ATTACHMENT14"; break;
      case GL_COLOR_ATTACHMENT15: RETVAL = "GL_COLOR_ATTACHMENT15"; break;
      case GL_COLOR_ATTACHMENT2: RETVAL = "GL_COLOR_ATTACHMENT2"; break;
      case GL_COLOR_ATTACHMENT3: RETVAL = "GL_COLOR_ATTACHMENT3"; break;
      case GL_COLOR_ATTACHMENT4: RETVAL = "GL_COLOR_ATTACHMENT4"; break;
      case GL_COLOR_ATTACHMENT5: RETVAL = "GL_COLOR_ATTACHMENT5"; break;
      case GL_COLOR_ATTACHMENT6: RETVAL = "GL_COLOR_ATTACHMENT6"; break;
      case GL_COLOR_ATTACHMENT7: RETVAL = "GL_COLOR_ATTACHMENT7"; break;
      case GL_COLOR_ATTACHMENT8: RETVAL = "GL_COLOR_ATTACHMENT8"; break;
      case GL_COLOR_ATTACHMENT9: RETVAL = "GL_COLOR_ATTACHMENT9"; break;
      case GL_DEPTH_ATTACHMENT: RETVAL = "GL_DEPTH_ATTACHMENT"; break;
      case GL_DEPTH_STENCIL_ATTACHMENT: RETVAL = "GL_DEPTH_STENCIL_ATTACHMENT"; break;
      case GL_SHADING_RATE_ATTACHMENT_EXT: RETVAL = "GL_SHADING_RATE_ATTACHMENT_EXT"; break;
      case GL_STENCIL_ATTACHMENT: RETVAL = "GL_STENCIL_ATTACHMENT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FramebufferAttachmentParameterName")) {
    switch (e) {
      case GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_LAYERED: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_LAYERED"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_BASE_VIEW_INDEX_OVR: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_BASE_VIEW_INDEX_OVR"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_NUM_VIEWS_OVR: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_NUM_VIEWS_OVR"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_SAMPLES_EXT: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_SAMPLES_EXT"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_SCALE_IMG: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_SCALE_IMG"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FramebufferParameterName")) {
    switch (e) {
      case GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS: RETVAL = "GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS"; break;
      case GL_FRAMEBUFFER_DEFAULT_HEIGHT: RETVAL = "GL_FRAMEBUFFER_DEFAULT_HEIGHT"; break;
      case GL_FRAMEBUFFER_DEFAULT_LAYERS: RETVAL = "GL_FRAMEBUFFER_DEFAULT_LAYERS"; break;
      case GL_FRAMEBUFFER_DEFAULT_SAMPLES: RETVAL = "GL_FRAMEBUFFER_DEFAULT_SAMPLES"; break;
      case GL_FRAMEBUFFER_DEFAULT_WIDTH: RETVAL = "GL_FRAMEBUFFER_DEFAULT_WIDTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FramebufferStatus")) {
    switch (e) {
      case GL_FRAMEBUFFER_COMPLETE: RETVAL = "GL_FRAMEBUFFER_COMPLETE"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER"; break;
      case GL_FRAMEBUFFER_UNDEFINED: RETVAL = "GL_FRAMEBUFFER_UNDEFINED"; break;
      case GL_FRAMEBUFFER_UNSUPPORTED: RETVAL = "GL_FRAMEBUFFER_UNSUPPORTED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FramebufferTarget")) {
    switch (e) {
      case GL_DRAW_FRAMEBUFFER: RETVAL = "GL_DRAW_FRAMEBUFFER"; break;
      case GL_FRAMEBUFFER: RETVAL = "GL_FRAMEBUFFER"; break;
      case GL_READ_FRAMEBUFFER: RETVAL = "GL_READ_FRAMEBUFFER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FrontFaceDirection")) {
    switch (e) {
      case GL_CCW: RETVAL = "GL_CCW"; break;
      case GL_CW: RETVAL = "GL_CW"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetFramebufferParameter")) {
    switch (e) {
      case GL_DOUBLEBUFFER: RETVAL = "GL_DOUBLEBUFFER"; break;
      case GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS: RETVAL = "GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS"; break;
      case GL_FRAMEBUFFER_DEFAULT_HEIGHT: RETVAL = "GL_FRAMEBUFFER_DEFAULT_HEIGHT"; break;
      case GL_FRAMEBUFFER_DEFAULT_LAYERS: RETVAL = "GL_FRAMEBUFFER_DEFAULT_LAYERS"; break;
      case GL_FRAMEBUFFER_DEFAULT_SAMPLES: RETVAL = "GL_FRAMEBUFFER_DEFAULT_SAMPLES"; break;
      case GL_FRAMEBUFFER_DEFAULT_WIDTH: RETVAL = "GL_FRAMEBUFFER_DEFAULT_WIDTH"; break;
      case GL_IMPLEMENTATION_COLOR_READ_FORMAT: RETVAL = "GL_IMPLEMENTATION_COLOR_READ_FORMAT"; break;
      case GL_IMPLEMENTATION_COLOR_READ_TYPE: RETVAL = "GL_IMPLEMENTATION_COLOR_READ_TYPE"; break;
      case GL_SAMPLES: RETVAL = "GL_SAMPLES"; break;
      case GL_SAMPLE_BUFFERS: RETVAL = "GL_SAMPLE_BUFFERS"; break;
      case GL_STEREO: RETVAL = "GL_STEREO"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetHistogramParameterPNameEXT")) {
    switch (e) {
      case GL_HISTOGRAM_ALPHA_SIZE: RETVAL = "GL_HISTOGRAM_ALPHA_SIZE"; break;
      case GL_HISTOGRAM_BLUE_SIZE: RETVAL = "GL_HISTOGRAM_BLUE_SIZE"; break;
      case GL_HISTOGRAM_FORMAT: RETVAL = "GL_HISTOGRAM_FORMAT"; break;
      case GL_HISTOGRAM_GREEN_SIZE: RETVAL = "GL_HISTOGRAM_GREEN_SIZE"; break;
      case GL_HISTOGRAM_LUMINANCE_SIZE: RETVAL = "GL_HISTOGRAM_LUMINANCE_SIZE"; break;
      case GL_HISTOGRAM_RED_SIZE: RETVAL = "GL_HISTOGRAM_RED_SIZE"; break;
      case GL_HISTOGRAM_SINK: RETVAL = "GL_HISTOGRAM_SINK"; break;
      case GL_HISTOGRAM_WIDTH: RETVAL = "GL_HISTOGRAM_WIDTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetMapQuery")) {
    switch (e) {
      case GL_COEFF: RETVAL = "GL_COEFF"; break;
      case GL_DOMAIN: RETVAL = "GL_DOMAIN"; break;
      case GL_ORDER: RETVAL = "GL_ORDER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetMinmaxParameterPNameEXT")) {
    switch (e) {
      case GL_MINMAX_FORMAT: RETVAL = "GL_MINMAX_FORMAT"; break;
      case GL_MINMAX_SINK: RETVAL = "GL_MINMAX_SINK"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetMultisamplePNameNV")) {
    switch (e) {
      case GL_PROGRAMMABLE_SAMPLE_LOCATION_ARB: RETVAL = "GL_PROGRAMMABLE_SAMPLE_LOCATION_ARB"; break;
      case GL_SAMPLE_POSITION: RETVAL = "GL_SAMPLE_POSITION"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetPName")) {
    switch (e) {
      case GL_ACCUM_ALPHA_BITS: RETVAL = "GL_ACCUM_ALPHA_BITS"; break;
      case GL_ACCUM_BLUE_BITS: RETVAL = "GL_ACCUM_BLUE_BITS"; break;
      case GL_ACCUM_CLEAR_VALUE: RETVAL = "GL_ACCUM_CLEAR_VALUE"; break;
      case GL_ACCUM_GREEN_BITS: RETVAL = "GL_ACCUM_GREEN_BITS"; break;
      case GL_ACCUM_RED_BITS: RETVAL = "GL_ACCUM_RED_BITS"; break;
      case GL_ACTIVE_TEXTURE: RETVAL = "GL_ACTIVE_TEXTURE"; break;
      case GL_ALIASED_LINE_WIDTH_RANGE: RETVAL = "GL_ALIASED_LINE_WIDTH_RANGE"; break;
      case GL_ALIASED_POINT_SIZE_RANGE: RETVAL = "GL_ALIASED_POINT_SIZE_RANGE"; break;
      case GL_ALPHA_BIAS: RETVAL = "GL_ALPHA_BIAS"; break;
      case GL_ALPHA_BITS: RETVAL = "GL_ALPHA_BITS"; break;
      case GL_ALPHA_SCALE: RETVAL = "GL_ALPHA_SCALE"; break;
      case GL_ALPHA_TEST: RETVAL = "GL_ALPHA_TEST"; break;
      case GL_ALPHA_TEST_FUNC: RETVAL = "GL_ALPHA_TEST_FUNC"; break;
      case GL_ALPHA_TEST_REF: RETVAL = "GL_ALPHA_TEST_REF"; break;
      case GL_ARRAY_BUFFER_BINDING: RETVAL = "GL_ARRAY_BUFFER_BINDING"; break;
      case GL_ASYNC_DRAW_PIXELS_SGIX: RETVAL = "GL_ASYNC_DRAW_PIXELS_SGIX"; break;
      case GL_ASYNC_HISTOGRAM_SGIX: RETVAL = "GL_ASYNC_HISTOGRAM_SGIX"; break;
      case GL_ASYNC_MARKER_SGIX: RETVAL = "GL_ASYNC_MARKER_SGIX"; break;
      case GL_ASYNC_READ_PIXELS_SGIX: RETVAL = "GL_ASYNC_READ_PIXELS_SGIX"; break;
      case GL_ASYNC_TEX_IMAGE_SGIX: RETVAL = "GL_ASYNC_TEX_IMAGE_SGIX"; break;
      case GL_ATTRIB_STACK_DEPTH: RETVAL = "GL_ATTRIB_STACK_DEPTH"; break;
      case GL_AUTO_NORMAL: RETVAL = "GL_AUTO_NORMAL"; break;
      case GL_AUX_BUFFERS: RETVAL = "GL_AUX_BUFFERS"; break;
      case GL_BLEND: RETVAL = "GL_BLEND"; break;
      case GL_BLEND_COLOR: RETVAL = "GL_BLEND_COLOR"; break;
      case GL_BLEND_DST: RETVAL = "GL_BLEND_DST"; break;
      case GL_BLEND_DST_ALPHA: RETVAL = "GL_BLEND_DST_ALPHA"; break;
      case GL_BLEND_DST_RGB: RETVAL = "GL_BLEND_DST_RGB"; break;
      case GL_BLEND_EQUATION: RETVAL = "GL_BLEND_EQUATION"; break;
      case GL_BLEND_EQUATION_ALPHA: RETVAL = "GL_BLEND_EQUATION_ALPHA"; break;
      case GL_BLEND_SRC: RETVAL = "GL_BLEND_SRC"; break;
      case GL_BLEND_SRC_ALPHA: RETVAL = "GL_BLEND_SRC_ALPHA"; break;
      case GL_BLEND_SRC_RGB: RETVAL = "GL_BLEND_SRC_RGB"; break;
      case GL_BLUE_BIAS: RETVAL = "GL_BLUE_BIAS"; break;
      case GL_BLUE_BITS: RETVAL = "GL_BLUE_BITS"; break;
      case GL_BLUE_SCALE: RETVAL = "GL_BLUE_SCALE"; break;
      case GL_CLIENT_ATTRIB_STACK_DEPTH: RETVAL = "GL_CLIENT_ATTRIB_STACK_DEPTH"; break;
      case GL_CLIP_PLANE0: RETVAL = "GL_CLIP_PLANE0"; break;
      case GL_CLIP_PLANE1: RETVAL = "GL_CLIP_PLANE1"; break;
      case GL_CLIP_PLANE2: RETVAL = "GL_CLIP_PLANE2"; break;
      case GL_CLIP_PLANE3: RETVAL = "GL_CLIP_PLANE3"; break;
      case GL_CLIP_PLANE4: RETVAL = "GL_CLIP_PLANE4"; break;
      case GL_CLIP_PLANE5: RETVAL = "GL_CLIP_PLANE5"; break;
      case GL_COLOR_ARRAY: RETVAL = "GL_COLOR_ARRAY"; break;
      case GL_COLOR_ARRAY_COUNT_EXT: RETVAL = "GL_COLOR_ARRAY_COUNT_EXT"; break;
      case GL_COLOR_ARRAY_SIZE: RETVAL = "GL_COLOR_ARRAY_SIZE"; break;
      case GL_COLOR_ARRAY_STRIDE: RETVAL = "GL_COLOR_ARRAY_STRIDE"; break;
      case GL_COLOR_ARRAY_TYPE: RETVAL = "GL_COLOR_ARRAY_TYPE"; break;
      case GL_COLOR_CLEAR_VALUE: RETVAL = "GL_COLOR_CLEAR_VALUE"; break;
      case GL_COLOR_LOGIC_OP: RETVAL = "GL_COLOR_LOGIC_OP"; break;
      case GL_COLOR_MATERIAL: RETVAL = "GL_COLOR_MATERIAL"; break;
      case GL_COLOR_MATERIAL_FACE: RETVAL = "GL_COLOR_MATERIAL_FACE"; break;
      case GL_COLOR_MATERIAL_PARAMETER: RETVAL = "GL_COLOR_MATERIAL_PARAMETER"; break;
      case GL_COLOR_MATRIX_SGI: RETVAL = "GL_COLOR_MATRIX_SGI"; break;
      case GL_COLOR_MATRIX_STACK_DEPTH_SGI: RETVAL = "GL_COLOR_MATRIX_STACK_DEPTH_SGI"; break;
      case GL_COLOR_TABLE_SGI: RETVAL = "GL_COLOR_TABLE_SGI"; break;
      case GL_COLOR_WRITEMASK: RETVAL = "GL_COLOR_WRITEMASK"; break;
      case GL_COMPRESSED_TEXTURE_FORMATS: RETVAL = "GL_COMPRESSED_TEXTURE_FORMATS"; break;
      case GL_CONTEXT_FLAGS: RETVAL = "GL_CONTEXT_FLAGS"; break;
      case GL_CONTEXT_PROFILE_MASK: RETVAL = "GL_CONTEXT_PROFILE_MASK"; break;
      case GL_CONVOLUTION_1D_EXT: RETVAL = "GL_CONVOLUTION_1D_EXT"; break;
      case GL_CONVOLUTION_2D_EXT: RETVAL = "GL_CONVOLUTION_2D_EXT"; break;
      case GL_CONVOLUTION_HINT_SGIX: RETVAL = "GL_CONVOLUTION_HINT_SGIX"; break;
      case GL_CULL_FACE: RETVAL = "GL_CULL_FACE"; break;
      case GL_CULL_FACE_MODE: RETVAL = "GL_CULL_FACE_MODE"; break;
      case GL_CURRENT_COLOR: RETVAL = "GL_CURRENT_COLOR"; break;
      case GL_CURRENT_INDEX: RETVAL = "GL_CURRENT_INDEX"; break;
      case GL_CURRENT_NORMAL: RETVAL = "GL_CURRENT_NORMAL"; break;
      case GL_CURRENT_PROGRAM: RETVAL = "GL_CURRENT_PROGRAM"; break;
      case GL_CURRENT_RASTER_COLOR: RETVAL = "GL_CURRENT_RASTER_COLOR"; break;
      case GL_CURRENT_RASTER_DISTANCE: RETVAL = "GL_CURRENT_RASTER_DISTANCE"; break;
      case GL_CURRENT_RASTER_INDEX: RETVAL = "GL_CURRENT_RASTER_INDEX"; break;
      case GL_CURRENT_RASTER_POSITION: RETVAL = "GL_CURRENT_RASTER_POSITION"; break;
      case GL_CURRENT_RASTER_POSITION_VALID: RETVAL = "GL_CURRENT_RASTER_POSITION_VALID"; break;
      case GL_CURRENT_RASTER_TEXTURE_COORDS: RETVAL = "GL_CURRENT_RASTER_TEXTURE_COORDS"; break;
      case GL_CURRENT_TEXTURE_COORDS: RETVAL = "GL_CURRENT_TEXTURE_COORDS"; break;
      case GL_DEBUG_GROUP_STACK_DEPTH: RETVAL = "GL_DEBUG_GROUP_STACK_DEPTH"; break;
      case GL_DEPTH_BIAS: RETVAL = "GL_DEPTH_BIAS"; break;
      case GL_DEPTH_BITS: RETVAL = "GL_DEPTH_BITS"; break;
      case GL_DEPTH_CLEAR_VALUE: RETVAL = "GL_DEPTH_CLEAR_VALUE"; break;
      case GL_DEPTH_FUNC: RETVAL = "GL_DEPTH_FUNC"; break;
      case GL_DEPTH_RANGE: RETVAL = "GL_DEPTH_RANGE"; break;
      case GL_DEPTH_SCALE: RETVAL = "GL_DEPTH_SCALE"; break;
      case GL_DEPTH_TEST: RETVAL = "GL_DEPTH_TEST"; break;
      case GL_DEPTH_WRITEMASK: RETVAL = "GL_DEPTH_WRITEMASK"; break;
      case GL_DEVICE_LUID_EXT: RETVAL = "GL_DEVICE_LUID_EXT"; break;
      case GL_DEVICE_NODE_MASK_EXT: RETVAL = "GL_DEVICE_NODE_MASK_EXT"; break;
      case GL_DEVICE_UUID_EXT: RETVAL = "GL_DEVICE_UUID_EXT"; break;
      case GL_DISPATCH_INDIRECT_BUFFER_BINDING: RETVAL = "GL_DISPATCH_INDIRECT_BUFFER_BINDING"; break;
      case GL_DISTANCE_ATTENUATION_EXT: RETVAL = "GL_DISTANCE_ATTENUATION_EXT"; break;
      case GL_DITHER: RETVAL = "GL_DITHER"; break;
      case GL_DOUBLEBUFFER: RETVAL = "GL_DOUBLEBUFFER"; break;
      case GL_DRAW_BUFFER: RETVAL = "GL_DRAW_BUFFER"; break;
      case GL_DRAW_FRAMEBUFFER_BINDING: RETVAL = "GL_DRAW_FRAMEBUFFER_BINDING"; break;
      case GL_DRIVER_UUID_EXT: RETVAL = "GL_DRIVER_UUID_EXT"; break;
      case GL_EDGE_FLAG: RETVAL = "GL_EDGE_FLAG"; break;
      case GL_EDGE_FLAG_ARRAY: RETVAL = "GL_EDGE_FLAG_ARRAY"; break;
      case GL_EDGE_FLAG_ARRAY_COUNT_EXT: RETVAL = "GL_EDGE_FLAG_ARRAY_COUNT_EXT"; break;
      case GL_EDGE_FLAG_ARRAY_STRIDE: RETVAL = "GL_EDGE_FLAG_ARRAY_STRIDE"; break;
      case GL_ELEMENT_ARRAY_BUFFER_BINDING: RETVAL = "GL_ELEMENT_ARRAY_BUFFER_BINDING"; break;
      case GL_FEEDBACK_BUFFER_SIZE: RETVAL = "GL_FEEDBACK_BUFFER_SIZE"; break;
      case GL_FEEDBACK_BUFFER_TYPE: RETVAL = "GL_FEEDBACK_BUFFER_TYPE"; break;
      case GL_FETCH_PER_SAMPLE_ARM: RETVAL = "GL_FETCH_PER_SAMPLE_ARM"; break;
      case GL_FOG: RETVAL = "GL_FOG"; break;
      case GL_FOG_COLOR: RETVAL = "GL_FOG_COLOR"; break;
      case GL_FOG_DENSITY: RETVAL = "GL_FOG_DENSITY"; break;
      case GL_FOG_END: RETVAL = "GL_FOG_END"; break;
      case GL_FOG_HINT: RETVAL = "GL_FOG_HINT"; break;
      case GL_FOG_INDEX: RETVAL = "GL_FOG_INDEX"; break;
      case GL_FOG_MODE: RETVAL = "GL_FOG_MODE"; break;
      case GL_FOG_OFFSET_SGIX: RETVAL = "GL_FOG_OFFSET_SGIX"; break;
      case GL_FOG_OFFSET_VALUE_SGIX: RETVAL = "GL_FOG_OFFSET_VALUE_SGIX"; break;
      case GL_FOG_START: RETVAL = "GL_FOG_START"; break;
      case GL_FRAGMENT_SHADER_ATI: RETVAL = "GL_FRAGMENT_SHADER_ATI"; break;
      case GL_FRAGMENT_SHADER_DERIVATIVE_HINT: RETVAL = "GL_FRAGMENT_SHADER_DERIVATIVE_HINT"; break;
      case GL_FRAGMENT_SHADER_FRAMEBUFFER_FETCH_MRT_ARM: RETVAL = "GL_FRAGMENT_SHADER_FRAMEBUFFER_FETCH_MRT_ARM"; break;
      case GL_FRAGMENT_SHADING_RATE_ATTACHMENT_WITH_DEFAULT_FRAMEBUFFER_SUPPORTED_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_ATTACHMENT_WITH_DEFAULT_FRAMEBUFFER_SUPPORTED_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_NON_TRIVIAL_COMBINERS_SUPPORTED_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_NON_TRIVIAL_COMBINERS_SUPPORTED_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_PRIMITIVE_RATE_WITH_MULTI_VIEWPORT_SUPPORTED_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_PRIMITIVE_RATE_WITH_MULTI_VIEWPORT_SUPPORTED_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_WITH_SAMPLE_MASK_SUPPORTED_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_WITH_SAMPLE_MASK_SUPPORTED_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_WITH_SHADER_DEPTH_STENCIL_WRITES_SUPPORTED_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_WITH_SHADER_DEPTH_STENCIL_WRITES_SUPPORTED_EXT"; break;
      case GL_FRAMEBUFFER_FETCH_NONCOHERENT_QCOM: RETVAL = "GL_FRAMEBUFFER_FETCH_NONCOHERENT_QCOM"; break;
      case GL_FRONT_FACE: RETVAL = "GL_FRONT_FACE"; break;
      case GL_GENERATE_MIPMAP_HINT_SGIS: RETVAL = "GL_GENERATE_MIPMAP_HINT_SGIS"; break;
      case GL_GREEN_BIAS: RETVAL = "GL_GREEN_BIAS"; break;
      case GL_GREEN_BITS: RETVAL = "GL_GREEN_BITS"; break;
      case GL_GREEN_SCALE: RETVAL = "GL_GREEN_SCALE"; break;
      case GL_HISTOGRAM_EXT: RETVAL = "GL_HISTOGRAM_EXT"; break;
      case GL_IMPLEMENTATION_COLOR_READ_FORMAT: RETVAL = "GL_IMPLEMENTATION_COLOR_READ_FORMAT"; break;
      case GL_IMPLEMENTATION_COLOR_READ_TYPE: RETVAL = "GL_IMPLEMENTATION_COLOR_READ_TYPE"; break;
      case GL_INDEX_ARRAY: RETVAL = "GL_INDEX_ARRAY"; break;
      case GL_INDEX_ARRAY_COUNT_EXT: RETVAL = "GL_INDEX_ARRAY_COUNT_EXT"; break;
      case GL_INDEX_ARRAY_STRIDE: RETVAL = "GL_INDEX_ARRAY_STRIDE"; break;
      case GL_INDEX_ARRAY_TYPE: RETVAL = "GL_INDEX_ARRAY_TYPE"; break;
      case GL_INDEX_BITS: RETVAL = "GL_INDEX_BITS"; break;
      case GL_INDEX_CLEAR_VALUE: RETVAL = "GL_INDEX_CLEAR_VALUE"; break;
      case GL_INDEX_MODE: RETVAL = "GL_INDEX_MODE"; break;
      case GL_INDEX_OFFSET: RETVAL = "GL_INDEX_OFFSET"; break;
      case GL_INDEX_SHIFT: RETVAL = "GL_INDEX_SHIFT"; break;
      case GL_INDEX_WRITEMASK: RETVAL = "GL_INDEX_WRITEMASK"; break;
      case GL_INTERLACE_SGIX: RETVAL = "GL_INTERLACE_SGIX"; break;
      case GL_LAYER_PROVOKING_VERTEX: RETVAL = "GL_LAYER_PROVOKING_VERTEX"; break;
      case GL_LIGHT0: RETVAL = "GL_LIGHT0"; break;
      case GL_LIGHT1: RETVAL = "GL_LIGHT1"; break;
      case GL_LIGHT2: RETVAL = "GL_LIGHT2"; break;
      case GL_LIGHT3: RETVAL = "GL_LIGHT3"; break;
      case GL_LIGHT4: RETVAL = "GL_LIGHT4"; break;
      case GL_LIGHT5: RETVAL = "GL_LIGHT5"; break;
      case GL_LIGHT6: RETVAL = "GL_LIGHT6"; break;
      case GL_LIGHT7: RETVAL = "GL_LIGHT7"; break;
      case GL_LIGHTING: RETVAL = "GL_LIGHTING"; break;
      case GL_LIGHT_MODEL_AMBIENT: RETVAL = "GL_LIGHT_MODEL_AMBIENT"; break;
      case GL_LIGHT_MODEL_COLOR_CONTROL: RETVAL = "GL_LIGHT_MODEL_COLOR_CONTROL"; break;
      case GL_LIGHT_MODEL_LOCAL_VIEWER: RETVAL = "GL_LIGHT_MODEL_LOCAL_VIEWER"; break;
      case GL_LIGHT_MODEL_TWO_SIDE: RETVAL = "GL_LIGHT_MODEL_TWO_SIDE"; break;
      case GL_LINE_SMOOTH: RETVAL = "GL_LINE_SMOOTH"; break;
      case GL_LINE_SMOOTH_HINT: RETVAL = "GL_LINE_SMOOTH_HINT"; break;
      case GL_LINE_STIPPLE: RETVAL = "GL_LINE_STIPPLE"; break;
      case GL_LINE_STIPPLE_PATTERN: RETVAL = "GL_LINE_STIPPLE_PATTERN"; break;
      case GL_LINE_STIPPLE_REPEAT: RETVAL = "GL_LINE_STIPPLE_REPEAT"; break;
      case GL_LINE_WIDTH: RETVAL = "GL_LINE_WIDTH"; break;
      case GL_LINE_WIDTH_GRANULARITY: RETVAL = "GL_LINE_WIDTH_GRANULARITY"; break;
      case GL_LINE_WIDTH_RANGE: RETVAL = "GL_LINE_WIDTH_RANGE"; break;
      case GL_LIST_BASE: RETVAL = "GL_LIST_BASE"; break;
      case GL_LIST_INDEX: RETVAL = "GL_LIST_INDEX"; break;
      case GL_LIST_MODE: RETVAL = "GL_LIST_MODE"; break;
      case GL_LOGIC_OP: RETVAL = "GL_LOGIC_OP"; break;
      case GL_LOGIC_OP_MODE: RETVAL = "GL_LOGIC_OP_MODE"; break;
      case GL_MAJOR_VERSION: RETVAL = "GL_MAJOR_VERSION"; break;
      case GL_MAP1_COLOR_4: RETVAL = "GL_MAP1_COLOR_4"; break;
      case GL_MAP1_GRID_DOMAIN: RETVAL = "GL_MAP1_GRID_DOMAIN"; break;
      case GL_MAP1_GRID_SEGMENTS: RETVAL = "GL_MAP1_GRID_SEGMENTS"; break;
      case GL_MAP1_INDEX: RETVAL = "GL_MAP1_INDEX"; break;
      case GL_MAP1_NORMAL: RETVAL = "GL_MAP1_NORMAL"; break;
      case GL_MAP1_TEXTURE_COORD_1: RETVAL = "GL_MAP1_TEXTURE_COORD_1"; break;
      case GL_MAP1_TEXTURE_COORD_2: RETVAL = "GL_MAP1_TEXTURE_COORD_2"; break;
      case GL_MAP1_TEXTURE_COORD_3: RETVAL = "GL_MAP1_TEXTURE_COORD_3"; break;
      case GL_MAP1_TEXTURE_COORD_4: RETVAL = "GL_MAP1_TEXTURE_COORD_4"; break;
      case GL_MAP1_VERTEX_3: RETVAL = "GL_MAP1_VERTEX_3"; break;
      case GL_MAP1_VERTEX_4: RETVAL = "GL_MAP1_VERTEX_4"; break;
      case GL_MAP2_COLOR_4: RETVAL = "GL_MAP2_COLOR_4"; break;
      case GL_MAP2_GRID_DOMAIN: RETVAL = "GL_MAP2_GRID_DOMAIN"; break;
      case GL_MAP2_GRID_SEGMENTS: RETVAL = "GL_MAP2_GRID_SEGMENTS"; break;
      case GL_MAP2_INDEX: RETVAL = "GL_MAP2_INDEX"; break;
      case GL_MAP2_NORMAL: RETVAL = "GL_MAP2_NORMAL"; break;
      case GL_MAP2_TEXTURE_COORD_1: RETVAL = "GL_MAP2_TEXTURE_COORD_1"; break;
      case GL_MAP2_TEXTURE_COORD_2: RETVAL = "GL_MAP2_TEXTURE_COORD_2"; break;
      case GL_MAP2_TEXTURE_COORD_3: RETVAL = "GL_MAP2_TEXTURE_COORD_3"; break;
      case GL_MAP2_TEXTURE_COORD_4: RETVAL = "GL_MAP2_TEXTURE_COORD_4"; break;
      case GL_MAP2_VERTEX_3: RETVAL = "GL_MAP2_VERTEX_3"; break;
      case GL_MAP2_VERTEX_4: RETVAL = "GL_MAP2_VERTEX_4"; break;
      case GL_MAP_COLOR: RETVAL = "GL_MAP_COLOR"; break;
      case GL_MAP_STENCIL: RETVAL = "GL_MAP_STENCIL"; break;
      case GL_MATRIX_MODE: RETVAL = "GL_MATRIX_MODE"; break;
      case GL_MAX_3D_TEXTURE_SIZE: RETVAL = "GL_MAX_3D_TEXTURE_SIZE"; break;
      case GL_MAX_ARRAY_TEXTURE_LAYERS: RETVAL = "GL_MAX_ARRAY_TEXTURE_LAYERS"; break;
      case GL_MAX_ASYNC_DRAW_PIXELS_SGIX: RETVAL = "GL_MAX_ASYNC_DRAW_PIXELS_SGIX"; break;
      case GL_MAX_ASYNC_HISTOGRAM_SGIX: RETVAL = "GL_MAX_ASYNC_HISTOGRAM_SGIX"; break;
      case GL_MAX_ASYNC_READ_PIXELS_SGIX: RETVAL = "GL_MAX_ASYNC_READ_PIXELS_SGIX"; break;
      case GL_MAX_ASYNC_TEX_IMAGE_SGIX: RETVAL = "GL_MAX_ASYNC_TEX_IMAGE_SGIX"; break;
      case GL_MAX_ATTRIB_STACK_DEPTH: RETVAL = "GL_MAX_ATTRIB_STACK_DEPTH"; break;
      case GL_MAX_CLIENT_ATTRIB_STACK_DEPTH: RETVAL = "GL_MAX_CLIENT_ATTRIB_STACK_DEPTH"; break;
      case GL_MAX_CLIP_PLANES: RETVAL = "GL_MAX_CLIP_PLANES"; break;
      case GL_MAX_COLOR_ATTACHMENTS: RETVAL = "GL_MAX_COLOR_ATTACHMENTS"; break;
      case GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI: RETVAL = "GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI"; break;
      case GL_MAX_COLOR_TEXTURE_SAMPLES: RETVAL = "GL_MAX_COLOR_TEXTURE_SAMPLES"; break;
      case GL_MAX_COMBINED_ATOMIC_COUNTERS: RETVAL = "GL_MAX_COMBINED_ATOMIC_COUNTERS"; break;
      case GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS"; break;
      case GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS"; break;
      case GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS"; break;
      case GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS: RETVAL = "GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS"; break;
      case GL_MAX_COMBINED_UNIFORM_BLOCKS: RETVAL = "GL_MAX_COMBINED_UNIFORM_BLOCKS"; break;
      case GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS"; break;
      case GL_MAX_COMPUTE_ATOMIC_COUNTERS: RETVAL = "GL_MAX_COMPUTE_ATOMIC_COUNTERS"; break;
      case GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS: RETVAL = "GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS"; break;
      case GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS: RETVAL = "GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS"; break;
      case GL_MAX_COMPUTE_UNIFORM_BLOCKS: RETVAL = "GL_MAX_COMPUTE_UNIFORM_BLOCKS"; break;
      case GL_MAX_COMPUTE_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_COMPUTE_UNIFORM_COMPONENTS"; break;
      case GL_MAX_COMPUTE_WORK_GROUP_COUNT: RETVAL = "GL_MAX_COMPUTE_WORK_GROUP_COUNT"; break;
      case GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS: RETVAL = "GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS"; break;
      case GL_MAX_COMPUTE_WORK_GROUP_SIZE: RETVAL = "GL_MAX_COMPUTE_WORK_GROUP_SIZE"; break;
      case GL_MAX_CUBE_MAP_TEXTURE_SIZE: RETVAL = "GL_MAX_CUBE_MAP_TEXTURE_SIZE"; break;
      case GL_MAX_DEBUG_GROUP_STACK_DEPTH: RETVAL = "GL_MAX_DEBUG_GROUP_STACK_DEPTH"; break;
      case GL_MAX_DEPTH_TEXTURE_SAMPLES: RETVAL = "GL_MAX_DEPTH_TEXTURE_SAMPLES"; break;
      case GL_MAX_DRAW_BUFFERS: RETVAL = "GL_MAX_DRAW_BUFFERS"; break;
      case GL_MAX_DUAL_SOURCE_DRAW_BUFFERS: RETVAL = "GL_MAX_DUAL_SOURCE_DRAW_BUFFERS"; break;
      case GL_MAX_ELEMENTS_INDICES: RETVAL = "GL_MAX_ELEMENTS_INDICES"; break;
      case GL_MAX_ELEMENTS_VERTICES: RETVAL = "GL_MAX_ELEMENTS_VERTICES"; break;
      case GL_MAX_ELEMENT_INDEX: RETVAL = "GL_MAX_ELEMENT_INDEX"; break;
      case GL_MAX_EVAL_ORDER: RETVAL = "GL_MAX_EVAL_ORDER"; break;
      case GL_MAX_FRAGMENT_ATOMIC_COUNTERS: RETVAL = "GL_MAX_FRAGMENT_ATOMIC_COUNTERS"; break;
      case GL_MAX_FRAGMENT_INPUT_COMPONENTS: RETVAL = "GL_MAX_FRAGMENT_INPUT_COMPONENTS"; break;
      case GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_LAYERS_EXT: RETVAL = "GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_LAYERS_EXT"; break;
      case GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_ASPECT_RATIO_EXT: RETVAL = "GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_ASPECT_RATIO_EXT"; break;
      case GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT: RETVAL = "GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT"; break;
      case GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT: RETVAL = "GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT"; break;
      case GL_MAX_FRAGMENT_UNIFORM_BLOCKS: RETVAL = "GL_MAX_FRAGMENT_UNIFORM_BLOCKS"; break;
      case GL_MAX_FRAGMENT_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_FRAGMENT_UNIFORM_COMPONENTS"; break;
      case GL_MAX_FRAGMENT_UNIFORM_VECTORS: RETVAL = "GL_MAX_FRAGMENT_UNIFORM_VECTORS"; break;
      case GL_MAX_FRAMEBUFFER_HEIGHT: RETVAL = "GL_MAX_FRAMEBUFFER_HEIGHT"; break;
      case GL_MAX_FRAMEBUFFER_LAYERS: RETVAL = "GL_MAX_FRAMEBUFFER_LAYERS"; break;
      case GL_MAX_FRAMEBUFFER_SAMPLES: RETVAL = "GL_MAX_FRAMEBUFFER_SAMPLES"; break;
      case GL_MAX_FRAMEBUFFER_WIDTH: RETVAL = "GL_MAX_FRAMEBUFFER_WIDTH"; break;
      case GL_MAX_GEOMETRY_ATOMIC_COUNTERS: RETVAL = "GL_MAX_GEOMETRY_ATOMIC_COUNTERS"; break;
      case GL_MAX_GEOMETRY_INPUT_COMPONENTS: RETVAL = "GL_MAX_GEOMETRY_INPUT_COMPONENTS"; break;
      case GL_MAX_GEOMETRY_OUTPUT_COMPONENTS: RETVAL = "GL_MAX_GEOMETRY_OUTPUT_COMPONENTS"; break;
      case GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS: RETVAL = "GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS"; break;
      case GL_MAX_GEOMETRY_UNIFORM_BLOCKS: RETVAL = "GL_MAX_GEOMETRY_UNIFORM_BLOCKS"; break;
      case GL_MAX_GEOMETRY_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_GEOMETRY_UNIFORM_COMPONENTS"; break;
      case GL_MAX_INTEGER_SAMPLES: RETVAL = "GL_MAX_INTEGER_SAMPLES"; break;
      case GL_MAX_LABEL_LENGTH: RETVAL = "GL_MAX_LABEL_LENGTH"; break;
      case GL_MAX_LIGHTS: RETVAL = "GL_MAX_LIGHTS"; break;
      case GL_MAX_LIST_NESTING: RETVAL = "GL_MAX_LIST_NESTING"; break;
      case GL_MAX_MESH_OUTPUT_COMPONENTS_EXT: RETVAL = "GL_MAX_MESH_OUTPUT_COMPONENTS_EXT"; break;
      case GL_MAX_MESH_OUTPUT_LAYERS_EXT: RETVAL = "GL_MAX_MESH_OUTPUT_LAYERS_EXT"; break;
      case GL_MAX_MESH_OUTPUT_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_MESH_OUTPUT_MEMORY_SIZE_EXT"; break;
      case GL_MAX_MESH_OUTPUT_PRIMITIVES_EXT: RETVAL = "GL_MAX_MESH_OUTPUT_PRIMITIVES_EXT"; break;
      case GL_MAX_MESH_PAYLOAD_AND_OUTPUT_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_MESH_PAYLOAD_AND_OUTPUT_MEMORY_SIZE_EXT"; break;
      case GL_MAX_MESH_PAYLOAD_AND_SHARED_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_MESH_PAYLOAD_AND_SHARED_MEMORY_SIZE_EXT"; break;
      case GL_MAX_MESH_SHARED_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_MESH_SHARED_MEMORY_SIZE_EXT"; break;
      case GL_MAX_MESH_WORK_GROUP_COUNT_EXT: RETVAL = "GL_MAX_MESH_WORK_GROUP_COUNT_EXT"; break;
      case GL_MAX_MESH_WORK_GROUP_INVOCATIONS_EXT: RETVAL = "GL_MAX_MESH_WORK_GROUP_INVOCATIONS_EXT"; break;
      case GL_MAX_MESH_WORK_GROUP_SIZE_EXT: RETVAL = "GL_MAX_MESH_WORK_GROUP_SIZE_EXT"; break;
      case GL_MAX_MESH_WORK_GROUP_TOTAL_COUNT_EXT: RETVAL = "GL_MAX_MESH_WORK_GROUP_TOTAL_COUNT_EXT"; break;
      case GL_MAX_MODELVIEW_STACK_DEPTH: RETVAL = "GL_MAX_MODELVIEW_STACK_DEPTH"; break;
      case GL_MAX_NAME_STACK_DEPTH: RETVAL = "GL_MAX_NAME_STACK_DEPTH"; break;
      case GL_MAX_PIXEL_MAP_TABLE: RETVAL = "GL_MAX_PIXEL_MAP_TABLE"; break;
      case GL_MAX_PREFERRED_MESH_WORK_GROUP_INVOCATIONS_EXT: RETVAL = "GL_MAX_PREFERRED_MESH_WORK_GROUP_INVOCATIONS_EXT"; break;
      case GL_MAX_PREFERRED_TASK_WORK_GROUP_INVOCATIONS_EXT: RETVAL = "GL_MAX_PREFERRED_TASK_WORK_GROUP_INVOCATIONS_EXT"; break;
      case GL_MAX_PROGRAM_TEXEL_OFFSET: RETVAL = "GL_MAX_PROGRAM_TEXEL_OFFSET"; break;
      case GL_MAX_PROJECTION_STACK_DEPTH: RETVAL = "GL_MAX_PROJECTION_STACK_DEPTH"; break;
      case GL_MAX_RECTANGLE_TEXTURE_SIZE: RETVAL = "GL_MAX_RECTANGLE_TEXTURE_SIZE"; break;
      case GL_MAX_RENDERBUFFER_SIZE: RETVAL = "GL_MAX_RENDERBUFFER_SIZE"; break;
      case GL_MAX_SAMPLE_MASK_WORDS: RETVAL = "GL_MAX_SAMPLE_MASK_WORDS"; break;
      case GL_MAX_SERVER_WAIT_TIMEOUT: RETVAL = "GL_MAX_SERVER_WAIT_TIMEOUT"; break;
      case GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS: RETVAL = "GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS"; break;
      case GL_MAX_TASK_PAYLOAD_AND_SHARED_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_TASK_PAYLOAD_AND_SHARED_MEMORY_SIZE_EXT"; break;
      case GL_MAX_TASK_PAYLOAD_SIZE_EXT: RETVAL = "GL_MAX_TASK_PAYLOAD_SIZE_EXT"; break;
      case GL_MAX_TASK_SHARED_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_TASK_SHARED_MEMORY_SIZE_EXT"; break;
      case GL_MAX_TASK_WORK_GROUP_COUNT_EXT: RETVAL = "GL_MAX_TASK_WORK_GROUP_COUNT_EXT"; break;
      case GL_MAX_TASK_WORK_GROUP_INVOCATIONS_EXT: RETVAL = "GL_MAX_TASK_WORK_GROUP_INVOCATIONS_EXT"; break;
      case GL_MAX_TASK_WORK_GROUP_SIZE_EXT: RETVAL = "GL_MAX_TASK_WORK_GROUP_SIZE_EXT"; break;
      case GL_MAX_TASK_WORK_GROUP_TOTAL_COUNT_EXT: RETVAL = "GL_MAX_TASK_WORK_GROUP_TOTAL_COUNT_EXT"; break;
      case GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS: RETVAL = "GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS"; break;
      case GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS: RETVAL = "GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS"; break;
      case GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS: RETVAL = "GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS"; break;
      case GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS: RETVAL = "GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS"; break;
      case GL_MAX_TEXTURE_BUFFER_SIZE: RETVAL = "GL_MAX_TEXTURE_BUFFER_SIZE"; break;
      case GL_MAX_TEXTURE_IMAGE_UNITS: RETVAL = "GL_MAX_TEXTURE_IMAGE_UNITS"; break;
      case GL_MAX_TEXTURE_LOD_BIAS: RETVAL = "GL_MAX_TEXTURE_LOD_BIAS"; break;
      case GL_MAX_TEXTURE_SIZE: RETVAL = "GL_MAX_TEXTURE_SIZE"; break;
      case GL_MAX_TEXTURE_STACK_DEPTH: RETVAL = "GL_MAX_TEXTURE_STACK_DEPTH"; break;
      case GL_MAX_TIMELINE_SEMAPHORE_VALUE_DIFFERENCE_NV: RETVAL = "GL_MAX_TIMELINE_SEMAPHORE_VALUE_DIFFERENCE_NV"; break;
      case GL_MAX_UNIFORM_BLOCK_SIZE: RETVAL = "GL_MAX_UNIFORM_BLOCK_SIZE"; break;
      case GL_MAX_UNIFORM_BUFFER_BINDINGS: RETVAL = "GL_MAX_UNIFORM_BUFFER_BINDINGS"; break;
      case GL_MAX_UNIFORM_LOCATIONS: RETVAL = "GL_MAX_UNIFORM_LOCATIONS"; break;
      case GL_MAX_VARYING_FLOATS: RETVAL = "GL_MAX_VARYING_FLOATS"; break;
      case GL_MAX_VARYING_VECTORS: RETVAL = "GL_MAX_VARYING_VECTORS"; break;
      case GL_MAX_VERTEX_ATOMIC_COUNTERS: RETVAL = "GL_MAX_VERTEX_ATOMIC_COUNTERS"; break;
      case GL_MAX_VERTEX_ATTRIBS: RETVAL = "GL_MAX_VERTEX_ATTRIBS"; break;
      case GL_MAX_VERTEX_ATTRIB_BINDINGS: RETVAL = "GL_MAX_VERTEX_ATTRIB_BINDINGS"; break;
      case GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET: RETVAL = "GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET"; break;
      case GL_MAX_VERTEX_OUTPUT_COMPONENTS: RETVAL = "GL_MAX_VERTEX_OUTPUT_COMPONENTS"; break;
      case GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS: RETVAL = "GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS"; break;
      case GL_MAX_VERTEX_UNIFORM_BLOCKS: RETVAL = "GL_MAX_VERTEX_UNIFORM_BLOCKS"; break;
      case GL_MAX_VERTEX_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_VERTEX_UNIFORM_COMPONENTS"; break;
      case GL_MAX_VERTEX_UNIFORM_VECTORS: RETVAL = "GL_MAX_VERTEX_UNIFORM_VECTORS"; break;
      case GL_MAX_VIEWPORTS: RETVAL = "GL_MAX_VIEWPORTS"; break;
      case GL_MAX_VIEWPORT_DIMS: RETVAL = "GL_MAX_VIEWPORT_DIMS"; break;
      case GL_MESH_PREFERS_COMPACT_PRIMITIVE_OUTPUT_EXT: RETVAL = "GL_MESH_PREFERS_COMPACT_PRIMITIVE_OUTPUT_EXT"; break;
      case GL_MESH_PREFERS_COMPACT_VERTEX_OUTPUT_EXT: RETVAL = "GL_MESH_PREFERS_COMPACT_VERTEX_OUTPUT_EXT"; break;
      case GL_MESH_PREFERS_LOCAL_INVOCATION_PRIMITIVE_OUTPUT_EXT: RETVAL = "GL_MESH_PREFERS_LOCAL_INVOCATION_PRIMITIVE_OUTPUT_EXT"; break;
      case GL_MESH_PREFERS_LOCAL_INVOCATION_VERTEX_OUTPUT_EXT: RETVAL = "GL_MESH_PREFERS_LOCAL_INVOCATION_VERTEX_OUTPUT_EXT"; break;
      case GL_MINMAX_EXT: RETVAL = "GL_MINMAX_EXT"; break;
      case GL_MINOR_VERSION: RETVAL = "GL_MINOR_VERSION"; break;
      case GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT: RETVAL = "GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT"; break;
      case GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT: RETVAL = "GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT"; break;
      case GL_MIN_MAP_BUFFER_ALIGNMENT: RETVAL = "GL_MIN_MAP_BUFFER_ALIGNMENT"; break;
      case GL_MIN_PROGRAM_TEXEL_OFFSET: RETVAL = "GL_MIN_PROGRAM_TEXEL_OFFSET"; break;
      case GL_MODELVIEW_MATRIX: RETVAL = "GL_MODELVIEW_MATRIX"; break;
      case GL_MODELVIEW_STACK_DEPTH: RETVAL = "GL_MODELVIEW_STACK_DEPTH"; break;
      case GL_MOTION_ESTIMATION_SEARCH_BLOCK_X_QCOM: RETVAL = "GL_MOTION_ESTIMATION_SEARCH_BLOCK_X_QCOM"; break;
      case GL_MOTION_ESTIMATION_SEARCH_BLOCK_Y_QCOM: RETVAL = "GL_MOTION_ESTIMATION_SEARCH_BLOCK_Y_QCOM"; break;
      case GL_MULTISAMPLE_SGIS: RETVAL = "GL_MULTISAMPLE_SGIS"; break;
      case GL_NAME_STACK_DEPTH: RETVAL = "GL_NAME_STACK_DEPTH"; break;
      case GL_NORMALIZE: RETVAL = "GL_NORMALIZE"; break;
      case GL_NORMAL_ARRAY: RETVAL = "GL_NORMAL_ARRAY"; break;
      case GL_NORMAL_ARRAY_COUNT_EXT: RETVAL = "GL_NORMAL_ARRAY_COUNT_EXT"; break;
      case GL_NORMAL_ARRAY_STRIDE: RETVAL = "GL_NORMAL_ARRAY_STRIDE"; break;
      case GL_NORMAL_ARRAY_TYPE: RETVAL = "GL_NORMAL_ARRAY_TYPE"; break;
      case GL_NUM_COMPRESSED_TEXTURE_FORMATS: RETVAL = "GL_NUM_COMPRESSED_TEXTURE_FORMATS"; break;
      case GL_NUM_DEVICE_UUIDS_EXT: RETVAL = "GL_NUM_DEVICE_UUIDS_EXT"; break;
      case GL_NUM_EXTENSIONS: RETVAL = "GL_NUM_EXTENSIONS"; break;
      case GL_NUM_PROGRAM_BINARY_FORMATS: RETVAL = "GL_NUM_PROGRAM_BINARY_FORMATS"; break;
      case GL_NUM_SHADER_BINARY_FORMATS: RETVAL = "GL_NUM_SHADER_BINARY_FORMATS"; break;
      case GL_PACK_ALIGNMENT: RETVAL = "GL_PACK_ALIGNMENT"; break;
      case GL_PACK_CMYK_HINT_EXT: RETVAL = "GL_PACK_CMYK_HINT_EXT"; break;
      case GL_PACK_IMAGE_HEIGHT: RETVAL = "GL_PACK_IMAGE_HEIGHT"; break;
      case GL_PACK_LSB_FIRST: RETVAL = "GL_PACK_LSB_FIRST"; break;
      case GL_PACK_RESAMPLE_SGIX: RETVAL = "GL_PACK_RESAMPLE_SGIX"; break;
      case GL_PACK_ROW_LENGTH: RETVAL = "GL_PACK_ROW_LENGTH"; break;
      case GL_PACK_SKIP_IMAGES: RETVAL = "GL_PACK_SKIP_IMAGES"; break;
      case GL_PACK_SKIP_PIXELS: RETVAL = "GL_PACK_SKIP_PIXELS"; break;
      case GL_PACK_SKIP_ROWS: RETVAL = "GL_PACK_SKIP_ROWS"; break;
      case GL_PACK_SUBSAMPLE_RATE_SGIX: RETVAL = "GL_PACK_SUBSAMPLE_RATE_SGIX"; break;
      case GL_PACK_SWAP_BYTES: RETVAL = "GL_PACK_SWAP_BYTES"; break;
      case GL_PERSPECTIVE_CORRECTION_HINT: RETVAL = "GL_PERSPECTIVE_CORRECTION_HINT"; break;
      case GL_PIXEL_MAP_A_TO_A_SIZE: RETVAL = "GL_PIXEL_MAP_A_TO_A_SIZE"; break;
      case GL_PIXEL_MAP_B_TO_B_SIZE: RETVAL = "GL_PIXEL_MAP_B_TO_B_SIZE"; break;
      case GL_PIXEL_MAP_G_TO_G_SIZE: RETVAL = "GL_PIXEL_MAP_G_TO_G_SIZE"; break;
      case GL_PIXEL_MAP_I_TO_A_SIZE: RETVAL = "GL_PIXEL_MAP_I_TO_A_SIZE"; break;
      case GL_PIXEL_MAP_I_TO_B_SIZE: RETVAL = "GL_PIXEL_MAP_I_TO_B_SIZE"; break;
      case GL_PIXEL_MAP_I_TO_G_SIZE: RETVAL = "GL_PIXEL_MAP_I_TO_G_SIZE"; break;
      case GL_PIXEL_MAP_I_TO_I_SIZE: RETVAL = "GL_PIXEL_MAP_I_TO_I_SIZE"; break;
      case GL_PIXEL_MAP_I_TO_R_SIZE: RETVAL = "GL_PIXEL_MAP_I_TO_R_SIZE"; break;
      case GL_PIXEL_MAP_R_TO_R_SIZE: RETVAL = "GL_PIXEL_MAP_R_TO_R_SIZE"; break;
      case GL_PIXEL_MAP_S_TO_S_SIZE: RETVAL = "GL_PIXEL_MAP_S_TO_S_SIZE"; break;
      case GL_PIXEL_PACK_BUFFER_BINDING: RETVAL = "GL_PIXEL_PACK_BUFFER_BINDING"; break;
      case GL_PIXEL_UNPACK_BUFFER_BINDING: RETVAL = "GL_PIXEL_UNPACK_BUFFER_BINDING"; break;
      case GL_POINT_FADE_THRESHOLD_SIZE: RETVAL = "GL_POINT_FADE_THRESHOLD_SIZE"; break;
      case GL_POINT_SIZE: RETVAL = "GL_POINT_SIZE"; break;
      case GL_POINT_SIZE_GRANULARITY: RETVAL = "GL_POINT_SIZE_GRANULARITY"; break;
      case GL_POINT_SIZE_MAX: RETVAL = "GL_POINT_SIZE_MAX"; break;
      case GL_POINT_SIZE_MIN: RETVAL = "GL_POINT_SIZE_MIN"; break;
      case GL_POINT_SIZE_RANGE: RETVAL = "GL_POINT_SIZE_RANGE"; break;
      case GL_POINT_SMOOTH: RETVAL = "GL_POINT_SMOOTH"; break;
      case GL_POINT_SMOOTH_HINT: RETVAL = "GL_POINT_SMOOTH_HINT"; break;
      case GL_POLYGON_MODE: RETVAL = "GL_POLYGON_MODE"; break;
      case GL_POLYGON_OFFSET_BIAS_EXT: RETVAL = "GL_POLYGON_OFFSET_BIAS_EXT"; break;
      case GL_POLYGON_OFFSET_FACTOR: RETVAL = "GL_POLYGON_OFFSET_FACTOR"; break;
      case GL_POLYGON_OFFSET_FILL: RETVAL = "GL_POLYGON_OFFSET_FILL"; break;
      case GL_POLYGON_OFFSET_LINE: RETVAL = "GL_POLYGON_OFFSET_LINE"; break;
      case GL_POLYGON_OFFSET_POINT: RETVAL = "GL_POLYGON_OFFSET_POINT"; break;
      case GL_POLYGON_OFFSET_UNITS: RETVAL = "GL_POLYGON_OFFSET_UNITS"; break;
      case GL_POLYGON_SMOOTH: RETVAL = "GL_POLYGON_SMOOTH"; break;
      case GL_POLYGON_SMOOTH_HINT: RETVAL = "GL_POLYGON_SMOOTH_HINT"; break;
      case GL_POLYGON_STIPPLE: RETVAL = "GL_POLYGON_STIPPLE"; break;
      case GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI: RETVAL = "GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI"; break;
      case GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI: RETVAL = "GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI"; break;
      case GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI: RETVAL = "GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI"; break;
      case GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI: RETVAL = "GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI"; break;
      case GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI: RETVAL = "GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI"; break;
      case GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI: RETVAL = "GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI"; break;
      case GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI: RETVAL = "GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI"; break;
      case GL_POST_COLOR_MATRIX_RED_BIAS_SGI: RETVAL = "GL_POST_COLOR_MATRIX_RED_BIAS_SGI"; break;
      case GL_POST_COLOR_MATRIX_RED_SCALE_SGI: RETVAL = "GL_POST_COLOR_MATRIX_RED_SCALE_SGI"; break;
      case GL_POST_CONVOLUTION_ALPHA_BIAS_EXT: RETVAL = "GL_POST_CONVOLUTION_ALPHA_BIAS_EXT"; break;
      case GL_POST_CONVOLUTION_ALPHA_SCALE_EXT: RETVAL = "GL_POST_CONVOLUTION_ALPHA_SCALE_EXT"; break;
      case GL_POST_CONVOLUTION_BLUE_BIAS_EXT: RETVAL = "GL_POST_CONVOLUTION_BLUE_BIAS_EXT"; break;
      case GL_POST_CONVOLUTION_BLUE_SCALE_EXT: RETVAL = "GL_POST_CONVOLUTION_BLUE_SCALE_EXT"; break;
      case GL_POST_CONVOLUTION_COLOR_TABLE_SGI: RETVAL = "GL_POST_CONVOLUTION_COLOR_TABLE_SGI"; break;
      case GL_POST_CONVOLUTION_GREEN_BIAS_EXT: RETVAL = "GL_POST_CONVOLUTION_GREEN_BIAS_EXT"; break;
      case GL_POST_CONVOLUTION_GREEN_SCALE_EXT: RETVAL = "GL_POST_CONVOLUTION_GREEN_SCALE_EXT"; break;
      case GL_POST_CONVOLUTION_RED_BIAS_EXT: RETVAL = "GL_POST_CONVOLUTION_RED_BIAS_EXT"; break;
      case GL_POST_CONVOLUTION_RED_SCALE_EXT: RETVAL = "GL_POST_CONVOLUTION_RED_SCALE_EXT"; break;
      case GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX"; break;
      case GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX"; break;
      case GL_PRIMITIVE_RESTART_INDEX: RETVAL = "GL_PRIMITIVE_RESTART_INDEX"; break;
      case GL_PROGRAM_BINARY_FORMATS: RETVAL = "GL_PROGRAM_BINARY_FORMATS"; break;
      case GL_PROGRAM_PIPELINE_BINDING: RETVAL = "GL_PROGRAM_PIPELINE_BINDING"; break;
      case GL_PROGRAM_POINT_SIZE: RETVAL = "GL_PROGRAM_POINT_SIZE"; break;
      case GL_PROJECTION_MATRIX: RETVAL = "GL_PROJECTION_MATRIX"; break;
      case GL_PROJECTION_STACK_DEPTH: RETVAL = "GL_PROJECTION_STACK_DEPTH"; break;
      case GL_PROVOKING_VERTEX: RETVAL = "GL_PROVOKING_VERTEX"; break;
      case GL_READ_BUFFER: RETVAL = "GL_READ_BUFFER"; break;
      case GL_READ_FRAMEBUFFER_BINDING: RETVAL = "GL_READ_FRAMEBUFFER_BINDING"; break;
      case GL_RED_BIAS: RETVAL = "GL_RED_BIAS"; break;
      case GL_RED_BITS: RETVAL = "GL_RED_BITS"; break;
      case GL_RED_SCALE: RETVAL = "GL_RED_SCALE"; break;
      case GL_RENDERBUFFER_BINDING: RETVAL = "GL_RENDERBUFFER_BINDING"; break;
      case GL_RENDER_MODE: RETVAL = "GL_RENDER_MODE"; break;
      case GL_RESCALE_NORMAL_EXT: RETVAL = "GL_RESCALE_NORMAL_EXT"; break;
      case GL_RGBA_MODE: RETVAL = "GL_RGBA_MODE"; break;
      case GL_SAMPLER_BINDING: RETVAL = "GL_SAMPLER_BINDING"; break;
      case GL_SAMPLES: RETVAL = "GL_SAMPLES"; break;
      case GL_SAMPLE_ALPHA_TO_MASK_SGIS: RETVAL = "GL_SAMPLE_ALPHA_TO_MASK_SGIS"; break;
      case GL_SAMPLE_ALPHA_TO_ONE_SGIS: RETVAL = "GL_SAMPLE_ALPHA_TO_ONE_SGIS"; break;
      case GL_SAMPLE_BUFFERS: RETVAL = "GL_SAMPLE_BUFFERS"; break;
      case GL_SAMPLE_COVERAGE_INVERT: RETVAL = "GL_SAMPLE_COVERAGE_INVERT"; break;
      case GL_SAMPLE_COVERAGE_VALUE: RETVAL = "GL_SAMPLE_COVERAGE_VALUE"; break;
      case GL_SAMPLE_MASK_SGIS: RETVAL = "GL_SAMPLE_MASK_SGIS"; break;
      case GL_SAMPLE_PATTERN_SGIS: RETVAL = "GL_SAMPLE_PATTERN_SGIS"; break;
      case GL_SCISSOR_BOX: RETVAL = "GL_SCISSOR_BOX"; break;
      case GL_SCISSOR_TEST: RETVAL = "GL_SCISSOR_TEST"; break;
      case GL_SELECTION_BUFFER_SIZE: RETVAL = "GL_SELECTION_BUFFER_SIZE"; break;
      case GL_SEPARABLE_2D_EXT: RETVAL = "GL_SEPARABLE_2D_EXT"; break;
      case GL_SHADER_BINARY_FORMATS: RETVAL = "GL_SHADER_BINARY_FORMATS"; break;
      case GL_SHADER_COMPILER: RETVAL = "GL_SHADER_COMPILER"; break;
      case GL_SHADER_CORE_ACTIVE_COUNT_ARM: RETVAL = "GL_SHADER_CORE_ACTIVE_COUNT_ARM"; break;
      case GL_SHADER_CORE_COUNT_ARM: RETVAL = "GL_SHADER_CORE_COUNT_ARM"; break;
      case GL_SHADER_CORE_FMA_RATE_ARM: RETVAL = "GL_SHADER_CORE_FMA_RATE_ARM"; break;
      case GL_SHADER_CORE_MAX_WARP_COUNT_ARM: RETVAL = "GL_SHADER_CORE_MAX_WARP_COUNT_ARM"; break;
      case GL_SHADER_CORE_PIXEL_RATE_ARM: RETVAL = "GL_SHADER_CORE_PIXEL_RATE_ARM"; break;
      case GL_SHADER_CORE_PRESENT_MASK_ARM: RETVAL = "GL_SHADER_CORE_PRESENT_MASK_ARM"; break;
      case GL_SHADER_CORE_TEXEL_RATE_ARM: RETVAL = "GL_SHADER_CORE_TEXEL_RATE_ARM"; break;
      case GL_SHADER_STORAGE_BUFFER_BINDING: RETVAL = "GL_SHADER_STORAGE_BUFFER_BINDING"; break;
      case GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT: RETVAL = "GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT"; break;
      case GL_SHADER_STORAGE_BUFFER_SIZE: RETVAL = "GL_SHADER_STORAGE_BUFFER_SIZE"; break;
      case GL_SHADER_STORAGE_BUFFER_START: RETVAL = "GL_SHADER_STORAGE_BUFFER_START"; break;
      case GL_SHADE_MODEL: RETVAL = "GL_SHADE_MODEL"; break;
      case GL_SHADING_RATE_EXT: RETVAL = "GL_SHADING_RATE_EXT"; break;
      case GL_SHADING_RATE_IMAGE_PALETTE_COUNT_NV: RETVAL = "GL_SHADING_RATE_IMAGE_PALETTE_COUNT_NV"; break;
      case GL_SHADING_RATE_IMAGE_PER_PRIMITIVE_NV: RETVAL = "GL_SHADING_RATE_IMAGE_PER_PRIMITIVE_NV"; break;
      case GL_SHADING_RATE_QCOM: RETVAL = "GL_SHADING_RATE_QCOM"; break;
      case GL_SHARED_TEXTURE_PALETTE_EXT: RETVAL = "GL_SHARED_TEXTURE_PALETTE_EXT"; break;
      case GL_STENCIL_BACK_FAIL: RETVAL = "GL_STENCIL_BACK_FAIL"; break;
      case GL_STENCIL_BACK_FUNC: RETVAL = "GL_STENCIL_BACK_FUNC"; break;
      case GL_STENCIL_BACK_PASS_DEPTH_FAIL: RETVAL = "GL_STENCIL_BACK_PASS_DEPTH_FAIL"; break;
      case GL_STENCIL_BACK_PASS_DEPTH_PASS: RETVAL = "GL_STENCIL_BACK_PASS_DEPTH_PASS"; break;
      case GL_STENCIL_BACK_REF: RETVAL = "GL_STENCIL_BACK_REF"; break;
      case GL_STENCIL_BACK_VALUE_MASK: RETVAL = "GL_STENCIL_BACK_VALUE_MASK"; break;
      case GL_STENCIL_BACK_WRITEMASK: RETVAL = "GL_STENCIL_BACK_WRITEMASK"; break;
      case GL_STENCIL_BITS: RETVAL = "GL_STENCIL_BITS"; break;
      case GL_STENCIL_CLEAR_VALUE: RETVAL = "GL_STENCIL_CLEAR_VALUE"; break;
      case GL_STENCIL_FAIL: RETVAL = "GL_STENCIL_FAIL"; break;
      case GL_STENCIL_FUNC: RETVAL = "GL_STENCIL_FUNC"; break;
      case GL_STENCIL_PASS_DEPTH_FAIL: RETVAL = "GL_STENCIL_PASS_DEPTH_FAIL"; break;
      case GL_STENCIL_PASS_DEPTH_PASS: RETVAL = "GL_STENCIL_PASS_DEPTH_PASS"; break;
      case GL_STENCIL_REF: RETVAL = "GL_STENCIL_REF"; break;
      case GL_STENCIL_TEST: RETVAL = "GL_STENCIL_TEST"; break;
      case GL_STENCIL_VALUE_MASK: RETVAL = "GL_STENCIL_VALUE_MASK"; break;
      case GL_STENCIL_WRITEMASK: RETVAL = "GL_STENCIL_WRITEMASK"; break;
      case GL_STEREO: RETVAL = "GL_STEREO"; break;
      case GL_SUBPIXEL_BITS: RETVAL = "GL_SUBPIXEL_BITS"; break;
      case GL_TEXTURE_1D: RETVAL = "GL_TEXTURE_1D"; break;
      case GL_TEXTURE_2D: RETVAL = "GL_TEXTURE_2D"; break;
      case GL_TEXTURE_3D_EXT: RETVAL = "GL_TEXTURE_3D_EXT"; break;
      case GL_TEXTURE_BINDING_1D: RETVAL = "GL_TEXTURE_BINDING_1D"; break;
      case GL_TEXTURE_BINDING_1D_ARRAY: RETVAL = "GL_TEXTURE_BINDING_1D_ARRAY"; break;
      case GL_TEXTURE_BINDING_2D: RETVAL = "GL_TEXTURE_BINDING_2D"; break;
      case GL_TEXTURE_BINDING_2D_ARRAY: RETVAL = "GL_TEXTURE_BINDING_2D_ARRAY"; break;
      case GL_TEXTURE_BINDING_2D_MULTISAMPLE: RETVAL = "GL_TEXTURE_BINDING_2D_MULTISAMPLE"; break;
      case GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY"; break;
      case GL_TEXTURE_BINDING_3D: RETVAL = "GL_TEXTURE_BINDING_3D"; break;
      case GL_TEXTURE_BINDING_BUFFER: RETVAL = "GL_TEXTURE_BINDING_BUFFER"; break;
      case GL_TEXTURE_BINDING_CUBE_MAP: RETVAL = "GL_TEXTURE_BINDING_CUBE_MAP"; break;
      case GL_TEXTURE_BINDING_RECTANGLE: RETVAL = "GL_TEXTURE_BINDING_RECTANGLE"; break;
      case GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT: RETVAL = "GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT"; break;
      case GL_TEXTURE_COLOR_TABLE_SGI: RETVAL = "GL_TEXTURE_COLOR_TABLE_SGI"; break;
      case GL_TEXTURE_COMPRESSION_HINT: RETVAL = "GL_TEXTURE_COMPRESSION_HINT"; break;
      case GL_TEXTURE_COORD_ARRAY: RETVAL = "GL_TEXTURE_COORD_ARRAY"; break;
      case GL_TEXTURE_COORD_ARRAY_COUNT_EXT: RETVAL = "GL_TEXTURE_COORD_ARRAY_COUNT_EXT"; break;
      case GL_TEXTURE_COORD_ARRAY_SIZE: RETVAL = "GL_TEXTURE_COORD_ARRAY_SIZE"; break;
      case GL_TEXTURE_COORD_ARRAY_STRIDE: RETVAL = "GL_TEXTURE_COORD_ARRAY_STRIDE"; break;
      case GL_TEXTURE_COORD_ARRAY_TYPE: RETVAL = "GL_TEXTURE_COORD_ARRAY_TYPE"; break;
      case GL_TEXTURE_GEN_Q: RETVAL = "GL_TEXTURE_GEN_Q"; break;
      case GL_TEXTURE_GEN_R: RETVAL = "GL_TEXTURE_GEN_R"; break;
      case GL_TEXTURE_GEN_S: RETVAL = "GL_TEXTURE_GEN_S"; break;
      case GL_TEXTURE_GEN_T: RETVAL = "GL_TEXTURE_GEN_T"; break;
      case GL_TEXTURE_MATRIX: RETVAL = "GL_TEXTURE_MATRIX"; break;
      case GL_TEXTURE_STACK_DEPTH: RETVAL = "GL_TEXTURE_STACK_DEPTH"; break;
      case GL_TIMESTAMP: RETVAL = "GL_TIMESTAMP"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_BINDING: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_BINDING"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_SIZE: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_SIZE"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_START: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_START"; break;
      case GL_UNIFORM_BUFFER_BINDING: RETVAL = "GL_UNIFORM_BUFFER_BINDING"; break;
      case GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT: RETVAL = "GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT"; break;
      case GL_UNIFORM_BUFFER_SIZE: RETVAL = "GL_UNIFORM_BUFFER_SIZE"; break;
      case GL_UNIFORM_BUFFER_START: RETVAL = "GL_UNIFORM_BUFFER_START"; break;
      case GL_UNPACK_ALIGNMENT: RETVAL = "GL_UNPACK_ALIGNMENT"; break;
      case GL_UNPACK_CMYK_HINT_EXT: RETVAL = "GL_UNPACK_CMYK_HINT_EXT"; break;
      case GL_UNPACK_IMAGE_HEIGHT: RETVAL = "GL_UNPACK_IMAGE_HEIGHT"; break;
      case GL_UNPACK_LSB_FIRST: RETVAL = "GL_UNPACK_LSB_FIRST"; break;
      case GL_UNPACK_RESAMPLE_SGIX: RETVAL = "GL_UNPACK_RESAMPLE_SGIX"; break;
      case GL_UNPACK_ROW_LENGTH: RETVAL = "GL_UNPACK_ROW_LENGTH"; break;
      case GL_UNPACK_SKIP_IMAGES: RETVAL = "GL_UNPACK_SKIP_IMAGES"; break;
      case GL_UNPACK_SKIP_PIXELS: RETVAL = "GL_UNPACK_SKIP_PIXELS"; break;
      case GL_UNPACK_SKIP_ROWS: RETVAL = "GL_UNPACK_SKIP_ROWS"; break;
      case GL_UNPACK_SUBSAMPLE_RATE_SGIX: RETVAL = "GL_UNPACK_SUBSAMPLE_RATE_SGIX"; break;
      case GL_UNPACK_SWAP_BYTES: RETVAL = "GL_UNPACK_SWAP_BYTES"; break;
      case GL_VERTEX_ARRAY: RETVAL = "GL_VERTEX_ARRAY"; break;
      case GL_VERTEX_ARRAY_BINDING: RETVAL = "GL_VERTEX_ARRAY_BINDING"; break;
      case GL_VERTEX_ARRAY_COUNT_EXT: RETVAL = "GL_VERTEX_ARRAY_COUNT_EXT"; break;
      case GL_VERTEX_ARRAY_SIZE: RETVAL = "GL_VERTEX_ARRAY_SIZE"; break;
      case GL_VERTEX_ARRAY_STRIDE: RETVAL = "GL_VERTEX_ARRAY_STRIDE"; break;
      case GL_VERTEX_ARRAY_TYPE: RETVAL = "GL_VERTEX_ARRAY_TYPE"; break;
      case GL_VERTEX_BINDING_DIVISOR: RETVAL = "GL_VERTEX_BINDING_DIVISOR"; break;
      case GL_VERTEX_BINDING_OFFSET: RETVAL = "GL_VERTEX_BINDING_OFFSET"; break;
      case GL_VERTEX_BINDING_STRIDE: RETVAL = "GL_VERTEX_BINDING_STRIDE"; break;
      case GL_VERTEX_PRECLIP_HINT_SGIX: RETVAL = "GL_VERTEX_PRECLIP_HINT_SGIX"; break;
      case GL_VERTEX_PRECLIP_SGIX: RETVAL = "GL_VERTEX_PRECLIP_SGIX"; break;
      case GL_VIEWPORT: RETVAL = "GL_VIEWPORT"; break;
      case GL_VIEWPORT_BOUNDS_RANGE: RETVAL = "GL_VIEWPORT_BOUNDS_RANGE"; break;
      case GL_VIEWPORT_INDEX_PROVOKING_VERTEX: RETVAL = "GL_VIEWPORT_INDEX_PROVOKING_VERTEX"; break;
      case GL_VIEWPORT_SUBPIXEL_BITS: RETVAL = "GL_VIEWPORT_SUBPIXEL_BITS"; break;
      case GL_ZOOM_X: RETVAL = "GL_ZOOM_X"; break;
      case GL_ZOOM_Y: RETVAL = "GL_ZOOM_Y"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetPointervPName")) {
    switch (e) {
      case GL_COLOR_ARRAY_POINTER: RETVAL = "GL_COLOR_ARRAY_POINTER"; break;
      case GL_DEBUG_CALLBACK_FUNCTION: RETVAL = "GL_DEBUG_CALLBACK_FUNCTION"; break;
      case GL_DEBUG_CALLBACK_USER_PARAM: RETVAL = "GL_DEBUG_CALLBACK_USER_PARAM"; break;
      case GL_EDGE_FLAG_ARRAY_POINTER: RETVAL = "GL_EDGE_FLAG_ARRAY_POINTER"; break;
      case GL_FEEDBACK_BUFFER_POINTER: RETVAL = "GL_FEEDBACK_BUFFER_POINTER"; break;
      case GL_INDEX_ARRAY_POINTER: RETVAL = "GL_INDEX_ARRAY_POINTER"; break;
      case GL_NORMAL_ARRAY_POINTER: RETVAL = "GL_NORMAL_ARRAY_POINTER"; break;
      case GL_SELECTION_BUFFER_POINTER: RETVAL = "GL_SELECTION_BUFFER_POINTER"; break;
      case GL_TEXTURE_COORD_ARRAY_POINTER: RETVAL = "GL_TEXTURE_COORD_ARRAY_POINTER"; break;
      case GL_VERTEX_ARRAY_POINTER: RETVAL = "GL_VERTEX_ARRAY_POINTER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetTexBumpParameterATI")) {
    switch (e) {
      case GL_BUMP_NUM_TEX_UNITS_ATI: RETVAL = "GL_BUMP_NUM_TEX_UNITS_ATI"; break;
      case GL_BUMP_ROT_MATRIX_ATI: RETVAL = "GL_BUMP_ROT_MATRIX_ATI"; break;
      case GL_BUMP_ROT_MATRIX_SIZE_ATI: RETVAL = "GL_BUMP_ROT_MATRIX_SIZE_ATI"; break;
      case GL_BUMP_TEX_UNITS_ATI: RETVAL = "GL_BUMP_TEX_UNITS_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetTextureParameter")) {
    switch (e) {
      case GL_GENERATE_MIPMAP_SGIS: RETVAL = "GL_GENERATE_MIPMAP_SGIS"; break;
      case GL_NORMAL_MAP: RETVAL = "GL_NORMAL_MAP"; break;
      case GL_POST_TEXTURE_FILTER_BIAS_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_BIAS_SGIX"; break;
      case GL_POST_TEXTURE_FILTER_SCALE_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_SCALE_SGIX"; break;
      case GL_REFLECTION_MAP: RETVAL = "GL_REFLECTION_MAP"; break;
      case GL_SHADOW_AMBIENT_SGIX: RETVAL = "GL_SHADOW_AMBIENT_SGIX"; break;
      case GL_SURFACE_COMPRESSION_EXT: RETVAL = "GL_SURFACE_COMPRESSION_EXT"; break;
      case GL_TEXTURE_ALPHA_SIZE: RETVAL = "GL_TEXTURE_ALPHA_SIZE"; break;
      case GL_TEXTURE_BASE_LEVEL_SGIS: RETVAL = "GL_TEXTURE_BASE_LEVEL_SGIS"; break;
      case GL_TEXTURE_BLUE_SIZE: RETVAL = "GL_TEXTURE_BLUE_SIZE"; break;
      case GL_TEXTURE_BORDER: RETVAL = "GL_TEXTURE_BORDER"; break;
      case GL_TEXTURE_BORDER_COLOR: RETVAL = "GL_TEXTURE_BORDER_COLOR"; break;
      case GL_TEXTURE_CBCR_DEGAMMA_QCOM: RETVAL = "GL_TEXTURE_CBCR_DEGAMMA_QCOM"; break;
      case GL_TEXTURE_COMPARE_OPERATOR_SGIX: RETVAL = "GL_TEXTURE_COMPARE_OPERATOR_SGIX"; break;
      case GL_TEXTURE_COMPARE_SGIX: RETVAL = "GL_TEXTURE_COMPARE_SGIX"; break;
      case GL_TEXTURE_COMPONENTS: RETVAL = "GL_TEXTURE_COMPONENTS"; break;
      case GL_TEXTURE_DEPTH_EXT: RETVAL = "GL_TEXTURE_DEPTH_EXT"; break;
      case GL_TEXTURE_GEQUAL_R_SGIX: RETVAL = "GL_TEXTURE_GEQUAL_R_SGIX"; break;
      case GL_TEXTURE_GREEN_SIZE: RETVAL = "GL_TEXTURE_GREEN_SIZE"; break;
      case GL_TEXTURE_HEIGHT: RETVAL = "GL_TEXTURE_HEIGHT"; break;
      case GL_TEXTURE_INTENSITY_SIZE: RETVAL = "GL_TEXTURE_INTENSITY_SIZE"; break;
      case GL_TEXTURE_LEQUAL_R_SGIX: RETVAL = "GL_TEXTURE_LEQUAL_R_SGIX"; break;
      case GL_TEXTURE_LUMINANCE_SIZE: RETVAL = "GL_TEXTURE_LUMINANCE_SIZE"; break;
      case GL_TEXTURE_MAG_FILTER: RETVAL = "GL_TEXTURE_MAG_FILTER"; break;
      case GL_TEXTURE_MAX_CLAMP_R_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_R_SGIX"; break;
      case GL_TEXTURE_MAX_CLAMP_S_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_S_SGIX"; break;
      case GL_TEXTURE_MAX_CLAMP_T_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_T_SGIX"; break;
      case GL_TEXTURE_MAX_LEVEL_SGIS: RETVAL = "GL_TEXTURE_MAX_LEVEL_SGIS"; break;
      case GL_TEXTURE_MAX_LOD_SGIS: RETVAL = "GL_TEXTURE_MAX_LOD_SGIS"; break;
      case GL_TEXTURE_MIN_FILTER: RETVAL = "GL_TEXTURE_MIN_FILTER"; break;
      case GL_TEXTURE_MIN_LOD_SGIS: RETVAL = "GL_TEXTURE_MIN_LOD_SGIS"; break;
      case GL_TEXTURE_PRIORITY: RETVAL = "GL_TEXTURE_PRIORITY"; break;
      case GL_TEXTURE_RED_SIZE: RETVAL = "GL_TEXTURE_RED_SIZE"; break;
      case GL_TEXTURE_RESIDENT: RETVAL = "GL_TEXTURE_RESIDENT"; break;
      case GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM: RETVAL = "GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM"; break;
      case GL_TEXTURE_WIDTH: RETVAL = "GL_TEXTURE_WIDTH"; break;
      case GL_TEXTURE_WRAP_R_EXT: RETVAL = "GL_TEXTURE_WRAP_R_EXT"; break;
      case GL_TEXTURE_WRAP_S: RETVAL = "GL_TEXTURE_WRAP_S"; break;
      case GL_TEXTURE_WRAP_T: RETVAL = "GL_TEXTURE_WRAP_T"; break;
      case GL_TEXTURE_Y_DEGAMMA_QCOM: RETVAL = "GL_TEXTURE_Y_DEGAMMA_QCOM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetVariantValueEXT")) {
    switch (e) {
      case GL_VARIANT_ARRAY_STRIDE_EXT: RETVAL = "GL_VARIANT_ARRAY_STRIDE_EXT"; break;
      case GL_VARIANT_ARRAY_TYPE_EXT: RETVAL = "GL_VARIANT_ARRAY_TYPE_EXT"; break;
      case GL_VARIANT_DATATYPE_EXT: RETVAL = "GL_VARIANT_DATATYPE_EXT"; break;
      case GL_VARIANT_VALUE_EXT: RETVAL = "GL_VARIANT_VALUE_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GraphicsResetStatus")) {
    switch (e) {
      case GL_GUILTY_CONTEXT_RESET: RETVAL = "GL_GUILTY_CONTEXT_RESET"; break;
      case GL_INNOCENT_CONTEXT_RESET: RETVAL = "GL_INNOCENT_CONTEXT_RESET"; break;
      case GL_NO_ERROR: RETVAL = "GL_NO_ERROR"; break;
      case GL_UNKNOWN_CONTEXT_RESET: RETVAL = "GL_UNKNOWN_CONTEXT_RESET"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "HintMode")) {
    switch (e) {
      case GL_DONT_CARE: RETVAL = "GL_DONT_CARE"; break;
      case GL_FASTEST: RETVAL = "GL_FASTEST"; break;
      case GL_NICEST: RETVAL = "GL_NICEST"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "HintTarget")) {
    switch (e) {
      case GL_ALLOW_DRAW_FRG_HINT_PGI: RETVAL = "GL_ALLOW_DRAW_FRG_HINT_PGI"; break;
      case GL_ALLOW_DRAW_MEM_HINT_PGI: RETVAL = "GL_ALLOW_DRAW_MEM_HINT_PGI"; break;
      case GL_ALLOW_DRAW_OBJ_HINT_PGI: RETVAL = "GL_ALLOW_DRAW_OBJ_HINT_PGI"; break;
      case GL_ALLOW_DRAW_WIN_HINT_PGI: RETVAL = "GL_ALLOW_DRAW_WIN_HINT_PGI"; break;
      case GL_ALWAYS_FAST_HINT_PGI: RETVAL = "GL_ALWAYS_FAST_HINT_PGI"; break;
      case GL_ALWAYS_SOFT_HINT_PGI: RETVAL = "GL_ALWAYS_SOFT_HINT_PGI"; break;
      case GL_BACK_NORMALS_HINT_PGI: RETVAL = "GL_BACK_NORMALS_HINT_PGI"; break;
      case GL_BINNING_CONTROL_HINT_QCOM: RETVAL = "GL_BINNING_CONTROL_HINT_QCOM"; break;
      case GL_CLIP_FAR_HINT_PGI: RETVAL = "GL_CLIP_FAR_HINT_PGI"; break;
      case GL_CLIP_NEAR_HINT_PGI: RETVAL = "GL_CLIP_NEAR_HINT_PGI"; break;
      case GL_CLIP_VOLUME_CLIPPING_HINT_EXT: RETVAL = "GL_CLIP_VOLUME_CLIPPING_HINT_EXT"; break;
      case GL_CONSERVE_MEMORY_HINT_PGI: RETVAL = "GL_CONSERVE_MEMORY_HINT_PGI"; break;
      case GL_CONVOLUTION_HINT_SGIX: RETVAL = "GL_CONVOLUTION_HINT_SGIX"; break;
      case GL_FOG_HINT: RETVAL = "GL_FOG_HINT"; break;
      case GL_FRAGMENT_SHADER_DERIVATIVE_HINT: RETVAL = "GL_FRAGMENT_SHADER_DERIVATIVE_HINT"; break;
      case GL_FULL_STIPPLE_HINT_PGI: RETVAL = "GL_FULL_STIPPLE_HINT_PGI"; break;
      case GL_GENERATE_MIPMAP_HINT: RETVAL = "GL_GENERATE_MIPMAP_HINT"; break;
      case GL_LINE_QUALITY_HINT_SGIX: RETVAL = "GL_LINE_QUALITY_HINT_SGIX"; break;
      case GL_LINE_SMOOTH_HINT: RETVAL = "GL_LINE_SMOOTH_HINT"; break;
      case GL_MATERIAL_SIDE_HINT_PGI: RETVAL = "GL_MATERIAL_SIDE_HINT_PGI"; break;
      case GL_MAX_VERTEX_HINT_PGI: RETVAL = "GL_MAX_VERTEX_HINT_PGI"; break;
      case GL_MULTISAMPLE_FILTER_HINT_NV: RETVAL = "GL_MULTISAMPLE_FILTER_HINT_NV"; break;
      case GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI: RETVAL = "GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI"; break;
      case GL_NATIVE_GRAPHICS_END_HINT_PGI: RETVAL = "GL_NATIVE_GRAPHICS_END_HINT_PGI"; break;
      case GL_PACK_CMYK_HINT_EXT: RETVAL = "GL_PACK_CMYK_HINT_EXT"; break;
      case GL_PERSPECTIVE_CORRECTION_HINT: RETVAL = "GL_PERSPECTIVE_CORRECTION_HINT"; break;
      case GL_PHONG_HINT_WIN: RETVAL = "GL_PHONG_HINT_WIN"; break;
      case GL_POINT_SMOOTH_HINT: RETVAL = "GL_POINT_SMOOTH_HINT"; break;
      case GL_POLYGON_SMOOTH_HINT: RETVAL = "GL_POLYGON_SMOOTH_HINT"; break;
      case GL_PREFER_DOUBLEBUFFER_HINT_PGI: RETVAL = "GL_PREFER_DOUBLEBUFFER_HINT_PGI"; break;
      case GL_PROGRAM_BINARY_RETRIEVABLE_HINT: RETVAL = "GL_PROGRAM_BINARY_RETRIEVABLE_HINT"; break;
      case GL_RECLAIM_MEMORY_HINT_PGI: RETVAL = "GL_RECLAIM_MEMORY_HINT_PGI"; break;
      case GL_SCALEBIAS_HINT_SGIX: RETVAL = "GL_SCALEBIAS_HINT_SGIX"; break;
      case GL_STRICT_DEPTHFUNC_HINT_PGI: RETVAL = "GL_STRICT_DEPTHFUNC_HINT_PGI"; break;
      case GL_STRICT_LIGHTING_HINT_PGI: RETVAL = "GL_STRICT_LIGHTING_HINT_PGI"; break;
      case GL_STRICT_SCISSOR_HINT_PGI: RETVAL = "GL_STRICT_SCISSOR_HINT_PGI"; break;
      case GL_TEXTURE_COMPRESSION_HINT: RETVAL = "GL_TEXTURE_COMPRESSION_HINT"; break;
      case GL_TEXTURE_MULTI_BUFFER_HINT_SGIX: RETVAL = "GL_TEXTURE_MULTI_BUFFER_HINT_SGIX"; break;
      case GL_TEXTURE_STORAGE_HINT_APPLE: RETVAL = "GL_TEXTURE_STORAGE_HINT_APPLE"; break;
      case GL_TRANSFORM_HINT_APPLE: RETVAL = "GL_TRANSFORM_HINT_APPLE"; break;
      case GL_UNPACK_CMYK_HINT_EXT: RETVAL = "GL_UNPACK_CMYK_HINT_EXT"; break;
      case GL_VERTEX_ARRAY_STORAGE_HINT_APPLE: RETVAL = "GL_VERTEX_ARRAY_STORAGE_HINT_APPLE"; break;
      case GL_VERTEX_CONSISTENT_HINT_PGI: RETVAL = "GL_VERTEX_CONSISTENT_HINT_PGI"; break;
      case GL_VERTEX_DATA_HINT_PGI: RETVAL = "GL_VERTEX_DATA_HINT_PGI"; break;
      case GL_VERTEX_PRECLIP_HINT_SGIX: RETVAL = "GL_VERTEX_PRECLIP_HINT_SGIX"; break;
      case GL_VERTEX_PRECLIP_SGIX: RETVAL = "GL_VERTEX_PRECLIP_SGIX"; break;
      case GL_WIDE_LINE_HINT_PGI: RETVAL = "GL_WIDE_LINE_HINT_PGI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "HintTargetPGI")) {
    switch (e) {
      case GL_MATERIAL_SIDE_HINT_PGI: RETVAL = "GL_MATERIAL_SIDE_HINT_PGI"; break;
      case GL_MAX_VERTEX_HINT_PGI: RETVAL = "GL_MAX_VERTEX_HINT_PGI"; break;
      case GL_VERTEX_CONSISTENT_HINT_PGI: RETVAL = "GL_VERTEX_CONSISTENT_HINT_PGI"; break;
      case GL_VERTEX_DATA_HINT_PGI: RETVAL = "GL_VERTEX_DATA_HINT_PGI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "HistogramTarget")) {
    switch (e) {
      case GL_HISTOGRAM: RETVAL = "GL_HISTOGRAM"; break;
      case GL_PROXY_HISTOGRAM: RETVAL = "GL_PROXY_HISTOGRAM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "HistogramTargetEXT")) {
    switch (e) {
      case GL_HISTOGRAM: RETVAL = "GL_HISTOGRAM"; break;
      case GL_PROXY_HISTOGRAM: RETVAL = "GL_PROXY_HISTOGRAM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "IndexFunctionEXT")) {
    switch (e) {
      case GL_ALWAYS: RETVAL = "GL_ALWAYS"; break;
      case GL_EQUAL: RETVAL = "GL_EQUAL"; break;
      case GL_GEQUAL: RETVAL = "GL_GEQUAL"; break;
      case GL_GREATER: RETVAL = "GL_GREATER"; break;
      case GL_LEQUAL: RETVAL = "GL_LEQUAL"; break;
      case GL_LESS: RETVAL = "GL_LESS"; break;
      case GL_NEVER: RETVAL = "GL_NEVER"; break;
      case GL_NOTEQUAL: RETVAL = "GL_NOTEQUAL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "IndexMaterialParameterEXT")) {
    switch (e) {
      case GL_INDEX_OFFSET: RETVAL = "GL_INDEX_OFFSET"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "IndexPointerType")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "InstancedPathCoverMode")) {
    switch (e) {
      case GL_BOUNDING_BOX_NV: RETVAL = "GL_BOUNDING_BOX_NV"; break;
      case GL_BOUNDING_BOX_OF_BOUNDING_BOXES_NV: RETVAL = "GL_BOUNDING_BOX_OF_BOUNDING_BOXES_NV"; break;
      case GL_CONVEX_HULL_NV: RETVAL = "GL_CONVEX_HULL_NV"; break;
      case GL_PATH_FILL_COVER_MODE_NV: RETVAL = "GL_PATH_FILL_COVER_MODE_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "InterleavedArrayFormat")) {
    switch (e) {
      case GL_C3F_V3F: RETVAL = "GL_C3F_V3F"; break;
      case GL_C4F_N3F_V3F: RETVAL = "GL_C4F_N3F_V3F"; break;
      case GL_C4UB_V2F: RETVAL = "GL_C4UB_V2F"; break;
      case GL_C4UB_V3F: RETVAL = "GL_C4UB_V3F"; break;
      case GL_N3F_V3F: RETVAL = "GL_N3F_V3F"; break;
      case GL_T2F_C3F_V3F: RETVAL = "GL_T2F_C3F_V3F"; break;
      case GL_T2F_C4F_N3F_V3F: RETVAL = "GL_T2F_C4F_N3F_V3F"; break;
      case GL_T2F_C4UB_V3F: RETVAL = "GL_T2F_C4UB_V3F"; break;
      case GL_T2F_N3F_V3F: RETVAL = "GL_T2F_N3F_V3F"; break;
      case GL_T2F_V3F: RETVAL = "GL_T2F_V3F"; break;
      case GL_T4F_C4F_N3F_V4F: RETVAL = "GL_T4F_C4F_N3F_V4F"; break;
      case GL_T4F_V4F: RETVAL = "GL_T4F_V4F"; break;
      case GL_V2F: RETVAL = "GL_V2F"; break;
      case GL_V3F: RETVAL = "GL_V3F"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "InternalFormat")) {
    switch (e) {
      case GL_ALPHA12: RETVAL = "GL_ALPHA12"; break;
      case GL_ALPHA16: RETVAL = "GL_ALPHA16"; break;
      case GL_ALPHA16I_EXT: RETVAL = "GL_ALPHA16I_EXT"; break;
      case GL_ALPHA16UI_EXT: RETVAL = "GL_ALPHA16UI_EXT"; break;
      case GL_ALPHA32I_EXT: RETVAL = "GL_ALPHA32I_EXT"; break;
      case GL_ALPHA32UI_EXT: RETVAL = "GL_ALPHA32UI_EXT"; break;
      case GL_ALPHA4: RETVAL = "GL_ALPHA4"; break;
      case GL_ALPHA8: RETVAL = "GL_ALPHA8"; break;
      case GL_ALPHA8I_EXT: RETVAL = "GL_ALPHA8I_EXT"; break;
      case GL_ALPHA8UI_EXT: RETVAL = "GL_ALPHA8UI_EXT"; break;
      case GL_COMPRESSED_R11_EAC: RETVAL = "GL_COMPRESSED_R11_EAC"; break;
      case GL_COMPRESSED_RED: RETVAL = "GL_COMPRESSED_RED"; break;
      case GL_COMPRESSED_RED_RGTC1: RETVAL = "GL_COMPRESSED_RED_RGTC1"; break;
      case GL_COMPRESSED_RG: RETVAL = "GL_COMPRESSED_RG"; break;
      case GL_COMPRESSED_RG11_EAC: RETVAL = "GL_COMPRESSED_RG11_EAC"; break;
      case GL_COMPRESSED_RGB: RETVAL = "GL_COMPRESSED_RGB"; break;
      case GL_COMPRESSED_RGB8_ETC2: RETVAL = "GL_COMPRESSED_RGB8_ETC2"; break;
      case GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2: RETVAL = "GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2"; break;
      case GL_COMPRESSED_RGBA: RETVAL = "GL_COMPRESSED_RGBA"; break;
      case GL_COMPRESSED_RGBA8_ETC2_EAC: RETVAL = "GL_COMPRESSED_RGBA8_ETC2_EAC"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x10_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x10_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x8_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x8_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_12x10_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_12x10_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_12x12_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_12x12_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_4x4_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_4x4_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_5x4_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_5x4_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_5x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_5x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_6x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_6x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_6x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_6x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x8_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x8_KHR"; break;
      case GL_COMPRESSED_RGBA_BPTC_UNORM: RETVAL = "GL_COMPRESSED_RGBA_BPTC_UNORM"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT1_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT1_EXT"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT3_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT3_EXT"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT5_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT5_EXT"; break;
      case GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT: RETVAL = "GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT"; break;
      case GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT: RETVAL = "GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT"; break;
      case GL_COMPRESSED_RGB_S3TC_DXT1_EXT: RETVAL = "GL_COMPRESSED_RGB_S3TC_DXT1_EXT"; break;
      case GL_COMPRESSED_RG_RGTC2: RETVAL = "GL_COMPRESSED_RG_RGTC2"; break;
      case GL_COMPRESSED_SIGNED_R11_EAC: RETVAL = "GL_COMPRESSED_SIGNED_R11_EAC"; break;
      case GL_COMPRESSED_SIGNED_RED_RGTC1: RETVAL = "GL_COMPRESSED_SIGNED_RED_RGTC1"; break;
      case GL_COMPRESSED_SIGNED_RG11_EAC: RETVAL = "GL_COMPRESSED_SIGNED_RG11_EAC"; break;
      case GL_COMPRESSED_SIGNED_RG_RGTC2: RETVAL = "GL_COMPRESSED_SIGNED_RG_RGTC2"; break;
      case GL_COMPRESSED_SRGB: RETVAL = "GL_COMPRESSED_SRGB"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC"; break;
      case GL_COMPRESSED_SRGB8_ETC2: RETVAL = "GL_COMPRESSED_SRGB8_ETC2"; break;
      case GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2: RETVAL = "GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2"; break;
      case GL_COMPRESSED_SRGB_ALPHA: RETVAL = "GL_COMPRESSED_SRGB_ALPHA"; break;
      case GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV"; break;
      case GL_COMPRESSED_SRGB_S3TC_DXT1_NV: RETVAL = "GL_COMPRESSED_SRGB_S3TC_DXT1_NV"; break;
      case GL_DEPTH24_STENCIL8: RETVAL = "GL_DEPTH24_STENCIL8"; break;
      case GL_DEPTH32F_STENCIL8: RETVAL = "GL_DEPTH32F_STENCIL8"; break;
      case GL_DEPTH32F_STENCIL8_NV: RETVAL = "GL_DEPTH32F_STENCIL8_NV"; break;
      case GL_DEPTH_COMPONENT: RETVAL = "GL_DEPTH_COMPONENT"; break;
      case GL_DEPTH_COMPONENT16: RETVAL = "GL_DEPTH_COMPONENT16"; break;
      case GL_DEPTH_COMPONENT24: RETVAL = "GL_DEPTH_COMPONENT24"; break;
      case GL_DEPTH_COMPONENT32: RETVAL = "GL_DEPTH_COMPONENT32"; break;
      case GL_DEPTH_COMPONENT32F: RETVAL = "GL_DEPTH_COMPONENT32F"; break;
      case GL_DEPTH_COMPONENT32F_NV: RETVAL = "GL_DEPTH_COMPONENT32F_NV"; break;
      case GL_DEPTH_STENCIL: RETVAL = "GL_DEPTH_STENCIL"; break;
      case GL_INTENSITY: RETVAL = "GL_INTENSITY"; break;
      case GL_INTENSITY12: RETVAL = "GL_INTENSITY12"; break;
      case GL_INTENSITY16: RETVAL = "GL_INTENSITY16"; break;
      case GL_INTENSITY16I_EXT: RETVAL = "GL_INTENSITY16I_EXT"; break;
      case GL_INTENSITY16UI_EXT: RETVAL = "GL_INTENSITY16UI_EXT"; break;
      case GL_INTENSITY32I_EXT: RETVAL = "GL_INTENSITY32I_EXT"; break;
      case GL_INTENSITY32UI_EXT: RETVAL = "GL_INTENSITY32UI_EXT"; break;
      case GL_INTENSITY4: RETVAL = "GL_INTENSITY4"; break;
      case GL_INTENSITY8: RETVAL = "GL_INTENSITY8"; break;
      case GL_INTENSITY8I_EXT: RETVAL = "GL_INTENSITY8I_EXT"; break;
      case GL_INTENSITY8UI_EXT: RETVAL = "GL_INTENSITY8UI_EXT"; break;
      case GL_LUMINANCE12: RETVAL = "GL_LUMINANCE12"; break;
      case GL_LUMINANCE12_ALPHA12: RETVAL = "GL_LUMINANCE12_ALPHA12"; break;
      case GL_LUMINANCE12_ALPHA4: RETVAL = "GL_LUMINANCE12_ALPHA4"; break;
      case GL_LUMINANCE16: RETVAL = "GL_LUMINANCE16"; break;
      case GL_LUMINANCE16I_EXT: RETVAL = "GL_LUMINANCE16I_EXT"; break;
      case GL_LUMINANCE16UI_EXT: RETVAL = "GL_LUMINANCE16UI_EXT"; break;
      case GL_LUMINANCE16_ALPHA16: RETVAL = "GL_LUMINANCE16_ALPHA16"; break;
      case GL_LUMINANCE32I_EXT: RETVAL = "GL_LUMINANCE32I_EXT"; break;
      case GL_LUMINANCE32UI_EXT: RETVAL = "GL_LUMINANCE32UI_EXT"; break;
      case GL_LUMINANCE4: RETVAL = "GL_LUMINANCE4"; break;
      case GL_LUMINANCE4_ALPHA4: RETVAL = "GL_LUMINANCE4_ALPHA4"; break;
      case GL_LUMINANCE6_ALPHA2: RETVAL = "GL_LUMINANCE6_ALPHA2"; break;
      case GL_LUMINANCE8: RETVAL = "GL_LUMINANCE8"; break;
      case GL_LUMINANCE8I_EXT: RETVAL = "GL_LUMINANCE8I_EXT"; break;
      case GL_LUMINANCE8UI_EXT: RETVAL = "GL_LUMINANCE8UI_EXT"; break;
      case GL_LUMINANCE8_ALPHA8: RETVAL = "GL_LUMINANCE8_ALPHA8"; break;
      case GL_LUMINANCE_ALPHA16I_EXT: RETVAL = "GL_LUMINANCE_ALPHA16I_EXT"; break;
      case GL_LUMINANCE_ALPHA16UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA16UI_EXT"; break;
      case GL_LUMINANCE_ALPHA32I_EXT: RETVAL = "GL_LUMINANCE_ALPHA32I_EXT"; break;
      case GL_LUMINANCE_ALPHA32UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA32UI_EXT"; break;
      case GL_LUMINANCE_ALPHA8I_EXT: RETVAL = "GL_LUMINANCE_ALPHA8I_EXT"; break;
      case GL_LUMINANCE_ALPHA8UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA8UI_EXT"; break;
      case GL_R11F_G11F_B10F: RETVAL = "GL_R11F_G11F_B10F"; break;
      case GL_R16: RETVAL = "GL_R16"; break;
      case GL_R16F: RETVAL = "GL_R16F"; break;
      case GL_R16I: RETVAL = "GL_R16I"; break;
      case GL_R16UI: RETVAL = "GL_R16UI"; break;
      case GL_R16_SNORM: RETVAL = "GL_R16_SNORM"; break;
      case GL_R32F: RETVAL = "GL_R32F"; break;
      case GL_R32I: RETVAL = "GL_R32I"; break;
      case GL_R32UI: RETVAL = "GL_R32UI"; break;
      case GL_R3_G3_B2: RETVAL = "GL_R3_G3_B2"; break;
      case GL_R8: RETVAL = "GL_R8"; break;
      case GL_R8I: RETVAL = "GL_R8I"; break;
      case GL_R8UI: RETVAL = "GL_R8UI"; break;
      case GL_R8_SNORM: RETVAL = "GL_R8_SNORM"; break;
      case GL_RED: RETVAL = "GL_RED"; break;
      case GL_RG: RETVAL = "GL_RG"; break;
      case GL_RG16: RETVAL = "GL_RG16"; break;
      case GL_RG16F: RETVAL = "GL_RG16F"; break;
      case GL_RG16I: RETVAL = "GL_RG16I"; break;
      case GL_RG16UI: RETVAL = "GL_RG16UI"; break;
      case GL_RG16_SNORM: RETVAL = "GL_RG16_SNORM"; break;
      case GL_RG32F: RETVAL = "GL_RG32F"; break;
      case GL_RG32I: RETVAL = "GL_RG32I"; break;
      case GL_RG32UI: RETVAL = "GL_RG32UI"; break;
      case GL_RG8: RETVAL = "GL_RG8"; break;
      case GL_RG8I: RETVAL = "GL_RG8I"; break;
      case GL_RG8UI: RETVAL = "GL_RG8UI"; break;
      case GL_RG8_SNORM: RETVAL = "GL_RG8_SNORM"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      case GL_RGB10: RETVAL = "GL_RGB10"; break;
      case GL_RGB10_A2: RETVAL = "GL_RGB10_A2"; break;
      case GL_RGB10_A2UI: RETVAL = "GL_RGB10_A2UI"; break;
      case GL_RGB12: RETVAL = "GL_RGB12"; break;
      case GL_RGB16: RETVAL = "GL_RGB16"; break;
      case GL_RGB16F: RETVAL = "GL_RGB16F"; break;
      case GL_RGB16I: RETVAL = "GL_RGB16I"; break;
      case GL_RGB16UI: RETVAL = "GL_RGB16UI"; break;
      case GL_RGB16_SNORM: RETVAL = "GL_RGB16_SNORM"; break;
      case GL_RGB2_EXT: RETVAL = "GL_RGB2_EXT"; break;
      case GL_RGB32F: RETVAL = "GL_RGB32F"; break;
      case GL_RGB32I: RETVAL = "GL_RGB32I"; break;
      case GL_RGB32UI: RETVAL = "GL_RGB32UI"; break;
      case GL_RGB4: RETVAL = "GL_RGB4"; break;
      case GL_RGB5: RETVAL = "GL_RGB5"; break;
      case GL_RGB565: RETVAL = "GL_RGB565"; break;
      case GL_RGB5_A1: RETVAL = "GL_RGB5_A1"; break;
      case GL_RGB8: RETVAL = "GL_RGB8"; break;
      case GL_RGB8I: RETVAL = "GL_RGB8I"; break;
      case GL_RGB8UI: RETVAL = "GL_RGB8UI"; break;
      case GL_RGB8_SNORM: RETVAL = "GL_RGB8_SNORM"; break;
      case GL_RGB9_E5: RETVAL = "GL_RGB9_E5"; break;
      case GL_RGBA: RETVAL = "GL_RGBA"; break;
      case GL_RGBA12: RETVAL = "GL_RGBA12"; break;
      case GL_RGBA16: RETVAL = "GL_RGBA16"; break;
      case GL_RGBA16F: RETVAL = "GL_RGBA16F"; break;
      case GL_RGBA16I: RETVAL = "GL_RGBA16I"; break;
      case GL_RGBA16UI: RETVAL = "GL_RGBA16UI"; break;
      case GL_RGBA16_SNORM: RETVAL = "GL_RGBA16_SNORM"; break;
      case GL_RGBA2: RETVAL = "GL_RGBA2"; break;
      case GL_RGBA32F: RETVAL = "GL_RGBA32F"; break;
      case GL_RGBA32I: RETVAL = "GL_RGBA32I"; break;
      case GL_RGBA32UI: RETVAL = "GL_RGBA32UI"; break;
      case GL_RGBA4: RETVAL = "GL_RGBA4"; break;
      case GL_RGBA8: RETVAL = "GL_RGBA8"; break;
      case GL_RGBA8I: RETVAL = "GL_RGBA8I"; break;
      case GL_RGBA8UI: RETVAL = "GL_RGBA8UI"; break;
      case GL_RGBA8_SNORM: RETVAL = "GL_RGBA8_SNORM"; break;
      case GL_SR8_EXT: RETVAL = "GL_SR8_EXT"; break;
      case GL_SRG8_EXT: RETVAL = "GL_SRG8_EXT"; break;
      case GL_SRGB: RETVAL = "GL_SRGB"; break;
      case GL_SRGB8: RETVAL = "GL_SRGB8"; break;
      case GL_SRGB8_ALPHA8: RETVAL = "GL_SRGB8_ALPHA8"; break;
      case GL_SRGB_ALPHA: RETVAL = "GL_SRGB_ALPHA"; break;
      case GL_STENCIL_INDEX: RETVAL = "GL_STENCIL_INDEX"; break;
      case GL_STENCIL_INDEX1: RETVAL = "GL_STENCIL_INDEX1"; break;
      case GL_STENCIL_INDEX16: RETVAL = "GL_STENCIL_INDEX16"; break;
      case GL_STENCIL_INDEX4: RETVAL = "GL_STENCIL_INDEX4"; break;
      case GL_STENCIL_INDEX8: RETVAL = "GL_STENCIL_INDEX8"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "InternalFormatPName")) {
    switch (e) {
      case GL_AUTO_GENERATE_MIPMAP: RETVAL = "GL_AUTO_GENERATE_MIPMAP"; break;
      case GL_CLEAR_BUFFER: RETVAL = "GL_CLEAR_BUFFER"; break;
      case GL_CLEAR_TEXTURE: RETVAL = "GL_CLEAR_TEXTURE"; break;
      case GL_COLOR_COMPONENTS: RETVAL = "GL_COLOR_COMPONENTS"; break;
      case GL_COLOR_ENCODING: RETVAL = "GL_COLOR_ENCODING"; break;
      case GL_COLOR_RENDERABLE: RETVAL = "GL_COLOR_RENDERABLE"; break;
      case GL_COMPUTE_TEXTURE: RETVAL = "GL_COMPUTE_TEXTURE"; break;
      case GL_DEPTH_RENDERABLE: RETVAL = "GL_DEPTH_RENDERABLE"; break;
      case GL_FILTER: RETVAL = "GL_FILTER"; break;
      case GL_FRAGMENT_TEXTURE: RETVAL = "GL_FRAGMENT_TEXTURE"; break;
      case GL_FRAMEBUFFER_BLEND: RETVAL = "GL_FRAMEBUFFER_BLEND"; break;
      case GL_FRAMEBUFFER_RENDERABLE: RETVAL = "GL_FRAMEBUFFER_RENDERABLE"; break;
      case GL_FRAMEBUFFER_RENDERABLE_LAYERED: RETVAL = "GL_FRAMEBUFFER_RENDERABLE_LAYERED"; break;
      case GL_GENERATE_MIPMAP: RETVAL = "GL_GENERATE_MIPMAP"; break;
      case GL_GEOMETRY_TEXTURE: RETVAL = "GL_GEOMETRY_TEXTURE"; break;
      case GL_GET_TEXTURE_IMAGE_FORMAT: RETVAL = "GL_GET_TEXTURE_IMAGE_FORMAT"; break;
      case GL_GET_TEXTURE_IMAGE_TYPE: RETVAL = "GL_GET_TEXTURE_IMAGE_TYPE"; break;
      case GL_IMAGE_COMPATIBILITY_CLASS: RETVAL = "GL_IMAGE_COMPATIBILITY_CLASS"; break;
      case GL_IMAGE_FORMAT_COMPATIBILITY_TYPE: RETVAL = "GL_IMAGE_FORMAT_COMPATIBILITY_TYPE"; break;
      case GL_IMAGE_PIXEL_FORMAT: RETVAL = "GL_IMAGE_PIXEL_FORMAT"; break;
      case GL_IMAGE_PIXEL_TYPE: RETVAL = "GL_IMAGE_PIXEL_TYPE"; break;
      case GL_IMAGE_TEXEL_SIZE: RETVAL = "GL_IMAGE_TEXEL_SIZE"; break;
      case GL_INTERNALFORMAT_ALPHA_SIZE: RETVAL = "GL_INTERNALFORMAT_ALPHA_SIZE"; break;
      case GL_INTERNALFORMAT_ALPHA_TYPE: RETVAL = "GL_INTERNALFORMAT_ALPHA_TYPE"; break;
      case GL_INTERNALFORMAT_BLUE_SIZE: RETVAL = "GL_INTERNALFORMAT_BLUE_SIZE"; break;
      case GL_INTERNALFORMAT_BLUE_TYPE: RETVAL = "GL_INTERNALFORMAT_BLUE_TYPE"; break;
      case GL_INTERNALFORMAT_DEPTH_SIZE: RETVAL = "GL_INTERNALFORMAT_DEPTH_SIZE"; break;
      case GL_INTERNALFORMAT_DEPTH_TYPE: RETVAL = "GL_INTERNALFORMAT_DEPTH_TYPE"; break;
      case GL_INTERNALFORMAT_GREEN_SIZE: RETVAL = "GL_INTERNALFORMAT_GREEN_SIZE"; break;
      case GL_INTERNALFORMAT_GREEN_TYPE: RETVAL = "GL_INTERNALFORMAT_GREEN_TYPE"; break;
      case GL_INTERNALFORMAT_PREFERRED: RETVAL = "GL_INTERNALFORMAT_PREFERRED"; break;
      case GL_INTERNALFORMAT_RED_SIZE: RETVAL = "GL_INTERNALFORMAT_RED_SIZE"; break;
      case GL_INTERNALFORMAT_RED_TYPE: RETVAL = "GL_INTERNALFORMAT_RED_TYPE"; break;
      case GL_INTERNALFORMAT_SHARED_SIZE: RETVAL = "GL_INTERNALFORMAT_SHARED_SIZE"; break;
      case GL_INTERNALFORMAT_STENCIL_SIZE: RETVAL = "GL_INTERNALFORMAT_STENCIL_SIZE"; break;
      case GL_INTERNALFORMAT_STENCIL_TYPE: RETVAL = "GL_INTERNALFORMAT_STENCIL_TYPE"; break;
      case GL_INTERNALFORMAT_SUPPORTED: RETVAL = "GL_INTERNALFORMAT_SUPPORTED"; break;
      case GL_MAX_DEPTH: RETVAL = "GL_MAX_DEPTH"; break;
      case GL_MAX_HEIGHT: RETVAL = "GL_MAX_HEIGHT"; break;
      case GL_MAX_LAYERS: RETVAL = "GL_MAX_LAYERS"; break;
      case GL_MAX_WIDTH: RETVAL = "GL_MAX_WIDTH"; break;
      case GL_MIPMAP: RETVAL = "GL_MIPMAP"; break;
      case GL_NUM_SAMPLE_COUNTS: RETVAL = "GL_NUM_SAMPLE_COUNTS"; break;
      case GL_NUM_SURFACE_COMPRESSION_FIXED_RATES_EXT: RETVAL = "GL_NUM_SURFACE_COMPRESSION_FIXED_RATES_EXT"; break;
      case GL_READ_PIXELS: RETVAL = "GL_READ_PIXELS"; break;
      case GL_READ_PIXELS_FORMAT: RETVAL = "GL_READ_PIXELS_FORMAT"; break;
      case GL_READ_PIXELS_TYPE: RETVAL = "GL_READ_PIXELS_TYPE"; break;
      case GL_SAMPLES: RETVAL = "GL_SAMPLES"; break;
      case GL_SHADER_IMAGE_ATOMIC: RETVAL = "GL_SHADER_IMAGE_ATOMIC"; break;
      case GL_SHADER_IMAGE_LOAD: RETVAL = "GL_SHADER_IMAGE_LOAD"; break;
      case GL_SHADER_IMAGE_STORE: RETVAL = "GL_SHADER_IMAGE_STORE"; break;
      case GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_TEST: RETVAL = "GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_TEST"; break;
      case GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_WRITE: RETVAL = "GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_WRITE"; break;
      case GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_TEST: RETVAL = "GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_TEST"; break;
      case GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_WRITE: RETVAL = "GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_WRITE"; break;
      case GL_SRGB_READ: RETVAL = "GL_SRGB_READ"; break;
      case GL_SRGB_WRITE: RETVAL = "GL_SRGB_WRITE"; break;
      case GL_STENCIL_RENDERABLE: RETVAL = "GL_STENCIL_RENDERABLE"; break;
      case GL_TESS_CONTROL_TEXTURE: RETVAL = "GL_TESS_CONTROL_TEXTURE"; break;
      case GL_TESS_EVALUATION_TEXTURE: RETVAL = "GL_TESS_EVALUATION_TEXTURE"; break;
      case GL_TEXTURE_COMPRESSED: RETVAL = "GL_TEXTURE_COMPRESSED"; break;
      case GL_TEXTURE_COMPRESSED_BLOCK_HEIGHT: RETVAL = "GL_TEXTURE_COMPRESSED_BLOCK_HEIGHT"; break;
      case GL_TEXTURE_COMPRESSED_BLOCK_SIZE: RETVAL = "GL_TEXTURE_COMPRESSED_BLOCK_SIZE"; break;
      case GL_TEXTURE_COMPRESSED_BLOCK_WIDTH: RETVAL = "GL_TEXTURE_COMPRESSED_BLOCK_WIDTH"; break;
      case GL_TEXTURE_GATHER: RETVAL = "GL_TEXTURE_GATHER"; break;
      case GL_TEXTURE_GATHER_SHADOW: RETVAL = "GL_TEXTURE_GATHER_SHADOW"; break;
      case GL_TEXTURE_IMAGE_FORMAT: RETVAL = "GL_TEXTURE_IMAGE_FORMAT"; break;
      case GL_TEXTURE_IMAGE_TYPE: RETVAL = "GL_TEXTURE_IMAGE_TYPE"; break;
      case GL_TEXTURE_SHADOW: RETVAL = "GL_TEXTURE_SHADOW"; break;
      case GL_TEXTURE_VIEW: RETVAL = "GL_TEXTURE_VIEW"; break;
      case GL_VERTEX_TEXTURE: RETVAL = "GL_VERTEX_TEXTURE"; break;
      case GL_VIEW_COMPATIBILITY_CLASS: RETVAL = "GL_VIEW_COMPATIBILITY_CLASS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "InvalidateFramebufferAttachment")) {
    switch (e) {
      case GL_COLOR: RETVAL = "GL_COLOR"; break;
      case GL_COLOR_ATTACHMENT0: RETVAL = "GL_COLOR_ATTACHMENT0"; break;
      case GL_COLOR_ATTACHMENT1: RETVAL = "GL_COLOR_ATTACHMENT1"; break;
      case GL_COLOR_ATTACHMENT10: RETVAL = "GL_COLOR_ATTACHMENT10"; break;
      case GL_COLOR_ATTACHMENT11: RETVAL = "GL_COLOR_ATTACHMENT11"; break;
      case GL_COLOR_ATTACHMENT12: RETVAL = "GL_COLOR_ATTACHMENT12"; break;
      case GL_COLOR_ATTACHMENT13: RETVAL = "GL_COLOR_ATTACHMENT13"; break;
      case GL_COLOR_ATTACHMENT14: RETVAL = "GL_COLOR_ATTACHMENT14"; break;
      case GL_COLOR_ATTACHMENT15: RETVAL = "GL_COLOR_ATTACHMENT15"; break;
      case GL_COLOR_ATTACHMENT2: RETVAL = "GL_COLOR_ATTACHMENT2"; break;
      case GL_COLOR_ATTACHMENT3: RETVAL = "GL_COLOR_ATTACHMENT3"; break;
      case GL_COLOR_ATTACHMENT4: RETVAL = "GL_COLOR_ATTACHMENT4"; break;
      case GL_COLOR_ATTACHMENT5: RETVAL = "GL_COLOR_ATTACHMENT5"; break;
      case GL_COLOR_ATTACHMENT6: RETVAL = "GL_COLOR_ATTACHMENT6"; break;
      case GL_COLOR_ATTACHMENT7: RETVAL = "GL_COLOR_ATTACHMENT7"; break;
      case GL_COLOR_ATTACHMENT8: RETVAL = "GL_COLOR_ATTACHMENT8"; break;
      case GL_COLOR_ATTACHMENT9: RETVAL = "GL_COLOR_ATTACHMENT9"; break;
      case GL_DEPTH: RETVAL = "GL_DEPTH"; break;
      case GL_DEPTH_ATTACHMENT: RETVAL = "GL_DEPTH_ATTACHMENT"; break;
      case GL_DEPTH_STENCIL_ATTACHMENT: RETVAL = "GL_DEPTH_STENCIL_ATTACHMENT"; break;
      case GL_STENCIL: RETVAL = "GL_STENCIL"; break;
      case GL_STENCIL_ATTACHMENT_EXT: RETVAL = "GL_STENCIL_ATTACHMENT_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightEnvModeSGIX")) {
    switch (e) {
      case GL_ADD: RETVAL = "GL_ADD"; break;
      case GL_MODULATE: RETVAL = "GL_MODULATE"; break;
      case GL_REPLACE: RETVAL = "GL_REPLACE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightModelColorControl")) {
    switch (e) {
      case GL_SEPARATE_SPECULAR_COLOR: RETVAL = "GL_SEPARATE_SPECULAR_COLOR"; break;
      case GL_SINGLE_COLOR: RETVAL = "GL_SINGLE_COLOR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightModelParameter")) {
    switch (e) {
      case GL_LIGHT_MODEL_AMBIENT: RETVAL = "GL_LIGHT_MODEL_AMBIENT"; break;
      case GL_LIGHT_MODEL_COLOR_CONTROL: RETVAL = "GL_LIGHT_MODEL_COLOR_CONTROL"; break;
      case GL_LIGHT_MODEL_LOCAL_VIEWER: RETVAL = "GL_LIGHT_MODEL_LOCAL_VIEWER"; break;
      case GL_LIGHT_MODEL_TWO_SIDE: RETVAL = "GL_LIGHT_MODEL_TWO_SIDE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightName")) {
    switch (e) {
      case GL_LIGHT0: RETVAL = "GL_LIGHT0"; break;
      case GL_LIGHT1: RETVAL = "GL_LIGHT1"; break;
      case GL_LIGHT2: RETVAL = "GL_LIGHT2"; break;
      case GL_LIGHT3: RETVAL = "GL_LIGHT3"; break;
      case GL_LIGHT4: RETVAL = "GL_LIGHT4"; break;
      case GL_LIGHT5: RETVAL = "GL_LIGHT5"; break;
      case GL_LIGHT6: RETVAL = "GL_LIGHT6"; break;
      case GL_LIGHT7: RETVAL = "GL_LIGHT7"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightParameter")) {
    switch (e) {
      case GL_AMBIENT: RETVAL = "GL_AMBIENT"; break;
      case GL_CONSTANT_ATTENUATION: RETVAL = "GL_CONSTANT_ATTENUATION"; break;
      case GL_DIFFUSE: RETVAL = "GL_DIFFUSE"; break;
      case GL_LINEAR_ATTENUATION: RETVAL = "GL_LINEAR_ATTENUATION"; break;
      case GL_POSITION: RETVAL = "GL_POSITION"; break;
      case GL_QUADRATIC_ATTENUATION: RETVAL = "GL_QUADRATIC_ATTENUATION"; break;
      case GL_SPECULAR: RETVAL = "GL_SPECULAR"; break;
      case GL_SPOT_CUTOFF: RETVAL = "GL_SPOT_CUTOFF"; break;
      case GL_SPOT_DIRECTION: RETVAL = "GL_SPOT_DIRECTION"; break;
      case GL_SPOT_EXPONENT: RETVAL = "GL_SPOT_EXPONENT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightTextureModeEXT")) {
    switch (e) {
      case GL_FRAGMENT_COLOR_EXT: RETVAL = "GL_FRAGMENT_COLOR_EXT"; break;
      case GL_FRAGMENT_DEPTH: RETVAL = "GL_FRAGMENT_DEPTH"; break;
      case GL_FRAGMENT_MATERIAL_EXT: RETVAL = "GL_FRAGMENT_MATERIAL_EXT"; break;
      case GL_FRAGMENT_NORMAL_EXT: RETVAL = "GL_FRAGMENT_NORMAL_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightTexturePNameEXT")) {
    switch (e) {
      case GL_ATTENUATION_EXT: RETVAL = "GL_ATTENUATION_EXT"; break;
      case GL_SHADOW_ATTENUATION_EXT: RETVAL = "GL_SHADOW_ATTENUATION_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ListMode")) {
    switch (e) {
      case GL_COMPILE: RETVAL = "GL_COMPILE"; break;
      case GL_COMPILE_AND_EXECUTE: RETVAL = "GL_COMPILE_AND_EXECUTE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ListNameType")) {
    switch (e) {
      case GL_2_BYTES: RETVAL = "GL_2_BYTES"; break;
      case GL_3_BYTES: RETVAL = "GL_3_BYTES"; break;
      case GL_4_BYTES: RETVAL = "GL_4_BYTES"; break;
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LogicOp")) {
    switch (e) {
      case GL_AND: RETVAL = "GL_AND"; break;
      case GL_AND_INVERTED: RETVAL = "GL_AND_INVERTED"; break;
      case GL_AND_REVERSE: RETVAL = "GL_AND_REVERSE"; break;
      case GL_CLEAR: RETVAL = "GL_CLEAR"; break;
      case GL_COPY: RETVAL = "GL_COPY"; break;
      case GL_COPY_INVERTED: RETVAL = "GL_COPY_INVERTED"; break;
      case GL_EQUIV: RETVAL = "GL_EQUIV"; break;
      case GL_INVERT: RETVAL = "GL_INVERT"; break;
      case GL_NAND: RETVAL = "GL_NAND"; break;
      case GL_NOOP: RETVAL = "GL_NOOP"; break;
      case GL_NOR: RETVAL = "GL_NOR"; break;
      case GL_OR: RETVAL = "GL_OR"; break;
      case GL_OR_INVERTED: RETVAL = "GL_OR_INVERTED"; break;
      case GL_OR_REVERSE: RETVAL = "GL_OR_REVERSE"; break;
      case GL_SET: RETVAL = "GL_SET"; break;
      case GL_XOR: RETVAL = "GL_XOR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapAttribParameterNV")) {
    switch (e) {
      case GL_MAP_ATTRIB_U_ORDER_NV: RETVAL = "GL_MAP_ATTRIB_U_ORDER_NV"; break;
      case GL_MAP_ATTRIB_V_ORDER_NV: RETVAL = "GL_MAP_ATTRIB_V_ORDER_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapBufferAccessMask")) {
    switch (e) {
      case GL_MAP_COHERENT_BIT: RETVAL = "GL_MAP_COHERENT_BIT"; break;
      case GL_MAP_FLUSH_EXPLICIT_BIT: RETVAL = "GL_MAP_FLUSH_EXPLICIT_BIT"; break;
      case GL_MAP_INVALIDATE_BUFFER_BIT: RETVAL = "GL_MAP_INVALIDATE_BUFFER_BIT"; break;
      case GL_MAP_INVALIDATE_RANGE_BIT: RETVAL = "GL_MAP_INVALIDATE_RANGE_BIT"; break;
      case GL_MAP_PERSISTENT_BIT: RETVAL = "GL_MAP_PERSISTENT_BIT"; break;
      case GL_MAP_READ_BIT: RETVAL = "GL_MAP_READ_BIT"; break;
      case GL_MAP_UNSYNCHRONIZED_BIT: RETVAL = "GL_MAP_UNSYNCHRONIZED_BIT"; break;
      case GL_MAP_WRITE_BIT: RETVAL = "GL_MAP_WRITE_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapParameterNV")) {
    switch (e) {
      case GL_MAP_TESSELLATION_NV: RETVAL = "GL_MAP_TESSELLATION_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapQuery")) {
    switch (e) {
      case GL_COEFF: RETVAL = "GL_COEFF"; break;
      case GL_DOMAIN: RETVAL = "GL_DOMAIN"; break;
      case GL_ORDER: RETVAL = "GL_ORDER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapTarget")) {
    switch (e) {
      case GL_MAP1_COLOR_4: RETVAL = "GL_MAP1_COLOR_4"; break;
      case GL_MAP1_INDEX: RETVAL = "GL_MAP1_INDEX"; break;
      case GL_MAP1_NORMAL: RETVAL = "GL_MAP1_NORMAL"; break;
      case GL_MAP1_TEXTURE_COORD_1: RETVAL = "GL_MAP1_TEXTURE_COORD_1"; break;
      case GL_MAP1_TEXTURE_COORD_2: RETVAL = "GL_MAP1_TEXTURE_COORD_2"; break;
      case GL_MAP1_TEXTURE_COORD_3: RETVAL = "GL_MAP1_TEXTURE_COORD_3"; break;
      case GL_MAP1_TEXTURE_COORD_4: RETVAL = "GL_MAP1_TEXTURE_COORD_4"; break;
      case GL_MAP1_VERTEX_3: RETVAL = "GL_MAP1_VERTEX_3"; break;
      case GL_MAP1_VERTEX_4: RETVAL = "GL_MAP1_VERTEX_4"; break;
      case GL_MAP2_COLOR_4: RETVAL = "GL_MAP2_COLOR_4"; break;
      case GL_MAP2_INDEX: RETVAL = "GL_MAP2_INDEX"; break;
      case GL_MAP2_NORMAL: RETVAL = "GL_MAP2_NORMAL"; break;
      case GL_MAP2_TEXTURE_COORD_1: RETVAL = "GL_MAP2_TEXTURE_COORD_1"; break;
      case GL_MAP2_TEXTURE_COORD_2: RETVAL = "GL_MAP2_TEXTURE_COORD_2"; break;
      case GL_MAP2_TEXTURE_COORD_3: RETVAL = "GL_MAP2_TEXTURE_COORD_3"; break;
      case GL_MAP2_TEXTURE_COORD_4: RETVAL = "GL_MAP2_TEXTURE_COORD_4"; break;
      case GL_MAP2_VERTEX_3: RETVAL = "GL_MAP2_VERTEX_3"; break;
      case GL_MAP2_VERTEX_4: RETVAL = "GL_MAP2_VERTEX_4"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapTextureFormatINTEL")) {
    switch (e) {
      case GL_LAYOUT_DEFAULT_INTEL: RETVAL = "GL_LAYOUT_DEFAULT_INTEL"; break;
      case GL_LAYOUT_LINEAR_CPU_CACHED_INTEL: RETVAL = "GL_LAYOUT_LINEAR_CPU_CACHED_INTEL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapTypeNV")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MaterialParameter")) {
    switch (e) {
      case GL_AMBIENT: RETVAL = "GL_AMBIENT"; break;
      case GL_AMBIENT_AND_DIFFUSE: RETVAL = "GL_AMBIENT_AND_DIFFUSE"; break;
      case GL_COLOR_INDEXES: RETVAL = "GL_COLOR_INDEXES"; break;
      case GL_DIFFUSE: RETVAL = "GL_DIFFUSE"; break;
      case GL_EMISSION: RETVAL = "GL_EMISSION"; break;
      case GL_SHININESS: RETVAL = "GL_SHININESS"; break;
      case GL_SPECULAR: RETVAL = "GL_SPECULAR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MatrixIndexPointerTypeARB")) {
    switch (e) {
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MatrixMode")) {
    switch (e) {
      case GL_MODELVIEW: RETVAL = "GL_MODELVIEW"; break;
      case GL_PROJECTION: RETVAL = "GL_PROJECTION"; break;
      case GL_TEXTURE: RETVAL = "GL_TEXTURE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MemoryBarrierMask")) {
    switch (e) {
      case GL_ALL_BARRIER_BITS: RETVAL = "GL_ALL_BARRIER_BITS"; break;
      case GL_ATOMIC_COUNTER_BARRIER_BIT: RETVAL = "GL_ATOMIC_COUNTER_BARRIER_BIT"; break;
      case GL_BUFFER_UPDATE_BARRIER_BIT: RETVAL = "GL_BUFFER_UPDATE_BARRIER_BIT"; break;
      case GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT: RETVAL = "GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT"; break;
      case GL_COMMAND_BARRIER_BIT: RETVAL = "GL_COMMAND_BARRIER_BIT"; break;
      case GL_ELEMENT_ARRAY_BARRIER_BIT: RETVAL = "GL_ELEMENT_ARRAY_BARRIER_BIT"; break;
      case GL_FRAMEBUFFER_BARRIER_BIT: RETVAL = "GL_FRAMEBUFFER_BARRIER_BIT"; break;
      case GL_PIXEL_BUFFER_BARRIER_BIT: RETVAL = "GL_PIXEL_BUFFER_BARRIER_BIT"; break;
      case GL_QUERY_BUFFER_BARRIER_BIT: RETVAL = "GL_QUERY_BUFFER_BARRIER_BIT"; break;
      case GL_SHADER_IMAGE_ACCESS_BARRIER_BIT: RETVAL = "GL_SHADER_IMAGE_ACCESS_BARRIER_BIT"; break;
      case GL_SHADER_STORAGE_BARRIER_BIT: RETVAL = "GL_SHADER_STORAGE_BARRIER_BIT"; break;
      case GL_TEXTURE_FETCH_BARRIER_BIT: RETVAL = "GL_TEXTURE_FETCH_BARRIER_BIT"; break;
      case GL_TEXTURE_UPDATE_BARRIER_BIT: RETVAL = "GL_TEXTURE_UPDATE_BARRIER_BIT"; break;
      case GL_TRANSFORM_FEEDBACK_BARRIER_BIT: RETVAL = "GL_TRANSFORM_FEEDBACK_BARRIER_BIT"; break;
      case GL_UNIFORM_BARRIER_BIT: RETVAL = "GL_UNIFORM_BARRIER_BIT"; break;
      case GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MemoryObjectParameterName")) {
    switch (e) {
      case GL_DEDICATED_MEMORY_OBJECT_EXT: RETVAL = "GL_DEDICATED_MEMORY_OBJECT_EXT"; break;
      case GL_PROTECTED_MEMORY_OBJECT_EXT: RETVAL = "GL_PROTECTED_MEMORY_OBJECT_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MeshMode1")) {
    switch (e) {
      case GL_LINE: RETVAL = "GL_LINE"; break;
      case GL_POINT: RETVAL = "GL_POINT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MeshMode2")) {
    switch (e) {
      case GL_FILL: RETVAL = "GL_FILL"; break;
      case GL_LINE: RETVAL = "GL_LINE"; break;
      case GL_POINT: RETVAL = "GL_POINT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MinmaxTarget")) {
    switch (e) {
      case GL_MINMAX: RETVAL = "GL_MINMAX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MinmaxTargetEXT")) {
    switch (e) {
      case GL_MINMAX: RETVAL = "GL_MINMAX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "NormalPointerType")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ObjectIdentifier")) {
    switch (e) {
      case GL_BUFFER: RETVAL = "GL_BUFFER"; break;
      case GL_FRAMEBUFFER: RETVAL = "GL_FRAMEBUFFER"; break;
      case GL_PROGRAM: RETVAL = "GL_PROGRAM"; break;
      case GL_PROGRAM_PIPELINE: RETVAL = "GL_PROGRAM_PIPELINE"; break;
      case GL_QUERY: RETVAL = "GL_QUERY"; break;
      case GL_RENDERBUFFER: RETVAL = "GL_RENDERBUFFER"; break;
      case GL_SAMPLER: RETVAL = "GL_SAMPLER"; break;
      case GL_SHADER: RETVAL = "GL_SHADER"; break;
      case GL_TEXTURE: RETVAL = "GL_TEXTURE"; break;
      case GL_TRANSFORM_FEEDBACK: RETVAL = "GL_TRANSFORM_FEEDBACK"; break;
      case GL_VERTEX_ARRAY: RETVAL = "GL_VERTEX_ARRAY"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ObjectTypeAPPLE")) {
    switch (e) {
      case GL_DRAW_PIXELS_APPLE: RETVAL = "GL_DRAW_PIXELS_APPLE"; break;
      case GL_FENCE_APPLE: RETVAL = "GL_FENCE_APPLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "OcclusionQueryEventMaskAMD")) {
    switch (e) {
      case GL_QUERY_ALL_EVENT_BITS_AMD: RETVAL = "GL_QUERY_ALL_EVENT_BITS_AMD"; break;
      case GL_QUERY_DEPTH_BOUNDS_FAIL_EVENT_BIT_AMD: RETVAL = "GL_QUERY_DEPTH_BOUNDS_FAIL_EVENT_BIT_AMD"; break;
      case GL_QUERY_DEPTH_FAIL_EVENT_BIT_AMD: RETVAL = "GL_QUERY_DEPTH_FAIL_EVENT_BIT_AMD"; break;
      case GL_QUERY_DEPTH_PASS_EVENT_BIT_AMD: RETVAL = "GL_QUERY_DEPTH_PASS_EVENT_BIT_AMD"; break;
      case GL_QUERY_STENCIL_FAIL_EVENT_BIT_AMD: RETVAL = "GL_QUERY_STENCIL_FAIL_EVENT_BIT_AMD"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "OcclusionQueryParameterNameNV")) {
    switch (e) {
      case GL_PIXEL_COUNT_AVAILABLE_NV: RETVAL = "GL_PIXEL_COUNT_AVAILABLE_NV"; break;
      case GL_PIXEL_COUNT_NV: RETVAL = "GL_PIXEL_COUNT_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PNTrianglesPNameATI")) {
    switch (e) {
      case GL_PN_TRIANGLES_NORMAL_MODE_ATI: RETVAL = "GL_PN_TRIANGLES_NORMAL_MODE_ATI"; break;
      case GL_PN_TRIANGLES_POINT_MODE_ATI: RETVAL = "GL_PN_TRIANGLES_POINT_MODE_ATI"; break;
      case GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI: RETVAL = "GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ParameterRangeEXT")) {
    switch (e) {
      case GL_FULL_RANGE_EXT: RETVAL = "GL_FULL_RANGE_EXT"; break;
      case GL_NORMALIZED_RANGE_EXT: RETVAL = "GL_NORMALIZED_RANGE_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PatchParameterName")) {
    switch (e) {
      case GL_PATCH_DEFAULT_INNER_LEVEL: RETVAL = "GL_PATCH_DEFAULT_INNER_LEVEL"; break;
      case GL_PATCH_DEFAULT_OUTER_LEVEL: RETVAL = "GL_PATCH_DEFAULT_OUTER_LEVEL"; break;
      case GL_PATCH_VERTICES: RETVAL = "GL_PATCH_VERTICES"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathColor")) {
    switch (e) {
      case GL_PRIMARY_COLOR: RETVAL = "GL_PRIMARY_COLOR"; break;
      case GL_PRIMARY_COLOR_NV: RETVAL = "GL_PRIMARY_COLOR_NV"; break;
      case GL_SECONDARY_COLOR_NV: RETVAL = "GL_SECONDARY_COLOR_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathColorFormat")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_INTENSITY: RETVAL = "GL_INTENSITY"; break;
      case GL_LUMINANCE: RETVAL = "GL_LUMINANCE"; break;
      case GL_LUMINANCE_ALPHA: RETVAL = "GL_LUMINANCE_ALPHA"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      case GL_RGBA: RETVAL = "GL_RGBA"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathCoordType")) {
    switch (e) {
      case GL_ARC_TO_NV: RETVAL = "GL_ARC_TO_NV"; break;
      case GL_CIRCULAR_CCW_ARC_TO_NV: RETVAL = "GL_CIRCULAR_CCW_ARC_TO_NV"; break;
      case GL_CIRCULAR_CW_ARC_TO_NV: RETVAL = "GL_CIRCULAR_CW_ARC_TO_NV"; break;
      case GL_CIRCULAR_TANGENT_ARC_TO_NV: RETVAL = "GL_CIRCULAR_TANGENT_ARC_TO_NV"; break;
      case GL_CLOSE_PATH_NV: RETVAL = "GL_CLOSE_PATH_NV"; break;
      case GL_CONIC_CURVE_TO_NV: RETVAL = "GL_CONIC_CURVE_TO_NV"; break;
      case GL_CUBIC_CURVE_TO_NV: RETVAL = "GL_CUBIC_CURVE_TO_NV"; break;
      case GL_DUP_FIRST_CUBIC_CURVE_TO_NV: RETVAL = "GL_DUP_FIRST_CUBIC_CURVE_TO_NV"; break;
      case GL_DUP_LAST_CUBIC_CURVE_TO_NV: RETVAL = "GL_DUP_LAST_CUBIC_CURVE_TO_NV"; break;
      case GL_HORIZONTAL_LINE_TO_NV: RETVAL = "GL_HORIZONTAL_LINE_TO_NV"; break;
      case GL_LARGE_CCW_ARC_TO_NV: RETVAL = "GL_LARGE_CCW_ARC_TO_NV"; break;
      case GL_LARGE_CW_ARC_TO_NV: RETVAL = "GL_LARGE_CW_ARC_TO_NV"; break;
      case GL_LINE_TO_NV: RETVAL = "GL_LINE_TO_NV"; break;
      case GL_MOVE_TO_NV: RETVAL = "GL_MOVE_TO_NV"; break;
      case GL_QUADRATIC_CURVE_TO_NV: RETVAL = "GL_QUADRATIC_CURVE_TO_NV"; break;
      case GL_RECT_NV: RETVAL = "GL_RECT_NV"; break;
      case GL_RELATIVE_ARC_TO_NV: RETVAL = "GL_RELATIVE_ARC_TO_NV"; break;
      case GL_RELATIVE_CONIC_CURVE_TO_NV: RETVAL = "GL_RELATIVE_CONIC_CURVE_TO_NV"; break;
      case GL_RELATIVE_CUBIC_CURVE_TO_NV: RETVAL = "GL_RELATIVE_CUBIC_CURVE_TO_NV"; break;
      case GL_RELATIVE_HORIZONTAL_LINE_TO_NV: RETVAL = "GL_RELATIVE_HORIZONTAL_LINE_TO_NV"; break;
      case GL_RELATIVE_LARGE_CCW_ARC_TO_NV: RETVAL = "GL_RELATIVE_LARGE_CCW_ARC_TO_NV"; break;
      case GL_RELATIVE_LARGE_CW_ARC_TO_NV: RETVAL = "GL_RELATIVE_LARGE_CW_ARC_TO_NV"; break;
      case GL_RELATIVE_LINE_TO_NV: RETVAL = "GL_RELATIVE_LINE_TO_NV"; break;
      case GL_RELATIVE_MOVE_TO_NV: RETVAL = "GL_RELATIVE_MOVE_TO_NV"; break;
      case GL_RELATIVE_QUADRATIC_CURVE_TO_NV: RETVAL = "GL_RELATIVE_QUADRATIC_CURVE_TO_NV"; break;
      case GL_RELATIVE_RECT_NV: RETVAL = "GL_RELATIVE_RECT_NV"; break;
      case GL_RELATIVE_ROUNDED_RECT2_NV: RETVAL = "GL_RELATIVE_ROUNDED_RECT2_NV"; break;
      case GL_RELATIVE_ROUNDED_RECT4_NV: RETVAL = "GL_RELATIVE_ROUNDED_RECT4_NV"; break;
      case GL_RELATIVE_ROUNDED_RECT8_NV: RETVAL = "GL_RELATIVE_ROUNDED_RECT8_NV"; break;
      case GL_RELATIVE_ROUNDED_RECT_NV: RETVAL = "GL_RELATIVE_ROUNDED_RECT_NV"; break;
      case GL_RELATIVE_SMALL_CCW_ARC_TO_NV: RETVAL = "GL_RELATIVE_SMALL_CCW_ARC_TO_NV"; break;
      case GL_RELATIVE_SMALL_CW_ARC_TO_NV: RETVAL = "GL_RELATIVE_SMALL_CW_ARC_TO_NV"; break;
      case GL_RELATIVE_SMOOTH_CUBIC_CURVE_TO_NV: RETVAL = "GL_RELATIVE_SMOOTH_CUBIC_CURVE_TO_NV"; break;
      case GL_RELATIVE_SMOOTH_QUADRATIC_CURVE_TO_NV: RETVAL = "GL_RELATIVE_SMOOTH_QUADRATIC_CURVE_TO_NV"; break;
      case GL_RELATIVE_VERTICAL_LINE_TO_NV: RETVAL = "GL_RELATIVE_VERTICAL_LINE_TO_NV"; break;
      case GL_RESTART_PATH_NV: RETVAL = "GL_RESTART_PATH_NV"; break;
      case GL_ROUNDED_RECT2_NV: RETVAL = "GL_ROUNDED_RECT2_NV"; break;
      case GL_ROUNDED_RECT4_NV: RETVAL = "GL_ROUNDED_RECT4_NV"; break;
      case GL_ROUNDED_RECT8_NV: RETVAL = "GL_ROUNDED_RECT8_NV"; break;
      case GL_ROUNDED_RECT_NV: RETVAL = "GL_ROUNDED_RECT_NV"; break;
      case GL_SMALL_CCW_ARC_TO_NV: RETVAL = "GL_SMALL_CCW_ARC_TO_NV"; break;
      case GL_SMALL_CW_ARC_TO_NV: RETVAL = "GL_SMALL_CW_ARC_TO_NV"; break;
      case GL_SMOOTH_CUBIC_CURVE_TO_NV: RETVAL = "GL_SMOOTH_CUBIC_CURVE_TO_NV"; break;
      case GL_SMOOTH_QUADRATIC_CURVE_TO_NV: RETVAL = "GL_SMOOTH_QUADRATIC_CURVE_TO_NV"; break;
      case GL_VERTICAL_LINE_TO_NV: RETVAL = "GL_VERTICAL_LINE_TO_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathCoverMode")) {
    switch (e) {
      case GL_BOUNDING_BOX_NV: RETVAL = "GL_BOUNDING_BOX_NV"; break;
      case GL_CONVEX_HULL_NV: RETVAL = "GL_CONVEX_HULL_NV"; break;
      case GL_PATH_FILL_COVER_MODE_NV: RETVAL = "GL_PATH_FILL_COVER_MODE_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathElementType")) {
    switch (e) {
      case GL_UTF16_NV: RETVAL = "GL_UTF16_NV"; break;
      case GL_UTF8_NV: RETVAL = "GL_UTF8_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathFillMode")) {
    switch (e) {
      case GL_COUNT_DOWN_NV: RETVAL = "GL_COUNT_DOWN_NV"; break;
      case GL_COUNT_UP_NV: RETVAL = "GL_COUNT_UP_NV"; break;
      case GL_INVERT: RETVAL = "GL_INVERT"; break;
      case GL_PATH_FILL_MODE_NV: RETVAL = "GL_PATH_FILL_MODE_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathFontStyle")) {
    switch (e) {
      case GL_BOLD_BIT_NV: RETVAL = "GL_BOLD_BIT_NV"; break;
      case GL_ITALIC_BIT_NV: RETVAL = "GL_ITALIC_BIT_NV"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathFontTarget")) {
    switch (e) {
      case GL_FILE_NAME_NV: RETVAL = "GL_FILE_NAME_NV"; break;
      case GL_STANDARD_FONT_NAME_NV: RETVAL = "GL_STANDARD_FONT_NAME_NV"; break;
      case GL_SYSTEM_FONT_NAME_NV: RETVAL = "GL_SYSTEM_FONT_NAME_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathGenMode")) {
    switch (e) {
      case GL_CONSTANT: RETVAL = "GL_CONSTANT"; break;
      case GL_EYE_LINEAR: RETVAL = "GL_EYE_LINEAR"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_OBJECT_LINEAR: RETVAL = "GL_OBJECT_LINEAR"; break;
      case GL_PATH_OBJECT_BOUNDING_BOX_NV: RETVAL = "GL_PATH_OBJECT_BOUNDING_BOX_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathHandleMissingGlyphs")) {
    switch (e) {
      case GL_SKIP_MISSING_GLYPH_NV: RETVAL = "GL_SKIP_MISSING_GLYPH_NV"; break;
      case GL_USE_MISSING_GLYPH_NV: RETVAL = "GL_USE_MISSING_GLYPH_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathListMode")) {
    switch (e) {
      case GL_ACCUM_ADJACENT_PAIRS_NV: RETVAL = "GL_ACCUM_ADJACENT_PAIRS_NV"; break;
      case GL_ADJACENT_PAIRS_NV: RETVAL = "GL_ADJACENT_PAIRS_NV"; break;
      case GL_FIRST_TO_REST_NV: RETVAL = "GL_FIRST_TO_REST_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathMetricMask")) {
    switch (e) {
      case GL_FONT_ASCENDER_BIT_NV: RETVAL = "GL_FONT_ASCENDER_BIT_NV"; break;
      case GL_FONT_DESCENDER_BIT_NV: RETVAL = "GL_FONT_DESCENDER_BIT_NV"; break;
      case GL_FONT_HAS_KERNING_BIT_NV: RETVAL = "GL_FONT_HAS_KERNING_BIT_NV"; break;
      case GL_FONT_HEIGHT_BIT_NV: RETVAL = "GL_FONT_HEIGHT_BIT_NV"; break;
      case GL_FONT_MAX_ADVANCE_HEIGHT_BIT_NV: RETVAL = "GL_FONT_MAX_ADVANCE_HEIGHT_BIT_NV"; break;
      case GL_FONT_MAX_ADVANCE_WIDTH_BIT_NV: RETVAL = "GL_FONT_MAX_ADVANCE_WIDTH_BIT_NV"; break;
      case GL_FONT_NUM_GLYPH_INDICES_BIT_NV: RETVAL = "GL_FONT_NUM_GLYPH_INDICES_BIT_NV"; break;
      case GL_FONT_UNDERLINE_POSITION_BIT_NV: RETVAL = "GL_FONT_UNDERLINE_POSITION_BIT_NV"; break;
      case GL_FONT_UNDERLINE_THICKNESS_BIT_NV: RETVAL = "GL_FONT_UNDERLINE_THICKNESS_BIT_NV"; break;
      case GL_FONT_UNITS_PER_EM_BIT_NV: RETVAL = "GL_FONT_UNITS_PER_EM_BIT_NV"; break;
      case GL_FONT_X_MAX_BOUNDS_BIT_NV: RETVAL = "GL_FONT_X_MAX_BOUNDS_BIT_NV"; break;
      case GL_FONT_X_MIN_BOUNDS_BIT_NV: RETVAL = "GL_FONT_X_MIN_BOUNDS_BIT_NV"; break;
      case GL_FONT_Y_MAX_BOUNDS_BIT_NV: RETVAL = "GL_FONT_Y_MAX_BOUNDS_BIT_NV"; break;
      case GL_FONT_Y_MIN_BOUNDS_BIT_NV: RETVAL = "GL_FONT_Y_MIN_BOUNDS_BIT_NV"; break;
      case GL_GLYPH_HAS_KERNING_BIT_NV: RETVAL = "GL_GLYPH_HAS_KERNING_BIT_NV"; break;
      case GL_GLYPH_HEIGHT_BIT_NV: RETVAL = "GL_GLYPH_HEIGHT_BIT_NV"; break;
      case GL_GLYPH_HORIZONTAL_BEARING_ADVANCE_BIT_NV: RETVAL = "GL_GLYPH_HORIZONTAL_BEARING_ADVANCE_BIT_NV"; break;
      case GL_GLYPH_HORIZONTAL_BEARING_X_BIT_NV: RETVAL = "GL_GLYPH_HORIZONTAL_BEARING_X_BIT_NV"; break;
      case GL_GLYPH_HORIZONTAL_BEARING_Y_BIT_NV: RETVAL = "GL_GLYPH_HORIZONTAL_BEARING_Y_BIT_NV"; break;
      case GL_GLYPH_VERTICAL_BEARING_ADVANCE_BIT_NV: RETVAL = "GL_GLYPH_VERTICAL_BEARING_ADVANCE_BIT_NV"; break;
      case GL_GLYPH_VERTICAL_BEARING_X_BIT_NV: RETVAL = "GL_GLYPH_VERTICAL_BEARING_X_BIT_NV"; break;
      case GL_GLYPH_VERTICAL_BEARING_Y_BIT_NV: RETVAL = "GL_GLYPH_VERTICAL_BEARING_Y_BIT_NV"; break;
      case GL_GLYPH_WIDTH_BIT_NV: RETVAL = "GL_GLYPH_WIDTH_BIT_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathParameter")) {
    switch (e) {
      case GL_PATH_CLIENT_LENGTH_NV: RETVAL = "GL_PATH_CLIENT_LENGTH_NV"; break;
      case GL_PATH_COMMAND_COUNT_NV: RETVAL = "GL_PATH_COMMAND_COUNT_NV"; break;
      case GL_PATH_COMPUTED_LENGTH_NV: RETVAL = "GL_PATH_COMPUTED_LENGTH_NV"; break;
      case GL_PATH_COORD_COUNT_NV: RETVAL = "GL_PATH_COORD_COUNT_NV"; break;
      case GL_PATH_DASH_ARRAY_COUNT_NV: RETVAL = "GL_PATH_DASH_ARRAY_COUNT_NV"; break;
      case GL_PATH_DASH_CAPS_NV: RETVAL = "GL_PATH_DASH_CAPS_NV"; break;
      case GL_PATH_DASH_OFFSET_NV: RETVAL = "GL_PATH_DASH_OFFSET_NV"; break;
      case GL_PATH_DASH_OFFSET_RESET_NV: RETVAL = "GL_PATH_DASH_OFFSET_RESET_NV"; break;
      case GL_PATH_END_CAPS_NV: RETVAL = "GL_PATH_END_CAPS_NV"; break;
      case GL_PATH_FILL_BOUNDING_BOX_NV: RETVAL = "GL_PATH_FILL_BOUNDING_BOX_NV"; break;
      case GL_PATH_FILL_COVER_MODE_NV: RETVAL = "GL_PATH_FILL_COVER_MODE_NV"; break;
      case GL_PATH_FILL_MASK_NV: RETVAL = "GL_PATH_FILL_MASK_NV"; break;
      case GL_PATH_FILL_MODE_NV: RETVAL = "GL_PATH_FILL_MODE_NV"; break;
      case GL_PATH_INITIAL_DASH_CAP_NV: RETVAL = "GL_PATH_INITIAL_DASH_CAP_NV"; break;
      case GL_PATH_INITIAL_END_CAP_NV: RETVAL = "GL_PATH_INITIAL_END_CAP_NV"; break;
      case GL_PATH_JOIN_STYLE_NV: RETVAL = "GL_PATH_JOIN_STYLE_NV"; break;
      case GL_PATH_MITER_LIMIT_NV: RETVAL = "GL_PATH_MITER_LIMIT_NV"; break;
      case GL_PATH_OBJECT_BOUNDING_BOX_NV: RETVAL = "GL_PATH_OBJECT_BOUNDING_BOX_NV"; break;
      case GL_PATH_STROKE_BOUNDING_BOX_NV: RETVAL = "GL_PATH_STROKE_BOUNDING_BOX_NV"; break;
      case GL_PATH_STROKE_COVER_MODE_NV: RETVAL = "GL_PATH_STROKE_COVER_MODE_NV"; break;
      case GL_PATH_STROKE_MASK_NV: RETVAL = "GL_PATH_STROKE_MASK_NV"; break;
      case GL_PATH_STROKE_WIDTH_NV: RETVAL = "GL_PATH_STROKE_WIDTH_NV"; break;
      case GL_PATH_TERMINAL_DASH_CAP_NV: RETVAL = "GL_PATH_TERMINAL_DASH_CAP_NV"; break;
      case GL_PATH_TERMINAL_END_CAP_NV: RETVAL = "GL_PATH_TERMINAL_END_CAP_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathStringFormat")) {
    switch (e) {
      case GL_PATH_FORMAT_PS_NV: RETVAL = "GL_PATH_FORMAT_PS_NV"; break;
      case GL_PATH_FORMAT_SVG_NV: RETVAL = "GL_PATH_FORMAT_SVG_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathTransformType")) {
    switch (e) {
      case GL_AFFINE_2D_NV: RETVAL = "GL_AFFINE_2D_NV"; break;
      case GL_AFFINE_3D_NV: RETVAL = "GL_AFFINE_3D_NV"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_TRANSLATE_2D_NV: RETVAL = "GL_TRANSLATE_2D_NV"; break;
      case GL_TRANSLATE_3D_NV: RETVAL = "GL_TRANSLATE_3D_NV"; break;
      case GL_TRANSLATE_X_NV: RETVAL = "GL_TRANSLATE_X_NV"; break;
      case GL_TRANSLATE_Y_NV: RETVAL = "GL_TRANSLATE_Y_NV"; break;
      case GL_TRANSPOSE_AFFINE_2D_NV: RETVAL = "GL_TRANSPOSE_AFFINE_2D_NV"; break;
      case GL_TRANSPOSE_AFFINE_3D_NV: RETVAL = "GL_TRANSPOSE_AFFINE_3D_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PerfQueryDataFlags")) {
    switch (e) {
      case GL_PERFQUERY_DONOT_FLUSH_INTEL: RETVAL = "GL_PERFQUERY_DONOT_FLUSH_INTEL"; break;
      case GL_PERFQUERY_FLUSH_INTEL: RETVAL = "GL_PERFQUERY_FLUSH_INTEL"; break;
      case GL_PERFQUERY_WAIT_INTEL: RETVAL = "GL_PERFQUERY_WAIT_INTEL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PerformanceQueryCapsMaskINTEL")) {
    switch (e) {
      case GL_PERFQUERY_GLOBAL_CONTEXT_INTEL: RETVAL = "GL_PERFQUERY_GLOBAL_CONTEXT_INTEL"; break;
      case GL_PERFQUERY_SINGLE_CONTEXT_INTEL: RETVAL = "GL_PERFQUERY_SINGLE_CONTEXT_INTEL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PipelineParameterName")) {
    switch (e) {
      case GL_ACTIVE_PROGRAM: RETVAL = "GL_ACTIVE_PROGRAM"; break;
      case GL_FRAGMENT_SHADER: RETVAL = "GL_FRAGMENT_SHADER"; break;
      case GL_GEOMETRY_SHADER: RETVAL = "GL_GEOMETRY_SHADER"; break;
      case GL_INFO_LOG_LENGTH: RETVAL = "GL_INFO_LOG_LENGTH"; break;
      case GL_TESS_CONTROL_SHADER: RETVAL = "GL_TESS_CONTROL_SHADER"; break;
      case GL_TESS_EVALUATION_SHADER: RETVAL = "GL_TESS_EVALUATION_SHADER"; break;
      case GL_VERTEX_SHADER: RETVAL = "GL_VERTEX_SHADER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelCopyType")) {
    switch (e) {
      case GL_COLOR: RETVAL = "GL_COLOR"; break;
      case GL_DEPTH: RETVAL = "GL_DEPTH"; break;
      case GL_STENCIL: RETVAL = "GL_STENCIL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelDataRangeTargetNV")) {
    switch (e) {
      case GL_READ_PIXEL_DATA_RANGE_NV: RETVAL = "GL_READ_PIXEL_DATA_RANGE_NV"; break;
      case GL_WRITE_PIXEL_DATA_RANGE_NV: RETVAL = "GL_WRITE_PIXEL_DATA_RANGE_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelFormat")) {
    switch (e) {
      case GL_ABGR_EXT: RETVAL = "GL_ABGR_EXT"; break;
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_BGR: RETVAL = "GL_BGR"; break;
      case GL_BGRA: RETVAL = "GL_BGRA"; break;
      case GL_BGRA_INTEGER: RETVAL = "GL_BGRA_INTEGER"; break;
      case GL_BGR_INTEGER: RETVAL = "GL_BGR_INTEGER"; break;
      case GL_BLUE: RETVAL = "GL_BLUE"; break;
      case GL_BLUE_INTEGER: RETVAL = "GL_BLUE_INTEGER"; break;
      case GL_CMYKA_EXT: RETVAL = "GL_CMYKA_EXT"; break;
      case GL_CMYK_EXT: RETVAL = "GL_CMYK_EXT"; break;
      case GL_COLOR_INDEX: RETVAL = "GL_COLOR_INDEX"; break;
      case GL_DEPTH_COMPONENT: RETVAL = "GL_DEPTH_COMPONENT"; break;
      case GL_DEPTH_STENCIL: RETVAL = "GL_DEPTH_STENCIL"; break;
      case GL_GREEN: RETVAL = "GL_GREEN"; break;
      case GL_GREEN_INTEGER: RETVAL = "GL_GREEN_INTEGER"; break;
      case GL_LUMINANCE: RETVAL = "GL_LUMINANCE"; break;
      case GL_LUMINANCE_ALPHA: RETVAL = "GL_LUMINANCE_ALPHA"; break;
      case GL_RED: RETVAL = "GL_RED"; break;
      case GL_RED_INTEGER: RETVAL = "GL_RED_INTEGER"; break;
      case GL_RG: RETVAL = "GL_RG"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      case GL_RGBA: RETVAL = "GL_RGBA"; break;
      case GL_RGBA_INTEGER: RETVAL = "GL_RGBA_INTEGER"; break;
      case GL_RGB_INTEGER: RETVAL = "GL_RGB_INTEGER"; break;
      case GL_RG_INTEGER: RETVAL = "GL_RG_INTEGER"; break;
      case GL_STENCIL_INDEX: RETVAL = "GL_STENCIL_INDEX"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelMap")) {
    switch (e) {
      case GL_PIXEL_MAP_A_TO_A: RETVAL = "GL_PIXEL_MAP_A_TO_A"; break;
      case GL_PIXEL_MAP_B_TO_B: RETVAL = "GL_PIXEL_MAP_B_TO_B"; break;
      case GL_PIXEL_MAP_G_TO_G: RETVAL = "GL_PIXEL_MAP_G_TO_G"; break;
      case GL_PIXEL_MAP_I_TO_A: RETVAL = "GL_PIXEL_MAP_I_TO_A"; break;
      case GL_PIXEL_MAP_I_TO_B: RETVAL = "GL_PIXEL_MAP_I_TO_B"; break;
      case GL_PIXEL_MAP_I_TO_G: RETVAL = "GL_PIXEL_MAP_I_TO_G"; break;
      case GL_PIXEL_MAP_I_TO_I: RETVAL = "GL_PIXEL_MAP_I_TO_I"; break;
      case GL_PIXEL_MAP_I_TO_R: RETVAL = "GL_PIXEL_MAP_I_TO_R"; break;
      case GL_PIXEL_MAP_R_TO_R: RETVAL = "GL_PIXEL_MAP_R_TO_R"; break;
      case GL_PIXEL_MAP_S_TO_S: RETVAL = "GL_PIXEL_MAP_S_TO_S"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelStoreParameter")) {
    switch (e) {
      case GL_PACK_ALIGNMENT: RETVAL = "GL_PACK_ALIGNMENT"; break;
      case GL_PACK_IMAGE_HEIGHT: RETVAL = "GL_PACK_IMAGE_HEIGHT"; break;
      case GL_PACK_LSB_FIRST: RETVAL = "GL_PACK_LSB_FIRST"; break;
      case GL_PACK_RESAMPLE_OML: RETVAL = "GL_PACK_RESAMPLE_OML"; break;
      case GL_PACK_RESAMPLE_SGIX: RETVAL = "GL_PACK_RESAMPLE_SGIX"; break;
      case GL_PACK_ROW_LENGTH: RETVAL = "GL_PACK_ROW_LENGTH"; break;
      case GL_PACK_SKIP_IMAGES: RETVAL = "GL_PACK_SKIP_IMAGES"; break;
      case GL_PACK_SKIP_PIXELS: RETVAL = "GL_PACK_SKIP_PIXELS"; break;
      case GL_PACK_SKIP_ROWS: RETVAL = "GL_PACK_SKIP_ROWS"; break;
      case GL_PACK_SUBSAMPLE_RATE_SGIX: RETVAL = "GL_PACK_SUBSAMPLE_RATE_SGIX"; break;
      case GL_PACK_SWAP_BYTES: RETVAL = "GL_PACK_SWAP_BYTES"; break;
      case GL_UNPACK_ALIGNMENT: RETVAL = "GL_UNPACK_ALIGNMENT"; break;
      case GL_UNPACK_IMAGE_HEIGHT: RETVAL = "GL_UNPACK_IMAGE_HEIGHT"; break;
      case GL_UNPACK_LSB_FIRST: RETVAL = "GL_UNPACK_LSB_FIRST"; break;
      case GL_UNPACK_RESAMPLE_OML: RETVAL = "GL_UNPACK_RESAMPLE_OML"; break;
      case GL_UNPACK_RESAMPLE_SGIX: RETVAL = "GL_UNPACK_RESAMPLE_SGIX"; break;
      case GL_UNPACK_ROW_LENGTH: RETVAL = "GL_UNPACK_ROW_LENGTH"; break;
      case GL_UNPACK_SKIP_IMAGES: RETVAL = "GL_UNPACK_SKIP_IMAGES"; break;
      case GL_UNPACK_SKIP_PIXELS: RETVAL = "GL_UNPACK_SKIP_PIXELS"; break;
      case GL_UNPACK_SKIP_ROWS: RETVAL = "GL_UNPACK_SKIP_ROWS"; break;
      case GL_UNPACK_SUBSAMPLE_RATE_SGIX: RETVAL = "GL_UNPACK_SUBSAMPLE_RATE_SGIX"; break;
      case GL_UNPACK_SWAP_BYTES: RETVAL = "GL_UNPACK_SWAP_BYTES"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelStoreResampleMode")) {
    switch (e) {
      case GL_RESAMPLE_DECIMATE_SGIX: RETVAL = "GL_RESAMPLE_DECIMATE_SGIX"; break;
      case GL_RESAMPLE_REPLICATE_SGIX: RETVAL = "GL_RESAMPLE_REPLICATE_SGIX"; break;
      case GL_RESAMPLE_ZERO_FILL_SGIX: RETVAL = "GL_RESAMPLE_ZERO_FILL_SGIX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelStoreSubsampleRate")) {
    switch (e) {
      case GL_PIXEL_SUBSAMPLE_2424_SGIX: RETVAL = "GL_PIXEL_SUBSAMPLE_2424_SGIX"; break;
      case GL_PIXEL_SUBSAMPLE_4242_SGIX: RETVAL = "GL_PIXEL_SUBSAMPLE_4242_SGIX"; break;
      case GL_PIXEL_SUBSAMPLE_4444_SGIX: RETVAL = "GL_PIXEL_SUBSAMPLE_4444_SGIX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelTexGenModeSGIX")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      case GL_RGBA: RETVAL = "GL_RGBA"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelTransferParameter")) {
    switch (e) {
      case GL_ALPHA_BIAS: RETVAL = "GL_ALPHA_BIAS"; break;
      case GL_ALPHA_SCALE: RETVAL = "GL_ALPHA_SCALE"; break;
      case GL_BLUE_BIAS: RETVAL = "GL_BLUE_BIAS"; break;
      case GL_BLUE_SCALE: RETVAL = "GL_BLUE_SCALE"; break;
      case GL_DEPTH_BIAS: RETVAL = "GL_DEPTH_BIAS"; break;
      case GL_DEPTH_SCALE: RETVAL = "GL_DEPTH_SCALE"; break;
      case GL_GREEN_BIAS: RETVAL = "GL_GREEN_BIAS"; break;
      case GL_GREEN_SCALE: RETVAL = "GL_GREEN_SCALE"; break;
      case GL_INDEX_OFFSET: RETVAL = "GL_INDEX_OFFSET"; break;
      case GL_INDEX_SHIFT: RETVAL = "GL_INDEX_SHIFT"; break;
      case GL_MAP_COLOR: RETVAL = "GL_MAP_COLOR"; break;
      case GL_MAP_STENCIL: RETVAL = "GL_MAP_STENCIL"; break;
      case GL_POST_COLOR_MATRIX_ALPHA_BIAS: RETVAL = "GL_POST_COLOR_MATRIX_ALPHA_BIAS"; break;
      case GL_POST_COLOR_MATRIX_ALPHA_SCALE: RETVAL = "GL_POST_COLOR_MATRIX_ALPHA_SCALE"; break;
      case GL_POST_COLOR_MATRIX_BLUE_BIAS: RETVAL = "GL_POST_COLOR_MATRIX_BLUE_BIAS"; break;
      case GL_POST_COLOR_MATRIX_BLUE_SCALE: RETVAL = "GL_POST_COLOR_MATRIX_BLUE_SCALE"; break;
      case GL_POST_COLOR_MATRIX_GREEN_BIAS: RETVAL = "GL_POST_COLOR_MATRIX_GREEN_BIAS"; break;
      case GL_POST_COLOR_MATRIX_GREEN_SCALE: RETVAL = "GL_POST_COLOR_MATRIX_GREEN_SCALE"; break;
      case GL_POST_COLOR_MATRIX_RED_BIAS: RETVAL = "GL_POST_COLOR_MATRIX_RED_BIAS"; break;
      case GL_POST_COLOR_MATRIX_RED_SCALE: RETVAL = "GL_POST_COLOR_MATRIX_RED_SCALE"; break;
      case GL_POST_CONVOLUTION_ALPHA_BIAS: RETVAL = "GL_POST_CONVOLUTION_ALPHA_BIAS"; break;
      case GL_POST_CONVOLUTION_ALPHA_SCALE: RETVAL = "GL_POST_CONVOLUTION_ALPHA_SCALE"; break;
      case GL_POST_CONVOLUTION_BLUE_BIAS: RETVAL = "GL_POST_CONVOLUTION_BLUE_BIAS"; break;
      case GL_POST_CONVOLUTION_BLUE_SCALE: RETVAL = "GL_POST_CONVOLUTION_BLUE_SCALE"; break;
      case GL_POST_CONVOLUTION_GREEN_BIAS: RETVAL = "GL_POST_CONVOLUTION_GREEN_BIAS"; break;
      case GL_POST_CONVOLUTION_GREEN_SCALE: RETVAL = "GL_POST_CONVOLUTION_GREEN_SCALE"; break;
      case GL_POST_CONVOLUTION_RED_BIAS: RETVAL = "GL_POST_CONVOLUTION_RED_BIAS"; break;
      case GL_POST_CONVOLUTION_RED_SCALE: RETVAL = "GL_POST_CONVOLUTION_RED_SCALE"; break;
      case GL_RED_BIAS: RETVAL = "GL_RED_BIAS"; break;
      case GL_RED_SCALE: RETVAL = "GL_RED_SCALE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelTransformPNameEXT")) {
    switch (e) {
      case GL_PIXEL_CUBIC_WEIGHT_EXT: RETVAL = "GL_PIXEL_CUBIC_WEIGHT_EXT"; break;
      case GL_PIXEL_MAG_FILTER_EXT: RETVAL = "GL_PIXEL_MAG_FILTER_EXT"; break;
      case GL_PIXEL_MIN_FILTER_EXT: RETVAL = "GL_PIXEL_MIN_FILTER_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelTransformTargetEXT")) {
    switch (e) {
      case GL_PIXEL_TRANSFORM_2D_EXT: RETVAL = "GL_PIXEL_TRANSFORM_2D_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelType")) {
    switch (e) {
      case GL_BITMAP: RETVAL = "GL_BITMAP"; break;
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_FLOAT_32_UNSIGNED_INT_24_8_REV: RETVAL = "GL_FLOAT_32_UNSIGNED_INT_24_8_REV"; break;
      case GL_HALF_FLOAT: RETVAL = "GL_HALF_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_BYTE_2_3_3_REV: RETVAL = "GL_UNSIGNED_BYTE_2_3_3_REV"; break;
      case GL_UNSIGNED_BYTE_3_3_2: RETVAL = "GL_UNSIGNED_BYTE_3_3_2"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_INT_10F_11F_11F_REV: RETVAL = "GL_UNSIGNED_INT_10F_11F_11F_REV"; break;
      case GL_UNSIGNED_INT_10_10_10_2: RETVAL = "GL_UNSIGNED_INT_10_10_10_2"; break;
      case GL_UNSIGNED_INT_24_8: RETVAL = "GL_UNSIGNED_INT_24_8"; break;
      case GL_UNSIGNED_INT_2_10_10_10_REV: RETVAL = "GL_UNSIGNED_INT_2_10_10_10_REV"; break;
      case GL_UNSIGNED_INT_5_9_9_9_REV: RETVAL = "GL_UNSIGNED_INT_5_9_9_9_REV"; break;
      case GL_UNSIGNED_INT_8_8_8_8: RETVAL = "GL_UNSIGNED_INT_8_8_8_8"; break;
      case GL_UNSIGNED_INT_8_8_8_8_REV: RETVAL = "GL_UNSIGNED_INT_8_8_8_8_REV"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      case GL_UNSIGNED_SHORT_1_5_5_5_REV: RETVAL = "GL_UNSIGNED_SHORT_1_5_5_5_REV"; break;
      case GL_UNSIGNED_SHORT_4_4_4_4: RETVAL = "GL_UNSIGNED_SHORT_4_4_4_4"; break;
      case GL_UNSIGNED_SHORT_4_4_4_4_REV: RETVAL = "GL_UNSIGNED_SHORT_4_4_4_4_REV"; break;
      case GL_UNSIGNED_SHORT_5_5_5_1: RETVAL = "GL_UNSIGNED_SHORT_5_5_5_1"; break;
      case GL_UNSIGNED_SHORT_5_6_5: RETVAL = "GL_UNSIGNED_SHORT_5_6_5"; break;
      case GL_UNSIGNED_SHORT_5_6_5_REV: RETVAL = "GL_UNSIGNED_SHORT_5_6_5_REV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PointParameterNameARB")) {
    switch (e) {
      case GL_DISTANCE_ATTENUATION_EXT: RETVAL = "GL_DISTANCE_ATTENUATION_EXT"; break;
      case GL_POINT_FADE_THRESHOLD_SIZE: RETVAL = "GL_POINT_FADE_THRESHOLD_SIZE"; break;
      case GL_POINT_SIZE_MAX: RETVAL = "GL_POINT_SIZE_MAX"; break;
      case GL_POINT_SIZE_MIN: RETVAL = "GL_POINT_SIZE_MIN"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PolygonMode")) {
    switch (e) {
      case GL_FILL: RETVAL = "GL_FILL"; break;
      case GL_LINE: RETVAL = "GL_LINE"; break;
      case GL_POINT: RETVAL = "GL_POINT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PrecisionType")) {
    switch (e) {
      case GL_HIGH_FLOAT: RETVAL = "GL_HIGH_FLOAT"; break;
      case GL_HIGH_INT: RETVAL = "GL_HIGH_INT"; break;
      case GL_LOW_FLOAT: RETVAL = "GL_LOW_FLOAT"; break;
      case GL_LOW_INT: RETVAL = "GL_LOW_INT"; break;
      case GL_MEDIUM_FLOAT: RETVAL = "GL_MEDIUM_FLOAT"; break;
      case GL_MEDIUM_INT: RETVAL = "GL_MEDIUM_INT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PreserveModeATI")) {
    switch (e) {
      case GL_DISCARD_ATI: RETVAL = "GL_DISCARD_ATI"; break;
      case GL_PRESERVE_ATI: RETVAL = "GL_PRESERVE_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PrimitiveType")) {
    switch (e) {
      case GL_LINES: RETVAL = "GL_LINES"; break;
      case GL_LINES_ADJACENCY: RETVAL = "GL_LINES_ADJACENCY"; break;
      case GL_LINE_LOOP: RETVAL = "GL_LINE_LOOP"; break;
      case GL_LINE_STRIP: RETVAL = "GL_LINE_STRIP"; break;
      case GL_LINE_STRIP_ADJACENCY: RETVAL = "GL_LINE_STRIP_ADJACENCY"; break;
      case GL_PATCHES: RETVAL = "GL_PATCHES"; break;
      case GL_POINTS: RETVAL = "GL_POINTS"; break;
      case GL_POLYGON: RETVAL = "GL_POLYGON"; break;
      case GL_QUADS: RETVAL = "GL_QUADS"; break;
      case GL_QUAD_STRIP: RETVAL = "GL_QUAD_STRIP"; break;
      case GL_TRIANGLES: RETVAL = "GL_TRIANGLES"; break;
      case GL_TRIANGLES_ADJACENCY: RETVAL = "GL_TRIANGLES_ADJACENCY"; break;
      case GL_TRIANGLE_FAN: RETVAL = "GL_TRIANGLE_FAN"; break;
      case GL_TRIANGLE_STRIP: RETVAL = "GL_TRIANGLE_STRIP"; break;
      case GL_TRIANGLE_STRIP_ADJACENCY: RETVAL = "GL_TRIANGLE_STRIP_ADJACENCY"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramFormat")) {
    switch (e) {
      case GL_PROGRAM_FORMAT_ASCII_ARB: RETVAL = "GL_PROGRAM_FORMAT_ASCII_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramInterface")) {
    switch (e) {
      case GL_BUFFER_VARIABLE: RETVAL = "GL_BUFFER_VARIABLE"; break;
      case GL_COMPUTE_SUBROUTINE: RETVAL = "GL_COMPUTE_SUBROUTINE"; break;
      case GL_COMPUTE_SUBROUTINE_UNIFORM: RETVAL = "GL_COMPUTE_SUBROUTINE_UNIFORM"; break;
      case GL_FRAGMENT_SUBROUTINE: RETVAL = "GL_FRAGMENT_SUBROUTINE"; break;
      case GL_FRAGMENT_SUBROUTINE_UNIFORM: RETVAL = "GL_FRAGMENT_SUBROUTINE_UNIFORM"; break;
      case GL_GEOMETRY_SUBROUTINE: RETVAL = "GL_GEOMETRY_SUBROUTINE"; break;
      case GL_GEOMETRY_SUBROUTINE_UNIFORM: RETVAL = "GL_GEOMETRY_SUBROUTINE_UNIFORM"; break;
      case GL_PROGRAM_INPUT: RETVAL = "GL_PROGRAM_INPUT"; break;
      case GL_PROGRAM_OUTPUT: RETVAL = "GL_PROGRAM_OUTPUT"; break;
      case GL_SHADER_STORAGE_BLOCK: RETVAL = "GL_SHADER_STORAGE_BLOCK"; break;
      case GL_TESS_CONTROL_SUBROUTINE: RETVAL = "GL_TESS_CONTROL_SUBROUTINE"; break;
      case GL_TESS_CONTROL_SUBROUTINE_UNIFORM: RETVAL = "GL_TESS_CONTROL_SUBROUTINE_UNIFORM"; break;
      case GL_TESS_EVALUATION_SUBROUTINE: RETVAL = "GL_TESS_EVALUATION_SUBROUTINE"; break;
      case GL_TESS_EVALUATION_SUBROUTINE_UNIFORM: RETVAL = "GL_TESS_EVALUATION_SUBROUTINE_UNIFORM"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER"; break;
      case GL_TRANSFORM_FEEDBACK_VARYING: RETVAL = "GL_TRANSFORM_FEEDBACK_VARYING"; break;
      case GL_UNIFORM: RETVAL = "GL_UNIFORM"; break;
      case GL_UNIFORM_BLOCK: RETVAL = "GL_UNIFORM_BLOCK"; break;
      case GL_VERTEX_SUBROUTINE: RETVAL = "GL_VERTEX_SUBROUTINE"; break;
      case GL_VERTEX_SUBROUTINE_UNIFORM: RETVAL = "GL_VERTEX_SUBROUTINE_UNIFORM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramInterfacePName")) {
    switch (e) {
      case GL_ACTIVE_RESOURCES: RETVAL = "GL_ACTIVE_RESOURCES"; break;
      case GL_MAX_NAME_LENGTH: RETVAL = "GL_MAX_NAME_LENGTH"; break;
      case GL_MAX_NUM_ACTIVE_VARIABLES: RETVAL = "GL_MAX_NUM_ACTIVE_VARIABLES"; break;
      case GL_MAX_NUM_COMPATIBLE_SUBROUTINES: RETVAL = "GL_MAX_NUM_COMPATIBLE_SUBROUTINES"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramParameterPName")) {
    switch (e) {
      case GL_PROGRAM_BINARY_RETRIEVABLE_HINT: RETVAL = "GL_PROGRAM_BINARY_RETRIEVABLE_HINT"; break;
      case GL_PROGRAM_SEPARABLE: RETVAL = "GL_PROGRAM_SEPARABLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramPropertyARB")) {
    switch (e) {
      case GL_ACTIVE_ATOMIC_COUNTER_BUFFERS: RETVAL = "GL_ACTIVE_ATOMIC_COUNTER_BUFFERS"; break;
      case GL_ACTIVE_ATTRIBUTES: RETVAL = "GL_ACTIVE_ATTRIBUTES"; break;
      case GL_ACTIVE_ATTRIBUTE_MAX_LENGTH: RETVAL = "GL_ACTIVE_ATTRIBUTE_MAX_LENGTH"; break;
      case GL_ACTIVE_UNIFORMS: RETVAL = "GL_ACTIVE_UNIFORMS"; break;
      case GL_ACTIVE_UNIFORM_BLOCKS: RETVAL = "GL_ACTIVE_UNIFORM_BLOCKS"; break;
      case GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH: RETVAL = "GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH"; break;
      case GL_ACTIVE_UNIFORM_MAX_LENGTH: RETVAL = "GL_ACTIVE_UNIFORM_MAX_LENGTH"; break;
      case GL_ATTACHED_SHADERS: RETVAL = "GL_ATTACHED_SHADERS"; break;
      case GL_COMPUTE_WORK_GROUP_SIZE: RETVAL = "GL_COMPUTE_WORK_GROUP_SIZE"; break;
      case GL_DELETE_STATUS: RETVAL = "GL_DELETE_STATUS"; break;
      case GL_GEOMETRY_INPUT_TYPE: RETVAL = "GL_GEOMETRY_INPUT_TYPE"; break;
      case GL_GEOMETRY_OUTPUT_TYPE: RETVAL = "GL_GEOMETRY_OUTPUT_TYPE"; break;
      case GL_GEOMETRY_VERTICES_OUT: RETVAL = "GL_GEOMETRY_VERTICES_OUT"; break;
      case GL_INFO_LOG_LENGTH: RETVAL = "GL_INFO_LOG_LENGTH"; break;
      case GL_LINK_STATUS: RETVAL = "GL_LINK_STATUS"; break;
      case GL_PROGRAM_BINARY_LENGTH: RETVAL = "GL_PROGRAM_BINARY_LENGTH"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_MODE: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_MODE"; break;
      case GL_TRANSFORM_FEEDBACK_VARYINGS: RETVAL = "GL_TRANSFORM_FEEDBACK_VARYINGS"; break;
      case GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH: RETVAL = "GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH"; break;
      case GL_VALIDATE_STATUS: RETVAL = "GL_VALIDATE_STATUS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramResourceProperty")) {
    switch (e) {
      case GL_ACTIVE_VARIABLES: RETVAL = "GL_ACTIVE_VARIABLES"; break;
      case GL_ARRAY_SIZE: RETVAL = "GL_ARRAY_SIZE"; break;
      case GL_ARRAY_STRIDE: RETVAL = "GL_ARRAY_STRIDE"; break;
      case GL_ATOMIC_COUNTER_BUFFER_INDEX: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_INDEX"; break;
      case GL_BLOCK_INDEX: RETVAL = "GL_BLOCK_INDEX"; break;
      case GL_BUFFER_BINDING: RETVAL = "GL_BUFFER_BINDING"; break;
      case GL_BUFFER_DATA_SIZE: RETVAL = "GL_BUFFER_DATA_SIZE"; break;
      case GL_COMPATIBLE_SUBROUTINES: RETVAL = "GL_COMPATIBLE_SUBROUTINES"; break;
      case GL_IS_PER_PATCH: RETVAL = "GL_IS_PER_PATCH"; break;
      case GL_IS_ROW_MAJOR: RETVAL = "GL_IS_ROW_MAJOR"; break;
      case GL_LOCATION: RETVAL = "GL_LOCATION"; break;
      case GL_LOCATION_COMPONENT: RETVAL = "GL_LOCATION_COMPONENT"; break;
      case GL_LOCATION_INDEX: RETVAL = "GL_LOCATION_INDEX"; break;
      case GL_MATRIX_STRIDE: RETVAL = "GL_MATRIX_STRIDE"; break;
      case GL_NAME_LENGTH: RETVAL = "GL_NAME_LENGTH"; break;
      case GL_NUM_ACTIVE_VARIABLES: RETVAL = "GL_NUM_ACTIVE_VARIABLES"; break;
      case GL_NUM_COMPATIBLE_SUBROUTINES: RETVAL = "GL_NUM_COMPATIBLE_SUBROUTINES"; break;
      case GL_OFFSET: RETVAL = "GL_OFFSET"; break;
      case GL_REFERENCED_BY_COMPUTE_SHADER: RETVAL = "GL_REFERENCED_BY_COMPUTE_SHADER"; break;
      case GL_REFERENCED_BY_FRAGMENT_SHADER: RETVAL = "GL_REFERENCED_BY_FRAGMENT_SHADER"; break;
      case GL_REFERENCED_BY_GEOMETRY_SHADER: RETVAL = "GL_REFERENCED_BY_GEOMETRY_SHADER"; break;
      case GL_REFERENCED_BY_TESS_CONTROL_SHADER: RETVAL = "GL_REFERENCED_BY_TESS_CONTROL_SHADER"; break;
      case GL_REFERENCED_BY_TESS_EVALUATION_SHADER: RETVAL = "GL_REFERENCED_BY_TESS_EVALUATION_SHADER"; break;
      case GL_REFERENCED_BY_VERTEX_SHADER: RETVAL = "GL_REFERENCED_BY_VERTEX_SHADER"; break;
      case GL_TOP_LEVEL_ARRAY_SIZE: RETVAL = "GL_TOP_LEVEL_ARRAY_SIZE"; break;
      case GL_TOP_LEVEL_ARRAY_STRIDE: RETVAL = "GL_TOP_LEVEL_ARRAY_STRIDE"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_INDEX: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_INDEX"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE"; break;
      case GL_TYPE: RETVAL = "GL_TYPE"; break;
      case GL_UNIFORM: RETVAL = "GL_UNIFORM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramStagePName")) {
    switch (e) {
      case GL_ACTIVE_SUBROUTINES: RETVAL = "GL_ACTIVE_SUBROUTINES"; break;
      case GL_ACTIVE_SUBROUTINE_MAX_LENGTH: RETVAL = "GL_ACTIVE_SUBROUTINE_MAX_LENGTH"; break;
      case GL_ACTIVE_SUBROUTINE_UNIFORMS: RETVAL = "GL_ACTIVE_SUBROUTINE_UNIFORMS"; break;
      case GL_ACTIVE_SUBROUTINE_UNIFORM_LOCATIONS: RETVAL = "GL_ACTIVE_SUBROUTINE_UNIFORM_LOCATIONS"; break;
      case GL_ACTIVE_SUBROUTINE_UNIFORM_MAX_LENGTH: RETVAL = "GL_ACTIVE_SUBROUTINE_UNIFORM_MAX_LENGTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramStringProperty")) {
    switch (e) {
      case GL_PROGRAM_STRING_ARB: RETVAL = "GL_PROGRAM_STRING_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramTarget")) {
    switch (e) {
      case GL_COMPUTE_PROGRAM_NV: RETVAL = "GL_COMPUTE_PROGRAM_NV"; break;
      case GL_FRAGMENT_PROGRAM_ARB: RETVAL = "GL_FRAGMENT_PROGRAM_ARB"; break;
      case GL_GEOMETRY_PROGRAM_NV: RETVAL = "GL_GEOMETRY_PROGRAM_NV"; break;
      case GL_TESS_CONTROL_PROGRAM_NV: RETVAL = "GL_TESS_CONTROL_PROGRAM_NV"; break;
      case GL_TESS_EVALUATION_PROGRAM_NV: RETVAL = "GL_TESS_EVALUATION_PROGRAM_NV"; break;
      case GL_TEXT_FRAGMENT_SHADER_ATI: RETVAL = "GL_TEXT_FRAGMENT_SHADER_ATI"; break;
      case GL_VERTEX_PROGRAM_ARB: RETVAL = "GL_VERTEX_PROGRAM_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "QueryCounterTarget")) {
    switch (e) {
      case GL_TIMESTAMP: RETVAL = "GL_TIMESTAMP"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "QueryObjectParameterName")) {
    switch (e) {
      case GL_QUERY_RESULT: RETVAL = "GL_QUERY_RESULT"; break;
      case GL_QUERY_RESULT_AVAILABLE: RETVAL = "GL_QUERY_RESULT_AVAILABLE"; break;
      case GL_QUERY_RESULT_NO_WAIT: RETVAL = "GL_QUERY_RESULT_NO_WAIT"; break;
      case GL_QUERY_TARGET: RETVAL = "GL_QUERY_TARGET"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "QueryParameterName")) {
    switch (e) {
      case GL_CURRENT_QUERY: RETVAL = "GL_CURRENT_QUERY"; break;
      case GL_QUERY_COUNTER_BITS: RETVAL = "GL_QUERY_COUNTER_BITS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "QueryTarget")) {
    switch (e) {
      case GL_ANY_SAMPLES_PASSED: RETVAL = "GL_ANY_SAMPLES_PASSED"; break;
      case GL_ANY_SAMPLES_PASSED_CONSERVATIVE: RETVAL = "GL_ANY_SAMPLES_PASSED_CONSERVATIVE"; break;
      case GL_MESH_PRIMITIVES_GENERATED_EXT: RETVAL = "GL_MESH_PRIMITIVES_GENERATED_EXT"; break;
      case GL_MESH_SHADER_INVOCATIONS_EXT: RETVAL = "GL_MESH_SHADER_INVOCATIONS_EXT"; break;
      case GL_PRIMITIVES_GENERATED: RETVAL = "GL_PRIMITIVES_GENERATED"; break;
      case GL_PRIMITIVES_SUBMITTED: RETVAL = "GL_PRIMITIVES_SUBMITTED"; break;
      case GL_SAMPLES_PASSED: RETVAL = "GL_SAMPLES_PASSED"; break;
      case GL_TASK_SHADER_INVOCATIONS_EXT: RETVAL = "GL_TASK_SHADER_INVOCATIONS_EXT"; break;
      case GL_TIME_ELAPSED: RETVAL = "GL_TIME_ELAPSED"; break;
      case GL_TRANSFORM_FEEDBACK_OVERFLOW: RETVAL = "GL_TRANSFORM_FEEDBACK_OVERFLOW"; break;
      case GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN: RETVAL = "GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN"; break;
      case GL_VERTEX_SHADER_INVOCATIONS: RETVAL = "GL_VERTEX_SHADER_INVOCATIONS"; break;
      case GL_VERTICES_SUBMITTED: RETVAL = "GL_VERTICES_SUBMITTED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ReadBufferMode")) {
    switch (e) {
      case GL_AUX0: RETVAL = "GL_AUX0"; break;
      case GL_AUX1: RETVAL = "GL_AUX1"; break;
      case GL_AUX2: RETVAL = "GL_AUX2"; break;
      case GL_AUX3: RETVAL = "GL_AUX3"; break;
      case GL_BACK: RETVAL = "GL_BACK"; break;
      case GL_BACK_LEFT: RETVAL = "GL_BACK_LEFT"; break;
      case GL_BACK_RIGHT: RETVAL = "GL_BACK_RIGHT"; break;
      case GL_COLOR_ATTACHMENT0: RETVAL = "GL_COLOR_ATTACHMENT0"; break;
      case GL_COLOR_ATTACHMENT1: RETVAL = "GL_COLOR_ATTACHMENT1"; break;
      case GL_COLOR_ATTACHMENT10: RETVAL = "GL_COLOR_ATTACHMENT10"; break;
      case GL_COLOR_ATTACHMENT11: RETVAL = "GL_COLOR_ATTACHMENT11"; break;
      case GL_COLOR_ATTACHMENT12: RETVAL = "GL_COLOR_ATTACHMENT12"; break;
      case GL_COLOR_ATTACHMENT13: RETVAL = "GL_COLOR_ATTACHMENT13"; break;
      case GL_COLOR_ATTACHMENT14: RETVAL = "GL_COLOR_ATTACHMENT14"; break;
      case GL_COLOR_ATTACHMENT15: RETVAL = "GL_COLOR_ATTACHMENT15"; break;
      case GL_COLOR_ATTACHMENT2: RETVAL = "GL_COLOR_ATTACHMENT2"; break;
      case GL_COLOR_ATTACHMENT3: RETVAL = "GL_COLOR_ATTACHMENT3"; break;
      case GL_COLOR_ATTACHMENT4: RETVAL = "GL_COLOR_ATTACHMENT4"; break;
      case GL_COLOR_ATTACHMENT5: RETVAL = "GL_COLOR_ATTACHMENT5"; break;
      case GL_COLOR_ATTACHMENT6: RETVAL = "GL_COLOR_ATTACHMENT6"; break;
      case GL_COLOR_ATTACHMENT7: RETVAL = "GL_COLOR_ATTACHMENT7"; break;
      case GL_COLOR_ATTACHMENT8: RETVAL = "GL_COLOR_ATTACHMENT8"; break;
      case GL_COLOR_ATTACHMENT9: RETVAL = "GL_COLOR_ATTACHMENT9"; break;
      case GL_FRONT: RETVAL = "GL_FRONT"; break;
      case GL_FRONT_LEFT: RETVAL = "GL_FRONT_LEFT"; break;
      case GL_FRONT_RIGHT: RETVAL = "GL_FRONT_RIGHT"; break;
      case GL_LEFT: RETVAL = "GL_LEFT"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RIGHT: RETVAL = "GL_RIGHT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "RenderbufferParameterName")) {
    switch (e) {
      case GL_RENDERBUFFER_ALPHA_SIZE: RETVAL = "GL_RENDERBUFFER_ALPHA_SIZE"; break;
      case GL_RENDERBUFFER_BLUE_SIZE: RETVAL = "GL_RENDERBUFFER_BLUE_SIZE"; break;
      case GL_RENDERBUFFER_COLOR_SAMPLES_NV: RETVAL = "GL_RENDERBUFFER_COLOR_SAMPLES_NV"; break;
      case GL_RENDERBUFFER_DEPTH_SIZE: RETVAL = "GL_RENDERBUFFER_DEPTH_SIZE"; break;
      case GL_RENDERBUFFER_GREEN_SIZE: RETVAL = "GL_RENDERBUFFER_GREEN_SIZE"; break;
      case GL_RENDERBUFFER_HEIGHT: RETVAL = "GL_RENDERBUFFER_HEIGHT"; break;
      case GL_RENDERBUFFER_INTERNAL_FORMAT: RETVAL = "GL_RENDERBUFFER_INTERNAL_FORMAT"; break;
      case GL_RENDERBUFFER_RED_SIZE: RETVAL = "GL_RENDERBUFFER_RED_SIZE"; break;
      case GL_RENDERBUFFER_SAMPLES: RETVAL = "GL_RENDERBUFFER_SAMPLES"; break;
      case GL_RENDERBUFFER_SAMPLES_IMG: RETVAL = "GL_RENDERBUFFER_SAMPLES_IMG"; break;
      case GL_RENDERBUFFER_STENCIL_SIZE: RETVAL = "GL_RENDERBUFFER_STENCIL_SIZE"; break;
      case GL_RENDERBUFFER_STORAGE_SAMPLES_AMD: RETVAL = "GL_RENDERBUFFER_STORAGE_SAMPLES_AMD"; break;
      case GL_RENDERBUFFER_WIDTH: RETVAL = "GL_RENDERBUFFER_WIDTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "RenderbufferTarget")) {
    switch (e) {
      case GL_RENDERBUFFER: RETVAL = "GL_RENDERBUFFER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "RenderingMode")) {
    switch (e) {
      case GL_FEEDBACK: RETVAL = "GL_FEEDBACK"; break;
      case GL_RENDER: RETVAL = "GL_RENDER"; break;
      case GL_SELECT: RETVAL = "GL_SELECT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ReplacementCodeTypeSUN")) {
    switch (e) {
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SamplePatternEXT")) {
    switch (e) {
      case GL_1PASS_EXT: RETVAL = "GL_1PASS_EXT"; break;
      case GL_2PASS_0_EXT: RETVAL = "GL_2PASS_0_EXT"; break;
      case GL_2PASS_1_EXT: RETVAL = "GL_2PASS_1_EXT"; break;
      case GL_4PASS_0_EXT: RETVAL = "GL_4PASS_0_EXT"; break;
      case GL_4PASS_1_EXT: RETVAL = "GL_4PASS_1_EXT"; break;
      case GL_4PASS_2_EXT: RETVAL = "GL_4PASS_2_EXT"; break;
      case GL_4PASS_3_EXT: RETVAL = "GL_4PASS_3_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SamplePatternSGIS")) {
    switch (e) {
      case GL_1PASS_EXT: RETVAL = "GL_1PASS_EXT"; break;
      case GL_2PASS_0_EXT: RETVAL = "GL_2PASS_0_EXT"; break;
      case GL_2PASS_1_EXT: RETVAL = "GL_2PASS_1_EXT"; break;
      case GL_4PASS_0_EXT: RETVAL = "GL_4PASS_0_EXT"; break;
      case GL_4PASS_1_EXT: RETVAL = "GL_4PASS_1_EXT"; break;
      case GL_4PASS_2_EXT: RETVAL = "GL_4PASS_2_EXT"; break;
      case GL_4PASS_3_EXT: RETVAL = "GL_4PASS_3_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SamplerParameterF")) {
    switch (e) {
      case GL_TEXTURE_BORDER_COLOR: RETVAL = "GL_TEXTURE_BORDER_COLOR"; break;
      case GL_TEXTURE_LOD_BIAS: RETVAL = "GL_TEXTURE_LOD_BIAS"; break;
      case GL_TEXTURE_MAX_ANISOTROPY: RETVAL = "GL_TEXTURE_MAX_ANISOTROPY"; break;
      case GL_TEXTURE_MAX_LOD: RETVAL = "GL_TEXTURE_MAX_LOD"; break;
      case GL_TEXTURE_MIN_LOD: RETVAL = "GL_TEXTURE_MIN_LOD"; break;
      case GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM: RETVAL = "GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SamplerParameterI")) {
    switch (e) {
      case GL_TEXTURE_COMPARE_FUNC: RETVAL = "GL_TEXTURE_COMPARE_FUNC"; break;
      case GL_TEXTURE_COMPARE_MODE: RETVAL = "GL_TEXTURE_COMPARE_MODE"; break;
      case GL_TEXTURE_MAG_FILTER: RETVAL = "GL_TEXTURE_MAG_FILTER"; break;
      case GL_TEXTURE_MIN_FILTER: RETVAL = "GL_TEXTURE_MIN_FILTER"; break;
      case GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM: RETVAL = "GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM"; break;
      case GL_TEXTURE_WRAP_R: RETVAL = "GL_TEXTURE_WRAP_R"; break;
      case GL_TEXTURE_WRAP_S: RETVAL = "GL_TEXTURE_WRAP_S"; break;
      case GL_TEXTURE_WRAP_T: RETVAL = "GL_TEXTURE_WRAP_T"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ScalarType")) {
    switch (e) {
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SecondaryColorPointerTypeIBM")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SemaphoreParameterName")) {
    switch (e) {
      case GL_D3D12_FENCE_VALUE_EXT: RETVAL = "GL_D3D12_FENCE_VALUE_EXT"; break;
      case GL_SEMAPHORE_TYPE_BINARY_NV: RETVAL = "GL_SEMAPHORE_TYPE_BINARY_NV"; break;
      case GL_SEMAPHORE_TYPE_NV: RETVAL = "GL_SEMAPHORE_TYPE_NV"; break;
      case GL_SEMAPHORE_TYPE_TIMELINE_NV: RETVAL = "GL_SEMAPHORE_TYPE_TIMELINE_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SeparableTarget")) {
    switch (e) {
      case GL_SEPARABLE_2D: RETVAL = "GL_SEPARABLE_2D"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SeparableTargetEXT")) {
    switch (e) {
      case GL_SEPARABLE_2D: RETVAL = "GL_SEPARABLE_2D"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShaderBinaryFormat")) {
    switch (e) {
      case GL_GCCSO_SHADER_BINARY_FJ: RETVAL = "GL_GCCSO_SHADER_BINARY_FJ"; break;
      case GL_MALI_SHADER_BINARY_ARM: RETVAL = "GL_MALI_SHADER_BINARY_ARM"; break;
      case GL_SGX_BINARY_IMG: RETVAL = "GL_SGX_BINARY_IMG"; break;
      case GL_SHADER_BINARY_DMP: RETVAL = "GL_SHADER_BINARY_DMP"; break;
      case GL_SHADER_BINARY_FORMAT_SPIR_V: RETVAL = "GL_SHADER_BINARY_FORMAT_SPIR_V"; break;
      case GL_SHADER_BINARY_VIV: RETVAL = "GL_SHADER_BINARY_VIV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShaderParameterName")) {
    switch (e) {
      case GL_COMPILE_STATUS: RETVAL = "GL_COMPILE_STATUS"; break;
      case GL_DELETE_STATUS: RETVAL = "GL_DELETE_STATUS"; break;
      case GL_INFO_LOG_LENGTH: RETVAL = "GL_INFO_LOG_LENGTH"; break;
      case GL_SHADER_SOURCE_LENGTH: RETVAL = "GL_SHADER_SOURCE_LENGTH"; break;
      case GL_SHADER_TYPE: RETVAL = "GL_SHADER_TYPE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShaderType")) {
    switch (e) {
      case GL_COMPUTE_SHADER: RETVAL = "GL_COMPUTE_SHADER"; break;
      case GL_FRAGMENT_SHADER: RETVAL = "GL_FRAGMENT_SHADER"; break;
      case GL_GEOMETRY_SHADER: RETVAL = "GL_GEOMETRY_SHADER"; break;
      case GL_TESS_CONTROL_SHADER: RETVAL = "GL_TESS_CONTROL_SHADER"; break;
      case GL_TESS_EVALUATION_SHADER: RETVAL = "GL_TESS_EVALUATION_SHADER"; break;
      case GL_VERTEX_SHADER: RETVAL = "GL_VERTEX_SHADER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShadingModel")) {
    switch (e) {
      case GL_FLAT: RETVAL = "GL_FLAT"; break;
      case GL_SMOOTH: RETVAL = "GL_SMOOTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShadingRate")) {
    switch (e) {
      case GL_SHADING_RATE_1X1_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_1X1_PIXELS_EXT"; break;
      case GL_SHADING_RATE_1X2_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_1X2_PIXELS_EXT"; break;
      case GL_SHADING_RATE_1X4_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_1X4_PIXELS_EXT"; break;
      case GL_SHADING_RATE_2X1_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_2X1_PIXELS_EXT"; break;
      case GL_SHADING_RATE_2X2_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_2X2_PIXELS_EXT"; break;
      case GL_SHADING_RATE_2X4_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_2X4_PIXELS_EXT"; break;
      case GL_SHADING_RATE_4X1_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_4X1_PIXELS_EXT"; break;
      case GL_SHADING_RATE_4X2_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_4X2_PIXELS_EXT"; break;
      case GL_SHADING_RATE_4X4_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_4X4_PIXELS_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShadingRateCombinerOp")) {
    switch (e) {
      case GL_FRAGMENT_SHADING_RATE_COMBINER_OP_KEEP_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_COMBINER_OP_KEEP_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MAX_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MAX_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MIN_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MIN_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MUL_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MUL_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_COMBINER_OP_REPLACE_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_COMBINER_OP_REPLACE_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShadingRateQCOM")) {
    switch (e) {
      case GL_SHADING_RATE_1X1_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_1X1_PIXELS_QCOM"; break;
      case GL_SHADING_RATE_1X2_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_1X2_PIXELS_QCOM"; break;
      case GL_SHADING_RATE_2X1_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_2X1_PIXELS_QCOM"; break;
      case GL_SHADING_RATE_2X2_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_2X2_PIXELS_QCOM"; break;
      case GL_SHADING_RATE_4X2_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_4X2_PIXELS_QCOM"; break;
      case GL_SHADING_RATE_4X4_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_4X4_PIXELS_QCOM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SizedInternalFormat")) {
    switch (e) {
      case GL_ALPHA12: RETVAL = "GL_ALPHA12"; break;
      case GL_ALPHA16: RETVAL = "GL_ALPHA16"; break;
      case GL_ALPHA16I_EXT: RETVAL = "GL_ALPHA16I_EXT"; break;
      case GL_ALPHA16UI_EXT: RETVAL = "GL_ALPHA16UI_EXT"; break;
      case GL_ALPHA32I_EXT: RETVAL = "GL_ALPHA32I_EXT"; break;
      case GL_ALPHA32UI_EXT: RETVAL = "GL_ALPHA32UI_EXT"; break;
      case GL_ALPHA4: RETVAL = "GL_ALPHA4"; break;
      case GL_ALPHA8: RETVAL = "GL_ALPHA8"; break;
      case GL_ALPHA8I_EXT: RETVAL = "GL_ALPHA8I_EXT"; break;
      case GL_ALPHA8UI_EXT: RETVAL = "GL_ALPHA8UI_EXT"; break;
      case GL_COMPRESSED_R11_EAC: RETVAL = "GL_COMPRESSED_R11_EAC"; break;
      case GL_COMPRESSED_RED_RGTC1: RETVAL = "GL_COMPRESSED_RED_RGTC1"; break;
      case GL_COMPRESSED_RG11_EAC: RETVAL = "GL_COMPRESSED_RG11_EAC"; break;
      case GL_COMPRESSED_RGB8_ETC2: RETVAL = "GL_COMPRESSED_RGB8_ETC2"; break;
      case GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2: RETVAL = "GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2"; break;
      case GL_COMPRESSED_RGBA8_ETC2_EAC: RETVAL = "GL_COMPRESSED_RGBA8_ETC2_EAC"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x10_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x10_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x8_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x8_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_12x10_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_12x10_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_12x12_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_12x12_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_4x4_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_4x4_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_5x4_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_5x4_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_5x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_5x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_6x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_6x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_6x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_6x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x8_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x8_KHR"; break;
      case GL_COMPRESSED_RGBA_BPTC_UNORM: RETVAL = "GL_COMPRESSED_RGBA_BPTC_UNORM"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT1_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT1_EXT"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT3_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT3_EXT"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT5_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT5_EXT"; break;
      case GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT: RETVAL = "GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT"; break;
      case GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT: RETVAL = "GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT"; break;
      case GL_COMPRESSED_RGB_S3TC_DXT1_EXT: RETVAL = "GL_COMPRESSED_RGB_S3TC_DXT1_EXT"; break;
      case GL_COMPRESSED_RG_RGTC2: RETVAL = "GL_COMPRESSED_RG_RGTC2"; break;
      case GL_COMPRESSED_SIGNED_R11_EAC: RETVAL = "GL_COMPRESSED_SIGNED_R11_EAC"; break;
      case GL_COMPRESSED_SIGNED_RED_RGTC1: RETVAL = "GL_COMPRESSED_SIGNED_RED_RGTC1"; break;
      case GL_COMPRESSED_SIGNED_RG11_EAC: RETVAL = "GL_COMPRESSED_SIGNED_RG11_EAC"; break;
      case GL_COMPRESSED_SIGNED_RG_RGTC2: RETVAL = "GL_COMPRESSED_SIGNED_RG_RGTC2"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC"; break;
      case GL_COMPRESSED_SRGB8_ETC2: RETVAL = "GL_COMPRESSED_SRGB8_ETC2"; break;
      case GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2: RETVAL = "GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2"; break;
      case GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV"; break;
      case GL_COMPRESSED_SRGB_S3TC_DXT1_NV: RETVAL = "GL_COMPRESSED_SRGB_S3TC_DXT1_NV"; break;
      case GL_DEPTH24_STENCIL8: RETVAL = "GL_DEPTH24_STENCIL8"; break;
      case GL_DEPTH32F_STENCIL8: RETVAL = "GL_DEPTH32F_STENCIL8"; break;
      case GL_DEPTH32F_STENCIL8_NV: RETVAL = "GL_DEPTH32F_STENCIL8_NV"; break;
      case GL_DEPTH_COMPONENT16: RETVAL = "GL_DEPTH_COMPONENT16"; break;
      case GL_DEPTH_COMPONENT24: RETVAL = "GL_DEPTH_COMPONENT24"; break;
      case GL_DEPTH_COMPONENT32: RETVAL = "GL_DEPTH_COMPONENT32"; break;
      case GL_DEPTH_COMPONENT32F: RETVAL = "GL_DEPTH_COMPONENT32F"; break;
      case GL_DEPTH_COMPONENT32F_NV: RETVAL = "GL_DEPTH_COMPONENT32F_NV"; break;
      case GL_INTENSITY12: RETVAL = "GL_INTENSITY12"; break;
      case GL_INTENSITY16: RETVAL = "GL_INTENSITY16"; break;
      case GL_INTENSITY16I_EXT: RETVAL = "GL_INTENSITY16I_EXT"; break;
      case GL_INTENSITY16UI_EXT: RETVAL = "GL_INTENSITY16UI_EXT"; break;
      case GL_INTENSITY32I_EXT: RETVAL = "GL_INTENSITY32I_EXT"; break;
      case GL_INTENSITY32UI_EXT: RETVAL = "GL_INTENSITY32UI_EXT"; break;
      case GL_INTENSITY4: RETVAL = "GL_INTENSITY4"; break;
      case GL_INTENSITY8: RETVAL = "GL_INTENSITY8"; break;
      case GL_INTENSITY8I_EXT: RETVAL = "GL_INTENSITY8I_EXT"; break;
      case GL_INTENSITY8UI_EXT: RETVAL = "GL_INTENSITY8UI_EXT"; break;
      case GL_LUMINANCE12: RETVAL = "GL_LUMINANCE12"; break;
      case GL_LUMINANCE12_ALPHA12: RETVAL = "GL_LUMINANCE12_ALPHA12"; break;
      case GL_LUMINANCE12_ALPHA4: RETVAL = "GL_LUMINANCE12_ALPHA4"; break;
      case GL_LUMINANCE16: RETVAL = "GL_LUMINANCE16"; break;
      case GL_LUMINANCE16I_EXT: RETVAL = "GL_LUMINANCE16I_EXT"; break;
      case GL_LUMINANCE16UI_EXT: RETVAL = "GL_LUMINANCE16UI_EXT"; break;
      case GL_LUMINANCE16_ALPHA16: RETVAL = "GL_LUMINANCE16_ALPHA16"; break;
      case GL_LUMINANCE32I_EXT: RETVAL = "GL_LUMINANCE32I_EXT"; break;
      case GL_LUMINANCE32UI_EXT: RETVAL = "GL_LUMINANCE32UI_EXT"; break;
      case GL_LUMINANCE4: RETVAL = "GL_LUMINANCE4"; break;
      case GL_LUMINANCE4_ALPHA4: RETVAL = "GL_LUMINANCE4_ALPHA4"; break;
      case GL_LUMINANCE6_ALPHA2: RETVAL = "GL_LUMINANCE6_ALPHA2"; break;
      case GL_LUMINANCE8: RETVAL = "GL_LUMINANCE8"; break;
      case GL_LUMINANCE8I_EXT: RETVAL = "GL_LUMINANCE8I_EXT"; break;
      case GL_LUMINANCE8UI_EXT: RETVAL = "GL_LUMINANCE8UI_EXT"; break;
      case GL_LUMINANCE8_ALPHA8: RETVAL = "GL_LUMINANCE8_ALPHA8"; break;
      case GL_LUMINANCE_ALPHA16I_EXT: RETVAL = "GL_LUMINANCE_ALPHA16I_EXT"; break;
      case GL_LUMINANCE_ALPHA16UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA16UI_EXT"; break;
      case GL_LUMINANCE_ALPHA32I_EXT: RETVAL = "GL_LUMINANCE_ALPHA32I_EXT"; break;
      case GL_LUMINANCE_ALPHA32UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA32UI_EXT"; break;
      case GL_LUMINANCE_ALPHA8I_EXT: RETVAL = "GL_LUMINANCE_ALPHA8I_EXT"; break;
      case GL_LUMINANCE_ALPHA8UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA8UI_EXT"; break;
      case GL_R11F_G11F_B10F: RETVAL = "GL_R11F_G11F_B10F"; break;
      case GL_R16: RETVAL = "GL_R16"; break;
      case GL_R16F: RETVAL = "GL_R16F"; break;
      case GL_R16I: RETVAL = "GL_R16I"; break;
      case GL_R16UI: RETVAL = "GL_R16UI"; break;
      case GL_R16_SNORM: RETVAL = "GL_R16_SNORM"; break;
      case GL_R32F: RETVAL = "GL_R32F"; break;
      case GL_R32I: RETVAL = "GL_R32I"; break;
      case GL_R32UI: RETVAL = "GL_R32UI"; break;
      case GL_R3_G3_B2: RETVAL = "GL_R3_G3_B2"; break;
      case GL_R8: RETVAL = "GL_R8"; break;
      case GL_R8I: RETVAL = "GL_R8I"; break;
      case GL_R8UI: RETVAL = "GL_R8UI"; break;
      case GL_R8_SNORM: RETVAL = "GL_R8_SNORM"; break;
      case GL_RG16: RETVAL = "GL_RG16"; break;
      case GL_RG16F: RETVAL = "GL_RG16F"; break;
      case GL_RG16I: RETVAL = "GL_RG16I"; break;
      case GL_RG16UI: RETVAL = "GL_RG16UI"; break;
      case GL_RG16_SNORM: RETVAL = "GL_RG16_SNORM"; break;
      case GL_RG32F: RETVAL = "GL_RG32F"; break;
      case GL_RG32I: RETVAL = "GL_RG32I"; break;
      case GL_RG32UI: RETVAL = "GL_RG32UI"; break;
      case GL_RG8: RETVAL = "GL_RG8"; break;
      case GL_RG8I: RETVAL = "GL_RG8I"; break;
      case GL_RG8UI: RETVAL = "GL_RG8UI"; break;
      case GL_RG8_SNORM: RETVAL = "GL_RG8_SNORM"; break;
      case GL_RGB10: RETVAL = "GL_RGB10"; break;
      case GL_RGB10_A2: RETVAL = "GL_RGB10_A2"; break;
      case GL_RGB10_A2UI: RETVAL = "GL_RGB10_A2UI"; break;
      case GL_RGB12: RETVAL = "GL_RGB12"; break;
      case GL_RGB16: RETVAL = "GL_RGB16"; break;
      case GL_RGB16F: RETVAL = "GL_RGB16F"; break;
      case GL_RGB16I: RETVAL = "GL_RGB16I"; break;
      case GL_RGB16UI: RETVAL = "GL_RGB16UI"; break;
      case GL_RGB16_SNORM: RETVAL = "GL_RGB16_SNORM"; break;
      case GL_RGB2_EXT: RETVAL = "GL_RGB2_EXT"; break;
      case GL_RGB32F: RETVAL = "GL_RGB32F"; break;
      case GL_RGB32I: RETVAL = "GL_RGB32I"; break;
      case GL_RGB32UI: RETVAL = "GL_RGB32UI"; break;
      case GL_RGB4: RETVAL = "GL_RGB4"; break;
      case GL_RGB5: RETVAL = "GL_RGB5"; break;
      case GL_RGB565: RETVAL = "GL_RGB565"; break;
      case GL_RGB5_A1: RETVAL = "GL_RGB5_A1"; break;
      case GL_RGB8: RETVAL = "GL_RGB8"; break;
      case GL_RGB8I: RETVAL = "GL_RGB8I"; break;
      case GL_RGB8UI: RETVAL = "GL_RGB8UI"; break;
      case GL_RGB8_SNORM: RETVAL = "GL_RGB8_SNORM"; break;
      case GL_RGB9_E5: RETVAL = "GL_RGB9_E5"; break;
      case GL_RGBA12: RETVAL = "GL_RGBA12"; break;
      case GL_RGBA16: RETVAL = "GL_RGBA16"; break;
      case GL_RGBA16F: RETVAL = "GL_RGBA16F"; break;
      case GL_RGBA16I: RETVAL = "GL_RGBA16I"; break;
      case GL_RGBA16UI: RETVAL = "GL_RGBA16UI"; break;
      case GL_RGBA16_SNORM: RETVAL = "GL_RGBA16_SNORM"; break;
      case GL_RGBA2: RETVAL = "GL_RGBA2"; break;
      case GL_RGBA32F: RETVAL = "GL_RGBA32F"; break;
      case GL_RGBA32I: RETVAL = "GL_RGBA32I"; break;
      case GL_RGBA32UI: RETVAL = "GL_RGBA32UI"; break;
      case GL_RGBA4: RETVAL = "GL_RGBA4"; break;
      case GL_RGBA8: RETVAL = "GL_RGBA8"; break;
      case GL_RGBA8I: RETVAL = "GL_RGBA8I"; break;
      case GL_RGBA8UI: RETVAL = "GL_RGBA8UI"; break;
      case GL_RGBA8_SNORM: RETVAL = "GL_RGBA8_SNORM"; break;
      case GL_SRGB8: RETVAL = "GL_SRGB8"; break;
      case GL_SRGB8_ALPHA8: RETVAL = "GL_SRGB8_ALPHA8"; break;
      case GL_STENCIL_INDEX1: RETVAL = "GL_STENCIL_INDEX1"; break;
      case GL_STENCIL_INDEX16: RETVAL = "GL_STENCIL_INDEX16"; break;
      case GL_STENCIL_INDEX4: RETVAL = "GL_STENCIL_INDEX4"; break;
      case GL_STENCIL_INDEX8: RETVAL = "GL_STENCIL_INDEX8"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "StencilFunction")) {
    switch (e) {
      case GL_ALWAYS: RETVAL = "GL_ALWAYS"; break;
      case GL_EQUAL: RETVAL = "GL_EQUAL"; break;
      case GL_GEQUAL: RETVAL = "GL_GEQUAL"; break;
      case GL_GREATER: RETVAL = "GL_GREATER"; break;
      case GL_LEQUAL: RETVAL = "GL_LEQUAL"; break;
      case GL_LESS: RETVAL = "GL_LESS"; break;
      case GL_NEVER: RETVAL = "GL_NEVER"; break;
      case GL_NOTEQUAL: RETVAL = "GL_NOTEQUAL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "StencilOp")) {
    switch (e) {
      case GL_DECR: RETVAL = "GL_DECR"; break;
      case GL_DECR_WRAP: RETVAL = "GL_DECR_WRAP"; break;
      case GL_INCR: RETVAL = "GL_INCR"; break;
      case GL_INCR_WRAP: RETVAL = "GL_INCR_WRAP"; break;
      case GL_INVERT: RETVAL = "GL_INVERT"; break;
      case GL_KEEP: RETVAL = "GL_KEEP"; break;
      case GL_REPLACE: RETVAL = "GL_REPLACE"; break;
      case GL_ZERO: RETVAL = "GL_ZERO"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "StringName")) {
    switch (e) {
      case GL_EXTENSIONS: RETVAL = "GL_EXTENSIONS"; break;
      case GL_RENDERER: RETVAL = "GL_RENDERER"; break;
      case GL_SHADING_LANGUAGE_VERSION: RETVAL = "GL_SHADING_LANGUAGE_VERSION"; break;
      case GL_VENDOR: RETVAL = "GL_VENDOR"; break;
      case GL_VERSION: RETVAL = "GL_VERSION"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SubgroupSupportedFeatures")) {
    switch (e) {
      case GL_SUBGROUP_FEATURE_ARITHMETIC_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_ARITHMETIC_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_BALLOT_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_BALLOT_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_BASIC_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_BASIC_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_CLUSTERED_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_CLUSTERED_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_PARTITIONED_BIT_NV: RETVAL = "GL_SUBGROUP_FEATURE_PARTITIONED_BIT_NV"; break;
      case GL_SUBGROUP_FEATURE_QUAD_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_QUAD_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_SHUFFLE_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_SHUFFLE_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_SHUFFLE_RELATIVE_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_SHUFFLE_RELATIVE_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_VOTE_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_VOTE_BIT_KHR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SubroutineParameterName")) {
    switch (e) {
      case GL_COMPATIBLE_SUBROUTINES: RETVAL = "GL_COMPATIBLE_SUBROUTINES"; break;
      case GL_NUM_COMPATIBLE_SUBROUTINES: RETVAL = "GL_NUM_COMPATIBLE_SUBROUTINES"; break;
      case GL_UNIFORM_NAME_LENGTH: RETVAL = "GL_UNIFORM_NAME_LENGTH"; break;
      case GL_UNIFORM_SIZE: RETVAL = "GL_UNIFORM_SIZE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SwizzleOpATI")) {
    switch (e) {
      case GL_SWIZZLE_STQ_ATI: RETVAL = "GL_SWIZZLE_STQ_ATI"; break;
      case GL_SWIZZLE_STQ_DQ_ATI: RETVAL = "GL_SWIZZLE_STQ_DQ_ATI"; break;
      case GL_SWIZZLE_STR_ATI: RETVAL = "GL_SWIZZLE_STR_ATI"; break;
      case GL_SWIZZLE_STR_DR_ATI: RETVAL = "GL_SWIZZLE_STR_DR_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SyncBehaviorFlags")) {
    switch (e) {
      case GL_NONE: RETVAL = "GL_NONE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SyncCondition")) {
    switch (e) {
      case GL_SYNC_GPU_COMMANDS_COMPLETE: RETVAL = "GL_SYNC_GPU_COMMANDS_COMPLETE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SyncObjectMask")) {
    switch (e) {
      case GL_SYNC_FLUSH_COMMANDS_BIT: RETVAL = "GL_SYNC_FLUSH_COMMANDS_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SyncParameterName")) {
    switch (e) {
      case GL_OBJECT_TYPE: RETVAL = "GL_OBJECT_TYPE"; break;
      case GL_SYNC_CONDITION: RETVAL = "GL_SYNC_CONDITION"; break;
      case GL_SYNC_FLAGS: RETVAL = "GL_SYNC_FLAGS"; break;
      case GL_SYNC_STATUS: RETVAL = "GL_SYNC_STATUS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SyncStatus")) {
    switch (e) {
      case GL_ALREADY_SIGNALED: RETVAL = "GL_ALREADY_SIGNALED"; break;
      case GL_CONDITION_SATISFIED: RETVAL = "GL_CONDITION_SATISFIED"; break;
      case GL_TIMEOUT_EXPIRED: RETVAL = "GL_TIMEOUT_EXPIRED"; break;
      case GL_WAIT_FAILED: RETVAL = "GL_WAIT_FAILED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TangentPointerTypeEXT")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TexBumpParameterATI")) {
    switch (e) {
      case GL_BUMP_ROT_MATRIX_ATI: RETVAL = "GL_BUMP_ROT_MATRIX_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TexCoordPointerType")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TexStorageAttribs")) {
    switch (e) {
      case GL_SURFACE_COMPRESSION_EXT: RETVAL = "GL_SURFACE_COMPRESSION_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_10BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_10BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_11BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_11BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_12BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_12BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_1BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_1BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_2BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_2BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_3BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_3BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_4BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_4BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_5BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_5BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_6BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_6BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_7BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_7BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_8BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_8BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_9BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_9BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_DEFAULT_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_DEFAULT_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_NONE_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_NONE_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureCompareMode")) {
    switch (e) {
      case GL_COMPARE_R_TO_TEXTURE: RETVAL = "GL_COMPARE_R_TO_TEXTURE"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureCoordName")) {
    switch (e) {
      case GL_Q: RETVAL = "GL_Q"; break;
      case GL_R: RETVAL = "GL_R"; break;
      case GL_S: RETVAL = "GL_S"; break;
      case GL_T: RETVAL = "GL_T"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureEnvMode")) {
    switch (e) {
      case GL_ADD: RETVAL = "GL_ADD"; break;
      case GL_BLEND: RETVAL = "GL_BLEND"; break;
      case GL_COMBINE: RETVAL = "GL_COMBINE"; break;
      case GL_DECAL: RETVAL = "GL_DECAL"; break;
      case GL_MODULATE: RETVAL = "GL_MODULATE"; break;
      case GL_REPLACE: RETVAL = "GL_REPLACE"; break;
      case GL_REPLACE_EXT: RETVAL = "GL_REPLACE_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureEnvParameter")) {
    switch (e) {
      case GL_ADD_SIGNED: RETVAL = "GL_ADD_SIGNED"; break;
      case GL_ALPHA_SCALE: RETVAL = "GL_ALPHA_SCALE"; break;
      case GL_COMBINE: RETVAL = "GL_COMBINE"; break;
      case GL_COMBINE_ALPHA: RETVAL = "GL_COMBINE_ALPHA"; break;
      case GL_COMBINE_RGB: RETVAL = "GL_COMBINE_RGB"; break;
      case GL_CONSTANT: RETVAL = "GL_CONSTANT"; break;
      case GL_COORD_REPLACE: RETVAL = "GL_COORD_REPLACE"; break;
      case GL_INTERPOLATE: RETVAL = "GL_INTERPOLATE"; break;
      case GL_OPERAND0_ALPHA: RETVAL = "GL_OPERAND0_ALPHA"; break;
      case GL_OPERAND0_RGB: RETVAL = "GL_OPERAND0_RGB"; break;
      case GL_OPERAND1_ALPHA: RETVAL = "GL_OPERAND1_ALPHA"; break;
      case GL_OPERAND1_RGB: RETVAL = "GL_OPERAND1_RGB"; break;
      case GL_OPERAND2_ALPHA: RETVAL = "GL_OPERAND2_ALPHA"; break;
      case GL_OPERAND2_RGB: RETVAL = "GL_OPERAND2_RGB"; break;
      case GL_OPERAND3_ALPHA_NV: RETVAL = "GL_OPERAND3_ALPHA_NV"; break;
      case GL_OPERAND3_RGB_NV: RETVAL = "GL_OPERAND3_RGB_NV"; break;
      case GL_PREVIOUS: RETVAL = "GL_PREVIOUS"; break;
      case GL_PRIMARY_COLOR: RETVAL = "GL_PRIMARY_COLOR"; break;
      case GL_RGB_SCALE: RETVAL = "GL_RGB_SCALE"; break;
      case GL_SOURCE3_ALPHA_NV: RETVAL = "GL_SOURCE3_ALPHA_NV"; break;
      case GL_SOURCE3_RGB_NV: RETVAL = "GL_SOURCE3_RGB_NV"; break;
      case GL_SRC0_ALPHA: RETVAL = "GL_SRC0_ALPHA"; break;
      case GL_SRC0_RGB: RETVAL = "GL_SRC0_RGB"; break;
      case GL_SRC1_ALPHA: RETVAL = "GL_SRC1_ALPHA"; break;
      case GL_SRC1_RGB: RETVAL = "GL_SRC1_RGB"; break;
      case GL_SRC2_ALPHA: RETVAL = "GL_SRC2_ALPHA"; break;
      case GL_SRC2_RGB: RETVAL = "GL_SRC2_RGB"; break;
      case GL_TEXTURE_ENV_COLOR: RETVAL = "GL_TEXTURE_ENV_COLOR"; break;
      case GL_TEXTURE_ENV_MODE: RETVAL = "GL_TEXTURE_ENV_MODE"; break;
      case GL_TEXTURE_LOD_BIAS: RETVAL = "GL_TEXTURE_LOD_BIAS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureEnvTarget")) {
    switch (e) {
      case GL_POINT_SPRITE: RETVAL = "GL_POINT_SPRITE"; break;
      case GL_TEXTURE_ENV: RETVAL = "GL_TEXTURE_ENV"; break;
      case GL_TEXTURE_FILTER_CONTROL: RETVAL = "GL_TEXTURE_FILTER_CONTROL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureGenMode")) {
    switch (e) {
      case GL_EYE_DISTANCE_TO_LINE_SGIS: RETVAL = "GL_EYE_DISTANCE_TO_LINE_SGIS"; break;
      case GL_EYE_DISTANCE_TO_POINT_SGIS: RETVAL = "GL_EYE_DISTANCE_TO_POINT_SGIS"; break;
      case GL_EYE_LINEAR: RETVAL = "GL_EYE_LINEAR"; break;
      case GL_OBJECT_DISTANCE_TO_LINE_SGIS: RETVAL = "GL_OBJECT_DISTANCE_TO_LINE_SGIS"; break;
      case GL_OBJECT_DISTANCE_TO_POINT_SGIS: RETVAL = "GL_OBJECT_DISTANCE_TO_POINT_SGIS"; break;
      case GL_OBJECT_LINEAR: RETVAL = "GL_OBJECT_LINEAR"; break;
      case GL_SPHERE_MAP: RETVAL = "GL_SPHERE_MAP"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureGenParameter")) {
    switch (e) {
      case GL_EYE_LINE_SGIS: RETVAL = "GL_EYE_LINE_SGIS"; break;
      case GL_EYE_PLANE: RETVAL = "GL_EYE_PLANE"; break;
      case GL_EYE_POINT_SGIS: RETVAL = "GL_EYE_POINT_SGIS"; break;
      case GL_OBJECT_LINE_SGIS: RETVAL = "GL_OBJECT_LINE_SGIS"; break;
      case GL_OBJECT_PLANE: RETVAL = "GL_OBJECT_PLANE"; break;
      case GL_OBJECT_POINT_SGIS: RETVAL = "GL_OBJECT_POINT_SGIS"; break;
      case GL_TEXTURE_GEN_MODE: RETVAL = "GL_TEXTURE_GEN_MODE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureLayout")) {
    switch (e) {
      case GL_LAYOUT_COLOR_ATTACHMENT_EXT: RETVAL = "GL_LAYOUT_COLOR_ATTACHMENT_EXT"; break;
      case GL_LAYOUT_DEPTH_ATTACHMENT_STENCIL_READ_ONLY_EXT: RETVAL = "GL_LAYOUT_DEPTH_ATTACHMENT_STENCIL_READ_ONLY_EXT"; break;
      case GL_LAYOUT_DEPTH_READ_ONLY_STENCIL_ATTACHMENT_EXT: RETVAL = "GL_LAYOUT_DEPTH_READ_ONLY_STENCIL_ATTACHMENT_EXT"; break;
      case GL_LAYOUT_DEPTH_STENCIL_ATTACHMENT_EXT: RETVAL = "GL_LAYOUT_DEPTH_STENCIL_ATTACHMENT_EXT"; break;
      case GL_LAYOUT_DEPTH_STENCIL_READ_ONLY_EXT: RETVAL = "GL_LAYOUT_DEPTH_STENCIL_READ_ONLY_EXT"; break;
      case GL_LAYOUT_GENERAL_EXT: RETVAL = "GL_LAYOUT_GENERAL_EXT"; break;
      case GL_LAYOUT_SHADER_READ_ONLY_EXT: RETVAL = "GL_LAYOUT_SHADER_READ_ONLY_EXT"; break;
      case GL_LAYOUT_TRANSFER_DST_EXT: RETVAL = "GL_LAYOUT_TRANSFER_DST_EXT"; break;
      case GL_LAYOUT_TRANSFER_SRC_EXT: RETVAL = "GL_LAYOUT_TRANSFER_SRC_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureMagFilter")) {
    switch (e) {
      case GL_LINEAR: RETVAL = "GL_LINEAR"; break;
      case GL_NEAREST: RETVAL = "GL_NEAREST"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureMinFilter")) {
    switch (e) {
      case GL_LINEAR: RETVAL = "GL_LINEAR"; break;
      case GL_LINEAR_MIPMAP_LINEAR: RETVAL = "GL_LINEAR_MIPMAP_LINEAR"; break;
      case GL_LINEAR_MIPMAP_NEAREST: RETVAL = "GL_LINEAR_MIPMAP_NEAREST"; break;
      case GL_NEAREST: RETVAL = "GL_NEAREST"; break;
      case GL_NEAREST_MIPMAP_LINEAR: RETVAL = "GL_NEAREST_MIPMAP_LINEAR"; break;
      case GL_NEAREST_MIPMAP_NEAREST: RETVAL = "GL_NEAREST_MIPMAP_NEAREST"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureNormalModeEXT")) {
    switch (e) {
      case GL_PERTURB_EXT: RETVAL = "GL_PERTURB_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureParameterName")) {
    switch (e) {
      case GL_DEPTH_STENCIL_TEXTURE_MODE: RETVAL = "GL_DEPTH_STENCIL_TEXTURE_MODE"; break;
      case GL_GENERATE_MIPMAP: RETVAL = "GL_GENERATE_MIPMAP"; break;
      case GL_POST_TEXTURE_FILTER_BIAS_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_BIAS_SGIX"; break;
      case GL_POST_TEXTURE_FILTER_SCALE_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_SCALE_SGIX"; break;
      case GL_SHADOW_AMBIENT_SGIX: RETVAL = "GL_SHADOW_AMBIENT_SGIX"; break;
      case GL_TEXTURE_ALPHA_SIZE: RETVAL = "GL_TEXTURE_ALPHA_SIZE"; break;
      case GL_TEXTURE_BASE_LEVEL: RETVAL = "GL_TEXTURE_BASE_LEVEL"; break;
      case GL_TEXTURE_BLUE_SIZE: RETVAL = "GL_TEXTURE_BLUE_SIZE"; break;
      case GL_TEXTURE_BORDER: RETVAL = "GL_TEXTURE_BORDER"; break;
      case GL_TEXTURE_BORDER_COLOR: RETVAL = "GL_TEXTURE_BORDER_COLOR"; break;
      case GL_TEXTURE_CBCR_DEGAMMA_QCOM: RETVAL = "GL_TEXTURE_CBCR_DEGAMMA_QCOM"; break;
      case GL_TEXTURE_COMPARE_FUNC: RETVAL = "GL_TEXTURE_COMPARE_FUNC"; break;
      case GL_TEXTURE_COMPARE_MODE: RETVAL = "GL_TEXTURE_COMPARE_MODE"; break;
      case GL_TEXTURE_COMPARE_OPERATOR_SGIX: RETVAL = "GL_TEXTURE_COMPARE_OPERATOR_SGIX"; break;
      case GL_TEXTURE_COMPARE_SGIX: RETVAL = "GL_TEXTURE_COMPARE_SGIX"; break;
      case GL_TEXTURE_COMPONENTS: RETVAL = "GL_TEXTURE_COMPONENTS"; break;
      case GL_TEXTURE_DEPTH_EXT: RETVAL = "GL_TEXTURE_DEPTH_EXT"; break;
      case GL_TEXTURE_FOVEATED_CUTOFF_DENSITY_QCOM: RETVAL = "GL_TEXTURE_FOVEATED_CUTOFF_DENSITY_QCOM"; break;
      case GL_TEXTURE_GEQUAL_R_SGIX: RETVAL = "GL_TEXTURE_GEQUAL_R_SGIX"; break;
      case GL_TEXTURE_GREEN_SIZE: RETVAL = "GL_TEXTURE_GREEN_SIZE"; break;
      case GL_TEXTURE_HEIGHT: RETVAL = "GL_TEXTURE_HEIGHT"; break;
      case GL_TEXTURE_INTENSITY_SIZE: RETVAL = "GL_TEXTURE_INTENSITY_SIZE"; break;
      case GL_TEXTURE_LEQUAL_R_SGIX: RETVAL = "GL_TEXTURE_LEQUAL_R_SGIX"; break;
      case GL_TEXTURE_LOD_BIAS: RETVAL = "GL_TEXTURE_LOD_BIAS"; break;
      case GL_TEXTURE_LUMINANCE_SIZE: RETVAL = "GL_TEXTURE_LUMINANCE_SIZE"; break;
      case GL_TEXTURE_MAG_FILTER: RETVAL = "GL_TEXTURE_MAG_FILTER"; break;
      case GL_TEXTURE_MAX_ANISOTROPY: RETVAL = "GL_TEXTURE_MAX_ANISOTROPY"; break;
      case GL_TEXTURE_MAX_CLAMP_R_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_R_SGIX"; break;
      case GL_TEXTURE_MAX_CLAMP_S_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_S_SGIX"; break;
      case GL_TEXTURE_MAX_CLAMP_T_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_T_SGIX"; break;
      case GL_TEXTURE_MAX_LEVEL: RETVAL = "GL_TEXTURE_MAX_LEVEL"; break;
      case GL_TEXTURE_MAX_LOD: RETVAL = "GL_TEXTURE_MAX_LOD"; break;
      case GL_TEXTURE_MEMORY_LAYOUT_INTEL: RETVAL = "GL_TEXTURE_MEMORY_LAYOUT_INTEL"; break;
      case GL_TEXTURE_MIN_FILTER: RETVAL = "GL_TEXTURE_MIN_FILTER"; break;
      case GL_TEXTURE_MIN_LOD: RETVAL = "GL_TEXTURE_MIN_LOD"; break;
      case GL_TEXTURE_PRIORITY: RETVAL = "GL_TEXTURE_PRIORITY"; break;
      case GL_TEXTURE_RED_SIZE: RETVAL = "GL_TEXTURE_RED_SIZE"; break;
      case GL_TEXTURE_RESIDENT: RETVAL = "GL_TEXTURE_RESIDENT"; break;
      case GL_TEXTURE_SWIZZLE_A: RETVAL = "GL_TEXTURE_SWIZZLE_A"; break;
      case GL_TEXTURE_SWIZZLE_B: RETVAL = "GL_TEXTURE_SWIZZLE_B"; break;
      case GL_TEXTURE_SWIZZLE_G: RETVAL = "GL_TEXTURE_SWIZZLE_G"; break;
      case GL_TEXTURE_SWIZZLE_R: RETVAL = "GL_TEXTURE_SWIZZLE_R"; break;
      case GL_TEXTURE_SWIZZLE_RGBA: RETVAL = "GL_TEXTURE_SWIZZLE_RGBA"; break;
      case GL_TEXTURE_TILING_EXT: RETVAL = "GL_TEXTURE_TILING_EXT"; break;
      case GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM: RETVAL = "GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM"; break;
      case GL_TEXTURE_WIDTH: RETVAL = "GL_TEXTURE_WIDTH"; break;
      case GL_TEXTURE_WRAP_R: RETVAL = "GL_TEXTURE_WRAP_R"; break;
      case GL_TEXTURE_WRAP_S: RETVAL = "GL_TEXTURE_WRAP_S"; break;
      case GL_TEXTURE_WRAP_T: RETVAL = "GL_TEXTURE_WRAP_T"; break;
      case GL_TEXTURE_Y_DEGAMMA_QCOM: RETVAL = "GL_TEXTURE_Y_DEGAMMA_QCOM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureStorageMaskAMD")) {
    switch (e) {
      case GL_TEXTURE_STORAGE_SPARSE_BIT_AMD: RETVAL = "GL_TEXTURE_STORAGE_SPARSE_BIT_AMD"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureSwizzle")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_BLUE: RETVAL = "GL_BLUE"; break;
      case GL_GREEN: RETVAL = "GL_GREEN"; break;
      case GL_ONE: RETVAL = "GL_ONE"; break;
      case GL_RED: RETVAL = "GL_RED"; break;
      case GL_ZERO: RETVAL = "GL_ZERO"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureTarget")) {
    switch (e) {
      case GL_PROXY_TEXTURE_1D: RETVAL = "GL_PROXY_TEXTURE_1D"; break;
      case GL_PROXY_TEXTURE_1D_ARRAY: RETVAL = "GL_PROXY_TEXTURE_1D_ARRAY"; break;
      case GL_PROXY_TEXTURE_2D: RETVAL = "GL_PROXY_TEXTURE_2D"; break;
      case GL_PROXY_TEXTURE_2D_ARRAY: RETVAL = "GL_PROXY_TEXTURE_2D_ARRAY"; break;
      case GL_PROXY_TEXTURE_2D_MULTISAMPLE: RETVAL = "GL_PROXY_TEXTURE_2D_MULTISAMPLE"; break;
      case GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_PROXY_TEXTURE_3D: RETVAL = "GL_PROXY_TEXTURE_3D"; break;
      case GL_PROXY_TEXTURE_CUBE_MAP: RETVAL = "GL_PROXY_TEXTURE_CUBE_MAP"; break;
      case GL_PROXY_TEXTURE_CUBE_MAP_ARRAY: RETVAL = "GL_PROXY_TEXTURE_CUBE_MAP_ARRAY"; break;
      case GL_PROXY_TEXTURE_RECTANGLE: RETVAL = "GL_PROXY_TEXTURE_RECTANGLE"; break;
      case GL_RENDERBUFFER: RETVAL = "GL_RENDERBUFFER"; break;
      case GL_TEXTURE_1D: RETVAL = "GL_TEXTURE_1D"; break;
      case GL_TEXTURE_1D_ARRAY: RETVAL = "GL_TEXTURE_1D_ARRAY"; break;
      case GL_TEXTURE_2D: RETVAL = "GL_TEXTURE_2D"; break;
      case GL_TEXTURE_2D_ARRAY: RETVAL = "GL_TEXTURE_2D_ARRAY"; break;
      case GL_TEXTURE_2D_MULTISAMPLE: RETVAL = "GL_TEXTURE_2D_MULTISAMPLE"; break;
      case GL_TEXTURE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_TEXTURE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_TEXTURE_3D: RETVAL = "GL_TEXTURE_3D"; break;
      case GL_TEXTURE_BUFFER: RETVAL = "GL_TEXTURE_BUFFER"; break;
      case GL_TEXTURE_CUBE_MAP: RETVAL = "GL_TEXTURE_CUBE_MAP"; break;
      case GL_TEXTURE_CUBE_MAP_ARRAY: RETVAL = "GL_TEXTURE_CUBE_MAP_ARRAY"; break;
      case GL_TEXTURE_CUBE_MAP_NEGATIVE_X: RETVAL = "GL_TEXTURE_CUBE_MAP_NEGATIVE_X"; break;
      case GL_TEXTURE_CUBE_MAP_NEGATIVE_Y: RETVAL = "GL_TEXTURE_CUBE_MAP_NEGATIVE_Y"; break;
      case GL_TEXTURE_CUBE_MAP_NEGATIVE_Z: RETVAL = "GL_TEXTURE_CUBE_MAP_NEGATIVE_Z"; break;
      case GL_TEXTURE_CUBE_MAP_POSITIVE_X: RETVAL = "GL_TEXTURE_CUBE_MAP_POSITIVE_X"; break;
      case GL_TEXTURE_CUBE_MAP_POSITIVE_Y: RETVAL = "GL_TEXTURE_CUBE_MAP_POSITIVE_Y"; break;
      case GL_TEXTURE_CUBE_MAP_POSITIVE_Z: RETVAL = "GL_TEXTURE_CUBE_MAP_POSITIVE_Z"; break;
      case GL_TEXTURE_RECTANGLE: RETVAL = "GL_TEXTURE_RECTANGLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureUnit")) {
    switch (e) {
      case GL_TEXTURE0: RETVAL = "GL_TEXTURE0"; break;
      case GL_TEXTURE1: RETVAL = "GL_TEXTURE1"; break;
      case GL_TEXTURE10: RETVAL = "GL_TEXTURE10"; break;
      case GL_TEXTURE11: RETVAL = "GL_TEXTURE11"; break;
      case GL_TEXTURE12: RETVAL = "GL_TEXTURE12"; break;
      case GL_TEXTURE13: RETVAL = "GL_TEXTURE13"; break;
      case GL_TEXTURE14: RETVAL = "GL_TEXTURE14"; break;
      case GL_TEXTURE15: RETVAL = "GL_TEXTURE15"; break;
      case GL_TEXTURE16: RETVAL = "GL_TEXTURE16"; break;
      case GL_TEXTURE17: RETVAL = "GL_TEXTURE17"; break;
      case GL_TEXTURE18: RETVAL = "GL_TEXTURE18"; break;
      case GL_TEXTURE19: RETVAL = "GL_TEXTURE19"; break;
      case GL_TEXTURE2: RETVAL = "GL_TEXTURE2"; break;
      case GL_TEXTURE20: RETVAL = "GL_TEXTURE20"; break;
      case GL_TEXTURE21: RETVAL = "GL_TEXTURE21"; break;
      case GL_TEXTURE22: RETVAL = "GL_TEXTURE22"; break;
      case GL_TEXTURE23: RETVAL = "GL_TEXTURE23"; break;
      case GL_TEXTURE24: RETVAL = "GL_TEXTURE24"; break;
      case GL_TEXTURE25: RETVAL = "GL_TEXTURE25"; break;
      case GL_TEXTURE26: RETVAL = "GL_TEXTURE26"; break;
      case GL_TEXTURE27: RETVAL = "GL_TEXTURE27"; break;
      case GL_TEXTURE28: RETVAL = "GL_TEXTURE28"; break;
      case GL_TEXTURE29: RETVAL = "GL_TEXTURE29"; break;
      case GL_TEXTURE3: RETVAL = "GL_TEXTURE3"; break;
      case GL_TEXTURE30: RETVAL = "GL_TEXTURE30"; break;
      case GL_TEXTURE31: RETVAL = "GL_TEXTURE31"; break;
      case GL_TEXTURE4: RETVAL = "GL_TEXTURE4"; break;
      case GL_TEXTURE5: RETVAL = "GL_TEXTURE5"; break;
      case GL_TEXTURE6: RETVAL = "GL_TEXTURE6"; break;
      case GL_TEXTURE7: RETVAL = "GL_TEXTURE7"; break;
      case GL_TEXTURE8: RETVAL = "GL_TEXTURE8"; break;
      case GL_TEXTURE9: RETVAL = "GL_TEXTURE9"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureWrapMode")) {
    switch (e) {
      case GL_CLAMP: RETVAL = "GL_CLAMP"; break;
      case GL_CLAMP_TO_BORDER: RETVAL = "GL_CLAMP_TO_BORDER"; break;
      case GL_CLAMP_TO_EDGE: RETVAL = "GL_CLAMP_TO_EDGE"; break;
      case GL_MIRRORED_REPEAT: RETVAL = "GL_MIRRORED_REPEAT"; break;
      case GL_REPEAT: RETVAL = "GL_REPEAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TransformFeedbackBufferMode")) {
    switch (e) {
      case GL_INTERLEAVED_ATTRIBS: RETVAL = "GL_INTERLEAVED_ATTRIBS"; break;
      case GL_SEPARATE_ATTRIBS: RETVAL = "GL_SEPARATE_ATTRIBS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TransformFeedbackPName")) {
    switch (e) {
      case GL_TRANSFORM_FEEDBACK_ACTIVE: RETVAL = "GL_TRANSFORM_FEEDBACK_ACTIVE"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_BINDING: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_BINDING"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_SIZE: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_SIZE"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_START: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_START"; break;
      case GL_TRANSFORM_FEEDBACK_PAUSED: RETVAL = "GL_TRANSFORM_FEEDBACK_PAUSED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TriangleFace")) {
    switch (e) {
      case GL_BACK: RETVAL = "GL_BACK"; break;
      case GL_FRONT: RETVAL = "GL_FRONT"; break;
      case GL_FRONT_AND_BACK: RETVAL = "GL_FRONT_AND_BACK"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TriangleListSUN")) {
    switch (e) {
      case GL_REPLACE_MIDDLE_SUN: RETVAL = "GL_REPLACE_MIDDLE_SUN"; break;
      case GL_REPLACE_OLDEST_SUN: RETVAL = "GL_REPLACE_OLDEST_SUN"; break;
      case GL_RESTART_SUN: RETVAL = "GL_RESTART_SUN"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "UniformBlockPName")) {
    switch (e) {
      case GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS: RETVAL = "GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS"; break;
      case GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES: RETVAL = "GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES"; break;
      case GL_UNIFORM_BLOCK_BINDING: RETVAL = "GL_UNIFORM_BLOCK_BINDING"; break;
      case GL_UNIFORM_BLOCK_DATA_SIZE: RETVAL = "GL_UNIFORM_BLOCK_DATA_SIZE"; break;
      case GL_UNIFORM_BLOCK_NAME_LENGTH: RETVAL = "GL_UNIFORM_BLOCK_NAME_LENGTH"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_COMPUTE_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_COMPUTE_SHADER"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_CONTROL_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_CONTROL_SHADER"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_EVALUATION_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_EVALUATION_SHADER"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "UniformPName")) {
    switch (e) {
      case GL_UNIFORM_ARRAY_STRIDE: RETVAL = "GL_UNIFORM_ARRAY_STRIDE"; break;
      case GL_UNIFORM_ATOMIC_COUNTER_BUFFER_INDEX: RETVAL = "GL_UNIFORM_ATOMIC_COUNTER_BUFFER_INDEX"; break;
      case GL_UNIFORM_BLOCK_INDEX: RETVAL = "GL_UNIFORM_BLOCK_INDEX"; break;
      case GL_UNIFORM_IS_ROW_MAJOR: RETVAL = "GL_UNIFORM_IS_ROW_MAJOR"; break;
      case GL_UNIFORM_MATRIX_STRIDE: RETVAL = "GL_UNIFORM_MATRIX_STRIDE"; break;
      case GL_UNIFORM_NAME_LENGTH: RETVAL = "GL_UNIFORM_NAME_LENGTH"; break;
      case GL_UNIFORM_OFFSET: RETVAL = "GL_UNIFORM_OFFSET"; break;
      case GL_UNIFORM_SIZE: RETVAL = "GL_UNIFORM_SIZE"; break;
      case GL_UNIFORM_TYPE: RETVAL = "GL_UNIFORM_TYPE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "UniformType")) {
    switch (e) {
      case GL_BOOL: RETVAL = "GL_BOOL"; break;
      case GL_BOOL_VEC2: RETVAL = "GL_BOOL_VEC2"; break;
      case GL_BOOL_VEC3: RETVAL = "GL_BOOL_VEC3"; break;
      case GL_BOOL_VEC4: RETVAL = "GL_BOOL_VEC4"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_DOUBLE_MAT2: RETVAL = "GL_DOUBLE_MAT2"; break;
      case GL_DOUBLE_MAT2x3: RETVAL = "GL_DOUBLE_MAT2x3"; break;
      case GL_DOUBLE_MAT2x4: RETVAL = "GL_DOUBLE_MAT2x4"; break;
      case GL_DOUBLE_MAT3: RETVAL = "GL_DOUBLE_MAT3"; break;
      case GL_DOUBLE_MAT3x2: RETVAL = "GL_DOUBLE_MAT3x2"; break;
      case GL_DOUBLE_MAT3x4: RETVAL = "GL_DOUBLE_MAT3x4"; break;
      case GL_DOUBLE_MAT4: RETVAL = "GL_DOUBLE_MAT4"; break;
      case GL_DOUBLE_MAT4x2: RETVAL = "GL_DOUBLE_MAT4x2"; break;
      case GL_DOUBLE_MAT4x3: RETVAL = "GL_DOUBLE_MAT4x3"; break;
      case GL_DOUBLE_VEC2: RETVAL = "GL_DOUBLE_VEC2"; break;
      case GL_DOUBLE_VEC3: RETVAL = "GL_DOUBLE_VEC3"; break;
      case GL_DOUBLE_VEC4: RETVAL = "GL_DOUBLE_VEC4"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_FLOAT_MAT2: RETVAL = "GL_FLOAT_MAT2"; break;
      case GL_FLOAT_MAT2x3: RETVAL = "GL_FLOAT_MAT2x3"; break;
      case GL_FLOAT_MAT2x4: RETVAL = "GL_FLOAT_MAT2x4"; break;
      case GL_FLOAT_MAT3: RETVAL = "GL_FLOAT_MAT3"; break;
      case GL_FLOAT_MAT3x2: RETVAL = "GL_FLOAT_MAT3x2"; break;
      case GL_FLOAT_MAT3x4: RETVAL = "GL_FLOAT_MAT3x4"; break;
      case GL_FLOAT_MAT4: RETVAL = "GL_FLOAT_MAT4"; break;
      case GL_FLOAT_MAT4x2: RETVAL = "GL_FLOAT_MAT4x2"; break;
      case GL_FLOAT_MAT4x3: RETVAL = "GL_FLOAT_MAT4x3"; break;
      case GL_FLOAT_VEC2: RETVAL = "GL_FLOAT_VEC2"; break;
      case GL_FLOAT_VEC3: RETVAL = "GL_FLOAT_VEC3"; break;
      case GL_FLOAT_VEC4: RETVAL = "GL_FLOAT_VEC4"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_INT_SAMPLER_1D: RETVAL = "GL_INT_SAMPLER_1D"; break;
      case GL_INT_SAMPLER_1D_ARRAY: RETVAL = "GL_INT_SAMPLER_1D_ARRAY"; break;
      case GL_INT_SAMPLER_2D: RETVAL = "GL_INT_SAMPLER_2D"; break;
      case GL_INT_SAMPLER_2D_ARRAY: RETVAL = "GL_INT_SAMPLER_2D_ARRAY"; break;
      case GL_INT_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_INT_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_INT_SAMPLER_2D_RECT: RETVAL = "GL_INT_SAMPLER_2D_RECT"; break;
      case GL_INT_SAMPLER_3D: RETVAL = "GL_INT_SAMPLER_3D"; break;
      case GL_INT_SAMPLER_BUFFER: RETVAL = "GL_INT_SAMPLER_BUFFER"; break;
      case GL_INT_SAMPLER_CUBE: RETVAL = "GL_INT_SAMPLER_CUBE"; break;
      case GL_INT_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_INT_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_INT_VEC2: RETVAL = "GL_INT_VEC2"; break;
      case GL_INT_VEC3: RETVAL = "GL_INT_VEC3"; break;
      case GL_INT_VEC4: RETVAL = "GL_INT_VEC4"; break;
      case GL_SAMPLER_1D: RETVAL = "GL_SAMPLER_1D"; break;
      case GL_SAMPLER_1D_ARRAY: RETVAL = "GL_SAMPLER_1D_ARRAY"; break;
      case GL_SAMPLER_1D_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_1D_ARRAY_SHADOW"; break;
      case GL_SAMPLER_1D_SHADOW: RETVAL = "GL_SAMPLER_1D_SHADOW"; break;
      case GL_SAMPLER_2D: RETVAL = "GL_SAMPLER_2D"; break;
      case GL_SAMPLER_2D_ARRAY: RETVAL = "GL_SAMPLER_2D_ARRAY"; break;
      case GL_SAMPLER_2D_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_2D_ARRAY_SHADOW"; break;
      case GL_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_SAMPLER_2D_RECT: RETVAL = "GL_SAMPLER_2D_RECT"; break;
      case GL_SAMPLER_2D_RECT_SHADOW: RETVAL = "GL_SAMPLER_2D_RECT_SHADOW"; break;
      case GL_SAMPLER_2D_SHADOW: RETVAL = "GL_SAMPLER_2D_SHADOW"; break;
      case GL_SAMPLER_3D: RETVAL = "GL_SAMPLER_3D"; break;
      case GL_SAMPLER_BUFFER: RETVAL = "GL_SAMPLER_BUFFER"; break;
      case GL_SAMPLER_CUBE: RETVAL = "GL_SAMPLER_CUBE"; break;
      case GL_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW"; break;
      case GL_SAMPLER_CUBE_SHADOW: RETVAL = "GL_SAMPLER_CUBE_SHADOW"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_INT_SAMPLER_1D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_1D"; break;
      case GL_UNSIGNED_INT_SAMPLER_1D_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_1D_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_RECT: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_RECT"; break;
      case GL_UNSIGNED_INT_SAMPLER_3D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_3D"; break;
      case GL_UNSIGNED_INT_SAMPLER_BUFFER: RETVAL = "GL_UNSIGNED_INT_SAMPLER_BUFFER"; break;
      case GL_UNSIGNED_INT_SAMPLER_CUBE: RETVAL = "GL_UNSIGNED_INT_SAMPLER_CUBE"; break;
      case GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_UNSIGNED_INT_VEC2: RETVAL = "GL_UNSIGNED_INT_VEC2"; break;
      case GL_UNSIGNED_INT_VEC3: RETVAL = "GL_UNSIGNED_INT_VEC3"; break;
      case GL_UNSIGNED_INT_VEC4: RETVAL = "GL_UNSIGNED_INT_VEC4"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "UseProgramStageMask")) {
    switch (e) {
      case GL_ALL_SHADER_BITS: RETVAL = "GL_ALL_SHADER_BITS"; break;
      case GL_COMPUTE_SHADER_BIT: RETVAL = "GL_COMPUTE_SHADER_BIT"; break;
      case GL_FRAGMENT_SHADER_BIT: RETVAL = "GL_FRAGMENT_SHADER_BIT"; break;
      case GL_GEOMETRY_SHADER_BIT: RETVAL = "GL_GEOMETRY_SHADER_BIT"; break;
      case GL_MESH_SHADER_BIT_NV: RETVAL = "GL_MESH_SHADER_BIT_NV"; break;
      case GL_TASK_SHADER_BIT_NV: RETVAL = "GL_TASK_SHADER_BIT_NV"; break;
      case GL_TESS_CONTROL_SHADER_BIT: RETVAL = "GL_TESS_CONTROL_SHADER_BIT"; break;
      case GL_TESS_EVALUATION_SHADER_BIT: RETVAL = "GL_TESS_EVALUATION_SHADER_BIT"; break;
      case GL_VERTEX_SHADER_BIT: RETVAL = "GL_VERTEX_SHADER_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VariantCapEXT")) {
    switch (e) {
      case GL_VARIANT_ARRAY_EXT: RETVAL = "GL_VARIANT_ARRAY_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexArrayPName")) {
    switch (e) {
      case GL_VERTEX_ATTRIB_ARRAY_DIVISOR: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_DIVISOR"; break;
      case GL_VERTEX_ATTRIB_ARRAY_ENABLED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_ENABLED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_INTEGER: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_INTEGER"; break;
      case GL_VERTEX_ATTRIB_ARRAY_LONG: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_LONG"; break;
      case GL_VERTEX_ATTRIB_ARRAY_NORMALIZED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_NORMALIZED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_SIZE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_SIZE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_STRIDE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_STRIDE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_TYPE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_TYPE"; break;
      case GL_VERTEX_ATTRIB_RELATIVE_OFFSET: RETVAL = "GL_VERTEX_ATTRIB_RELATIVE_OFFSET"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexArrayPNameAPPLE")) {
    switch (e) {
      case GL_STORAGE_CACHED_APPLE: RETVAL = "GL_STORAGE_CACHED_APPLE"; break;
      case GL_STORAGE_CLIENT_APPLE: RETVAL = "GL_STORAGE_CLIENT_APPLE"; break;
      case GL_STORAGE_SHARED_APPLE: RETVAL = "GL_STORAGE_SHARED_APPLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribEnum")) {
    switch (e) {
      case GL_CURRENT_VERTEX_ATTRIB: RETVAL = "GL_CURRENT_VERTEX_ATTRIB"; break;
      case GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING"; break;
      case GL_VERTEX_ATTRIB_ARRAY_DIVISOR: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_DIVISOR"; break;
      case GL_VERTEX_ATTRIB_ARRAY_ENABLED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_ENABLED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_INTEGER: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_INTEGER"; break;
      case GL_VERTEX_ATTRIB_ARRAY_NORMALIZED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_NORMALIZED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_SIZE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_SIZE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_STRIDE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_STRIDE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_TYPE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_TYPE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribEnumNV")) {
    switch (e) {
      case GL_PROGRAM_PARAMETER_NV: RETVAL = "GL_PROGRAM_PARAMETER_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribIType")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribLType")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribPointerPropertyARB")) {
    switch (e) {
      case GL_VERTEX_ATTRIB_ARRAY_POINTER: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_POINTER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribPointerType")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FIXED: RETVAL = "GL_FIXED"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_HALF_FLOAT: RETVAL = "GL_HALF_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_INT64_NV: RETVAL = "GL_INT64_NV"; break;
      case GL_INT_2_10_10_10_REV: RETVAL = "GL_INT_2_10_10_10_REV"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_INT64_NV: RETVAL = "GL_UNSIGNED_INT64_NV"; break;
      case GL_UNSIGNED_INT_10F_11F_11F_REV: RETVAL = "GL_UNSIGNED_INT_10F_11F_11F_REV"; break;
      case GL_UNSIGNED_INT_2_10_10_10_REV: RETVAL = "GL_UNSIGNED_INT_2_10_10_10_REV"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribPropertyARB")) {
    switch (e) {
      case GL_CURRENT_VERTEX_ATTRIB: RETVAL = "GL_CURRENT_VERTEX_ATTRIB"; break;
      case GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING"; break;
      case GL_VERTEX_ATTRIB_ARRAY_DIVISOR: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_DIVISOR"; break;
      case GL_VERTEX_ATTRIB_ARRAY_ENABLED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_ENABLED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_INTEGER: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_INTEGER"; break;
      case GL_VERTEX_ATTRIB_ARRAY_LONG: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_LONG"; break;
      case GL_VERTEX_ATTRIB_ARRAY_NORMALIZED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_NORMALIZED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_SIZE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_SIZE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_STRIDE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_STRIDE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_TYPE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_TYPE"; break;
      case GL_VERTEX_ATTRIB_BINDING: RETVAL = "GL_VERTEX_ATTRIB_BINDING"; break;
      case GL_VERTEX_ATTRIB_RELATIVE_OFFSET: RETVAL = "GL_VERTEX_ATTRIB_RELATIVE_OFFSET"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribType")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FIXED: RETVAL = "GL_FIXED"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_HALF_FLOAT: RETVAL = "GL_HALF_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_INT_2_10_10_10_REV: RETVAL = "GL_INT_2_10_10_10_REV"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_INT_10F_11F_11F_REV: RETVAL = "GL_UNSIGNED_INT_10F_11F_11F_REV"; break;
      case GL_UNSIGNED_INT_2_10_10_10_REV: RETVAL = "GL_UNSIGNED_INT_2_10_10_10_REV"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexHintsMaskPGI")) {
    switch (e) {
      case GL_COLOR3_BIT_PGI: RETVAL = "GL_COLOR3_BIT_PGI"; break;
      case GL_COLOR4_BIT_PGI: RETVAL = "GL_COLOR4_BIT_PGI"; break;
      case GL_EDGEFLAG_BIT_PGI: RETVAL = "GL_EDGEFLAG_BIT_PGI"; break;
      case GL_INDEX_BIT_PGI: RETVAL = "GL_INDEX_BIT_PGI"; break;
      case GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI: RETVAL = "GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI"; break;
      case GL_MAT_AMBIENT_BIT_PGI: RETVAL = "GL_MAT_AMBIENT_BIT_PGI"; break;
      case GL_MAT_COLOR_INDEXES_BIT_PGI: RETVAL = "GL_MAT_COLOR_INDEXES_BIT_PGI"; break;
      case GL_MAT_DIFFUSE_BIT_PGI: RETVAL = "GL_MAT_DIFFUSE_BIT_PGI"; break;
      case GL_MAT_EMISSION_BIT_PGI: RETVAL = "GL_MAT_EMISSION_BIT_PGI"; break;
      case GL_MAT_SHININESS_BIT_PGI: RETVAL = "GL_MAT_SHININESS_BIT_PGI"; break;
      case GL_MAT_SPECULAR_BIT_PGI: RETVAL = "GL_MAT_SPECULAR_BIT_PGI"; break;
      case GL_NORMAL_BIT_PGI: RETVAL = "GL_NORMAL_BIT_PGI"; break;
      case GL_TEXCOORD1_BIT_PGI: RETVAL = "GL_TEXCOORD1_BIT_PGI"; break;
      case GL_TEXCOORD2_BIT_PGI: RETVAL = "GL_TEXCOORD2_BIT_PGI"; break;
      case GL_TEXCOORD3_BIT_PGI: RETVAL = "GL_TEXCOORD3_BIT_PGI"; break;
      case GL_TEXCOORD4_BIT_PGI: RETVAL = "GL_TEXCOORD4_BIT_PGI"; break;
      case GL_VERTEX23_BIT_PGI: RETVAL = "GL_VERTEX23_BIT_PGI"; break;
      case GL_VERTEX4_BIT_PGI: RETVAL = "GL_VERTEX4_BIT_PGI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexPointerType")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexProvokingMode")) {
    switch (e) {
      case GL_FIRST_VERTEX_CONVENTION: RETVAL = "GL_FIRST_VERTEX_CONVENTION"; break;
      case GL_LAST_VERTEX_CONVENTION: RETVAL = "GL_LAST_VERTEX_CONVENTION"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderCoordOutEXT")) {
    switch (e) {
      case GL_NEGATIVE_ONE_EXT: RETVAL = "GL_NEGATIVE_ONE_EXT"; break;
      case GL_NEGATIVE_W_EXT: RETVAL = "GL_NEGATIVE_W_EXT"; break;
      case GL_NEGATIVE_X_EXT: RETVAL = "GL_NEGATIVE_X_EXT"; break;
      case GL_NEGATIVE_Y_EXT: RETVAL = "GL_NEGATIVE_Y_EXT"; break;
      case GL_NEGATIVE_Z_EXT: RETVAL = "GL_NEGATIVE_Z_EXT"; break;
      case GL_ONE_EXT: RETVAL = "GL_ONE_EXT"; break;
      case GL_W_EXT: RETVAL = "GL_W_EXT"; break;
      case GL_X_EXT: RETVAL = "GL_X_EXT"; break;
      case GL_Y_EXT: RETVAL = "GL_Y_EXT"; break;
      case GL_ZERO_EXT: RETVAL = "GL_ZERO_EXT"; break;
      case GL_Z_EXT: RETVAL = "GL_Z_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderOpEXT")) {
    switch (e) {
      case GL_OP_ADD_EXT: RETVAL = "GL_OP_ADD_EXT"; break;
      case GL_OP_CLAMP_EXT: RETVAL = "GL_OP_CLAMP_EXT"; break;
      case GL_OP_CROSS_PRODUCT_EXT: RETVAL = "GL_OP_CROSS_PRODUCT_EXT"; break;
      case GL_OP_DOT3_EXT: RETVAL = "GL_OP_DOT3_EXT"; break;
      case GL_OP_DOT4_EXT: RETVAL = "GL_OP_DOT4_EXT"; break;
      case GL_OP_EXP_BASE_2_EXT: RETVAL = "GL_OP_EXP_BASE_2_EXT"; break;
      case GL_OP_FLOOR_EXT: RETVAL = "GL_OP_FLOOR_EXT"; break;
      case GL_OP_FRAC_EXT: RETVAL = "GL_OP_FRAC_EXT"; break;
      case GL_OP_INDEX_EXT: RETVAL = "GL_OP_INDEX_EXT"; break;
      case GL_OP_LOG_BASE_2_EXT: RETVAL = "GL_OP_LOG_BASE_2_EXT"; break;
      case GL_OP_MADD_EXT: RETVAL = "GL_OP_MADD_EXT"; break;
      case GL_OP_MAX_EXT: RETVAL = "GL_OP_MAX_EXT"; break;
      case GL_OP_MIN_EXT: RETVAL = "GL_OP_MIN_EXT"; break;
      case GL_OP_MOV_EXT: RETVAL = "GL_OP_MOV_EXT"; break;
      case GL_OP_MULTIPLY_MATRIX_EXT: RETVAL = "GL_OP_MULTIPLY_MATRIX_EXT"; break;
      case GL_OP_MUL_EXT: RETVAL = "GL_OP_MUL_EXT"; break;
      case GL_OP_NEGATE_EXT: RETVAL = "GL_OP_NEGATE_EXT"; break;
      case GL_OP_POWER_EXT: RETVAL = "GL_OP_POWER_EXT"; break;
      case GL_OP_RECIP_EXT: RETVAL = "GL_OP_RECIP_EXT"; break;
      case GL_OP_RECIP_SQRT_EXT: RETVAL = "GL_OP_RECIP_SQRT_EXT"; break;
      case GL_OP_ROUND_EXT: RETVAL = "GL_OP_ROUND_EXT"; break;
      case GL_OP_SET_GE_EXT: RETVAL = "GL_OP_SET_GE_EXT"; break;
      case GL_OP_SET_LT_EXT: RETVAL = "GL_OP_SET_LT_EXT"; break;
      case GL_OP_SUB_EXT: RETVAL = "GL_OP_SUB_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderParameterEXT")) {
    switch (e) {
      case GL_CURRENT_VERTEX_EXT: RETVAL = "GL_CURRENT_VERTEX_EXT"; break;
      case GL_MVP_MATRIX_EXT: RETVAL = "GL_MVP_MATRIX_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderStorageTypeEXT")) {
    switch (e) {
      case GL_INVARIANT_EXT: RETVAL = "GL_INVARIANT_EXT"; break;
      case GL_LOCAL_CONSTANT_EXT: RETVAL = "GL_LOCAL_CONSTANT_EXT"; break;
      case GL_LOCAL_EXT: RETVAL = "GL_LOCAL_EXT"; break;
      case GL_VARIANT_EXT: RETVAL = "GL_VARIANT_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderTextureUnitParameter")) {
    switch (e) {
      case GL_CURRENT_TEXTURE_COORDS: RETVAL = "GL_CURRENT_TEXTURE_COORDS"; break;
      case GL_TEXTURE_MATRIX: RETVAL = "GL_TEXTURE_MATRIX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderWriteMaskEXT")) {
    switch (e) {
      case GL_FALSE: RETVAL = "GL_FALSE"; break;
      case GL_TRUE: RETVAL = "GL_TRUE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexStreamATI")) {
    switch (e) {
      case GL_VERTEX_STREAM0_ATI: RETVAL = "GL_VERTEX_STREAM0_ATI"; break;
      case GL_VERTEX_STREAM1_ATI: RETVAL = "GL_VERTEX_STREAM1_ATI"; break;
      case GL_VERTEX_STREAM2_ATI: RETVAL = "GL_VERTEX_STREAM2_ATI"; break;
      case GL_VERTEX_STREAM3_ATI: RETVAL = "GL_VERTEX_STREAM3_ATI"; break;
      case GL_VERTEX_STREAM4_ATI: RETVAL = "GL_VERTEX_STREAM4_ATI"; break;
      case GL_VERTEX_STREAM5_ATI: RETVAL = "GL_VERTEX_STREAM5_ATI"; break;
      case GL_VERTEX_STREAM6_ATI: RETVAL = "GL_VERTEX_STREAM6_ATI"; break;
      case GL_VERTEX_STREAM7_ATI: RETVAL = "GL_VERTEX_STREAM7_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexWeightPointerTypeEXT")) {
    switch (e) {
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "WeightPointerTypeARB")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!RETVAL) RETVAL = "UNKNOWN GROUP";
  alldone:
#line 5296 "lib/OpenGL/Modern/Const.c"
	sv_setpv(TARG, RETVAL);
	XSprePUSH;
	PUSHTARG;
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Const.xs' from '../../../auto-xs-enums.inc' */


/* INCLUDE:  Including '../../../auto-xs-var.inc' from 'Const.xs' */


XS_EUPXS(XS_OpenGL__Modern_GLEW_3DFX_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_3DFX_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_3DFX_multisample, )
  RETVAL = GLEW_3DFX_multisample;
  OGLM_CHECK_ERR(GLEW_3DFX_multisample, )
#line 5325 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_3DFX_tbuffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_3DFX_tbuffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 14 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_3DFX_tbuffer, )
  RETVAL = GLEW_3DFX_tbuffer;
  OGLM_CHECK_ERR(GLEW_3DFX_tbuffer, )
#line 5347 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_3DFX_texture_compression_FXT1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_3DFX_texture_compression_FXT1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 24 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_3DFX_texture_compression_FXT1, )
  RETVAL = GLEW_3DFX_texture_compression_FXT1;
  OGLM_CHECK_ERR(GLEW_3DFX_texture_compression_FXT1, )
#line 5369 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_blend_minmax_factor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_blend_minmax_factor)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 34 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_blend_minmax_factor, )
  RETVAL = GLEW_AMD_blend_minmax_factor;
  OGLM_CHECK_ERR(GLEW_AMD_blend_minmax_factor, )
#line 5391 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_compressed_3DC_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_compressed_3DC_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 44 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_compressed_3DC_texture, )
  RETVAL = GLEW_AMD_compressed_3DC_texture;
  OGLM_CHECK_ERR(GLEW_AMD_compressed_3DC_texture, )
#line 5413 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_compressed_ATC_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_compressed_ATC_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 54 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_compressed_ATC_texture, )
  RETVAL = GLEW_AMD_compressed_ATC_texture;
  OGLM_CHECK_ERR(GLEW_AMD_compressed_ATC_texture, )
#line 5435 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_conservative_depth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_conservative_depth)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 64 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_conservative_depth, )
  RETVAL = GLEW_AMD_conservative_depth;
  OGLM_CHECK_ERR(GLEW_AMD_conservative_depth, )
#line 5457 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_debug_output); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_debug_output)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 74 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_debug_output, )
  RETVAL = GLEW_AMD_debug_output;
  OGLM_CHECK_ERR(GLEW_AMD_debug_output, )
#line 5479 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_depth_clamp_separate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_depth_clamp_separate)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 84 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_depth_clamp_separate, )
  RETVAL = GLEW_AMD_depth_clamp_separate;
  OGLM_CHECK_ERR(GLEW_AMD_depth_clamp_separate, )
#line 5501 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_draw_buffers_blend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_draw_buffers_blend)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 94 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_draw_buffers_blend, )
  RETVAL = GLEW_AMD_draw_buffers_blend;
  OGLM_CHECK_ERR(GLEW_AMD_draw_buffers_blend, )
#line 5523 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_framebuffer_multisample_advanced); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_framebuffer_multisample_advanced)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 104 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_framebuffer_multisample_advanced, )
  RETVAL = GLEW_AMD_framebuffer_multisample_advanced;
  OGLM_CHECK_ERR(GLEW_AMD_framebuffer_multisample_advanced, )
#line 5545 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_framebuffer_sample_positions); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_framebuffer_sample_positions)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 114 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_framebuffer_sample_positions, )
  RETVAL = GLEW_AMD_framebuffer_sample_positions;
  OGLM_CHECK_ERR(GLEW_AMD_framebuffer_sample_positions, )
#line 5567 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_gcn_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_gcn_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 124 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_gcn_shader, )
  RETVAL = GLEW_AMD_gcn_shader;
  OGLM_CHECK_ERR(GLEW_AMD_gcn_shader, )
#line 5589 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_gpu_shader_half_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_gpu_shader_half_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 134 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_half_float, )
  RETVAL = GLEW_AMD_gpu_shader_half_float;
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_half_float, )
#line 5611 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_gpu_shader_half_float_fetch); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_gpu_shader_half_float_fetch)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 144 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_half_float_fetch, )
  RETVAL = GLEW_AMD_gpu_shader_half_float_fetch;
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_half_float_fetch, )
#line 5633 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_gpu_shader_int16); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_gpu_shader_int16)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 154 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_int16, )
  RETVAL = GLEW_AMD_gpu_shader_int16;
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_int16, )
#line 5655 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_gpu_shader_int64); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_gpu_shader_int64)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 164 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_int64, )
  RETVAL = GLEW_AMD_gpu_shader_int64;
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_int64, )
#line 5677 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_interleaved_elements); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_interleaved_elements)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 174 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_interleaved_elements, )
  RETVAL = GLEW_AMD_interleaved_elements;
  OGLM_CHECK_ERR(GLEW_AMD_interleaved_elements, )
#line 5699 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_multi_draw_indirect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_multi_draw_indirect)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 184 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_multi_draw_indirect, )
  RETVAL = GLEW_AMD_multi_draw_indirect;
  OGLM_CHECK_ERR(GLEW_AMD_multi_draw_indirect, )
#line 5721 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_name_gen_delete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_name_gen_delete)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 194 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_name_gen_delete, )
  RETVAL = GLEW_AMD_name_gen_delete;
  OGLM_CHECK_ERR(GLEW_AMD_name_gen_delete, )
#line 5743 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_occlusion_query_event); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_occlusion_query_event)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 204 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_occlusion_query_event, )
  RETVAL = GLEW_AMD_occlusion_query_event;
  OGLM_CHECK_ERR(GLEW_AMD_occlusion_query_event, )
#line 5765 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_performance_monitor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_performance_monitor)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 214 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_performance_monitor, )
  RETVAL = GLEW_AMD_performance_monitor;
  OGLM_CHECK_ERR(GLEW_AMD_performance_monitor, )
#line 5787 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_pinned_memory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_pinned_memory)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 224 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_pinned_memory, )
  RETVAL = GLEW_AMD_pinned_memory;
  OGLM_CHECK_ERR(GLEW_AMD_pinned_memory, )
#line 5809 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_program_binary_Z400); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_program_binary_Z400)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 234 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_program_binary_Z400, )
  RETVAL = GLEW_AMD_program_binary_Z400;
  OGLM_CHECK_ERR(GLEW_AMD_program_binary_Z400, )
#line 5831 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_query_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_query_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 244 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_query_buffer_object, )
  RETVAL = GLEW_AMD_query_buffer_object;
  OGLM_CHECK_ERR(GLEW_AMD_query_buffer_object, )
#line 5853 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_sample_positions); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_sample_positions)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 254 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_sample_positions, )
  RETVAL = GLEW_AMD_sample_positions;
  OGLM_CHECK_ERR(GLEW_AMD_sample_positions, )
#line 5875 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_seamless_cubemap_per_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_seamless_cubemap_per_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 264 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_seamless_cubemap_per_texture, )
  RETVAL = GLEW_AMD_seamless_cubemap_per_texture;
  OGLM_CHECK_ERR(GLEW_AMD_seamless_cubemap_per_texture, )
#line 5897 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_atomic_counter_ops); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_atomic_counter_ops)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 274 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_atomic_counter_ops, )
  RETVAL = GLEW_AMD_shader_atomic_counter_ops;
  OGLM_CHECK_ERR(GLEW_AMD_shader_atomic_counter_ops, )
#line 5919 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_ballot); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_ballot)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 284 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_ballot, )
  RETVAL = GLEW_AMD_shader_ballot;
  OGLM_CHECK_ERR(GLEW_AMD_shader_ballot, )
#line 5941 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_explicit_vertex_parameter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_explicit_vertex_parameter)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 294 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_explicit_vertex_parameter, )
  RETVAL = GLEW_AMD_shader_explicit_vertex_parameter;
  OGLM_CHECK_ERR(GLEW_AMD_shader_explicit_vertex_parameter, )
#line 5963 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_image_load_store_lod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_image_load_store_lod)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 304 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_image_load_store_lod, )
  RETVAL = GLEW_AMD_shader_image_load_store_lod;
  OGLM_CHECK_ERR(GLEW_AMD_shader_image_load_store_lod, )
#line 5985 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_stencil_export); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_stencil_export)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 314 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_stencil_export, )
  RETVAL = GLEW_AMD_shader_stencil_export;
  OGLM_CHECK_ERR(GLEW_AMD_shader_stencil_export, )
#line 6007 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_stencil_value_export); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_stencil_value_export)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 324 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_stencil_value_export, )
  RETVAL = GLEW_AMD_shader_stencil_value_export;
  OGLM_CHECK_ERR(GLEW_AMD_shader_stencil_value_export, )
#line 6029 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_trinary_minmax); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_shader_trinary_minmax)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 334 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_trinary_minmax, )
  RETVAL = GLEW_AMD_shader_trinary_minmax;
  OGLM_CHECK_ERR(GLEW_AMD_shader_trinary_minmax, )
#line 6051 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_sparse_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_sparse_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 344 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_sparse_texture, )
  RETVAL = GLEW_AMD_sparse_texture;
  OGLM_CHECK_ERR(GLEW_AMD_sparse_texture, )
#line 6073 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_stencil_operation_extended); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_stencil_operation_extended)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 354 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_stencil_operation_extended, )
  RETVAL = GLEW_AMD_stencil_operation_extended;
  OGLM_CHECK_ERR(GLEW_AMD_stencil_operation_extended, )
#line 6095 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_texture_gather_bias_lod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_texture_gather_bias_lod)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 364 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_texture_gather_bias_lod, )
  RETVAL = GLEW_AMD_texture_gather_bias_lod;
  OGLM_CHECK_ERR(GLEW_AMD_texture_gather_bias_lod, )
#line 6117 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_texture_texture4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_texture_texture4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 374 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_texture_texture4, )
  RETVAL = GLEW_AMD_texture_texture4;
  OGLM_CHECK_ERR(GLEW_AMD_texture_texture4, )
#line 6139 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_transform_feedback3_lines_triangles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_transform_feedback3_lines_triangles)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 384 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_transform_feedback3_lines_triangles, )
  RETVAL = GLEW_AMD_transform_feedback3_lines_triangles;
  OGLM_CHECK_ERR(GLEW_AMD_transform_feedback3_lines_triangles, )
#line 6161 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_transform_feedback4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_transform_feedback4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 394 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_transform_feedback4, )
  RETVAL = GLEW_AMD_transform_feedback4;
  OGLM_CHECK_ERR(GLEW_AMD_transform_feedback4, )
#line 6183 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_vertex_shader_layer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_vertex_shader_layer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 404 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_layer, )
  RETVAL = GLEW_AMD_vertex_shader_layer;
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_layer, )
#line 6205 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_vertex_shader_tessellator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_vertex_shader_tessellator)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 414 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_tessellator, )
  RETVAL = GLEW_AMD_vertex_shader_tessellator;
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_tessellator, )
#line 6227 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_vertex_shader_viewport_index); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_AMD_vertex_shader_viewport_index)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 424 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_viewport_index, )
  RETVAL = GLEW_AMD_vertex_shader_viewport_index;
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_viewport_index, )
#line 6249 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANDROID_extension_pack_es31a); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANDROID_extension_pack_es31a)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 434 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANDROID_extension_pack_es31a, )
  RETVAL = GLEW_ANDROID_extension_pack_es31a;
  OGLM_CHECK_ERR(GLEW_ANDROID_extension_pack_es31a, )
#line 6271 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_depth_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_depth_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 444 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_depth_texture, )
  RETVAL = GLEW_ANGLE_depth_texture;
  OGLM_CHECK_ERR(GLEW_ANGLE_depth_texture, )
#line 6293 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_framebuffer_blit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_framebuffer_blit)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 454 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_framebuffer_blit, )
  RETVAL = GLEW_ANGLE_framebuffer_blit;
  OGLM_CHECK_ERR(GLEW_ANGLE_framebuffer_blit, )
#line 6315 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_framebuffer_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_framebuffer_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 464 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_framebuffer_multisample, )
  RETVAL = GLEW_ANGLE_framebuffer_multisample;
  OGLM_CHECK_ERR(GLEW_ANGLE_framebuffer_multisample, )
#line 6337 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_instanced_arrays); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_instanced_arrays)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 474 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_instanced_arrays, )
  RETVAL = GLEW_ANGLE_instanced_arrays;
  OGLM_CHECK_ERR(GLEW_ANGLE_instanced_arrays, )
#line 6359 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_pack_reverse_row_order); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_pack_reverse_row_order)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 484 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_pack_reverse_row_order, )
  RETVAL = GLEW_ANGLE_pack_reverse_row_order;
  OGLM_CHECK_ERR(GLEW_ANGLE_pack_reverse_row_order, )
#line 6381 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_program_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_program_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 494 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_program_binary, )
  RETVAL = GLEW_ANGLE_program_binary;
  OGLM_CHECK_ERR(GLEW_ANGLE_program_binary, )
#line 6403 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_texture_compression_dxt1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_texture_compression_dxt1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 504 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt1, )
  RETVAL = GLEW_ANGLE_texture_compression_dxt1;
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt1, )
#line 6425 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_texture_compression_dxt3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_texture_compression_dxt3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 514 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt3, )
  RETVAL = GLEW_ANGLE_texture_compression_dxt3;
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt3, )
#line 6447 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_texture_compression_dxt5); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_texture_compression_dxt5)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 524 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt5, )
  RETVAL = GLEW_ANGLE_texture_compression_dxt5;
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt5, )
#line 6469 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_texture_usage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_texture_usage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 534 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_usage, )
  RETVAL = GLEW_ANGLE_texture_usage;
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_usage, )
#line 6491 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_timer_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_timer_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 544 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_timer_query, )
  RETVAL = GLEW_ANGLE_timer_query;
  OGLM_CHECK_ERR(GLEW_ANGLE_timer_query, )
#line 6513 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_translated_shader_source); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ANGLE_translated_shader_source)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 554 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_translated_shader_source, )
  RETVAL = GLEW_ANGLE_translated_shader_source;
  OGLM_CHECK_ERR(GLEW_ANGLE_translated_shader_source, )
#line 6535 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_aux_depth_stencil); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_aux_depth_stencil)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 564 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_aux_depth_stencil, )
  RETVAL = GLEW_APPLE_aux_depth_stencil;
  OGLM_CHECK_ERR(GLEW_APPLE_aux_depth_stencil, )
#line 6557 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_client_storage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_client_storage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 574 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_client_storage, )
  RETVAL = GLEW_APPLE_client_storage;
  OGLM_CHECK_ERR(GLEW_APPLE_client_storage, )
#line 6579 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_clip_distance); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_clip_distance)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 584 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_clip_distance, )
  RETVAL = GLEW_APPLE_clip_distance;
  OGLM_CHECK_ERR(GLEW_APPLE_clip_distance, )
#line 6601 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_color_buffer_packed_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_color_buffer_packed_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 594 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_color_buffer_packed_float, )
  RETVAL = GLEW_APPLE_color_buffer_packed_float;
  OGLM_CHECK_ERR(GLEW_APPLE_color_buffer_packed_float, )
#line 6623 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_copy_texture_levels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_copy_texture_levels)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 604 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_copy_texture_levels, )
  RETVAL = GLEW_APPLE_copy_texture_levels;
  OGLM_CHECK_ERR(GLEW_APPLE_copy_texture_levels, )
#line 6645 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_element_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_element_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 614 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_element_array, )
  RETVAL = GLEW_APPLE_element_array;
  OGLM_CHECK_ERR(GLEW_APPLE_element_array, )
#line 6667 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_fence); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_fence)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 624 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_fence, )
  RETVAL = GLEW_APPLE_fence;
  OGLM_CHECK_ERR(GLEW_APPLE_fence, )
#line 6689 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_float_pixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_float_pixels)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 634 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_float_pixels, )
  RETVAL = GLEW_APPLE_float_pixels;
  OGLM_CHECK_ERR(GLEW_APPLE_float_pixels, )
#line 6711 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_flush_buffer_range); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_flush_buffer_range)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 644 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_flush_buffer_range, )
  RETVAL = GLEW_APPLE_flush_buffer_range;
  OGLM_CHECK_ERR(GLEW_APPLE_flush_buffer_range, )
#line 6733 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_framebuffer_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_framebuffer_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 654 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_framebuffer_multisample, )
  RETVAL = GLEW_APPLE_framebuffer_multisample;
  OGLM_CHECK_ERR(GLEW_APPLE_framebuffer_multisample, )
#line 6755 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_object_purgeable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_object_purgeable)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 664 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_object_purgeable, )
  RETVAL = GLEW_APPLE_object_purgeable;
  OGLM_CHECK_ERR(GLEW_APPLE_object_purgeable, )
#line 6777 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_pixel_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_pixel_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 674 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_pixel_buffer, )
  RETVAL = GLEW_APPLE_pixel_buffer;
  OGLM_CHECK_ERR(GLEW_APPLE_pixel_buffer, )
#line 6799 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_rgb_422); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_rgb_422)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 684 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_rgb_422, )
  RETVAL = GLEW_APPLE_rgb_422;
  OGLM_CHECK_ERR(GLEW_APPLE_rgb_422, )
#line 6821 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_row_bytes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_row_bytes)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 694 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_row_bytes, )
  RETVAL = GLEW_APPLE_row_bytes;
  OGLM_CHECK_ERR(GLEW_APPLE_row_bytes, )
#line 6843 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_specular_vector); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_specular_vector)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 704 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_specular_vector, )
  RETVAL = GLEW_APPLE_specular_vector;
  OGLM_CHECK_ERR(GLEW_APPLE_specular_vector, )
#line 6865 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_sync); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_sync)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 714 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_sync, )
  RETVAL = GLEW_APPLE_sync;
  OGLM_CHECK_ERR(GLEW_APPLE_sync, )
#line 6887 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_texture_2D_limited_npot); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_texture_2D_limited_npot)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 724 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_texture_2D_limited_npot, )
  RETVAL = GLEW_APPLE_texture_2D_limited_npot;
  OGLM_CHECK_ERR(GLEW_APPLE_texture_2D_limited_npot, )
#line 6909 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_texture_format_BGRA8888); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_texture_format_BGRA8888)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 734 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_texture_format_BGRA8888, )
  RETVAL = GLEW_APPLE_texture_format_BGRA8888;
  OGLM_CHECK_ERR(GLEW_APPLE_texture_format_BGRA8888, )
#line 6931 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_texture_max_level); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_texture_max_level)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 744 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_texture_max_level, )
  RETVAL = GLEW_APPLE_texture_max_level;
  OGLM_CHECK_ERR(GLEW_APPLE_texture_max_level, )
#line 6953 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_texture_packed_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_texture_packed_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 754 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_texture_packed_float, )
  RETVAL = GLEW_APPLE_texture_packed_float;
  OGLM_CHECK_ERR(GLEW_APPLE_texture_packed_float, )
#line 6975 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_texture_range); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_texture_range)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 764 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_texture_range, )
  RETVAL = GLEW_APPLE_texture_range;
  OGLM_CHECK_ERR(GLEW_APPLE_texture_range, )
#line 6997 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_transform_hint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_transform_hint)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 774 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_transform_hint, )
  RETVAL = GLEW_APPLE_transform_hint;
  OGLM_CHECK_ERR(GLEW_APPLE_transform_hint, )
#line 7019 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_vertex_array_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_vertex_array_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 784 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_array_object, )
  RETVAL = GLEW_APPLE_vertex_array_object;
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_array_object, )
#line 7041 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_vertex_array_range); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_vertex_array_range)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 794 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_array_range, )
  RETVAL = GLEW_APPLE_vertex_array_range;
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_array_range, )
#line 7063 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_vertex_program_evaluators); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_vertex_program_evaluators)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 804 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_program_evaluators, )
  RETVAL = GLEW_APPLE_vertex_program_evaluators;
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_program_evaluators, )
#line 7085 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_ycbcr_422); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_APPLE_ycbcr_422)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 814 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_ycbcr_422, )
  RETVAL = GLEW_APPLE_ycbcr_422;
  OGLM_CHECK_ERR(GLEW_APPLE_ycbcr_422, )
#line 7107 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_ES2_compatibility); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_ES2_compatibility)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 824 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_ES2_compatibility, )
  RETVAL = GLEW_ARB_ES2_compatibility;
  OGLM_CHECK_ERR(GLEW_ARB_ES2_compatibility, )
#line 7129 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_ES3_1_compatibility); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_ES3_1_compatibility)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 834 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_ES3_1_compatibility, )
  RETVAL = GLEW_ARB_ES3_1_compatibility;
  OGLM_CHECK_ERR(GLEW_ARB_ES3_1_compatibility, )
#line 7151 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_ES3_2_compatibility); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_ES3_2_compatibility)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 844 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_ES3_2_compatibility, )
  RETVAL = GLEW_ARB_ES3_2_compatibility;
  OGLM_CHECK_ERR(GLEW_ARB_ES3_2_compatibility, )
#line 7173 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_ES3_compatibility); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_ES3_compatibility)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 854 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_ES3_compatibility, )
  RETVAL = GLEW_ARB_ES3_compatibility;
  OGLM_CHECK_ERR(GLEW_ARB_ES3_compatibility, )
#line 7195 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_arrays_of_arrays); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_arrays_of_arrays)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 864 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_arrays_of_arrays, )
  RETVAL = GLEW_ARB_arrays_of_arrays;
  OGLM_CHECK_ERR(GLEW_ARB_arrays_of_arrays, )
#line 7217 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_base_instance); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_base_instance)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 874 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_base_instance, )
  RETVAL = GLEW_ARB_base_instance;
  OGLM_CHECK_ERR(GLEW_ARB_base_instance, )
#line 7239 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_bindless_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_bindless_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 884 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_bindless_texture, )
  RETVAL = GLEW_ARB_bindless_texture;
  OGLM_CHECK_ERR(GLEW_ARB_bindless_texture, )
#line 7261 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_blend_func_extended); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_blend_func_extended)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 894 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_blend_func_extended, )
  RETVAL = GLEW_ARB_blend_func_extended;
  OGLM_CHECK_ERR(GLEW_ARB_blend_func_extended, )
#line 7283 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_buffer_storage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_buffer_storage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 904 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_buffer_storage, )
  RETVAL = GLEW_ARB_buffer_storage;
  OGLM_CHECK_ERR(GLEW_ARB_buffer_storage, )
#line 7305 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_cl_event); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_cl_event)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 914 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_cl_event, )
  RETVAL = GLEW_ARB_cl_event;
  OGLM_CHECK_ERR(GLEW_ARB_cl_event, )
#line 7327 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_clear_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_clear_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 924 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_clear_buffer_object, )
  RETVAL = GLEW_ARB_clear_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_clear_buffer_object, )
#line 7349 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_clear_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_clear_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 934 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_clear_texture, )
  RETVAL = GLEW_ARB_clear_texture;
  OGLM_CHECK_ERR(GLEW_ARB_clear_texture, )
#line 7371 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_clip_control); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_clip_control)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 944 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_clip_control, )
  RETVAL = GLEW_ARB_clip_control;
  OGLM_CHECK_ERR(GLEW_ARB_clip_control, )
#line 7393 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_color_buffer_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_color_buffer_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 954 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_color_buffer_float, )
  RETVAL = GLEW_ARB_color_buffer_float;
  OGLM_CHECK_ERR(GLEW_ARB_color_buffer_float, )
#line 7415 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_compatibility); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_compatibility)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 964 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_compatibility, )
  RETVAL = GLEW_ARB_compatibility;
  OGLM_CHECK_ERR(GLEW_ARB_compatibility, )
#line 7437 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_compressed_texture_pixel_storage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_compressed_texture_pixel_storage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 974 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_compressed_texture_pixel_storage, )
  RETVAL = GLEW_ARB_compressed_texture_pixel_storage;
  OGLM_CHECK_ERR(GLEW_ARB_compressed_texture_pixel_storage, )
#line 7459 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_compute_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_compute_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 984 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_compute_shader, )
  RETVAL = GLEW_ARB_compute_shader;
  OGLM_CHECK_ERR(GLEW_ARB_compute_shader, )
#line 7481 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_compute_variable_group_size); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_compute_variable_group_size)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 994 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_compute_variable_group_size, )
  RETVAL = GLEW_ARB_compute_variable_group_size;
  OGLM_CHECK_ERR(GLEW_ARB_compute_variable_group_size, )
#line 7503 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_conditional_render_inverted); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_conditional_render_inverted)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1004 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_conditional_render_inverted, )
  RETVAL = GLEW_ARB_conditional_render_inverted;
  OGLM_CHECK_ERR(GLEW_ARB_conditional_render_inverted, )
#line 7525 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_conservative_depth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_conservative_depth)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1014 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_conservative_depth, )
  RETVAL = GLEW_ARB_conservative_depth;
  OGLM_CHECK_ERR(GLEW_ARB_conservative_depth, )
#line 7547 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_copy_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_copy_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1024 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_copy_buffer, )
  RETVAL = GLEW_ARB_copy_buffer;
  OGLM_CHECK_ERR(GLEW_ARB_copy_buffer, )
#line 7569 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_copy_image); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_copy_image)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1034 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_copy_image, )
  RETVAL = GLEW_ARB_copy_image;
  OGLM_CHECK_ERR(GLEW_ARB_copy_image, )
#line 7591 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_cull_distance); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_cull_distance)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1044 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_cull_distance, )
  RETVAL = GLEW_ARB_cull_distance;
  OGLM_CHECK_ERR(GLEW_ARB_cull_distance, )
#line 7613 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_debug_output); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_debug_output)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1054 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_debug_output, )
  RETVAL = GLEW_ARB_debug_output;
  OGLM_CHECK_ERR(GLEW_ARB_debug_output, )
#line 7635 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_depth_buffer_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_depth_buffer_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1064 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_depth_buffer_float, )
  RETVAL = GLEW_ARB_depth_buffer_float;
  OGLM_CHECK_ERR(GLEW_ARB_depth_buffer_float, )
#line 7657 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_depth_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_depth_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1074 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_depth_clamp, )
  RETVAL = GLEW_ARB_depth_clamp;
  OGLM_CHECK_ERR(GLEW_ARB_depth_clamp, )
#line 7679 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_depth_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_depth_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1084 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_depth_texture, )
  RETVAL = GLEW_ARB_depth_texture;
  OGLM_CHECK_ERR(GLEW_ARB_depth_texture, )
#line 7701 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_derivative_control); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_derivative_control)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1094 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_derivative_control, )
  RETVAL = GLEW_ARB_derivative_control;
  OGLM_CHECK_ERR(GLEW_ARB_derivative_control, )
#line 7723 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_direct_state_access); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_direct_state_access)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1104 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_direct_state_access, )
  RETVAL = GLEW_ARB_direct_state_access;
  OGLM_CHECK_ERR(GLEW_ARB_direct_state_access, )
#line 7745 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_draw_buffers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_draw_buffers)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1114 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_draw_buffers, )
  RETVAL = GLEW_ARB_draw_buffers;
  OGLM_CHECK_ERR(GLEW_ARB_draw_buffers, )
#line 7767 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_draw_buffers_blend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_draw_buffers_blend)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1124 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_draw_buffers_blend, )
  RETVAL = GLEW_ARB_draw_buffers_blend;
  OGLM_CHECK_ERR(GLEW_ARB_draw_buffers_blend, )
#line 7789 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_draw_elements_base_vertex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_draw_elements_base_vertex)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1134 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_draw_elements_base_vertex, )
  RETVAL = GLEW_ARB_draw_elements_base_vertex;
  OGLM_CHECK_ERR(GLEW_ARB_draw_elements_base_vertex, )
#line 7811 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_draw_indirect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_draw_indirect)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1144 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_draw_indirect, )
  RETVAL = GLEW_ARB_draw_indirect;
  OGLM_CHECK_ERR(GLEW_ARB_draw_indirect, )
#line 7833 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_draw_instanced); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_draw_instanced)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1154 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_draw_instanced, )
  RETVAL = GLEW_ARB_draw_instanced;
  OGLM_CHECK_ERR(GLEW_ARB_draw_instanced, )
#line 7855 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_enhanced_layouts); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_enhanced_layouts)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1164 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_enhanced_layouts, )
  RETVAL = GLEW_ARB_enhanced_layouts;
  OGLM_CHECK_ERR(GLEW_ARB_enhanced_layouts, )
#line 7877 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_explicit_attrib_location); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_explicit_attrib_location)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1174 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_explicit_attrib_location, )
  RETVAL = GLEW_ARB_explicit_attrib_location;
  OGLM_CHECK_ERR(GLEW_ARB_explicit_attrib_location, )
#line 7899 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_explicit_uniform_location); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_explicit_uniform_location)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1184 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_explicit_uniform_location, )
  RETVAL = GLEW_ARB_explicit_uniform_location;
  OGLM_CHECK_ERR(GLEW_ARB_explicit_uniform_location, )
#line 7921 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_coord_conventions); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_coord_conventions)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1194 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_coord_conventions, )
  RETVAL = GLEW_ARB_fragment_coord_conventions;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_coord_conventions, )
#line 7943 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_layer_viewport); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_layer_viewport)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1204 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_layer_viewport, )
  RETVAL = GLEW_ARB_fragment_layer_viewport;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_layer_viewport, )
#line 7965 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_program); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_program)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1214 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_program, )
  RETVAL = GLEW_ARB_fragment_program;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_program, )
#line 7987 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_program_shadow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_program_shadow)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1224 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_program_shadow, )
  RETVAL = GLEW_ARB_fragment_program_shadow;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_program_shadow, )
#line 8009 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1234 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_shader, )
  RETVAL = GLEW_ARB_fragment_shader;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_shader, )
#line 8031 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_shader_interlock); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_fragment_shader_interlock)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1244 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_shader_interlock, )
  RETVAL = GLEW_ARB_fragment_shader_interlock;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_shader_interlock, )
#line 8053 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_framebuffer_no_attachments); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_framebuffer_no_attachments)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1254 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_no_attachments, )
  RETVAL = GLEW_ARB_framebuffer_no_attachments;
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_no_attachments, )
#line 8075 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_framebuffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_framebuffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1264 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_object, )
  RETVAL = GLEW_ARB_framebuffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_object, )
#line 8097 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_framebuffer_sRGB); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_framebuffer_sRGB)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1274 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_sRGB, )
  RETVAL = GLEW_ARB_framebuffer_sRGB;
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_sRGB, )
#line 8119 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_geometry_shader4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_geometry_shader4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1284 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_geometry_shader4, )
  RETVAL = GLEW_ARB_geometry_shader4;
  OGLM_CHECK_ERR(GLEW_ARB_geometry_shader4, )
#line 8141 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_get_program_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_get_program_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1294 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_get_program_binary, )
  RETVAL = GLEW_ARB_get_program_binary;
  OGLM_CHECK_ERR(GLEW_ARB_get_program_binary, )
#line 8163 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_get_texture_sub_image); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_get_texture_sub_image)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1304 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_get_texture_sub_image, )
  RETVAL = GLEW_ARB_get_texture_sub_image;
  OGLM_CHECK_ERR(GLEW_ARB_get_texture_sub_image, )
#line 8185 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_gl_spirv); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_gl_spirv)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1314 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_gl_spirv, )
  RETVAL = GLEW_ARB_gl_spirv;
  OGLM_CHECK_ERR(GLEW_ARB_gl_spirv, )
#line 8207 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_gpu_shader5); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_gpu_shader5)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1324 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader5, )
  RETVAL = GLEW_ARB_gpu_shader5;
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader5, )
#line 8229 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_gpu_shader_fp64); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_gpu_shader_fp64)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1334 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader_fp64, )
  RETVAL = GLEW_ARB_gpu_shader_fp64;
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader_fp64, )
#line 8251 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_gpu_shader_int64); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_gpu_shader_int64)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1344 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader_int64, )
  RETVAL = GLEW_ARB_gpu_shader_int64;
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader_int64, )
#line 8273 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_half_float_pixel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_half_float_pixel)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1354 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_half_float_pixel, )
  RETVAL = GLEW_ARB_half_float_pixel;
  OGLM_CHECK_ERR(GLEW_ARB_half_float_pixel, )
#line 8295 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_half_float_vertex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_half_float_vertex)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1364 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_half_float_vertex, )
  RETVAL = GLEW_ARB_half_float_vertex;
  OGLM_CHECK_ERR(GLEW_ARB_half_float_vertex, )
#line 8317 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_imaging); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_imaging)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1374 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_imaging, )
  RETVAL = GLEW_ARB_imaging;
  OGLM_CHECK_ERR(GLEW_ARB_imaging, )
#line 8339 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_indirect_parameters); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_indirect_parameters)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1384 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_indirect_parameters, )
  RETVAL = GLEW_ARB_indirect_parameters;
  OGLM_CHECK_ERR(GLEW_ARB_indirect_parameters, )
#line 8361 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_instanced_arrays); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_instanced_arrays)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1394 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_instanced_arrays, )
  RETVAL = GLEW_ARB_instanced_arrays;
  OGLM_CHECK_ERR(GLEW_ARB_instanced_arrays, )
#line 8383 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_internalformat_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_internalformat_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1404 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_internalformat_query, )
  RETVAL = GLEW_ARB_internalformat_query;
  OGLM_CHECK_ERR(GLEW_ARB_internalformat_query, )
#line 8405 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_internalformat_query2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_internalformat_query2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1414 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_internalformat_query2, )
  RETVAL = GLEW_ARB_internalformat_query2;
  OGLM_CHECK_ERR(GLEW_ARB_internalformat_query2, )
#line 8427 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_invalidate_subdata); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_invalidate_subdata)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1424 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_invalidate_subdata, )
  RETVAL = GLEW_ARB_invalidate_subdata;
  OGLM_CHECK_ERR(GLEW_ARB_invalidate_subdata, )
#line 8449 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_map_buffer_alignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_map_buffer_alignment)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1434 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_map_buffer_alignment, )
  RETVAL = GLEW_ARB_map_buffer_alignment;
  OGLM_CHECK_ERR(GLEW_ARB_map_buffer_alignment, )
#line 8471 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_map_buffer_range); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_map_buffer_range)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1444 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_map_buffer_range, )
  RETVAL = GLEW_ARB_map_buffer_range;
  OGLM_CHECK_ERR(GLEW_ARB_map_buffer_range, )
#line 8493 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_matrix_palette); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_matrix_palette)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1454 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_matrix_palette, )
  RETVAL = GLEW_ARB_matrix_palette;
  OGLM_CHECK_ERR(GLEW_ARB_matrix_palette, )
#line 8515 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_multi_bind); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_multi_bind)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1464 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_multi_bind, )
  RETVAL = GLEW_ARB_multi_bind;
  OGLM_CHECK_ERR(GLEW_ARB_multi_bind, )
#line 8537 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_multi_draw_indirect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_multi_draw_indirect)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1474 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_multi_draw_indirect, )
  RETVAL = GLEW_ARB_multi_draw_indirect;
  OGLM_CHECK_ERR(GLEW_ARB_multi_draw_indirect, )
#line 8559 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1484 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_multisample, )
  RETVAL = GLEW_ARB_multisample;
  OGLM_CHECK_ERR(GLEW_ARB_multisample, )
#line 8581 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_multitexture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_multitexture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1494 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_multitexture, )
  RETVAL = GLEW_ARB_multitexture;
  OGLM_CHECK_ERR(GLEW_ARB_multitexture, )
#line 8603 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_occlusion_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_occlusion_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1504 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_occlusion_query, )
  RETVAL = GLEW_ARB_occlusion_query;
  OGLM_CHECK_ERR(GLEW_ARB_occlusion_query, )
#line 8625 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_occlusion_query2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_occlusion_query2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1514 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_occlusion_query2, )
  RETVAL = GLEW_ARB_occlusion_query2;
  OGLM_CHECK_ERR(GLEW_ARB_occlusion_query2, )
#line 8647 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_parallel_shader_compile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_parallel_shader_compile)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1524 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_parallel_shader_compile, )
  RETVAL = GLEW_ARB_parallel_shader_compile;
  OGLM_CHECK_ERR(GLEW_ARB_parallel_shader_compile, )
#line 8669 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_pipeline_statistics_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_pipeline_statistics_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1534 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_pipeline_statistics_query, )
  RETVAL = GLEW_ARB_pipeline_statistics_query;
  OGLM_CHECK_ERR(GLEW_ARB_pipeline_statistics_query, )
#line 8691 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_pixel_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_pixel_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1544 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_pixel_buffer_object, )
  RETVAL = GLEW_ARB_pixel_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_pixel_buffer_object, )
#line 8713 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_point_parameters); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_point_parameters)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1554 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_point_parameters, )
  RETVAL = GLEW_ARB_point_parameters;
  OGLM_CHECK_ERR(GLEW_ARB_point_parameters, )
#line 8735 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_point_sprite); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_point_sprite)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1564 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_point_sprite, )
  RETVAL = GLEW_ARB_point_sprite;
  OGLM_CHECK_ERR(GLEW_ARB_point_sprite, )
#line 8757 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_polygon_offset_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_polygon_offset_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1574 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_polygon_offset_clamp, )
  RETVAL = GLEW_ARB_polygon_offset_clamp;
  OGLM_CHECK_ERR(GLEW_ARB_polygon_offset_clamp, )
#line 8779 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_post_depth_coverage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_post_depth_coverage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1584 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_post_depth_coverage, )
  RETVAL = GLEW_ARB_post_depth_coverage;
  OGLM_CHECK_ERR(GLEW_ARB_post_depth_coverage, )
#line 8801 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_program_interface_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_program_interface_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1594 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_program_interface_query, )
  RETVAL = GLEW_ARB_program_interface_query;
  OGLM_CHECK_ERR(GLEW_ARB_program_interface_query, )
#line 8823 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_provoking_vertex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_provoking_vertex)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1604 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_provoking_vertex, )
  RETVAL = GLEW_ARB_provoking_vertex;
  OGLM_CHECK_ERR(GLEW_ARB_provoking_vertex, )
#line 8845 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_query_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_query_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1614 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_query_buffer_object, )
  RETVAL = GLEW_ARB_query_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_query_buffer_object, )
#line 8867 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_robust_buffer_access_behavior); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_robust_buffer_access_behavior)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1624 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_robust_buffer_access_behavior, )
  RETVAL = GLEW_ARB_robust_buffer_access_behavior;
  OGLM_CHECK_ERR(GLEW_ARB_robust_buffer_access_behavior, )
#line 8889 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_robustness); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_robustness)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1634 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_robustness, )
  RETVAL = GLEW_ARB_robustness;
  OGLM_CHECK_ERR(GLEW_ARB_robustness, )
#line 8911 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_robustness_application_isolation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_robustness_application_isolation)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1644 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_robustness_application_isolation, )
  RETVAL = GLEW_ARB_robustness_application_isolation;
  OGLM_CHECK_ERR(GLEW_ARB_robustness_application_isolation, )
#line 8933 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_robustness_share_group_isolation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_robustness_share_group_isolation)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1654 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_robustness_share_group_isolation, )
  RETVAL = GLEW_ARB_robustness_share_group_isolation;
  OGLM_CHECK_ERR(GLEW_ARB_robustness_share_group_isolation, )
#line 8955 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sample_locations); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sample_locations)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1664 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sample_locations, )
  RETVAL = GLEW_ARB_sample_locations;
  OGLM_CHECK_ERR(GLEW_ARB_sample_locations, )
#line 8977 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sample_shading); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sample_shading)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1674 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sample_shading, )
  RETVAL = GLEW_ARB_sample_shading;
  OGLM_CHECK_ERR(GLEW_ARB_sample_shading, )
#line 8999 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sampler_objects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sampler_objects)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1684 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sampler_objects, )
  RETVAL = GLEW_ARB_sampler_objects;
  OGLM_CHECK_ERR(GLEW_ARB_sampler_objects, )
#line 9021 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_seamless_cube_map); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_seamless_cube_map)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1694 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_seamless_cube_map, )
  RETVAL = GLEW_ARB_seamless_cube_map;
  OGLM_CHECK_ERR(GLEW_ARB_seamless_cube_map, )
#line 9043 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_seamless_cubemap_per_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_seamless_cubemap_per_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1704 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_seamless_cubemap_per_texture, )
  RETVAL = GLEW_ARB_seamless_cubemap_per_texture;
  OGLM_CHECK_ERR(GLEW_ARB_seamless_cubemap_per_texture, )
#line 9065 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_separate_shader_objects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_separate_shader_objects)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1714 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_separate_shader_objects, )
  RETVAL = GLEW_ARB_separate_shader_objects;
  OGLM_CHECK_ERR(GLEW_ARB_separate_shader_objects, )
#line 9087 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_atomic_counter_ops); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_atomic_counter_ops)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1724 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_atomic_counter_ops, )
  RETVAL = GLEW_ARB_shader_atomic_counter_ops;
  OGLM_CHECK_ERR(GLEW_ARB_shader_atomic_counter_ops, )
#line 9109 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_atomic_counters); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_atomic_counters)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1734 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_atomic_counters, )
  RETVAL = GLEW_ARB_shader_atomic_counters;
  OGLM_CHECK_ERR(GLEW_ARB_shader_atomic_counters, )
#line 9131 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_ballot); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_ballot)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1744 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_ballot, )
  RETVAL = GLEW_ARB_shader_ballot;
  OGLM_CHECK_ERR(GLEW_ARB_shader_ballot, )
#line 9153 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_bit_encoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_bit_encoding)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1754 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_bit_encoding, )
  RETVAL = GLEW_ARB_shader_bit_encoding;
  OGLM_CHECK_ERR(GLEW_ARB_shader_bit_encoding, )
#line 9175 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_clock); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_clock)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1764 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_clock, )
  RETVAL = GLEW_ARB_shader_clock;
  OGLM_CHECK_ERR(GLEW_ARB_shader_clock, )
#line 9197 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_draw_parameters); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_draw_parameters)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1774 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_draw_parameters, )
  RETVAL = GLEW_ARB_shader_draw_parameters;
  OGLM_CHECK_ERR(GLEW_ARB_shader_draw_parameters, )
#line 9219 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_group_vote); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_group_vote)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1784 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_group_vote, )
  RETVAL = GLEW_ARB_shader_group_vote;
  OGLM_CHECK_ERR(GLEW_ARB_shader_group_vote, )
#line 9241 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_image_load_store); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_image_load_store)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1794 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_image_load_store, )
  RETVAL = GLEW_ARB_shader_image_load_store;
  OGLM_CHECK_ERR(GLEW_ARB_shader_image_load_store, )
#line 9263 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_image_size); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_image_size)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1804 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_image_size, )
  RETVAL = GLEW_ARB_shader_image_size;
  OGLM_CHECK_ERR(GLEW_ARB_shader_image_size, )
#line 9285 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_objects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_objects)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1814 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_objects, )
  RETVAL = GLEW_ARB_shader_objects;
  OGLM_CHECK_ERR(GLEW_ARB_shader_objects, )
#line 9307 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_precision); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_precision)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1824 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_precision, )
  RETVAL = GLEW_ARB_shader_precision;
  OGLM_CHECK_ERR(GLEW_ARB_shader_precision, )
#line 9329 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_stencil_export); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_stencil_export)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1834 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_stencil_export, )
  RETVAL = GLEW_ARB_shader_stencil_export;
  OGLM_CHECK_ERR(GLEW_ARB_shader_stencil_export, )
#line 9351 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_storage_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_storage_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1844 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_storage_buffer_object, )
  RETVAL = GLEW_ARB_shader_storage_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_shader_storage_buffer_object, )
#line 9373 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_subroutine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_subroutine)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1854 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_subroutine, )
  RETVAL = GLEW_ARB_shader_subroutine;
  OGLM_CHECK_ERR(GLEW_ARB_shader_subroutine, )
#line 9395 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_texture_image_samples); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_texture_image_samples)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1864 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_texture_image_samples, )
  RETVAL = GLEW_ARB_shader_texture_image_samples;
  OGLM_CHECK_ERR(GLEW_ARB_shader_texture_image_samples, )
#line 9417 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_texture_lod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_texture_lod)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1874 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_texture_lod, )
  RETVAL = GLEW_ARB_shader_texture_lod;
  OGLM_CHECK_ERR(GLEW_ARB_shader_texture_lod, )
#line 9439 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_viewport_layer_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shader_viewport_layer_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1884 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_viewport_layer_array, )
  RETVAL = GLEW_ARB_shader_viewport_layer_array;
  OGLM_CHECK_ERR(GLEW_ARB_shader_viewport_layer_array, )
#line 9461 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shading_language_100); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shading_language_100)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1894 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_100, )
  RETVAL = GLEW_ARB_shading_language_100;
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_100, )
#line 9483 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shading_language_420pack); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shading_language_420pack)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1904 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_420pack, )
  RETVAL = GLEW_ARB_shading_language_420pack;
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_420pack, )
#line 9505 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shading_language_include); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shading_language_include)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1914 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_include, )
  RETVAL = GLEW_ARB_shading_language_include;
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_include, )
#line 9527 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shading_language_packing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shading_language_packing)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1924 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_packing, )
  RETVAL = GLEW_ARB_shading_language_packing;
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_packing, )
#line 9549 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shadow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shadow)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1934 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shadow, )
  RETVAL = GLEW_ARB_shadow;
  OGLM_CHECK_ERR(GLEW_ARB_shadow, )
#line 9571 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shadow_ambient); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_shadow_ambient)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1944 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shadow_ambient, )
  RETVAL = GLEW_ARB_shadow_ambient;
  OGLM_CHECK_ERR(GLEW_ARB_shadow_ambient, )
#line 9593 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sparse_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sparse_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1954 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sparse_buffer, )
  RETVAL = GLEW_ARB_sparse_buffer;
  OGLM_CHECK_ERR(GLEW_ARB_sparse_buffer, )
#line 9615 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sparse_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sparse_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1964 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture, )
  RETVAL = GLEW_ARB_sparse_texture;
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture, )
#line 9637 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sparse_texture2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sparse_texture2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1974 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture2, )
  RETVAL = GLEW_ARB_sparse_texture2;
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture2, )
#line 9659 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sparse_texture_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sparse_texture_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1984 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture_clamp, )
  RETVAL = GLEW_ARB_sparse_texture_clamp;
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture_clamp, )
#line 9681 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_spirv_extensions); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_spirv_extensions)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 1994 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_spirv_extensions, )
  RETVAL = GLEW_ARB_spirv_extensions;
  OGLM_CHECK_ERR(GLEW_ARB_spirv_extensions, )
#line 9703 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_stencil_texturing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_stencil_texturing)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2004 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_stencil_texturing, )
  RETVAL = GLEW_ARB_stencil_texturing;
  OGLM_CHECK_ERR(GLEW_ARB_stencil_texturing, )
#line 9725 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sync); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_sync)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2014 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sync, )
  RETVAL = GLEW_ARB_sync;
  OGLM_CHECK_ERR(GLEW_ARB_sync, )
#line 9747 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_tessellation_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_tessellation_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2024 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_tessellation_shader, )
  RETVAL = GLEW_ARB_tessellation_shader;
  OGLM_CHECK_ERR(GLEW_ARB_tessellation_shader, )
#line 9769 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_barrier); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_barrier)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2034 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_barrier, )
  RETVAL = GLEW_ARB_texture_barrier;
  OGLM_CHECK_ERR(GLEW_ARB_texture_barrier, )
#line 9791 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_border_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_border_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2044 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_border_clamp, )
  RETVAL = GLEW_ARB_texture_border_clamp;
  OGLM_CHECK_ERR(GLEW_ARB_texture_border_clamp, )
#line 9813 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2054 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_object, )
  RETVAL = GLEW_ARB_texture_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_object, )
#line 9835 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_buffer_object_rgb32); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_buffer_object_rgb32)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2064 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_object_rgb32, )
  RETVAL = GLEW_ARB_texture_buffer_object_rgb32;
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_object_rgb32, )
#line 9857 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_buffer_range); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_buffer_range)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2074 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_range, )
  RETVAL = GLEW_ARB_texture_buffer_range;
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_range, )
#line 9879 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_compression); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_compression)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2084 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression, )
  RETVAL = GLEW_ARB_texture_compression;
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression, )
#line 9901 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_compression_bptc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_compression_bptc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2094 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression_bptc, )
  RETVAL = GLEW_ARB_texture_compression_bptc;
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression_bptc, )
#line 9923 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_compression_rgtc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_compression_rgtc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2104 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression_rgtc, )
  RETVAL = GLEW_ARB_texture_compression_rgtc;
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression_rgtc, )
#line 9945 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_cube_map); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_cube_map)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2114 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_cube_map, )
  RETVAL = GLEW_ARB_texture_cube_map;
  OGLM_CHECK_ERR(GLEW_ARB_texture_cube_map, )
#line 9967 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_cube_map_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_cube_map_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2124 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_cube_map_array, )
  RETVAL = GLEW_ARB_texture_cube_map_array;
  OGLM_CHECK_ERR(GLEW_ARB_texture_cube_map_array, )
#line 9989 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_env_add); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_env_add)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2134 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_add, )
  RETVAL = GLEW_ARB_texture_env_add;
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_add, )
#line 10011 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_env_combine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_env_combine)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2144 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_combine, )
  RETVAL = GLEW_ARB_texture_env_combine;
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_combine, )
#line 10033 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_env_crossbar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_env_crossbar)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2154 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_crossbar, )
  RETVAL = GLEW_ARB_texture_env_crossbar;
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_crossbar, )
#line 10055 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_env_dot3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_env_dot3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2164 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_dot3, )
  RETVAL = GLEW_ARB_texture_env_dot3;
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_dot3, )
#line 10077 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_filter_anisotropic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_filter_anisotropic)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2174 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_filter_anisotropic, )
  RETVAL = GLEW_ARB_texture_filter_anisotropic;
  OGLM_CHECK_ERR(GLEW_ARB_texture_filter_anisotropic, )
#line 10099 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_filter_minmax); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_filter_minmax)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2184 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_filter_minmax, )
  RETVAL = GLEW_ARB_texture_filter_minmax;
  OGLM_CHECK_ERR(GLEW_ARB_texture_filter_minmax, )
#line 10121 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2194 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_float, )
  RETVAL = GLEW_ARB_texture_float;
  OGLM_CHECK_ERR(GLEW_ARB_texture_float, )
#line 10143 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_gather); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_gather)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2204 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_gather, )
  RETVAL = GLEW_ARB_texture_gather;
  OGLM_CHECK_ERR(GLEW_ARB_texture_gather, )
#line 10165 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_mirror_clamp_to_edge); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_mirror_clamp_to_edge)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2214 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_mirror_clamp_to_edge, )
  RETVAL = GLEW_ARB_texture_mirror_clamp_to_edge;
  OGLM_CHECK_ERR(GLEW_ARB_texture_mirror_clamp_to_edge, )
#line 10187 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_mirrored_repeat); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_mirrored_repeat)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2224 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_mirrored_repeat, )
  RETVAL = GLEW_ARB_texture_mirrored_repeat;
  OGLM_CHECK_ERR(GLEW_ARB_texture_mirrored_repeat, )
#line 10209 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2234 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_multisample, )
  RETVAL = GLEW_ARB_texture_multisample;
  OGLM_CHECK_ERR(GLEW_ARB_texture_multisample, )
#line 10231 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_non_power_of_two); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_non_power_of_two)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2244 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_non_power_of_two, )
  RETVAL = GLEW_ARB_texture_non_power_of_two;
  OGLM_CHECK_ERR(GLEW_ARB_texture_non_power_of_two, )
#line 10253 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_query_levels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_query_levels)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2254 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_query_levels, )
  RETVAL = GLEW_ARB_texture_query_levels;
  OGLM_CHECK_ERR(GLEW_ARB_texture_query_levels, )
#line 10275 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_query_lod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_query_lod)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2264 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_query_lod, )
  RETVAL = GLEW_ARB_texture_query_lod;
  OGLM_CHECK_ERR(GLEW_ARB_texture_query_lod, )
#line 10297 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_rectangle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_rectangle)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2274 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_rectangle, )
  RETVAL = GLEW_ARB_texture_rectangle;
  OGLM_CHECK_ERR(GLEW_ARB_texture_rectangle, )
#line 10319 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_rg); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_rg)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2284 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_rg, )
  RETVAL = GLEW_ARB_texture_rg;
  OGLM_CHECK_ERR(GLEW_ARB_texture_rg, )
#line 10341 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_rgb10_a2ui); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_rgb10_a2ui)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2294 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_rgb10_a2ui, )
  RETVAL = GLEW_ARB_texture_rgb10_a2ui;
  OGLM_CHECK_ERR(GLEW_ARB_texture_rgb10_a2ui, )
#line 10363 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_stencil8); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_stencil8)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2304 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_stencil8, )
  RETVAL = GLEW_ARB_texture_stencil8;
  OGLM_CHECK_ERR(GLEW_ARB_texture_stencil8, )
#line 10385 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_storage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_storage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2314 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_storage, )
  RETVAL = GLEW_ARB_texture_storage;
  OGLM_CHECK_ERR(GLEW_ARB_texture_storage, )
#line 10407 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_storage_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_storage_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2324 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_storage_multisample, )
  RETVAL = GLEW_ARB_texture_storage_multisample;
  OGLM_CHECK_ERR(GLEW_ARB_texture_storage_multisample, )
#line 10429 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_swizzle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_swizzle)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2334 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_swizzle, )
  RETVAL = GLEW_ARB_texture_swizzle;
  OGLM_CHECK_ERR(GLEW_ARB_texture_swizzle, )
#line 10451 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_view); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_texture_view)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2344 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_view, )
  RETVAL = GLEW_ARB_texture_view;
  OGLM_CHECK_ERR(GLEW_ARB_texture_view, )
#line 10473 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_timer_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_timer_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2354 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_timer_query, )
  RETVAL = GLEW_ARB_timer_query;
  OGLM_CHECK_ERR(GLEW_ARB_timer_query, )
#line 10495 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_transform_feedback2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_transform_feedback2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2364 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback2, )
  RETVAL = GLEW_ARB_transform_feedback2;
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback2, )
#line 10517 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_transform_feedback3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_transform_feedback3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2374 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback3, )
  RETVAL = GLEW_ARB_transform_feedback3;
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback3, )
#line 10539 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_transform_feedback_instanced); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_transform_feedback_instanced)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2384 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback_instanced, )
  RETVAL = GLEW_ARB_transform_feedback_instanced;
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback_instanced, )
#line 10561 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_transform_feedback_overflow_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_transform_feedback_overflow_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2394 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback_overflow_query, )
  RETVAL = GLEW_ARB_transform_feedback_overflow_query;
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback_overflow_query, )
#line 10583 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_transpose_matrix); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_transpose_matrix)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2404 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_transpose_matrix, )
  RETVAL = GLEW_ARB_transpose_matrix;
  OGLM_CHECK_ERR(GLEW_ARB_transpose_matrix, )
#line 10605 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_uniform_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_uniform_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2414 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_uniform_buffer_object, )
  RETVAL = GLEW_ARB_uniform_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_uniform_buffer_object, )
#line 10627 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_array_bgra); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_array_bgra)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2424 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_array_bgra, )
  RETVAL = GLEW_ARB_vertex_array_bgra;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_array_bgra, )
#line 10649 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_array_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_array_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2434 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_array_object, )
  RETVAL = GLEW_ARB_vertex_array_object;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_array_object, )
#line 10671 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_attrib_64bit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_attrib_64bit)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2444 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_attrib_64bit, )
  RETVAL = GLEW_ARB_vertex_attrib_64bit;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_attrib_64bit, )
#line 10693 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_attrib_binding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_attrib_binding)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2454 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_attrib_binding, )
  RETVAL = GLEW_ARB_vertex_attrib_binding;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_attrib_binding, )
#line 10715 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_blend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_blend)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2464 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_blend, )
  RETVAL = GLEW_ARB_vertex_blend;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_blend, )
#line 10737 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2474 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_buffer_object, )
  RETVAL = GLEW_ARB_vertex_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_buffer_object, )
#line 10759 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_program); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_program)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2484 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_program, )
  RETVAL = GLEW_ARB_vertex_program;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_program, )
#line 10781 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2494 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_shader, )
  RETVAL = GLEW_ARB_vertex_shader;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_shader, )
#line 10803 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_type_10f_11f_11f_rev); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_type_10f_11f_11f_rev)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2504 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_type_10f_11f_11f_rev, )
  RETVAL = GLEW_ARB_vertex_type_10f_11f_11f_rev;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_type_10f_11f_11f_rev, )
#line 10825 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_type_2_10_10_10_rev); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_vertex_type_2_10_10_10_rev)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2514 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_type_2_10_10_10_rev, )
  RETVAL = GLEW_ARB_vertex_type_2_10_10_10_rev;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_type_2_10_10_10_rev, )
#line 10847 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_viewport_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_viewport_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2524 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_viewport_array, )
  RETVAL = GLEW_ARB_viewport_array;
  OGLM_CHECK_ERR(GLEW_ARB_viewport_array, )
#line 10869 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_window_pos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARB_window_pos)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2534 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_window_pos, )
  RETVAL = GLEW_ARB_window_pos;
  OGLM_CHECK_ERR(GLEW_ARB_window_pos, )
#line 10891 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_mali_program_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_mali_program_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2544 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_mali_program_binary, )
  RETVAL = GLEW_ARM_mali_program_binary;
  OGLM_CHECK_ERR(GLEW_ARM_mali_program_binary, )
#line 10913 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_mali_shader_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_mali_shader_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2554 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_mali_shader_binary, )
  RETVAL = GLEW_ARM_mali_shader_binary;
  OGLM_CHECK_ERR(GLEW_ARM_mali_shader_binary, )
#line 10935 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_rgba8); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_rgba8)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2564 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_rgba8, )
  RETVAL = GLEW_ARM_rgba8;
  OGLM_CHECK_ERR(GLEW_ARM_rgba8, )
#line 10957 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_shader_core_properties); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_shader_core_properties)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2574 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_shader_core_properties, )
  RETVAL = GLEW_ARM_shader_core_properties;
  OGLM_CHECK_ERR(GLEW_ARM_shader_core_properties, )
#line 10979 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_shader_framebuffer_fetch); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_shader_framebuffer_fetch)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2584 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_shader_framebuffer_fetch, )
  RETVAL = GLEW_ARM_shader_framebuffer_fetch;
  OGLM_CHECK_ERR(GLEW_ARM_shader_framebuffer_fetch, )
#line 11001 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_shader_framebuffer_fetch_depth_stencil); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_shader_framebuffer_fetch_depth_stencil)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2594 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_shader_framebuffer_fetch_depth_stencil, )
  RETVAL = GLEW_ARM_shader_framebuffer_fetch_depth_stencil;
  OGLM_CHECK_ERR(GLEW_ARM_shader_framebuffer_fetch_depth_stencil, )
#line 11023 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_texture_unnormalized_coordinates); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ARM_texture_unnormalized_coordinates)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2604 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_texture_unnormalized_coordinates, )
  RETVAL = GLEW_ARM_texture_unnormalized_coordinates;
  OGLM_CHECK_ERR(GLEW_ARM_texture_unnormalized_coordinates, )
#line 11045 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATIX_point_sprites); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATIX_point_sprites)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2614 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATIX_point_sprites, )
  RETVAL = GLEW_ATIX_point_sprites;
  OGLM_CHECK_ERR(GLEW_ATIX_point_sprites, )
#line 11067 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATIX_texture_env_combine3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATIX_texture_env_combine3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2624 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATIX_texture_env_combine3, )
  RETVAL = GLEW_ATIX_texture_env_combine3;
  OGLM_CHECK_ERR(GLEW_ATIX_texture_env_combine3, )
#line 11089 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATIX_texture_env_route); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATIX_texture_env_route)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2634 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATIX_texture_env_route, )
  RETVAL = GLEW_ATIX_texture_env_route;
  OGLM_CHECK_ERR(GLEW_ATIX_texture_env_route, )
#line 11111 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATIX_vertex_shader_output_point_size); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATIX_vertex_shader_output_point_size)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2644 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATIX_vertex_shader_output_point_size, )
  RETVAL = GLEW_ATIX_vertex_shader_output_point_size;
  OGLM_CHECK_ERR(GLEW_ATIX_vertex_shader_output_point_size, )
#line 11133 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_draw_buffers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_draw_buffers)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2654 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_draw_buffers, )
  RETVAL = GLEW_ATI_draw_buffers;
  OGLM_CHECK_ERR(GLEW_ATI_draw_buffers, )
#line 11155 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_element_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_element_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2664 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_element_array, )
  RETVAL = GLEW_ATI_element_array;
  OGLM_CHECK_ERR(GLEW_ATI_element_array, )
#line 11177 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_envmap_bumpmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_envmap_bumpmap)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2674 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_envmap_bumpmap, )
  RETVAL = GLEW_ATI_envmap_bumpmap;
  OGLM_CHECK_ERR(GLEW_ATI_envmap_bumpmap, )
#line 11199 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_fragment_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_fragment_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2684 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_fragment_shader, )
  RETVAL = GLEW_ATI_fragment_shader;
  OGLM_CHECK_ERR(GLEW_ATI_fragment_shader, )
#line 11221 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_map_object_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_map_object_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2694 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_map_object_buffer, )
  RETVAL = GLEW_ATI_map_object_buffer;
  OGLM_CHECK_ERR(GLEW_ATI_map_object_buffer, )
#line 11243 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_meminfo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_meminfo)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2704 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_meminfo, )
  RETVAL = GLEW_ATI_meminfo;
  OGLM_CHECK_ERR(GLEW_ATI_meminfo, )
#line 11265 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_pn_triangles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_pn_triangles)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2714 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_pn_triangles, )
  RETVAL = GLEW_ATI_pn_triangles;
  OGLM_CHECK_ERR(GLEW_ATI_pn_triangles, )
#line 11287 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_separate_stencil); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_separate_stencil)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2724 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_separate_stencil, )
  RETVAL = GLEW_ATI_separate_stencil;
  OGLM_CHECK_ERR(GLEW_ATI_separate_stencil, )
#line 11309 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_shader_texture_lod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_shader_texture_lod)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2734 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_shader_texture_lod, )
  RETVAL = GLEW_ATI_shader_texture_lod;
  OGLM_CHECK_ERR(GLEW_ATI_shader_texture_lod, )
#line 11331 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_text_fragment_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_text_fragment_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2744 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_text_fragment_shader, )
  RETVAL = GLEW_ATI_text_fragment_shader;
  OGLM_CHECK_ERR(GLEW_ATI_text_fragment_shader, )
#line 11353 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_texture_compression_3dc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_texture_compression_3dc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2754 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_texture_compression_3dc, )
  RETVAL = GLEW_ATI_texture_compression_3dc;
  OGLM_CHECK_ERR(GLEW_ATI_texture_compression_3dc, )
#line 11375 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_texture_env_combine3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_texture_env_combine3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2764 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_texture_env_combine3, )
  RETVAL = GLEW_ATI_texture_env_combine3;
  OGLM_CHECK_ERR(GLEW_ATI_texture_env_combine3, )
#line 11397 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_texture_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_texture_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2774 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_texture_float, )
  RETVAL = GLEW_ATI_texture_float;
  OGLM_CHECK_ERR(GLEW_ATI_texture_float, )
#line 11419 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_texture_mirror_once); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_texture_mirror_once)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2784 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_texture_mirror_once, )
  RETVAL = GLEW_ATI_texture_mirror_once;
  OGLM_CHECK_ERR(GLEW_ATI_texture_mirror_once, )
#line 11441 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_vertex_array_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_vertex_array_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2794 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_vertex_array_object, )
  RETVAL = GLEW_ATI_vertex_array_object;
  OGLM_CHECK_ERR(GLEW_ATI_vertex_array_object, )
#line 11463 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_vertex_attrib_array_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_vertex_attrib_array_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2804 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_vertex_attrib_array_object, )
  RETVAL = GLEW_ATI_vertex_attrib_array_object;
  OGLM_CHECK_ERR(GLEW_ATI_vertex_attrib_array_object, )
#line 11485 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_vertex_streams); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_ATI_vertex_streams)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2814 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_vertex_streams, )
  RETVAL = GLEW_ATI_vertex_streams;
  OGLM_CHECK_ERR(GLEW_ATI_vertex_streams, )
#line 11507 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_DMP_program_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_DMP_program_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2824 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_DMP_program_binary, )
  RETVAL = GLEW_DMP_program_binary;
  OGLM_CHECK_ERR(GLEW_DMP_program_binary, )
#line 11529 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_DMP_shader_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_DMP_shader_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2834 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_DMP_shader_binary, )
  RETVAL = GLEW_DMP_shader_binary;
  OGLM_CHECK_ERR(GLEW_DMP_shader_binary, )
#line 11551 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_422_pixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_422_pixels)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2844 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_422_pixels, )
  RETVAL = GLEW_EXT_422_pixels;
  OGLM_CHECK_ERR(GLEW_EXT_422_pixels, )
#line 11573 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_Cg_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_Cg_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2854 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_Cg_shader, )
  RETVAL = GLEW_EXT_Cg_shader;
  OGLM_CHECK_ERR(GLEW_EXT_Cg_shader, )
#line 11595 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_EGL_image_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_EGL_image_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2864 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_array, )
  RETVAL = GLEW_EXT_EGL_image_array;
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_array, )
#line 11617 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_EGL_image_external_wrap_modes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_EGL_image_external_wrap_modes)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2874 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_external_wrap_modes, )
  RETVAL = GLEW_EXT_EGL_image_external_wrap_modes;
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_external_wrap_modes, )
#line 11639 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_EGL_image_storage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_EGL_image_storage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2884 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_storage, )
  RETVAL = GLEW_EXT_EGL_image_storage;
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_storage, )
#line 11661 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_EGL_image_storage_compression); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_EGL_image_storage_compression)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2894 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_storage_compression, )
  RETVAL = GLEW_EXT_EGL_image_storage_compression;
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_storage_compression, )
#line 11683 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_EGL_sync); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_EGL_sync)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2904 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_EGL_sync, )
  RETVAL = GLEW_EXT_EGL_sync;
  OGLM_CHECK_ERR(GLEW_EXT_EGL_sync, )
#line 11705 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_YUV_target); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_YUV_target)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2914 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_YUV_target, )
  RETVAL = GLEW_EXT_YUV_target;
  OGLM_CHECK_ERR(GLEW_EXT_YUV_target, )
#line 11727 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_abgr); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_abgr)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2924 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_abgr, )
  RETVAL = GLEW_EXT_abgr;
  OGLM_CHECK_ERR(GLEW_EXT_abgr, )
#line 11749 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_base_instance); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_base_instance)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2934 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_base_instance, )
  RETVAL = GLEW_EXT_base_instance;
  OGLM_CHECK_ERR(GLEW_EXT_base_instance, )
#line 11771 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_bgra); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_bgra)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2944 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_bgra, )
  RETVAL = GLEW_EXT_bgra;
  OGLM_CHECK_ERR(GLEW_EXT_bgra, )
#line 11793 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_bindable_uniform); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_bindable_uniform)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2954 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_bindable_uniform, )
  RETVAL = GLEW_EXT_bindable_uniform;
  OGLM_CHECK_ERR(GLEW_EXT_bindable_uniform, )
#line 11815 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_color); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_color)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2964 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_color, )
  RETVAL = GLEW_EXT_blend_color;
  OGLM_CHECK_ERR(GLEW_EXT_blend_color, )
#line 11837 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_equation_separate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_equation_separate)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2974 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_equation_separate, )
  RETVAL = GLEW_EXT_blend_equation_separate;
  OGLM_CHECK_ERR(GLEW_EXT_blend_equation_separate, )
#line 11859 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_func_extended); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_func_extended)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2984 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_func_extended, )
  RETVAL = GLEW_EXT_blend_func_extended;
  OGLM_CHECK_ERR(GLEW_EXT_blend_func_extended, )
#line 11881 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_func_separate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_func_separate)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 2994 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_func_separate, )
  RETVAL = GLEW_EXT_blend_func_separate;
  OGLM_CHECK_ERR(GLEW_EXT_blend_func_separate, )
#line 11903 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_logic_op); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_logic_op)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3004 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_logic_op, )
  RETVAL = GLEW_EXT_blend_logic_op;
  OGLM_CHECK_ERR(GLEW_EXT_blend_logic_op, )
#line 11925 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_minmax); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_minmax)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3014 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_minmax, )
  RETVAL = GLEW_EXT_blend_minmax;
  OGLM_CHECK_ERR(GLEW_EXT_blend_minmax, )
#line 11947 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_subtract); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_blend_subtract)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3024 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_subtract, )
  RETVAL = GLEW_EXT_blend_subtract;
  OGLM_CHECK_ERR(GLEW_EXT_blend_subtract, )
#line 11969 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_buffer_storage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_buffer_storage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3034 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_buffer_storage, )
  RETVAL = GLEW_EXT_buffer_storage;
  OGLM_CHECK_ERR(GLEW_EXT_buffer_storage, )
#line 11991 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_clear_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_clear_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3044 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_clear_texture, )
  RETVAL = GLEW_EXT_clear_texture;
  OGLM_CHECK_ERR(GLEW_EXT_clear_texture, )
#line 12013 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_clip_control); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_clip_control)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3054 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_clip_control, )
  RETVAL = GLEW_EXT_clip_control;
  OGLM_CHECK_ERR(GLEW_EXT_clip_control, )
#line 12035 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_clip_cull_distance); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_clip_cull_distance)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3064 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_clip_cull_distance, )
  RETVAL = GLEW_EXT_clip_cull_distance;
  OGLM_CHECK_ERR(GLEW_EXT_clip_cull_distance, )
#line 12057 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_clip_volume_hint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_clip_volume_hint)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3074 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_clip_volume_hint, )
  RETVAL = GLEW_EXT_clip_volume_hint;
  OGLM_CHECK_ERR(GLEW_EXT_clip_volume_hint, )
#line 12079 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_cmyka); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_cmyka)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3084 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_cmyka, )
  RETVAL = GLEW_EXT_cmyka;
  OGLM_CHECK_ERR(GLEW_EXT_cmyka, )
#line 12101 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_color_buffer_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_color_buffer_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3094 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_color_buffer_float, )
  RETVAL = GLEW_EXT_color_buffer_float;
  OGLM_CHECK_ERR(GLEW_EXT_color_buffer_float, )
#line 12123 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_color_buffer_half_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_color_buffer_half_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3104 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_color_buffer_half_float, )
  RETVAL = GLEW_EXT_color_buffer_half_float;
  OGLM_CHECK_ERR(GLEW_EXT_color_buffer_half_float, )
#line 12145 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_color_subtable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_color_subtable)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3114 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_color_subtable, )
  RETVAL = GLEW_EXT_color_subtable;
  OGLM_CHECK_ERR(GLEW_EXT_color_subtable, )
#line 12167 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_compiled_vertex_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_compiled_vertex_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3124 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_compiled_vertex_array, )
  RETVAL = GLEW_EXT_compiled_vertex_array;
  OGLM_CHECK_ERR(GLEW_EXT_compiled_vertex_array, )
#line 12189 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_compressed_ETC1_RGB8_sub_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_compressed_ETC1_RGB8_sub_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3134 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_compressed_ETC1_RGB8_sub_texture, )
  RETVAL = GLEW_EXT_compressed_ETC1_RGB8_sub_texture;
  OGLM_CHECK_ERR(GLEW_EXT_compressed_ETC1_RGB8_sub_texture, )
#line 12211 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_conservative_depth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_conservative_depth)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3144 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_conservative_depth, )
  RETVAL = GLEW_EXT_conservative_depth;
  OGLM_CHECK_ERR(GLEW_EXT_conservative_depth, )
#line 12233 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_convolution); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_convolution)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3154 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_convolution, )
  RETVAL = GLEW_EXT_convolution;
  OGLM_CHECK_ERR(GLEW_EXT_convolution, )
#line 12255 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_coordinate_frame); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_coordinate_frame)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3164 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_coordinate_frame, )
  RETVAL = GLEW_EXT_coordinate_frame;
  OGLM_CHECK_ERR(GLEW_EXT_coordinate_frame, )
#line 12277 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_copy_image); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_copy_image)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3174 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_copy_image, )
  RETVAL = GLEW_EXT_copy_image;
  OGLM_CHECK_ERR(GLEW_EXT_copy_image, )
#line 12299 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_copy_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_copy_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3184 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_copy_texture, )
  RETVAL = GLEW_EXT_copy_texture;
  OGLM_CHECK_ERR(GLEW_EXT_copy_texture, )
#line 12321 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_cull_vertex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_cull_vertex)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3194 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_cull_vertex, )
  RETVAL = GLEW_EXT_cull_vertex;
  OGLM_CHECK_ERR(GLEW_EXT_cull_vertex, )
#line 12343 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_debug_label); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_debug_label)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3204 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_debug_label, )
  RETVAL = GLEW_EXT_debug_label;
  OGLM_CHECK_ERR(GLEW_EXT_debug_label, )
#line 12365 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_debug_marker); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_debug_marker)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3214 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_debug_marker, )
  RETVAL = GLEW_EXT_debug_marker;
  OGLM_CHECK_ERR(GLEW_EXT_debug_marker, )
#line 12387 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_depth_bounds_test); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_depth_bounds_test)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3224 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_depth_bounds_test, )
  RETVAL = GLEW_EXT_depth_bounds_test;
  OGLM_CHECK_ERR(GLEW_EXT_depth_bounds_test, )
#line 12409 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_depth_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_depth_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3234 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_depth_clamp, )
  RETVAL = GLEW_EXT_depth_clamp;
  OGLM_CHECK_ERR(GLEW_EXT_depth_clamp, )
#line 12431 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_direct_state_access); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_direct_state_access)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3244 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_direct_state_access, )
  RETVAL = GLEW_EXT_direct_state_access;
  OGLM_CHECK_ERR(GLEW_EXT_direct_state_access, )
#line 12453 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_discard_framebuffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_discard_framebuffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3254 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_discard_framebuffer, )
  RETVAL = GLEW_EXT_discard_framebuffer;
  OGLM_CHECK_ERR(GLEW_EXT_discard_framebuffer, )
#line 12475 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_disjoint_timer_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_disjoint_timer_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3264 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_disjoint_timer_query, )
  RETVAL = GLEW_EXT_disjoint_timer_query;
  OGLM_CHECK_ERR(GLEW_EXT_disjoint_timer_query, )
#line 12497 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_buffers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_buffers)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3274 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers, )
  RETVAL = GLEW_EXT_draw_buffers;
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers, )
#line 12519 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_buffers2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_buffers2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3284 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers2, )
  RETVAL = GLEW_EXT_draw_buffers2;
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers2, )
#line 12541 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_buffers_indexed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_buffers_indexed)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3294 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers_indexed, )
  RETVAL = GLEW_EXT_draw_buffers_indexed;
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers_indexed, )
#line 12563 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_elements_base_vertex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_elements_base_vertex)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3304 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_elements_base_vertex, )
  RETVAL = GLEW_EXT_draw_elements_base_vertex;
  OGLM_CHECK_ERR(GLEW_EXT_draw_elements_base_vertex, )
#line 12585 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_instanced); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_instanced)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3314 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_instanced, )
  RETVAL = GLEW_EXT_draw_instanced;
  OGLM_CHECK_ERR(GLEW_EXT_draw_instanced, )
#line 12607 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_range_elements); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_range_elements)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3324 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_range_elements, )
  RETVAL = GLEW_EXT_draw_range_elements;
  OGLM_CHECK_ERR(GLEW_EXT_draw_range_elements, )
#line 12629 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_transform_feedback); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_draw_transform_feedback)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3334 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_transform_feedback, )
  RETVAL = GLEW_EXT_draw_transform_feedback;
  OGLM_CHECK_ERR(GLEW_EXT_draw_transform_feedback, )
#line 12651 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_external_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_external_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3344 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_external_buffer, )
  RETVAL = GLEW_EXT_external_buffer;
  OGLM_CHECK_ERR(GLEW_EXT_external_buffer, )
#line 12673 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_float_blend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_float_blend)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3354 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_float_blend, )
  RETVAL = GLEW_EXT_float_blend;
  OGLM_CHECK_ERR(GLEW_EXT_float_blend, )
#line 12695 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_fog_coord); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_fog_coord)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3364 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_fog_coord, )
  RETVAL = GLEW_EXT_fog_coord;
  OGLM_CHECK_ERR(GLEW_EXT_fog_coord, )
#line 12717 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_frag_depth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_frag_depth)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3374 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_frag_depth, )
  RETVAL = GLEW_EXT_frag_depth;
  OGLM_CHECK_ERR(GLEW_EXT_frag_depth, )
#line 12739 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_fragment_lighting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_fragment_lighting)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3384 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_fragment_lighting, )
  RETVAL = GLEW_EXT_fragment_lighting;
  OGLM_CHECK_ERR(GLEW_EXT_fragment_lighting, )
#line 12761 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_fragment_shading_rate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_fragment_shading_rate)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3394 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate, )
  RETVAL = GLEW_EXT_fragment_shading_rate;
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate, )
#line 12783 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_fragment_shading_rate_attachment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_fragment_shading_rate_attachment)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3404 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate_attachment, )
  RETVAL = GLEW_EXT_fragment_shading_rate_attachment;
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate_attachment, )
#line 12805 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_fragment_shading_rate_primitive); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_fragment_shading_rate_primitive)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3414 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate_primitive, )
  RETVAL = GLEW_EXT_fragment_shading_rate_primitive;
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate_primitive, )
#line 12827 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_blit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_blit)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3424 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_blit, )
  RETVAL = GLEW_EXT_framebuffer_blit;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_blit, )
#line 12849 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_blit_layers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_blit_layers)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3434 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_blit_layers, )
  RETVAL = GLEW_EXT_framebuffer_blit_layers;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_blit_layers, )
#line 12871 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3444 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_multisample, )
  RETVAL = GLEW_EXT_framebuffer_multisample;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_multisample, )
#line 12893 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_multisample_blit_scaled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_multisample_blit_scaled)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3454 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_multisample_blit_scaled, )
  RETVAL = GLEW_EXT_framebuffer_multisample_blit_scaled;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_multisample_blit_scaled, )
#line 12915 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3464 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_object, )
  RETVAL = GLEW_EXT_framebuffer_object;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_object, )
#line 12937 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_sRGB); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_framebuffer_sRGB)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3474 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_sRGB, )
  RETVAL = GLEW_EXT_framebuffer_sRGB;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_sRGB, )
#line 12959 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_geometry_point_size); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_geometry_point_size)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3484 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_geometry_point_size, )
  RETVAL = GLEW_EXT_geometry_point_size;
  OGLM_CHECK_ERR(GLEW_EXT_geometry_point_size, )
#line 12981 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_geometry_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_geometry_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3494 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_geometry_shader, )
  RETVAL = GLEW_EXT_geometry_shader;
  OGLM_CHECK_ERR(GLEW_EXT_geometry_shader, )
#line 13003 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_geometry_shader4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_geometry_shader4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3504 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_geometry_shader4, )
  RETVAL = GLEW_EXT_geometry_shader4;
  OGLM_CHECK_ERR(GLEW_EXT_geometry_shader4, )
#line 13025 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_gpu_program_parameters); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_gpu_program_parameters)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3514 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_gpu_program_parameters, )
  RETVAL = GLEW_EXT_gpu_program_parameters;
  OGLM_CHECK_ERR(GLEW_EXT_gpu_program_parameters, )
#line 13047 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_gpu_shader4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_gpu_shader4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3524 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_gpu_shader4, )
  RETVAL = GLEW_EXT_gpu_shader4;
  OGLM_CHECK_ERR(GLEW_EXT_gpu_shader4, )
#line 13069 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_gpu_shader5); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_gpu_shader5)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3534 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_gpu_shader5, )
  RETVAL = GLEW_EXT_gpu_shader5;
  OGLM_CHECK_ERR(GLEW_EXT_gpu_shader5, )
#line 13091 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_histogram); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_histogram)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3544 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_histogram, )
  RETVAL = GLEW_EXT_histogram;
  OGLM_CHECK_ERR(GLEW_EXT_histogram, )
#line 13113 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_index_array_formats); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_index_array_formats)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3554 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_index_array_formats, )
  RETVAL = GLEW_EXT_index_array_formats;
  OGLM_CHECK_ERR(GLEW_EXT_index_array_formats, )
#line 13135 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_index_func); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_index_func)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3564 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_index_func, )
  RETVAL = GLEW_EXT_index_func;
  OGLM_CHECK_ERR(GLEW_EXT_index_func, )
#line 13157 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_index_material); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_index_material)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3574 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_index_material, )
  RETVAL = GLEW_EXT_index_material;
  OGLM_CHECK_ERR(GLEW_EXT_index_material, )
#line 13179 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_index_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_index_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3584 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_index_texture, )
  RETVAL = GLEW_EXT_index_texture;
  OGLM_CHECK_ERR(GLEW_EXT_index_texture, )
#line 13201 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_instanced_arrays); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_instanced_arrays)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3594 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_instanced_arrays, )
  RETVAL = GLEW_EXT_instanced_arrays;
  OGLM_CHECK_ERR(GLEW_EXT_instanced_arrays, )
#line 13223 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_light_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_light_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3604 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_light_texture, )
  RETVAL = GLEW_EXT_light_texture;
  OGLM_CHECK_ERR(GLEW_EXT_light_texture, )
#line 13245 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_map_buffer_range); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_map_buffer_range)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3614 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_map_buffer_range, )
  RETVAL = GLEW_EXT_map_buffer_range;
  OGLM_CHECK_ERR(GLEW_EXT_map_buffer_range, )
#line 13267 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_memory_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_memory_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3624 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_memory_object, )
  RETVAL = GLEW_EXT_memory_object;
  OGLM_CHECK_ERR(GLEW_EXT_memory_object, )
#line 13289 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_memory_object_fd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_memory_object_fd)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3634 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_memory_object_fd, )
  RETVAL = GLEW_EXT_memory_object_fd;
  OGLM_CHECK_ERR(GLEW_EXT_memory_object_fd, )
#line 13311 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_memory_object_win32); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_memory_object_win32)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3644 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_memory_object_win32, )
  RETVAL = GLEW_EXT_memory_object_win32;
  OGLM_CHECK_ERR(GLEW_EXT_memory_object_win32, )
#line 13333 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_mesh_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_mesh_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3654 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_mesh_shader, )
  RETVAL = GLEW_EXT_mesh_shader;
  OGLM_CHECK_ERR(GLEW_EXT_mesh_shader, )
#line 13355 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_misc_attribute); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_misc_attribute)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3664 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_misc_attribute, )
  RETVAL = GLEW_EXT_misc_attribute;
  OGLM_CHECK_ERR(GLEW_EXT_misc_attribute, )
#line 13377 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multi_draw_arrays); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multi_draw_arrays)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3674 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multi_draw_arrays, )
  RETVAL = GLEW_EXT_multi_draw_arrays;
  OGLM_CHECK_ERR(GLEW_EXT_multi_draw_arrays, )
#line 13399 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multi_draw_indirect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multi_draw_indirect)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3684 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multi_draw_indirect, )
  RETVAL = GLEW_EXT_multi_draw_indirect;
  OGLM_CHECK_ERR(GLEW_EXT_multi_draw_indirect, )
#line 13421 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multiple_textures); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multiple_textures)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3694 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multiple_textures, )
  RETVAL = GLEW_EXT_multiple_textures;
  OGLM_CHECK_ERR(GLEW_EXT_multiple_textures, )
#line 13443 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3704 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multisample, )
  RETVAL = GLEW_EXT_multisample;
  OGLM_CHECK_ERR(GLEW_EXT_multisample, )
#line 13465 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multisample_compatibility); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multisample_compatibility)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3714 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multisample_compatibility, )
  RETVAL = GLEW_EXT_multisample_compatibility;
  OGLM_CHECK_ERR(GLEW_EXT_multisample_compatibility, )
#line 13487 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multisampled_render_to_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multisampled_render_to_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3724 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multisampled_render_to_texture, )
  RETVAL = GLEW_EXT_multisampled_render_to_texture;
  OGLM_CHECK_ERR(GLEW_EXT_multisampled_render_to_texture, )
#line 13509 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multisampled_render_to_texture2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multisampled_render_to_texture2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3734 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multisampled_render_to_texture2, )
  RETVAL = GLEW_EXT_multisampled_render_to_texture2;
  OGLM_CHECK_ERR(GLEW_EXT_multisampled_render_to_texture2, )
#line 13531 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multiview_draw_buffers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multiview_draw_buffers)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3744 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multiview_draw_buffers, )
  RETVAL = GLEW_EXT_multiview_draw_buffers;
  OGLM_CHECK_ERR(GLEW_EXT_multiview_draw_buffers, )
#line 13553 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multiview_tessellation_geometry_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multiview_tessellation_geometry_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3754 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multiview_tessellation_geometry_shader, )
  RETVAL = GLEW_EXT_multiview_tessellation_geometry_shader;
  OGLM_CHECK_ERR(GLEW_EXT_multiview_tessellation_geometry_shader, )
#line 13575 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multiview_texture_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multiview_texture_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3764 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multiview_texture_multisample, )
  RETVAL = GLEW_EXT_multiview_texture_multisample;
  OGLM_CHECK_ERR(GLEW_EXT_multiview_texture_multisample, )
#line 13597 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multiview_timer_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_multiview_timer_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3774 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multiview_timer_query, )
  RETVAL = GLEW_EXT_multiview_timer_query;
  OGLM_CHECK_ERR(GLEW_EXT_multiview_timer_query, )
#line 13619 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_occlusion_query_boolean); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_occlusion_query_boolean)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3784 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_occlusion_query_boolean, )
  RETVAL = GLEW_EXT_occlusion_query_boolean;
  OGLM_CHECK_ERR(GLEW_EXT_occlusion_query_boolean, )
#line 13641 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_packed_depth_stencil); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_packed_depth_stencil)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3794 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_packed_depth_stencil, )
  RETVAL = GLEW_EXT_packed_depth_stencil;
  OGLM_CHECK_ERR(GLEW_EXT_packed_depth_stencil, )
#line 13663 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_packed_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_packed_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3804 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_packed_float, )
  RETVAL = GLEW_EXT_packed_float;
  OGLM_CHECK_ERR(GLEW_EXT_packed_float, )
#line 13685 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_packed_pixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_packed_pixels)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3814 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_packed_pixels, )
  RETVAL = GLEW_EXT_packed_pixels;
  OGLM_CHECK_ERR(GLEW_EXT_packed_pixels, )
#line 13707 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_paletted_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_paletted_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3824 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_paletted_texture, )
  RETVAL = GLEW_EXT_paletted_texture;
  OGLM_CHECK_ERR(GLEW_EXT_paletted_texture, )
#line 13729 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_pixel_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_pixel_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3834 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_pixel_buffer_object, )
  RETVAL = GLEW_EXT_pixel_buffer_object;
  OGLM_CHECK_ERR(GLEW_EXT_pixel_buffer_object, )
#line 13751 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_pixel_transform); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_pixel_transform)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3844 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_pixel_transform, )
  RETVAL = GLEW_EXT_pixel_transform;
  OGLM_CHECK_ERR(GLEW_EXT_pixel_transform, )
#line 13773 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_pixel_transform_color_table); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_pixel_transform_color_table)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3854 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_pixel_transform_color_table, )
  RETVAL = GLEW_EXT_pixel_transform_color_table;
  OGLM_CHECK_ERR(GLEW_EXT_pixel_transform_color_table, )
#line 13795 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_point_parameters); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_point_parameters)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3864 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_point_parameters, )
  RETVAL = GLEW_EXT_point_parameters;
  OGLM_CHECK_ERR(GLEW_EXT_point_parameters, )
#line 13817 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_polygon_offset); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_polygon_offset)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3874 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_polygon_offset, )
  RETVAL = GLEW_EXT_polygon_offset;
  OGLM_CHECK_ERR(GLEW_EXT_polygon_offset, )
#line 13839 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_polygon_offset_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_polygon_offset_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3884 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_polygon_offset_clamp, )
  RETVAL = GLEW_EXT_polygon_offset_clamp;
  OGLM_CHECK_ERR(GLEW_EXT_polygon_offset_clamp, )
#line 13861 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_post_depth_coverage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_post_depth_coverage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3894 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_post_depth_coverage, )
  RETVAL = GLEW_EXT_post_depth_coverage;
  OGLM_CHECK_ERR(GLEW_EXT_post_depth_coverage, )
#line 13883 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_primitive_bounding_box); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_primitive_bounding_box)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3904 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_primitive_bounding_box, )
  RETVAL = GLEW_EXT_primitive_bounding_box;
  OGLM_CHECK_ERR(GLEW_EXT_primitive_bounding_box, )
#line 13905 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_protected_textures); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_protected_textures)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3914 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_protected_textures, )
  RETVAL = GLEW_EXT_protected_textures;
  OGLM_CHECK_ERR(GLEW_EXT_protected_textures, )
#line 13927 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_provoking_vertex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_provoking_vertex)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3924 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_provoking_vertex, )
  RETVAL = GLEW_EXT_provoking_vertex;
  OGLM_CHECK_ERR(GLEW_EXT_provoking_vertex, )
#line 13949 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_pvrtc_sRGB); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_pvrtc_sRGB)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3934 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_pvrtc_sRGB, )
  RETVAL = GLEW_EXT_pvrtc_sRGB;
  OGLM_CHECK_ERR(GLEW_EXT_pvrtc_sRGB, )
#line 13971 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_raster_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_raster_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3944 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_raster_multisample, )
  RETVAL = GLEW_EXT_raster_multisample;
  OGLM_CHECK_ERR(GLEW_EXT_raster_multisample, )
#line 13993 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_read_format_bgra); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_read_format_bgra)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3954 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_read_format_bgra, )
  RETVAL = GLEW_EXT_read_format_bgra;
  OGLM_CHECK_ERR(GLEW_EXT_read_format_bgra, )
#line 14015 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_render_snorm); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_render_snorm)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3964 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_render_snorm, )
  RETVAL = GLEW_EXT_render_snorm;
  OGLM_CHECK_ERR(GLEW_EXT_render_snorm, )
#line 14037 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_rescale_normal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_rescale_normal)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3974 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_rescale_normal, )
  RETVAL = GLEW_EXT_rescale_normal;
  OGLM_CHECK_ERR(GLEW_EXT_rescale_normal, )
#line 14059 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_robustness); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_robustness)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3984 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_robustness, )
  RETVAL = GLEW_EXT_robustness;
  OGLM_CHECK_ERR(GLEW_EXT_robustness, )
#line 14081 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_sRGB); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_sRGB)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 3994 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_sRGB, )
  RETVAL = GLEW_EXT_sRGB;
  OGLM_CHECK_ERR(GLEW_EXT_sRGB, )
#line 14103 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_sRGB_write_control); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_sRGB_write_control)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4004 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_sRGB_write_control, )
  RETVAL = GLEW_EXT_sRGB_write_control;
  OGLM_CHECK_ERR(GLEW_EXT_sRGB_write_control, )
#line 14125 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_scene_marker); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_scene_marker)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4014 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_scene_marker, )
  RETVAL = GLEW_EXT_scene_marker;
  OGLM_CHECK_ERR(GLEW_EXT_scene_marker, )
#line 14147 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_secondary_color); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_secondary_color)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4024 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_secondary_color, )
  RETVAL = GLEW_EXT_secondary_color;
  OGLM_CHECK_ERR(GLEW_EXT_secondary_color, )
#line 14169 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_semaphore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_semaphore)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4034 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_semaphore, )
  RETVAL = GLEW_EXT_semaphore;
  OGLM_CHECK_ERR(GLEW_EXT_semaphore, )
#line 14191 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_semaphore_fd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_semaphore_fd)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4044 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_semaphore_fd, )
  RETVAL = GLEW_EXT_semaphore_fd;
  OGLM_CHECK_ERR(GLEW_EXT_semaphore_fd, )
#line 14213 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_semaphore_win32); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_semaphore_win32)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4054 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_semaphore_win32, )
  RETVAL = GLEW_EXT_semaphore_win32;
  OGLM_CHECK_ERR(GLEW_EXT_semaphore_win32, )
#line 14235 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_separate_depth_stencil); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_separate_depth_stencil)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4064 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_separate_depth_stencil, )
  RETVAL = GLEW_EXT_separate_depth_stencil;
  OGLM_CHECK_ERR(GLEW_EXT_separate_depth_stencil, )
#line 14257 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_separate_shader_objects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_separate_shader_objects)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4074 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_separate_shader_objects, )
  RETVAL = GLEW_EXT_separate_shader_objects;
  OGLM_CHECK_ERR(GLEW_EXT_separate_shader_objects, )
#line 14279 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_separate_specular_color); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_separate_specular_color)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4084 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_separate_specular_color, )
  RETVAL = GLEW_EXT_separate_specular_color;
  OGLM_CHECK_ERR(GLEW_EXT_separate_specular_color, )
#line 14301 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_clock); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_clock)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4094 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_clock, )
  RETVAL = GLEW_EXT_shader_clock;
  OGLM_CHECK_ERR(GLEW_EXT_shader_clock, )
#line 14323 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_framebuffer_fetch); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_framebuffer_fetch)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4104 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_framebuffer_fetch, )
  RETVAL = GLEW_EXT_shader_framebuffer_fetch;
  OGLM_CHECK_ERR(GLEW_EXT_shader_framebuffer_fetch, )
#line 14345 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_framebuffer_fetch_non_coherent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_framebuffer_fetch_non_coherent)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4114 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_framebuffer_fetch_non_coherent, )
  RETVAL = GLEW_EXT_shader_framebuffer_fetch_non_coherent;
  OGLM_CHECK_ERR(GLEW_EXT_shader_framebuffer_fetch_non_coherent, )
#line 14367 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_group_vote); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_group_vote)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4124 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_group_vote, )
  RETVAL = GLEW_EXT_shader_group_vote;
  OGLM_CHECK_ERR(GLEW_EXT_shader_group_vote, )
#line 14389 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_image_load_formatted); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_image_load_formatted)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4134 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_image_load_formatted, )
  RETVAL = GLEW_EXT_shader_image_load_formatted;
  OGLM_CHECK_ERR(GLEW_EXT_shader_image_load_formatted, )
#line 14411 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_image_load_store); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_image_load_store)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4144 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_image_load_store, )
  RETVAL = GLEW_EXT_shader_image_load_store;
  OGLM_CHECK_ERR(GLEW_EXT_shader_image_load_store, )
#line 14433 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_implicit_conversions); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_implicit_conversions)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4154 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_implicit_conversions, )
  RETVAL = GLEW_EXT_shader_implicit_conversions;
  OGLM_CHECK_ERR(GLEW_EXT_shader_implicit_conversions, )
#line 14455 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_integer_mix); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_integer_mix)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4164 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_integer_mix, )
  RETVAL = GLEW_EXT_shader_integer_mix;
  OGLM_CHECK_ERR(GLEW_EXT_shader_integer_mix, )
#line 14477 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_io_blocks); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_io_blocks)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4174 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_io_blocks, )
  RETVAL = GLEW_EXT_shader_io_blocks;
  OGLM_CHECK_ERR(GLEW_EXT_shader_io_blocks, )
#line 14499 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_non_constant_global_initializers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_non_constant_global_initializers)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4184 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_non_constant_global_initializers, )
  RETVAL = GLEW_EXT_shader_non_constant_global_initializers;
  OGLM_CHECK_ERR(GLEW_EXT_shader_non_constant_global_initializers, )
#line 14521 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_pixel_local_storage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_pixel_local_storage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4194 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_pixel_local_storage, )
  RETVAL = GLEW_EXT_shader_pixel_local_storage;
  OGLM_CHECK_ERR(GLEW_EXT_shader_pixel_local_storage, )
#line 14543 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_pixel_local_storage2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_pixel_local_storage2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4204 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_pixel_local_storage2, )
  RETVAL = GLEW_EXT_shader_pixel_local_storage2;
  OGLM_CHECK_ERR(GLEW_EXT_shader_pixel_local_storage2, )
#line 14565 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_realtime_clock); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_realtime_clock)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4214 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_realtime_clock, )
  RETVAL = GLEW_EXT_shader_realtime_clock;
  OGLM_CHECK_ERR(GLEW_EXT_shader_realtime_clock, )
#line 14587 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_samples_identical); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_samples_identical)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4224 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_samples_identical, )
  RETVAL = GLEW_EXT_shader_samples_identical;
  OGLM_CHECK_ERR(GLEW_EXT_shader_samples_identical, )
#line 14609 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_texture_lod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_texture_lod)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4234 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_texture_lod, )
  RETVAL = GLEW_EXT_shader_texture_lod;
  OGLM_CHECK_ERR(GLEW_EXT_shader_texture_lod, )
#line 14631 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_texture_samples); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shader_texture_samples)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4244 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_texture_samples, )
  RETVAL = GLEW_EXT_shader_texture_samples;
  OGLM_CHECK_ERR(GLEW_EXT_shader_texture_samples, )
#line 14653 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shadow_funcs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shadow_funcs)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4254 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shadow_funcs, )
  RETVAL = GLEW_EXT_shadow_funcs;
  OGLM_CHECK_ERR(GLEW_EXT_shadow_funcs, )
#line 14675 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shadow_samplers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shadow_samplers)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4264 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shadow_samplers, )
  RETVAL = GLEW_EXT_shadow_samplers;
  OGLM_CHECK_ERR(GLEW_EXT_shadow_samplers, )
#line 14697 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shared_texture_palette); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_shared_texture_palette)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4274 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shared_texture_palette, )
  RETVAL = GLEW_EXT_shared_texture_palette;
  OGLM_CHECK_ERR(GLEW_EXT_shared_texture_palette, )
#line 14719 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_sparse_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_sparse_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4284 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_sparse_texture, )
  RETVAL = GLEW_EXT_sparse_texture;
  OGLM_CHECK_ERR(GLEW_EXT_sparse_texture, )
#line 14741 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_sparse_texture2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_sparse_texture2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4294 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_sparse_texture2, )
  RETVAL = GLEW_EXT_sparse_texture2;
  OGLM_CHECK_ERR(GLEW_EXT_sparse_texture2, )
#line 14763 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_static_vertex_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_static_vertex_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4304 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_static_vertex_array, )
  RETVAL = GLEW_EXT_static_vertex_array;
  OGLM_CHECK_ERR(GLEW_EXT_static_vertex_array, )
#line 14785 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_stencil_clear_tag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_stencil_clear_tag)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4314 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_stencil_clear_tag, )
  RETVAL = GLEW_EXT_stencil_clear_tag;
  OGLM_CHECK_ERR(GLEW_EXT_stencil_clear_tag, )
#line 14807 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_stencil_two_side); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_stencil_two_side)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4324 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_stencil_two_side, )
  RETVAL = GLEW_EXT_stencil_two_side;
  OGLM_CHECK_ERR(GLEW_EXT_stencil_two_side, )
#line 14829 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_stencil_wrap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_stencil_wrap)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4334 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_stencil_wrap, )
  RETVAL = GLEW_EXT_stencil_wrap;
  OGLM_CHECK_ERR(GLEW_EXT_stencil_wrap, )
#line 14851 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_subtexture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_subtexture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4344 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_subtexture, )
  RETVAL = GLEW_EXT_subtexture;
  OGLM_CHECK_ERR(GLEW_EXT_subtexture, )
#line 14873 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_tessellation_point_size); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_tessellation_point_size)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4354 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_tessellation_point_size, )
  RETVAL = GLEW_EXT_tessellation_point_size;
  OGLM_CHECK_ERR(GLEW_EXT_tessellation_point_size, )
#line 14895 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_tessellation_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_tessellation_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4364 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_tessellation_shader, )
  RETVAL = GLEW_EXT_tessellation_shader;
  OGLM_CHECK_ERR(GLEW_EXT_tessellation_shader, )
#line 14917 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4374 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture, )
  RETVAL = GLEW_EXT_texture;
  OGLM_CHECK_ERR(GLEW_EXT_texture, )
#line 14939 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture3D); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture3D)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4384 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture3D, )
  RETVAL = GLEW_EXT_texture3D;
  OGLM_CHECK_ERR(GLEW_EXT_texture3D, )
#line 14961 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4394 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_array, )
  RETVAL = GLEW_EXT_texture_array;
  OGLM_CHECK_ERR(GLEW_EXT_texture_array, )
#line 14983 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_border_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_border_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4404 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_border_clamp, )
  RETVAL = GLEW_EXT_texture_border_clamp;
  OGLM_CHECK_ERR(GLEW_EXT_texture_border_clamp, )
#line 15005 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4414 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_buffer, )
  RETVAL = GLEW_EXT_texture_buffer;
  OGLM_CHECK_ERR(GLEW_EXT_texture_buffer, )
#line 15027 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4424 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_buffer_object, )
  RETVAL = GLEW_EXT_texture_buffer_object;
  OGLM_CHECK_ERR(GLEW_EXT_texture_buffer_object, )
#line 15049 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_astc_decode_mode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_astc_decode_mode)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4434 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_astc_decode_mode, )
  RETVAL = GLEW_EXT_texture_compression_astc_decode_mode;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_astc_decode_mode, )
#line 15071 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_astc_decode_mode_rgb9e5); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_astc_decode_mode_rgb9e5)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4444 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_astc_decode_mode_rgb9e5, )
  RETVAL = GLEW_EXT_texture_compression_astc_decode_mode_rgb9e5;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_astc_decode_mode_rgb9e5, )
#line 15093 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_bptc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_bptc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4454 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_bptc, )
  RETVAL = GLEW_EXT_texture_compression_bptc;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_bptc, )
#line 15115 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_dxt1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_dxt1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4464 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_dxt1, )
  RETVAL = GLEW_EXT_texture_compression_dxt1;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_dxt1, )
#line 15137 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_latc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_latc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4474 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_latc, )
  RETVAL = GLEW_EXT_texture_compression_latc;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_latc, )
#line 15159 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_rgtc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_rgtc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4484 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_rgtc, )
  RETVAL = GLEW_EXT_texture_compression_rgtc;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_rgtc, )
#line 15181 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_s3tc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_s3tc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4494 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_s3tc, )
  RETVAL = GLEW_EXT_texture_compression_s3tc;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_s3tc, )
#line 15203 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_s3tc_srgb); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_compression_s3tc_srgb)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4504 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_s3tc_srgb, )
  RETVAL = GLEW_EXT_texture_compression_s3tc_srgb;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_s3tc_srgb, )
#line 15225 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_cube_map); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_cube_map)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4514 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_cube_map, )
  RETVAL = GLEW_EXT_texture_cube_map;
  OGLM_CHECK_ERR(GLEW_EXT_texture_cube_map, )
#line 15247 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_cube_map_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_cube_map_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4524 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_cube_map_array, )
  RETVAL = GLEW_EXT_texture_cube_map_array;
  OGLM_CHECK_ERR(GLEW_EXT_texture_cube_map_array, )
#line 15269 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_edge_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_edge_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4534 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_edge_clamp, )
  RETVAL = GLEW_EXT_texture_edge_clamp;
  OGLM_CHECK_ERR(GLEW_EXT_texture_edge_clamp, )
#line 15291 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_env); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_env)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4544 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_env, )
  RETVAL = GLEW_EXT_texture_env;
  OGLM_CHECK_ERR(GLEW_EXT_texture_env, )
#line 15313 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_env_add); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_env_add)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4554 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_add, )
  RETVAL = GLEW_EXT_texture_env_add;
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_add, )
#line 15335 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_env_combine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_env_combine)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4564 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_combine, )
  RETVAL = GLEW_EXT_texture_env_combine;
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_combine, )
#line 15357 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_env_dot3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_env_dot3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4574 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_dot3, )
  RETVAL = GLEW_EXT_texture_env_dot3;
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_dot3, )
#line 15379 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_filter_anisotropic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_filter_anisotropic)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4584 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_filter_anisotropic, )
  RETVAL = GLEW_EXT_texture_filter_anisotropic;
  OGLM_CHECK_ERR(GLEW_EXT_texture_filter_anisotropic, )
#line 15401 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_filter_minmax); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_filter_minmax)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4594 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_filter_minmax, )
  RETVAL = GLEW_EXT_texture_filter_minmax;
  OGLM_CHECK_ERR(GLEW_EXT_texture_filter_minmax, )
#line 15423 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_format_BGRA8888); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_format_BGRA8888)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4604 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_format_BGRA8888, )
  RETVAL = GLEW_EXT_texture_format_BGRA8888;
  OGLM_CHECK_ERR(GLEW_EXT_texture_format_BGRA8888, )
#line 15445 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_format_sRGB_override); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_format_sRGB_override)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4614 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_format_sRGB_override, )
  RETVAL = GLEW_EXT_texture_format_sRGB_override;
  OGLM_CHECK_ERR(GLEW_EXT_texture_format_sRGB_override, )
#line 15467 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_integer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_integer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4624 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_integer, )
  RETVAL = GLEW_EXT_texture_integer;
  OGLM_CHECK_ERR(GLEW_EXT_texture_integer, )
#line 15489 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_lod_bias); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_lod_bias)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4634 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_lod_bias, )
  RETVAL = GLEW_EXT_texture_lod_bias;
  OGLM_CHECK_ERR(GLEW_EXT_texture_lod_bias, )
#line 15511 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_mirror_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_mirror_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4644 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_mirror_clamp, )
  RETVAL = GLEW_EXT_texture_mirror_clamp;
  OGLM_CHECK_ERR(GLEW_EXT_texture_mirror_clamp, )
#line 15533 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_mirror_clamp_to_edge); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_mirror_clamp_to_edge)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4654 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_mirror_clamp_to_edge, )
  RETVAL = GLEW_EXT_texture_mirror_clamp_to_edge;
  OGLM_CHECK_ERR(GLEW_EXT_texture_mirror_clamp_to_edge, )
#line 15555 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_norm16); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_norm16)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4664 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_norm16, )
  RETVAL = GLEW_EXT_texture_norm16;
  OGLM_CHECK_ERR(GLEW_EXT_texture_norm16, )
#line 15577 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4674 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_object, )
  RETVAL = GLEW_EXT_texture_object;
  OGLM_CHECK_ERR(GLEW_EXT_texture_object, )
#line 15599 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_perturb_normal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_perturb_normal)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4684 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_perturb_normal, )
  RETVAL = GLEW_EXT_texture_perturb_normal;
  OGLM_CHECK_ERR(GLEW_EXT_texture_perturb_normal, )
#line 15621 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_query_lod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_query_lod)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4694 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_query_lod, )
  RETVAL = GLEW_EXT_texture_query_lod;
  OGLM_CHECK_ERR(GLEW_EXT_texture_query_lod, )
#line 15643 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_rectangle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_rectangle)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4704 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_rectangle, )
  RETVAL = GLEW_EXT_texture_rectangle;
  OGLM_CHECK_ERR(GLEW_EXT_texture_rectangle, )
#line 15665 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_rg); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_rg)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4714 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_rg, )
  RETVAL = GLEW_EXT_texture_rg;
  OGLM_CHECK_ERR(GLEW_EXT_texture_rg, )
#line 15687 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_sRGB); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_sRGB)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4724 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB, )
  RETVAL = GLEW_EXT_texture_sRGB;
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB, )
#line 15709 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_sRGB_R8); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_sRGB_R8)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4734 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_R8, )
  RETVAL = GLEW_EXT_texture_sRGB_R8;
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_R8, )
#line 15731 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_sRGB_RG8); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_sRGB_RG8)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4744 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_RG8, )
  RETVAL = GLEW_EXT_texture_sRGB_RG8;
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_RG8, )
#line 15753 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_sRGB_decode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_sRGB_decode)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4754 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_decode, )
  RETVAL = GLEW_EXT_texture_sRGB_decode;
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_decode, )
#line 15775 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_shadow_lod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_shadow_lod)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4764 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_shadow_lod, )
  RETVAL = GLEW_EXT_texture_shadow_lod;
  OGLM_CHECK_ERR(GLEW_EXT_texture_shadow_lod, )
#line 15797 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_shared_exponent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_shared_exponent)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4774 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_shared_exponent, )
  RETVAL = GLEW_EXT_texture_shared_exponent;
  OGLM_CHECK_ERR(GLEW_EXT_texture_shared_exponent, )
#line 15819 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_snorm); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_snorm)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4784 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_snorm, )
  RETVAL = GLEW_EXT_texture_snorm;
  OGLM_CHECK_ERR(GLEW_EXT_texture_snorm, )
#line 15841 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_storage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_storage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4794 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_storage, )
  RETVAL = GLEW_EXT_texture_storage;
  OGLM_CHECK_ERR(GLEW_EXT_texture_storage, )
#line 15863 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_storage_compression); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_storage_compression)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4804 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_storage_compression, )
  RETVAL = GLEW_EXT_texture_storage_compression;
  OGLM_CHECK_ERR(GLEW_EXT_texture_storage_compression, )
#line 15885 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_swizzle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_swizzle)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4814 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_swizzle, )
  RETVAL = GLEW_EXT_texture_swizzle;
  OGLM_CHECK_ERR(GLEW_EXT_texture_swizzle, )
#line 15907 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_type_2_10_10_10_REV); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_type_2_10_10_10_REV)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4824 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_type_2_10_10_10_REV, )
  RETVAL = GLEW_EXT_texture_type_2_10_10_10_REV;
  OGLM_CHECK_ERR(GLEW_EXT_texture_type_2_10_10_10_REV, )
#line 15929 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_view); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_texture_view)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4834 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_view, )
  RETVAL = GLEW_EXT_texture_view;
  OGLM_CHECK_ERR(GLEW_EXT_texture_view, )
#line 15951 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_timer_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_timer_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4844 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_timer_query, )
  RETVAL = GLEW_EXT_timer_query;
  OGLM_CHECK_ERR(GLEW_EXT_timer_query, )
#line 15973 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_transform_feedback); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_transform_feedback)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4854 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_transform_feedback, )
  RETVAL = GLEW_EXT_transform_feedback;
  OGLM_CHECK_ERR(GLEW_EXT_transform_feedback, )
#line 15995 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_unpack_subimage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_unpack_subimage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4864 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_unpack_subimage, )
  RETVAL = GLEW_EXT_unpack_subimage;
  OGLM_CHECK_ERR(GLEW_EXT_unpack_subimage, )
#line 16017 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4874 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array, )
  RETVAL = GLEW_EXT_vertex_array;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array, )
#line 16039 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_array_bgra); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_array_bgra)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4884 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array_bgra, )
  RETVAL = GLEW_EXT_vertex_array_bgra;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array_bgra, )
#line 16061 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_array_setXXX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_array_setXXX)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4894 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array_setXXX, )
  RETVAL = GLEW_EXT_vertex_array_setXXX;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array_setXXX, )
#line 16083 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_attrib_64bit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_attrib_64bit)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4904 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_attrib_64bit, )
  RETVAL = GLEW_EXT_vertex_attrib_64bit;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_attrib_64bit, )
#line 16105 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4914 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_shader, )
  RETVAL = GLEW_EXT_vertex_shader;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_shader, )
#line 16127 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_weighting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_vertex_weighting)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4924 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_weighting, )
  RETVAL = GLEW_EXT_vertex_weighting;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_weighting, )
#line 16149 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_win32_keyed_mutex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_win32_keyed_mutex)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4934 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_win32_keyed_mutex, )
  RETVAL = GLEW_EXT_win32_keyed_mutex;
  OGLM_CHECK_ERR(GLEW_EXT_win32_keyed_mutex, )
#line 16171 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_window_rectangles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_window_rectangles)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4944 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_window_rectangles, )
  RETVAL = GLEW_EXT_window_rectangles;
  OGLM_CHECK_ERR(GLEW_EXT_window_rectangles, )
#line 16193 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_x11_sync_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_EXT_x11_sync_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4954 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_x11_sync_object, )
  RETVAL = GLEW_EXT_x11_sync_object;
  OGLM_CHECK_ERR(GLEW_EXT_x11_sync_object, )
#line 16215 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_FJ_shader_binary_GCCSO); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_FJ_shader_binary_GCCSO)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4964 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_FJ_shader_binary_GCCSO, )
  RETVAL = GLEW_FJ_shader_binary_GCCSO;
  OGLM_CHECK_ERR(GLEW_FJ_shader_binary_GCCSO, )
#line 16237 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_GREMEDY_frame_terminator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_GREMEDY_frame_terminator)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4974 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_GREMEDY_frame_terminator, )
  RETVAL = GLEW_GREMEDY_frame_terminator;
  OGLM_CHECK_ERR(GLEW_GREMEDY_frame_terminator, )
#line 16259 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_GREMEDY_string_marker); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_GREMEDY_string_marker)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4984 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_GREMEDY_string_marker, )
  RETVAL = GLEW_GREMEDY_string_marker;
  OGLM_CHECK_ERR(GLEW_GREMEDY_string_marker, )
#line 16281 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_HP_convolution_border_modes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_HP_convolution_border_modes)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 4994 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HP_convolution_border_modes, )
  RETVAL = GLEW_HP_convolution_border_modes;
  OGLM_CHECK_ERR(GLEW_HP_convolution_border_modes, )
#line 16303 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_HP_image_transform); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_HP_image_transform)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5004 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HP_image_transform, )
  RETVAL = GLEW_HP_image_transform;
  OGLM_CHECK_ERR(GLEW_HP_image_transform, )
#line 16325 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_HP_occlusion_test); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_HP_occlusion_test)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5014 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HP_occlusion_test, )
  RETVAL = GLEW_HP_occlusion_test;
  OGLM_CHECK_ERR(GLEW_HP_occlusion_test, )
#line 16347 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_HP_texture_lighting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_HP_texture_lighting)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5024 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HP_texture_lighting, )
  RETVAL = GLEW_HP_texture_lighting;
  OGLM_CHECK_ERR(GLEW_HP_texture_lighting, )
#line 16369 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_HUAWEI_program_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_HUAWEI_program_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5034 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HUAWEI_program_binary, )
  RETVAL = GLEW_HUAWEI_program_binary;
  OGLM_CHECK_ERR(GLEW_HUAWEI_program_binary, )
#line 16391 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_HUAWEI_shader_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_HUAWEI_shader_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5044 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HUAWEI_shader_binary, )
  RETVAL = GLEW_HUAWEI_shader_binary;
  OGLM_CHECK_ERR(GLEW_HUAWEI_shader_binary, )
#line 16413 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_cull_vertex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_cull_vertex)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5054 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_cull_vertex, )
  RETVAL = GLEW_IBM_cull_vertex;
  OGLM_CHECK_ERR(GLEW_IBM_cull_vertex, )
#line 16435 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_multimode_draw_arrays); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_multimode_draw_arrays)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5064 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_multimode_draw_arrays, )
  RETVAL = GLEW_IBM_multimode_draw_arrays;
  OGLM_CHECK_ERR(GLEW_IBM_multimode_draw_arrays, )
#line 16457 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_rasterpos_clip); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_rasterpos_clip)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5074 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_rasterpos_clip, )
  RETVAL = GLEW_IBM_rasterpos_clip;
  OGLM_CHECK_ERR(GLEW_IBM_rasterpos_clip, )
#line 16479 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_static_data); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_static_data)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5084 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_static_data, )
  RETVAL = GLEW_IBM_static_data;
  OGLM_CHECK_ERR(GLEW_IBM_static_data, )
#line 16501 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_texture_mirrored_repeat); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_texture_mirrored_repeat)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5094 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_texture_mirrored_repeat, )
  RETVAL = GLEW_IBM_texture_mirrored_repeat;
  OGLM_CHECK_ERR(GLEW_IBM_texture_mirrored_repeat, )
#line 16523 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_vertex_array_lists); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IBM_vertex_array_lists)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5104 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_vertex_array_lists, )
  RETVAL = GLEW_IBM_vertex_array_lists;
  OGLM_CHECK_ERR(GLEW_IBM_vertex_array_lists, )
#line 16545 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_bindless_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_bindless_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5114 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_bindless_texture, )
  RETVAL = GLEW_IMG_bindless_texture;
  OGLM_CHECK_ERR(GLEW_IMG_bindless_texture, )
#line 16567 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_framebuffer_downsample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_framebuffer_downsample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5124 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_framebuffer_downsample, )
  RETVAL = GLEW_IMG_framebuffer_downsample;
  OGLM_CHECK_ERR(GLEW_IMG_framebuffer_downsample, )
#line 16589 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_multisampled_render_to_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_multisampled_render_to_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5134 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_multisampled_render_to_texture, )
  RETVAL = GLEW_IMG_multisampled_render_to_texture;
  OGLM_CHECK_ERR(GLEW_IMG_multisampled_render_to_texture, )
#line 16611 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_program_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_program_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5144 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_program_binary, )
  RETVAL = GLEW_IMG_program_binary;
  OGLM_CHECK_ERR(GLEW_IMG_program_binary, )
#line 16633 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_pvric_end_to_end_signature); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_pvric_end_to_end_signature)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5154 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_pvric_end_to_end_signature, )
  RETVAL = GLEW_IMG_pvric_end_to_end_signature;
  OGLM_CHECK_ERR(GLEW_IMG_pvric_end_to_end_signature, )
#line 16655 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_read_format); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_read_format)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5164 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_read_format, )
  RETVAL = GLEW_IMG_read_format;
  OGLM_CHECK_ERR(GLEW_IMG_read_format, )
#line 16677 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_shader_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_shader_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5174 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_shader_binary, )
  RETVAL = GLEW_IMG_shader_binary;
  OGLM_CHECK_ERR(GLEW_IMG_shader_binary, )
#line 16699 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_texture_compression_pvrtc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_texture_compression_pvrtc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5184 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_texture_compression_pvrtc, )
  RETVAL = GLEW_IMG_texture_compression_pvrtc;
  OGLM_CHECK_ERR(GLEW_IMG_texture_compression_pvrtc, )
#line 16721 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_texture_compression_pvrtc2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_texture_compression_pvrtc2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5194 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_texture_compression_pvrtc2, )
  RETVAL = GLEW_IMG_texture_compression_pvrtc2;
  OGLM_CHECK_ERR(GLEW_IMG_texture_compression_pvrtc2, )
#line 16743 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_texture_env_enhanced_fixed_function); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_texture_env_enhanced_fixed_function)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5204 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_texture_env_enhanced_fixed_function, )
  RETVAL = GLEW_IMG_texture_env_enhanced_fixed_function;
  OGLM_CHECK_ERR(GLEW_IMG_texture_env_enhanced_fixed_function, )
#line 16765 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_texture_filter_cubic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_texture_filter_cubic)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5214 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_texture_filter_cubic, )
  RETVAL = GLEW_IMG_texture_filter_cubic;
  OGLM_CHECK_ERR(GLEW_IMG_texture_filter_cubic, )
#line 16787 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_tile_region_protection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_IMG_tile_region_protection)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5224 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_tile_region_protection, )
  RETVAL = GLEW_IMG_tile_region_protection;
  OGLM_CHECK_ERR(GLEW_IMG_tile_region_protection, )
#line 16809 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_INGR_color_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_INGR_color_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5234 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INGR_color_clamp, )
  RETVAL = GLEW_INGR_color_clamp;
  OGLM_CHECK_ERR(GLEW_INGR_color_clamp, )
#line 16831 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_INGR_interlace_read); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_INGR_interlace_read)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5244 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INGR_interlace_read, )
  RETVAL = GLEW_INGR_interlace_read;
  OGLM_CHECK_ERR(GLEW_INGR_interlace_read, )
#line 16853 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_blackhole_render); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_blackhole_render)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5254 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_blackhole_render, )
  RETVAL = GLEW_INTEL_blackhole_render;
  OGLM_CHECK_ERR(GLEW_INTEL_blackhole_render, )
#line 16875 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_conservative_rasterization); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_conservative_rasterization)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5264 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_conservative_rasterization, )
  RETVAL = GLEW_INTEL_conservative_rasterization;
  OGLM_CHECK_ERR(GLEW_INTEL_conservative_rasterization, )
#line 16897 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_fragment_shader_ordering); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_fragment_shader_ordering)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5274 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_fragment_shader_ordering, )
  RETVAL = GLEW_INTEL_fragment_shader_ordering;
  OGLM_CHECK_ERR(GLEW_INTEL_fragment_shader_ordering, )
#line 16919 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_framebuffer_CMAA); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_framebuffer_CMAA)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5284 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_framebuffer_CMAA, )
  RETVAL = GLEW_INTEL_framebuffer_CMAA;
  OGLM_CHECK_ERR(GLEW_INTEL_framebuffer_CMAA, )
#line 16941 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_map_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_map_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5294 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_map_texture, )
  RETVAL = GLEW_INTEL_map_texture;
  OGLM_CHECK_ERR(GLEW_INTEL_map_texture, )
#line 16963 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_parallel_arrays); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_parallel_arrays)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5304 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_parallel_arrays, )
  RETVAL = GLEW_INTEL_parallel_arrays;
  OGLM_CHECK_ERR(GLEW_INTEL_parallel_arrays, )
#line 16985 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_performance_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_performance_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5314 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_performance_query, )
  RETVAL = GLEW_INTEL_performance_query;
  OGLM_CHECK_ERR(GLEW_INTEL_performance_query, )
#line 17007 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_shader_integer_functions2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_shader_integer_functions2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5324 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_shader_integer_functions2, )
  RETVAL = GLEW_INTEL_shader_integer_functions2;
  OGLM_CHECK_ERR(GLEW_INTEL_shader_integer_functions2, )
#line 17029 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_texture_scissor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_INTEL_texture_scissor)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5334 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_texture_scissor, )
  RETVAL = GLEW_INTEL_texture_scissor;
  OGLM_CHECK_ERR(GLEW_INTEL_texture_scissor, )
#line 17051 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_blend_equation_advanced); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_blend_equation_advanced)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5344 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_blend_equation_advanced, )
  RETVAL = GLEW_KHR_blend_equation_advanced;
  OGLM_CHECK_ERR(GLEW_KHR_blend_equation_advanced, )
#line 17073 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_blend_equation_advanced_coherent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_blend_equation_advanced_coherent)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5354 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_blend_equation_advanced_coherent, )
  RETVAL = GLEW_KHR_blend_equation_advanced_coherent;
  OGLM_CHECK_ERR(GLEW_KHR_blend_equation_advanced_coherent, )
#line 17095 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_context_flush_control); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_context_flush_control)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5364 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_context_flush_control, )
  RETVAL = GLEW_KHR_context_flush_control;
  OGLM_CHECK_ERR(GLEW_KHR_context_flush_control, )
#line 17117 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_debug); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_debug)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5374 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_debug, )
  RETVAL = GLEW_KHR_debug;
  OGLM_CHECK_ERR(GLEW_KHR_debug, )
#line 17139 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_no_error); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_no_error)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5384 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_no_error, )
  RETVAL = GLEW_KHR_no_error;
  OGLM_CHECK_ERR(GLEW_KHR_no_error, )
#line 17161 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_parallel_shader_compile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_parallel_shader_compile)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5394 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_parallel_shader_compile, )
  RETVAL = GLEW_KHR_parallel_shader_compile;
  OGLM_CHECK_ERR(GLEW_KHR_parallel_shader_compile, )
#line 17183 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_robust_buffer_access_behavior); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_robust_buffer_access_behavior)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5404 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_robust_buffer_access_behavior, )
  RETVAL = GLEW_KHR_robust_buffer_access_behavior;
  OGLM_CHECK_ERR(GLEW_KHR_robust_buffer_access_behavior, )
#line 17205 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_robustness); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_robustness)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5414 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_robustness, )
  RETVAL = GLEW_KHR_robustness;
  OGLM_CHECK_ERR(GLEW_KHR_robustness, )
#line 17227 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_shader_subgroup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_shader_subgroup)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5424 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_shader_subgroup, )
  RETVAL = GLEW_KHR_shader_subgroup;
  OGLM_CHECK_ERR(GLEW_KHR_shader_subgroup, )
#line 17249 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_texture_compression_astc_hdr); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_texture_compression_astc_hdr)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5434 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_hdr, )
  RETVAL = GLEW_KHR_texture_compression_astc_hdr;
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_hdr, )
#line 17271 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_texture_compression_astc_ldr); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_texture_compression_astc_ldr)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5444 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_ldr, )
  RETVAL = GLEW_KHR_texture_compression_astc_ldr;
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_ldr, )
#line 17293 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_texture_compression_astc_sliced_3d); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KHR_texture_compression_astc_sliced_3d)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5454 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_sliced_3d, )
  RETVAL = GLEW_KHR_texture_compression_astc_sliced_3d;
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_sliced_3d, )
#line 17315 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_KTX_buffer_region); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_KTX_buffer_region)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5464 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KTX_buffer_region, )
  RETVAL = GLEW_KTX_buffer_region;
  OGLM_CHECK_ERR(GLEW_KTX_buffer_region, )
#line 17337 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESAX_texture_stack); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESAX_texture_stack)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5474 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESAX_texture_stack, )
  RETVAL = GLEW_MESAX_texture_stack;
  OGLM_CHECK_ERR(GLEW_MESAX_texture_stack, )
#line 17359 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_bgra); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_bgra)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5484 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_bgra, )
  RETVAL = GLEW_MESA_bgra;
  OGLM_CHECK_ERR(GLEW_MESA_bgra, )
#line 17381 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_framebuffer_flip_x); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_framebuffer_flip_x)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5494 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_flip_x, )
  RETVAL = GLEW_MESA_framebuffer_flip_x;
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_flip_x, )
#line 17403 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_framebuffer_flip_y); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_framebuffer_flip_y)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5504 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_flip_y, )
  RETVAL = GLEW_MESA_framebuffer_flip_y;
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_flip_y, )
#line 17425 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_framebuffer_swap_xy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_framebuffer_swap_xy)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5514 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_swap_xy, )
  RETVAL = GLEW_MESA_framebuffer_swap_xy;
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_swap_xy, )
#line 17447 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_pack_invert); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_pack_invert)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5524 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_pack_invert, )
  RETVAL = GLEW_MESA_pack_invert;
  OGLM_CHECK_ERR(GLEW_MESA_pack_invert, )
#line 17469 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_program_binary_formats); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_program_binary_formats)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5534 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_program_binary_formats, )
  RETVAL = GLEW_MESA_program_binary_formats;
  OGLM_CHECK_ERR(GLEW_MESA_program_binary_formats, )
#line 17491 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_resize_buffers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_resize_buffers)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5544 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_resize_buffers, )
  RETVAL = GLEW_MESA_resize_buffers;
  OGLM_CHECK_ERR(GLEW_MESA_resize_buffers, )
#line 17513 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_shader_integer_functions); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_shader_integer_functions)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5554 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_shader_integer_functions, )
  RETVAL = GLEW_MESA_shader_integer_functions;
  OGLM_CHECK_ERR(GLEW_MESA_shader_integer_functions, )
#line 17535 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_texture_const_bandwidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_texture_const_bandwidth)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5564 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_texture_const_bandwidth, )
  RETVAL = GLEW_MESA_texture_const_bandwidth;
  OGLM_CHECK_ERR(GLEW_MESA_texture_const_bandwidth, )
#line 17557 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_tile_raster_order); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_tile_raster_order)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5574 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_tile_raster_order, )
  RETVAL = GLEW_MESA_tile_raster_order;
  OGLM_CHECK_ERR(GLEW_MESA_tile_raster_order, )
#line 17579 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_window_pos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_window_pos)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5584 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_window_pos, )
  RETVAL = GLEW_MESA_window_pos;
  OGLM_CHECK_ERR(GLEW_MESA_window_pos, )
#line 17601 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_ycbcr_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_MESA_ycbcr_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5594 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_ycbcr_texture, )
  RETVAL = GLEW_MESA_ycbcr_texture;
  OGLM_CHECK_ERR(GLEW_MESA_ycbcr_texture, )
#line 17623 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_blend_equation_advanced_multi_draw_buffers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_blend_equation_advanced_multi_draw_buffers)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5604 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_blend_equation_advanced_multi_draw_buffers, )
  RETVAL = GLEW_NVX_blend_equation_advanced_multi_draw_buffers;
  OGLM_CHECK_ERR(GLEW_NVX_blend_equation_advanced_multi_draw_buffers, )
#line 17645 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_conditional_render); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_conditional_render)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5614 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_conditional_render, )
  RETVAL = GLEW_NVX_conditional_render;
  OGLM_CHECK_ERR(GLEW_NVX_conditional_render, )
#line 17667 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_gpu_memory_info); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_gpu_memory_info)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5624 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_gpu_memory_info, )
  RETVAL = GLEW_NVX_gpu_memory_info;
  OGLM_CHECK_ERR(GLEW_NVX_gpu_memory_info, )
#line 17689 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_gpu_multicast2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_gpu_multicast2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5634 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_gpu_multicast2, )
  RETVAL = GLEW_NVX_gpu_multicast2;
  OGLM_CHECK_ERR(GLEW_NVX_gpu_multicast2, )
#line 17711 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_linked_gpu_multicast); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_linked_gpu_multicast)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5644 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_linked_gpu_multicast, )
  RETVAL = GLEW_NVX_linked_gpu_multicast;
  OGLM_CHECK_ERR(GLEW_NVX_linked_gpu_multicast, )
#line 17733 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_progress_fence); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NVX_progress_fence)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5654 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_progress_fence, )
  RETVAL = GLEW_NVX_progress_fence;
  OGLM_CHECK_ERR(GLEW_NVX_progress_fence, )
#line 17755 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_3dvision_settings); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_3dvision_settings)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5664 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_3dvision_settings, )
  RETVAL = GLEW_NV_3dvision_settings;
  OGLM_CHECK_ERR(GLEW_NV_3dvision_settings, )
#line 17777 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_EGL_stream_consumer_external); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_EGL_stream_consumer_external)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5674 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_EGL_stream_consumer_external, )
  RETVAL = GLEW_NV_EGL_stream_consumer_external;
  OGLM_CHECK_ERR(GLEW_NV_EGL_stream_consumer_external, )
#line 17799 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_alpha_to_coverage_dither_control); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_alpha_to_coverage_dither_control)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5684 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_alpha_to_coverage_dither_control, )
  RETVAL = GLEW_NV_alpha_to_coverage_dither_control;
  OGLM_CHECK_ERR(GLEW_NV_alpha_to_coverage_dither_control, )
#line 17821 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_bgr); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_bgr)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5694 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_bgr, )
  RETVAL = GLEW_NV_bgr;
  OGLM_CHECK_ERR(GLEW_NV_bgr, )
#line 17843 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_bindless_multi_draw_indirect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_bindless_multi_draw_indirect)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5704 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_bindless_multi_draw_indirect, )
  RETVAL = GLEW_NV_bindless_multi_draw_indirect;
  OGLM_CHECK_ERR(GLEW_NV_bindless_multi_draw_indirect, )
#line 17865 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_bindless_multi_draw_indirect_count); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_bindless_multi_draw_indirect_count)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5714 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_bindless_multi_draw_indirect_count, )
  RETVAL = GLEW_NV_bindless_multi_draw_indirect_count;
  OGLM_CHECK_ERR(GLEW_NV_bindless_multi_draw_indirect_count, )
#line 17887 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_bindless_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_bindless_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5724 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_bindless_texture, )
  RETVAL = GLEW_NV_bindless_texture;
  OGLM_CHECK_ERR(GLEW_NV_bindless_texture, )
#line 17909 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_blend_equation_advanced); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_blend_equation_advanced)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5734 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_blend_equation_advanced, )
  RETVAL = GLEW_NV_blend_equation_advanced;
  OGLM_CHECK_ERR(GLEW_NV_blend_equation_advanced, )
#line 17931 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_blend_equation_advanced_coherent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_blend_equation_advanced_coherent)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5744 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_blend_equation_advanced_coherent, )
  RETVAL = GLEW_NV_blend_equation_advanced_coherent;
  OGLM_CHECK_ERR(GLEW_NV_blend_equation_advanced_coherent, )
#line 17953 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_blend_minmax_factor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_blend_minmax_factor)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5754 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_blend_minmax_factor, )
  RETVAL = GLEW_NV_blend_minmax_factor;
  OGLM_CHECK_ERR(GLEW_NV_blend_minmax_factor, )
#line 17975 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_blend_square); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_blend_square)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5764 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_blend_square, )
  RETVAL = GLEW_NV_blend_square;
  OGLM_CHECK_ERR(GLEW_NV_blend_square, )
#line 17997 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_clip_space_w_scaling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_clip_space_w_scaling)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5774 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_clip_space_w_scaling, )
  RETVAL = GLEW_NV_clip_space_w_scaling;
  OGLM_CHECK_ERR(GLEW_NV_clip_space_w_scaling, )
#line 18019 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_command_list); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_command_list)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5784 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_command_list, )
  RETVAL = GLEW_NV_command_list;
  OGLM_CHECK_ERR(GLEW_NV_command_list, )
#line 18041 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_compute_program5); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_compute_program5)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5794 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_compute_program5, )
  RETVAL = GLEW_NV_compute_program5;
  OGLM_CHECK_ERR(GLEW_NV_compute_program5, )
#line 18063 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_compute_shader_derivatives); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_compute_shader_derivatives)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5804 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_compute_shader_derivatives, )
  RETVAL = GLEW_NV_compute_shader_derivatives;
  OGLM_CHECK_ERR(GLEW_NV_compute_shader_derivatives, )
#line 18085 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conditional_render); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conditional_render)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5814 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conditional_render, )
  RETVAL = GLEW_NV_conditional_render;
  OGLM_CHECK_ERR(GLEW_NV_conditional_render, )
#line 18107 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conservative_raster); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conservative_raster)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5824 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster, )
  RETVAL = GLEW_NV_conservative_raster;
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster, )
#line 18129 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conservative_raster_dilate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conservative_raster_dilate)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5834 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_dilate, )
  RETVAL = GLEW_NV_conservative_raster_dilate;
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_dilate, )
#line 18151 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conservative_raster_pre_snap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conservative_raster_pre_snap)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5844 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_pre_snap, )
  RETVAL = GLEW_NV_conservative_raster_pre_snap;
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_pre_snap, )
#line 18173 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conservative_raster_pre_snap_triangles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conservative_raster_pre_snap_triangles)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5854 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_pre_snap_triangles, )
  RETVAL = GLEW_NV_conservative_raster_pre_snap_triangles;
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_pre_snap_triangles, )
#line 18195 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conservative_raster_underestimation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_conservative_raster_underestimation)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5864 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_underestimation, )
  RETVAL = GLEW_NV_conservative_raster_underestimation;
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_underestimation, )
#line 18217 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_copy_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_copy_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5874 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_copy_buffer, )
  RETVAL = GLEW_NV_copy_buffer;
  OGLM_CHECK_ERR(GLEW_NV_copy_buffer, )
#line 18239 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_copy_depth_to_color); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_copy_depth_to_color)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5884 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_copy_depth_to_color, )
  RETVAL = GLEW_NV_copy_depth_to_color;
  OGLM_CHECK_ERR(GLEW_NV_copy_depth_to_color, )
#line 18261 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_copy_image); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_copy_image)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5894 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_copy_image, )
  RETVAL = GLEW_NV_copy_image;
  OGLM_CHECK_ERR(GLEW_NV_copy_image, )
#line 18283 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_deep_texture3D); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_deep_texture3D)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5904 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_deep_texture3D, )
  RETVAL = GLEW_NV_deep_texture3D;
  OGLM_CHECK_ERR(GLEW_NV_deep_texture3D, )
#line 18305 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_depth_buffer_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_depth_buffer_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5914 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_depth_buffer_float, )
  RETVAL = GLEW_NV_depth_buffer_float;
  OGLM_CHECK_ERR(GLEW_NV_depth_buffer_float, )
#line 18327 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_depth_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_depth_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5924 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_depth_clamp, )
  RETVAL = GLEW_NV_depth_clamp;
  OGLM_CHECK_ERR(GLEW_NV_depth_clamp, )
#line 18349 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_depth_nonlinear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_depth_nonlinear)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5934 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_depth_nonlinear, )
  RETVAL = GLEW_NV_depth_nonlinear;
  OGLM_CHECK_ERR(GLEW_NV_depth_nonlinear, )
#line 18371 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_depth_range_unclamped); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_depth_range_unclamped)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5944 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_depth_range_unclamped, )
  RETVAL = GLEW_NV_depth_range_unclamped;
  OGLM_CHECK_ERR(GLEW_NV_depth_range_unclamped, )
#line 18393 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_draw_buffers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_draw_buffers)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5954 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_draw_buffers, )
  RETVAL = GLEW_NV_draw_buffers;
  OGLM_CHECK_ERR(GLEW_NV_draw_buffers, )
#line 18415 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_draw_instanced); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_draw_instanced)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5964 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_draw_instanced, )
  RETVAL = GLEW_NV_draw_instanced;
  OGLM_CHECK_ERR(GLEW_NV_draw_instanced, )
#line 18437 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_draw_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_draw_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5974 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_draw_texture, )
  RETVAL = GLEW_NV_draw_texture;
  OGLM_CHECK_ERR(GLEW_NV_draw_texture, )
#line 18459 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_draw_vulkan_image); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_draw_vulkan_image)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5984 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_draw_vulkan_image, )
  RETVAL = GLEW_NV_draw_vulkan_image;
  OGLM_CHECK_ERR(GLEW_NV_draw_vulkan_image, )
#line 18481 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_evaluators); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_evaluators)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 5994 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_evaluators, )
  RETVAL = GLEW_NV_evaluators;
  OGLM_CHECK_ERR(GLEW_NV_evaluators, )
#line 18503 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_explicit_attrib_location); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_explicit_attrib_location)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6004 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_explicit_attrib_location, )
  RETVAL = GLEW_NV_explicit_attrib_location;
  OGLM_CHECK_ERR(GLEW_NV_explicit_attrib_location, )
#line 18525 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_explicit_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_explicit_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6014 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_explicit_multisample, )
  RETVAL = GLEW_NV_explicit_multisample;
  OGLM_CHECK_ERR(GLEW_NV_explicit_multisample, )
#line 18547 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fbo_color_attachments); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fbo_color_attachments)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6024 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fbo_color_attachments, )
  RETVAL = GLEW_NV_fbo_color_attachments;
  OGLM_CHECK_ERR(GLEW_NV_fbo_color_attachments, )
#line 18569 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fence); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fence)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6034 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fence, )
  RETVAL = GLEW_NV_fence;
  OGLM_CHECK_ERR(GLEW_NV_fence, )
#line 18591 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fill_rectangle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fill_rectangle)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6044 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fill_rectangle, )
  RETVAL = GLEW_NV_fill_rectangle;
  OGLM_CHECK_ERR(GLEW_NV_fill_rectangle, )
#line 18613 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_float_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_float_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6054 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_float_buffer, )
  RETVAL = GLEW_NV_float_buffer;
  OGLM_CHECK_ERR(GLEW_NV_float_buffer, )
#line 18635 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fog_distance); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fog_distance)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6064 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fog_distance, )
  RETVAL = GLEW_NV_fog_distance;
  OGLM_CHECK_ERR(GLEW_NV_fog_distance, )
#line 18657 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_coverage_to_color); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_coverage_to_color)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6074 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_coverage_to_color, )
  RETVAL = GLEW_NV_fragment_coverage_to_color;
  OGLM_CHECK_ERR(GLEW_NV_fragment_coverage_to_color, )
#line 18679 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_program); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_program)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6084 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_program, )
  RETVAL = GLEW_NV_fragment_program;
  OGLM_CHECK_ERR(GLEW_NV_fragment_program, )
#line 18701 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_program2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_program2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6094 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_program2, )
  RETVAL = GLEW_NV_fragment_program2;
  OGLM_CHECK_ERR(GLEW_NV_fragment_program2, )
#line 18723 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_program4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_program4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6104 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_program4, )
  RETVAL = GLEW_NV_fragment_program4;
  OGLM_CHECK_ERR(GLEW_NV_fragment_program4, )
#line 18745 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_program_option); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_program_option)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6114 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_program_option, )
  RETVAL = GLEW_NV_fragment_program_option;
  OGLM_CHECK_ERR(GLEW_NV_fragment_program_option, )
#line 18767 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_shader_barycentric); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_shader_barycentric)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6124 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_shader_barycentric, )
  RETVAL = GLEW_NV_fragment_shader_barycentric;
  OGLM_CHECK_ERR(GLEW_NV_fragment_shader_barycentric, )
#line 18789 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_shader_interlock); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_fragment_shader_interlock)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6134 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_shader_interlock, )
  RETVAL = GLEW_NV_fragment_shader_interlock;
  OGLM_CHECK_ERR(GLEW_NV_fragment_shader_interlock, )
#line 18811 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_framebuffer_blit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_framebuffer_blit)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6144 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_blit, )
  RETVAL = GLEW_NV_framebuffer_blit;
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_blit, )
#line 18833 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_framebuffer_mixed_samples); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_framebuffer_mixed_samples)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6154 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_mixed_samples, )
  RETVAL = GLEW_NV_framebuffer_mixed_samples;
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_mixed_samples, )
#line 18855 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_framebuffer_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_framebuffer_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6164 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_multisample, )
  RETVAL = GLEW_NV_framebuffer_multisample;
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_multisample, )
#line 18877 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_framebuffer_multisample_coverage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_framebuffer_multisample_coverage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6174 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_multisample_coverage, )
  RETVAL = GLEW_NV_framebuffer_multisample_coverage;
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_multisample_coverage, )
#line 18899 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_generate_mipmap_sRGB); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_generate_mipmap_sRGB)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6184 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_generate_mipmap_sRGB, )
  RETVAL = GLEW_NV_generate_mipmap_sRGB;
  OGLM_CHECK_ERR(GLEW_NV_generate_mipmap_sRGB, )
#line 18921 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_geometry_program4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_geometry_program4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6194 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_geometry_program4, )
  RETVAL = GLEW_NV_geometry_program4;
  OGLM_CHECK_ERR(GLEW_NV_geometry_program4, )
#line 18943 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_geometry_shader4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_geometry_shader4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6204 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_geometry_shader4, )
  RETVAL = GLEW_NV_geometry_shader4;
  OGLM_CHECK_ERR(GLEW_NV_geometry_shader4, )
#line 18965 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_geometry_shader_passthrough); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_geometry_shader_passthrough)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6214 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_geometry_shader_passthrough, )
  RETVAL = GLEW_NV_geometry_shader_passthrough;
  OGLM_CHECK_ERR(GLEW_NV_geometry_shader_passthrough, )
#line 18987 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_multicast); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_multicast)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6224 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_multicast, )
  RETVAL = GLEW_NV_gpu_multicast;
  OGLM_CHECK_ERR(GLEW_NV_gpu_multicast, )
#line 19009 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_program4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_program4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6234 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_program4, )
  RETVAL = GLEW_NV_gpu_program4;
  OGLM_CHECK_ERR(GLEW_NV_gpu_program4, )
#line 19031 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_program5); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_program5)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6244 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_program5, )
  RETVAL = GLEW_NV_gpu_program5;
  OGLM_CHECK_ERR(GLEW_NV_gpu_program5, )
#line 19053 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_program5_mem_extended); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_program5_mem_extended)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6254 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_program5_mem_extended, )
  RETVAL = GLEW_NV_gpu_program5_mem_extended;
  OGLM_CHECK_ERR(GLEW_NV_gpu_program5_mem_extended, )
#line 19075 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_program_fp64); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_program_fp64)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6264 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_program_fp64, )
  RETVAL = GLEW_NV_gpu_program_fp64;
  OGLM_CHECK_ERR(GLEW_NV_gpu_program_fp64, )
#line 19097 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_shader5); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_gpu_shader5)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6274 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_shader5, )
  RETVAL = GLEW_NV_gpu_shader5;
  OGLM_CHECK_ERR(GLEW_NV_gpu_shader5, )
#line 19119 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_half_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_half_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6284 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_half_float, )
  RETVAL = GLEW_NV_half_float;
  OGLM_CHECK_ERR(GLEW_NV_half_float, )
#line 19141 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_image_formats); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_image_formats)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6294 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_image_formats, )
  RETVAL = GLEW_NV_image_formats;
  OGLM_CHECK_ERR(GLEW_NV_image_formats, )
#line 19163 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_instanced_arrays); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_instanced_arrays)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6304 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_instanced_arrays, )
  RETVAL = GLEW_NV_instanced_arrays;
  OGLM_CHECK_ERR(GLEW_NV_instanced_arrays, )
#line 19185 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_internalformat_sample_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_internalformat_sample_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6314 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_internalformat_sample_query, )
  RETVAL = GLEW_NV_internalformat_sample_query;
  OGLM_CHECK_ERR(GLEW_NV_internalformat_sample_query, )
#line 19207 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_light_max_exponent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_light_max_exponent)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6324 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_light_max_exponent, )
  RETVAL = GLEW_NV_light_max_exponent;
  OGLM_CHECK_ERR(GLEW_NV_light_max_exponent, )
#line 19229 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_memory_attachment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_memory_attachment)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6334 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_memory_attachment, )
  RETVAL = GLEW_NV_memory_attachment;
  OGLM_CHECK_ERR(GLEW_NV_memory_attachment, )
#line 19251 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_memory_object_sparse); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_memory_object_sparse)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6344 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_memory_object_sparse, )
  RETVAL = GLEW_NV_memory_object_sparse;
  OGLM_CHECK_ERR(GLEW_NV_memory_object_sparse, )
#line 19273 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_mesh_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_mesh_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6354 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_mesh_shader, )
  RETVAL = GLEW_NV_mesh_shader;
  OGLM_CHECK_ERR(GLEW_NV_mesh_shader, )
#line 19295 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_multisample_coverage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_multisample_coverage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6364 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_multisample_coverage, )
  RETVAL = GLEW_NV_multisample_coverage;
  OGLM_CHECK_ERR(GLEW_NV_multisample_coverage, )
#line 19317 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_multisample_filter_hint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_multisample_filter_hint)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6374 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_multisample_filter_hint, )
  RETVAL = GLEW_NV_multisample_filter_hint;
  OGLM_CHECK_ERR(GLEW_NV_multisample_filter_hint, )
#line 19339 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_non_square_matrices); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_non_square_matrices)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6384 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_non_square_matrices, )
  RETVAL = GLEW_NV_non_square_matrices;
  OGLM_CHECK_ERR(GLEW_NV_non_square_matrices, )
#line 19361 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_occlusion_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_occlusion_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6394 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_occlusion_query, )
  RETVAL = GLEW_NV_occlusion_query;
  OGLM_CHECK_ERR(GLEW_NV_occlusion_query, )
#line 19383 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_pack_subimage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_pack_subimage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6404 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_pack_subimage, )
  RETVAL = GLEW_NV_pack_subimage;
  OGLM_CHECK_ERR(GLEW_NV_pack_subimage, )
#line 19405 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_packed_depth_stencil); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_packed_depth_stencil)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6414 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_packed_depth_stencil, )
  RETVAL = GLEW_NV_packed_depth_stencil;
  OGLM_CHECK_ERR(GLEW_NV_packed_depth_stencil, )
#line 19427 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_packed_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_packed_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6424 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_packed_float, )
  RETVAL = GLEW_NV_packed_float;
  OGLM_CHECK_ERR(GLEW_NV_packed_float, )
#line 19449 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_packed_float_linear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_packed_float_linear)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6434 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_packed_float_linear, )
  RETVAL = GLEW_NV_packed_float_linear;
  OGLM_CHECK_ERR(GLEW_NV_packed_float_linear, )
#line 19471 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_parameter_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_parameter_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6444 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_parameter_buffer_object, )
  RETVAL = GLEW_NV_parameter_buffer_object;
  OGLM_CHECK_ERR(GLEW_NV_parameter_buffer_object, )
#line 19493 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_parameter_buffer_object2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_parameter_buffer_object2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6454 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_parameter_buffer_object2, )
  RETVAL = GLEW_NV_parameter_buffer_object2;
  OGLM_CHECK_ERR(GLEW_NV_parameter_buffer_object2, )
#line 19515 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_path_rendering); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_path_rendering)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6464 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_path_rendering, )
  RETVAL = GLEW_NV_path_rendering;
  OGLM_CHECK_ERR(GLEW_NV_path_rendering, )
#line 19537 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_path_rendering_shared_edge); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_path_rendering_shared_edge)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6474 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_path_rendering_shared_edge, )
  RETVAL = GLEW_NV_path_rendering_shared_edge;
  OGLM_CHECK_ERR(GLEW_NV_path_rendering_shared_edge, )
#line 19559 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_pixel_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_pixel_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6484 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_pixel_buffer_object, )
  RETVAL = GLEW_NV_pixel_buffer_object;
  OGLM_CHECK_ERR(GLEW_NV_pixel_buffer_object, )
#line 19581 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_pixel_data_range); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_pixel_data_range)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6494 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_pixel_data_range, )
  RETVAL = GLEW_NV_pixel_data_range;
  OGLM_CHECK_ERR(GLEW_NV_pixel_data_range, )
#line 19603 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_platform_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_platform_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6504 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_platform_binary, )
  RETVAL = GLEW_NV_platform_binary;
  OGLM_CHECK_ERR(GLEW_NV_platform_binary, )
#line 19625 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_point_sprite); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_point_sprite)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6514 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_point_sprite, )
  RETVAL = GLEW_NV_point_sprite;
  OGLM_CHECK_ERR(GLEW_NV_point_sprite, )
#line 19647 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_polygon_mode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_polygon_mode)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6524 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_polygon_mode, )
  RETVAL = GLEW_NV_polygon_mode;
  OGLM_CHECK_ERR(GLEW_NV_polygon_mode, )
#line 19669 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_present_video); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_present_video)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6534 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_present_video, )
  RETVAL = GLEW_NV_present_video;
  OGLM_CHECK_ERR(GLEW_NV_present_video, )
#line 19691 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_primitive_restart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_primitive_restart)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6544 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_primitive_restart, )
  RETVAL = GLEW_NV_primitive_restart;
  OGLM_CHECK_ERR(GLEW_NV_primitive_restart, )
#line 19713 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_primitive_shading_rate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_primitive_shading_rate)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6554 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_primitive_shading_rate, )
  RETVAL = GLEW_NV_primitive_shading_rate;
  OGLM_CHECK_ERR(GLEW_NV_primitive_shading_rate, )
#line 19735 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_query_resource_tag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_query_resource_tag)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6564 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_query_resource_tag, )
  RETVAL = GLEW_NV_query_resource_tag;
  OGLM_CHECK_ERR(GLEW_NV_query_resource_tag, )
#line 19757 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_read_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_read_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6574 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_read_buffer, )
  RETVAL = GLEW_NV_read_buffer;
  OGLM_CHECK_ERR(GLEW_NV_read_buffer, )
#line 19779 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_read_buffer_front); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_read_buffer_front)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6584 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_read_buffer_front, )
  RETVAL = GLEW_NV_read_buffer_front;
  OGLM_CHECK_ERR(GLEW_NV_read_buffer_front, )
#line 19801 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_read_depth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_read_depth)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6594 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_read_depth, )
  RETVAL = GLEW_NV_read_depth;
  OGLM_CHECK_ERR(GLEW_NV_read_depth, )
#line 19823 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_read_depth_stencil); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_read_depth_stencil)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6604 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_read_depth_stencil, )
  RETVAL = GLEW_NV_read_depth_stencil;
  OGLM_CHECK_ERR(GLEW_NV_read_depth_stencil, )
#line 19845 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_read_stencil); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_read_stencil)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6614 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_read_stencil, )
  RETVAL = GLEW_NV_read_stencil;
  OGLM_CHECK_ERR(GLEW_NV_read_stencil, )
#line 19867 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_register_combiners); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_register_combiners)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6624 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_register_combiners, )
  RETVAL = GLEW_NV_register_combiners;
  OGLM_CHECK_ERR(GLEW_NV_register_combiners, )
#line 19889 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_register_combiners2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_register_combiners2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6634 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_register_combiners2, )
  RETVAL = GLEW_NV_register_combiners2;
  OGLM_CHECK_ERR(GLEW_NV_register_combiners2, )
#line 19911 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_representative_fragment_test); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_representative_fragment_test)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6644 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_representative_fragment_test, )
  RETVAL = GLEW_NV_representative_fragment_test;
  OGLM_CHECK_ERR(GLEW_NV_representative_fragment_test, )
#line 19933 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_robustness_video_memory_purge); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_robustness_video_memory_purge)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6654 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_robustness_video_memory_purge, )
  RETVAL = GLEW_NV_robustness_video_memory_purge;
  OGLM_CHECK_ERR(GLEW_NV_robustness_video_memory_purge, )
#line 19955 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_sRGB_formats); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_sRGB_formats)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6664 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_sRGB_formats, )
  RETVAL = GLEW_NV_sRGB_formats;
  OGLM_CHECK_ERR(GLEW_NV_sRGB_formats, )
#line 19977 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_sample_locations); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_sample_locations)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6674 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_sample_locations, )
  RETVAL = GLEW_NV_sample_locations;
  OGLM_CHECK_ERR(GLEW_NV_sample_locations, )
#line 19999 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_sample_mask_override_coverage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_sample_mask_override_coverage)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6684 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_sample_mask_override_coverage, )
  RETVAL = GLEW_NV_sample_mask_override_coverage;
  OGLM_CHECK_ERR(GLEW_NV_sample_mask_override_coverage, )
#line 20021 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_scissor_exclusive); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_scissor_exclusive)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6694 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_scissor_exclusive, )
  RETVAL = GLEW_NV_scissor_exclusive;
  OGLM_CHECK_ERR(GLEW_NV_scissor_exclusive, )
#line 20043 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_atomic_counters); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_atomic_counters)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6704 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_counters, )
  RETVAL = GLEW_NV_shader_atomic_counters;
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_counters, )
#line 20065 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_atomic_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_atomic_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6714 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_float, )
  RETVAL = GLEW_NV_shader_atomic_float;
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_float, )
#line 20087 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_atomic_float64); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_atomic_float64)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6724 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_float64, )
  RETVAL = GLEW_NV_shader_atomic_float64;
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_float64, )
#line 20109 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_atomic_fp16_vector); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_atomic_fp16_vector)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6734 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_fp16_vector, )
  RETVAL = GLEW_NV_shader_atomic_fp16_vector;
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_fp16_vector, )
#line 20131 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_atomic_int64); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_atomic_int64)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6744 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_int64, )
  RETVAL = GLEW_NV_shader_atomic_int64;
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_int64, )
#line 20153 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_buffer_load); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_buffer_load)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6754 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_buffer_load, )
  RETVAL = GLEW_NV_shader_buffer_load;
  OGLM_CHECK_ERR(GLEW_NV_shader_buffer_load, )
#line 20175 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_noperspective_interpolation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_noperspective_interpolation)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6764 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_noperspective_interpolation, )
  RETVAL = GLEW_NV_shader_noperspective_interpolation;
  OGLM_CHECK_ERR(GLEW_NV_shader_noperspective_interpolation, )
#line 20197 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_storage_buffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_storage_buffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6774 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_storage_buffer_object, )
  RETVAL = GLEW_NV_shader_storage_buffer_object;
  OGLM_CHECK_ERR(GLEW_NV_shader_storage_buffer_object, )
#line 20219 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_subgroup_partitioned); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_subgroup_partitioned)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6784 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_subgroup_partitioned, )
  RETVAL = GLEW_NV_shader_subgroup_partitioned;
  OGLM_CHECK_ERR(GLEW_NV_shader_subgroup_partitioned, )
#line 20241 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_texture_footprint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_texture_footprint)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6794 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_texture_footprint, )
  RETVAL = GLEW_NV_shader_texture_footprint;
  OGLM_CHECK_ERR(GLEW_NV_shader_texture_footprint, )
#line 20263 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_thread_group); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_thread_group)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6804 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_thread_group, )
  RETVAL = GLEW_NV_shader_thread_group;
  OGLM_CHECK_ERR(GLEW_NV_shader_thread_group, )
#line 20285 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_thread_shuffle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shader_thread_shuffle)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6814 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_thread_shuffle, )
  RETVAL = GLEW_NV_shader_thread_shuffle;
  OGLM_CHECK_ERR(GLEW_NV_shader_thread_shuffle, )
#line 20307 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shading_rate_image); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shading_rate_image)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6824 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shading_rate_image, )
  RETVAL = GLEW_NV_shading_rate_image;
  OGLM_CHECK_ERR(GLEW_NV_shading_rate_image, )
#line 20329 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shadow_samplers_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shadow_samplers_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6834 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shadow_samplers_array, )
  RETVAL = GLEW_NV_shadow_samplers_array;
  OGLM_CHECK_ERR(GLEW_NV_shadow_samplers_array, )
#line 20351 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shadow_samplers_cube); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_shadow_samplers_cube)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6844 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shadow_samplers_cube, )
  RETVAL = GLEW_NV_shadow_samplers_cube;
  OGLM_CHECK_ERR(GLEW_NV_shadow_samplers_cube, )
#line 20373 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_stereo_view_rendering); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_stereo_view_rendering)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6854 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_stereo_view_rendering, )
  RETVAL = GLEW_NV_stereo_view_rendering;
  OGLM_CHECK_ERR(GLEW_NV_stereo_view_rendering, )
#line 20395 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_tessellation_program5); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_tessellation_program5)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6864 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_tessellation_program5, )
  RETVAL = GLEW_NV_tessellation_program5;
  OGLM_CHECK_ERR(GLEW_NV_tessellation_program5, )
#line 20417 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texgen_emboss); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texgen_emboss)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6874 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texgen_emboss, )
  RETVAL = GLEW_NV_texgen_emboss;
  OGLM_CHECK_ERR(GLEW_NV_texgen_emboss, )
#line 20439 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texgen_reflection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texgen_reflection)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6884 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texgen_reflection, )
  RETVAL = GLEW_NV_texgen_reflection;
  OGLM_CHECK_ERR(GLEW_NV_texgen_reflection, )
#line 20461 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6894 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_array, )
  RETVAL = GLEW_NV_texture_array;
  OGLM_CHECK_ERR(GLEW_NV_texture_array, )
#line 20483 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_barrier); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_barrier)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6904 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_barrier, )
  RETVAL = GLEW_NV_texture_barrier;
  OGLM_CHECK_ERR(GLEW_NV_texture_barrier, )
#line 20505 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_border_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_border_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6914 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_border_clamp, )
  RETVAL = GLEW_NV_texture_border_clamp;
  OGLM_CHECK_ERR(GLEW_NV_texture_border_clamp, )
#line 20527 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_compression_latc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_compression_latc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6924 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_latc, )
  RETVAL = GLEW_NV_texture_compression_latc;
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_latc, )
#line 20549 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_compression_s3tc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_compression_s3tc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6934 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_s3tc, )
  RETVAL = GLEW_NV_texture_compression_s3tc;
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_s3tc, )
#line 20571 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_compression_s3tc_update); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_compression_s3tc_update)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6944 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_s3tc_update, )
  RETVAL = GLEW_NV_texture_compression_s3tc_update;
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_s3tc_update, )
#line 20593 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_compression_vtc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_compression_vtc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6954 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_vtc, )
  RETVAL = GLEW_NV_texture_compression_vtc;
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_vtc, )
#line 20615 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_env_combine4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_env_combine4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6964 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_env_combine4, )
  RETVAL = GLEW_NV_texture_env_combine4;
  OGLM_CHECK_ERR(GLEW_NV_texture_env_combine4, )
#line 20637 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_expand_normal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_expand_normal)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6974 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_expand_normal, )
  RETVAL = GLEW_NV_texture_expand_normal;
  OGLM_CHECK_ERR(GLEW_NV_texture_expand_normal, )
#line 20659 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6984 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_multisample, )
  RETVAL = GLEW_NV_texture_multisample;
  OGLM_CHECK_ERR(GLEW_NV_texture_multisample, )
#line 20681 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_npot_2D_mipmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_npot_2D_mipmap)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 6994 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_npot_2D_mipmap, )
  RETVAL = GLEW_NV_texture_npot_2D_mipmap;
  OGLM_CHECK_ERR(GLEW_NV_texture_npot_2D_mipmap, )
#line 20703 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_rectangle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_rectangle)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7004 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_rectangle, )
  RETVAL = GLEW_NV_texture_rectangle;
  OGLM_CHECK_ERR(GLEW_NV_texture_rectangle, )
#line 20725 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_rectangle_compressed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_rectangle_compressed)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7014 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_rectangle_compressed, )
  RETVAL = GLEW_NV_texture_rectangle_compressed;
  OGLM_CHECK_ERR(GLEW_NV_texture_rectangle_compressed, )
#line 20747 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7024 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_shader, )
  RETVAL = GLEW_NV_texture_shader;
  OGLM_CHECK_ERR(GLEW_NV_texture_shader, )
#line 20769 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_shader2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_shader2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7034 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_shader2, )
  RETVAL = GLEW_NV_texture_shader2;
  OGLM_CHECK_ERR(GLEW_NV_texture_shader2, )
#line 20791 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_shader3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_texture_shader3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7044 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_shader3, )
  RETVAL = GLEW_NV_texture_shader3;
  OGLM_CHECK_ERR(GLEW_NV_texture_shader3, )
#line 20813 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_timeline_semaphore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_timeline_semaphore)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7054 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_timeline_semaphore, )
  RETVAL = GLEW_NV_timeline_semaphore;
  OGLM_CHECK_ERR(GLEW_NV_timeline_semaphore, )
#line 20835 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_transform_feedback); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_transform_feedback)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7064 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_transform_feedback, )
  RETVAL = GLEW_NV_transform_feedback;
  OGLM_CHECK_ERR(GLEW_NV_transform_feedback, )
#line 20857 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_transform_feedback2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_transform_feedback2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7074 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_transform_feedback2, )
  RETVAL = GLEW_NV_transform_feedback2;
  OGLM_CHECK_ERR(GLEW_NV_transform_feedback2, )
#line 20879 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_uniform_buffer_std430_layout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_uniform_buffer_std430_layout)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7084 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_uniform_buffer_std430_layout, )
  RETVAL = GLEW_NV_uniform_buffer_std430_layout;
  OGLM_CHECK_ERR(GLEW_NV_uniform_buffer_std430_layout, )
#line 20901 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_uniform_buffer_unified_memory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_uniform_buffer_unified_memory)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7094 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_uniform_buffer_unified_memory, )
  RETVAL = GLEW_NV_uniform_buffer_unified_memory;
  OGLM_CHECK_ERR(GLEW_NV_uniform_buffer_unified_memory, )
#line 20923 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vdpau_interop); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vdpau_interop)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7104 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vdpau_interop, )
  RETVAL = GLEW_NV_vdpau_interop;
  OGLM_CHECK_ERR(GLEW_NV_vdpau_interop, )
#line 20945 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vdpau_interop2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vdpau_interop2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7114 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vdpau_interop2, )
  RETVAL = GLEW_NV_vdpau_interop2;
  OGLM_CHECK_ERR(GLEW_NV_vdpau_interop2, )
#line 20967 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_array_range); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_array_range)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7124 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_array_range, )
  RETVAL = GLEW_NV_vertex_array_range;
  OGLM_CHECK_ERR(GLEW_NV_vertex_array_range, )
#line 20989 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_array_range2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_array_range2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7134 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_array_range2, )
  RETVAL = GLEW_NV_vertex_array_range2;
  OGLM_CHECK_ERR(GLEW_NV_vertex_array_range2, )
#line 21011 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_attrib_integer_64bit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_attrib_integer_64bit)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7144 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_attrib_integer_64bit, )
  RETVAL = GLEW_NV_vertex_attrib_integer_64bit;
  OGLM_CHECK_ERR(GLEW_NV_vertex_attrib_integer_64bit, )
#line 21033 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_buffer_unified_memory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_buffer_unified_memory)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7154 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_buffer_unified_memory, )
  RETVAL = GLEW_NV_vertex_buffer_unified_memory;
  OGLM_CHECK_ERR(GLEW_NV_vertex_buffer_unified_memory, )
#line 21055 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7164 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program, )
  RETVAL = GLEW_NV_vertex_program;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program, )
#line 21077 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program1_1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program1_1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7174 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program1_1, )
  RETVAL = GLEW_NV_vertex_program1_1;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program1_1, )
#line 21099 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7184 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program2, )
  RETVAL = GLEW_NV_vertex_program2;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program2, )
#line 21121 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program2_option); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program2_option)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7194 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program2_option, )
  RETVAL = GLEW_NV_vertex_program2_option;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program2_option, )
#line 21143 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7204 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program3, )
  RETVAL = GLEW_NV_vertex_program3;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program3, )
#line 21165 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_vertex_program4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7214 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program4, )
  RETVAL = GLEW_NV_vertex_program4;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program4, )
#line 21187 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_video_capture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_video_capture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7224 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_video_capture, )
  RETVAL = GLEW_NV_video_capture;
  OGLM_CHECK_ERR(GLEW_NV_video_capture, )
#line 21209 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_viewport_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_viewport_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7234 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_viewport_array, )
  RETVAL = GLEW_NV_viewport_array;
  OGLM_CHECK_ERR(GLEW_NV_viewport_array, )
#line 21231 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_viewport_array2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_viewport_array2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7244 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_viewport_array2, )
  RETVAL = GLEW_NV_viewport_array2;
  OGLM_CHECK_ERR(GLEW_NV_viewport_array2, )
#line 21253 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_viewport_swizzle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_NV_viewport_swizzle)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7254 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_viewport_swizzle, )
  RETVAL = GLEW_NV_viewport_swizzle;
  OGLM_CHECK_ERR(GLEW_NV_viewport_swizzle, )
#line 21275 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_EGL_image); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_EGL_image)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7264 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_EGL_image, )
  RETVAL = GLEW_OES_EGL_image;
  OGLM_CHECK_ERR(GLEW_OES_EGL_image, )
#line 21297 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_EGL_image_external); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_EGL_image_external)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7274 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_EGL_image_external, )
  RETVAL = GLEW_OES_EGL_image_external;
  OGLM_CHECK_ERR(GLEW_OES_EGL_image_external, )
#line 21319 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_EGL_image_external_essl3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_EGL_image_external_essl3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7284 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_EGL_image_external_essl3, )
  RETVAL = GLEW_OES_EGL_image_external_essl3;
  OGLM_CHECK_ERR(GLEW_OES_EGL_image_external_essl3, )
#line 21341 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_blend_equation_separate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_blend_equation_separate)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7294 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_blend_equation_separate, )
  RETVAL = GLEW_OES_blend_equation_separate;
  OGLM_CHECK_ERR(GLEW_OES_blend_equation_separate, )
#line 21363 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_blend_func_separate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_blend_func_separate)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7304 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_blend_func_separate, )
  RETVAL = GLEW_OES_blend_func_separate;
  OGLM_CHECK_ERR(GLEW_OES_blend_func_separate, )
#line 21385 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_blend_subtract); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_blend_subtract)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7314 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_blend_subtract, )
  RETVAL = GLEW_OES_blend_subtract;
  OGLM_CHECK_ERR(GLEW_OES_blend_subtract, )
#line 21407 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_byte_coordinates); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_byte_coordinates)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7324 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_byte_coordinates, )
  RETVAL = GLEW_OES_byte_coordinates;
  OGLM_CHECK_ERR(GLEW_OES_byte_coordinates, )
#line 21429 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_compressed_ETC1_RGB8_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_compressed_ETC1_RGB8_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7334 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_compressed_ETC1_RGB8_texture, )
  RETVAL = GLEW_OES_compressed_ETC1_RGB8_texture;
  OGLM_CHECK_ERR(GLEW_OES_compressed_ETC1_RGB8_texture, )
#line 21451 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_compressed_paletted_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_compressed_paletted_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7344 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_compressed_paletted_texture, )
  RETVAL = GLEW_OES_compressed_paletted_texture;
  OGLM_CHECK_ERR(GLEW_OES_compressed_paletted_texture, )
#line 21473 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_copy_image); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_copy_image)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7354 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_copy_image, )
  RETVAL = GLEW_OES_copy_image;
  OGLM_CHECK_ERR(GLEW_OES_copy_image, )
#line 21495 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_depth24); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_depth24)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7364 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_depth24, )
  RETVAL = GLEW_OES_depth24;
  OGLM_CHECK_ERR(GLEW_OES_depth24, )
#line 21517 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_depth32); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_depth32)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7374 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_depth32, )
  RETVAL = GLEW_OES_depth32;
  OGLM_CHECK_ERR(GLEW_OES_depth32, )
#line 21539 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_depth_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_depth_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7384 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_depth_texture, )
  RETVAL = GLEW_OES_depth_texture;
  OGLM_CHECK_ERR(GLEW_OES_depth_texture, )
#line 21561 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_depth_texture_cube_map); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_depth_texture_cube_map)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7394 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_depth_texture_cube_map, )
  RETVAL = GLEW_OES_depth_texture_cube_map;
  OGLM_CHECK_ERR(GLEW_OES_depth_texture_cube_map, )
#line 21583 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_draw_buffers_indexed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_draw_buffers_indexed)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7404 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_draw_buffers_indexed, )
  RETVAL = GLEW_OES_draw_buffers_indexed;
  OGLM_CHECK_ERR(GLEW_OES_draw_buffers_indexed, )
#line 21605 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_draw_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_draw_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7414 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_draw_texture, )
  RETVAL = GLEW_OES_draw_texture;
  OGLM_CHECK_ERR(GLEW_OES_draw_texture, )
#line 21627 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_element_index_uint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_element_index_uint)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7424 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_element_index_uint, )
  RETVAL = GLEW_OES_element_index_uint;
  OGLM_CHECK_ERR(GLEW_OES_element_index_uint, )
#line 21649 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_extended_matrix_palette); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_extended_matrix_palette)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7434 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_extended_matrix_palette, )
  RETVAL = GLEW_OES_extended_matrix_palette;
  OGLM_CHECK_ERR(GLEW_OES_extended_matrix_palette, )
#line 21671 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_fbo_render_mipmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_fbo_render_mipmap)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7444 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_fbo_render_mipmap, )
  RETVAL = GLEW_OES_fbo_render_mipmap;
  OGLM_CHECK_ERR(GLEW_OES_fbo_render_mipmap, )
#line 21693 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_fragment_precision_high); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_fragment_precision_high)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7454 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_fragment_precision_high, )
  RETVAL = GLEW_OES_fragment_precision_high;
  OGLM_CHECK_ERR(GLEW_OES_fragment_precision_high, )
#line 21715 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_framebuffer_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_framebuffer_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7464 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_framebuffer_object, )
  RETVAL = GLEW_OES_framebuffer_object;
  OGLM_CHECK_ERR(GLEW_OES_framebuffer_object, )
#line 21737 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_geometry_point_size); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_geometry_point_size)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7474 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_geometry_point_size, )
  RETVAL = GLEW_OES_geometry_point_size;
  OGLM_CHECK_ERR(GLEW_OES_geometry_point_size, )
#line 21759 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_geometry_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_geometry_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7484 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_geometry_shader, )
  RETVAL = GLEW_OES_geometry_shader;
  OGLM_CHECK_ERR(GLEW_OES_geometry_shader, )
#line 21781 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_get_program_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_get_program_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7494 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_get_program_binary, )
  RETVAL = GLEW_OES_get_program_binary;
  OGLM_CHECK_ERR(GLEW_OES_get_program_binary, )
#line 21803 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_gpu_shader5); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_gpu_shader5)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7504 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_gpu_shader5, )
  RETVAL = GLEW_OES_gpu_shader5;
  OGLM_CHECK_ERR(GLEW_OES_gpu_shader5, )
#line 21825 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_mapbuffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_mapbuffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7514 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_mapbuffer, )
  RETVAL = GLEW_OES_mapbuffer;
  OGLM_CHECK_ERR(GLEW_OES_mapbuffer, )
#line 21847 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_matrix_get); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_matrix_get)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7524 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_matrix_get, )
  RETVAL = GLEW_OES_matrix_get;
  OGLM_CHECK_ERR(GLEW_OES_matrix_get, )
#line 21869 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_matrix_palette); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_matrix_palette)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7534 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_matrix_palette, )
  RETVAL = GLEW_OES_matrix_palette;
  OGLM_CHECK_ERR(GLEW_OES_matrix_palette, )
#line 21891 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_packed_depth_stencil); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_packed_depth_stencil)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7544 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_packed_depth_stencil, )
  RETVAL = GLEW_OES_packed_depth_stencil;
  OGLM_CHECK_ERR(GLEW_OES_packed_depth_stencil, )
#line 21913 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_point_size_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_point_size_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7554 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_point_size_array, )
  RETVAL = GLEW_OES_point_size_array;
  OGLM_CHECK_ERR(GLEW_OES_point_size_array, )
#line 21935 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_point_sprite); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_point_sprite)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7564 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_point_sprite, )
  RETVAL = GLEW_OES_point_sprite;
  OGLM_CHECK_ERR(GLEW_OES_point_sprite, )
#line 21957 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_read_format); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_read_format)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7574 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_read_format, )
  RETVAL = GLEW_OES_read_format;
  OGLM_CHECK_ERR(GLEW_OES_read_format, )
#line 21979 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_required_internalformat); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_required_internalformat)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7584 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_required_internalformat, )
  RETVAL = GLEW_OES_required_internalformat;
  OGLM_CHECK_ERR(GLEW_OES_required_internalformat, )
#line 22001 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_rgb8_rgba8); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_rgb8_rgba8)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7594 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_rgb8_rgba8, )
  RETVAL = GLEW_OES_rgb8_rgba8;
  OGLM_CHECK_ERR(GLEW_OES_rgb8_rgba8, )
#line 22023 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_sample_shading); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_sample_shading)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7604 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_sample_shading, )
  RETVAL = GLEW_OES_sample_shading;
  OGLM_CHECK_ERR(GLEW_OES_sample_shading, )
#line 22045 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_sample_variables); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_sample_variables)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7614 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_sample_variables, )
  RETVAL = GLEW_OES_sample_variables;
  OGLM_CHECK_ERR(GLEW_OES_sample_variables, )
#line 22067 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_shader_image_atomic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_shader_image_atomic)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7624 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_shader_image_atomic, )
  RETVAL = GLEW_OES_shader_image_atomic;
  OGLM_CHECK_ERR(GLEW_OES_shader_image_atomic, )
#line 22089 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_shader_io_blocks); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_shader_io_blocks)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7634 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_shader_io_blocks, )
  RETVAL = GLEW_OES_shader_io_blocks;
  OGLM_CHECK_ERR(GLEW_OES_shader_io_blocks, )
#line 22111 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_shader_multisample_interpolation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_shader_multisample_interpolation)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7644 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_shader_multisample_interpolation, )
  RETVAL = GLEW_OES_shader_multisample_interpolation;
  OGLM_CHECK_ERR(GLEW_OES_shader_multisample_interpolation, )
#line 22133 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_single_precision); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_single_precision)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7654 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_single_precision, )
  RETVAL = GLEW_OES_single_precision;
  OGLM_CHECK_ERR(GLEW_OES_single_precision, )
#line 22155 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_standard_derivatives); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_standard_derivatives)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7664 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_standard_derivatives, )
  RETVAL = GLEW_OES_standard_derivatives;
  OGLM_CHECK_ERR(GLEW_OES_standard_derivatives, )
#line 22177 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_stencil1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_stencil1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7674 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_stencil1, )
  RETVAL = GLEW_OES_stencil1;
  OGLM_CHECK_ERR(GLEW_OES_stencil1, )
#line 22199 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_stencil4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_stencil4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7684 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_stencil4, )
  RETVAL = GLEW_OES_stencil4;
  OGLM_CHECK_ERR(GLEW_OES_stencil4, )
#line 22221 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_stencil8); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_stencil8)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7694 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_stencil8, )
  RETVAL = GLEW_OES_stencil8;
  OGLM_CHECK_ERR(GLEW_OES_stencil8, )
#line 22243 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_surfaceless_context); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_surfaceless_context)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7704 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_surfaceless_context, )
  RETVAL = GLEW_OES_surfaceless_context;
  OGLM_CHECK_ERR(GLEW_OES_surfaceless_context, )
#line 22265 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_tessellation_point_size); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_tessellation_point_size)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7714 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_tessellation_point_size, )
  RETVAL = GLEW_OES_tessellation_point_size;
  OGLM_CHECK_ERR(GLEW_OES_tessellation_point_size, )
#line 22287 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_tessellation_shader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_tessellation_shader)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7724 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_tessellation_shader, )
  RETVAL = GLEW_OES_tessellation_shader;
  OGLM_CHECK_ERR(GLEW_OES_tessellation_shader, )
#line 22309 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_3D); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_3D)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7734 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_3D, )
  RETVAL = GLEW_OES_texture_3D;
  OGLM_CHECK_ERR(GLEW_OES_texture_3D, )
#line 22331 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_border_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_border_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7744 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_border_clamp, )
  RETVAL = GLEW_OES_texture_border_clamp;
  OGLM_CHECK_ERR(GLEW_OES_texture_border_clamp, )
#line 22353 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7754 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_buffer, )
  RETVAL = GLEW_OES_texture_buffer;
  OGLM_CHECK_ERR(GLEW_OES_texture_buffer, )
#line 22375 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_compression_astc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_compression_astc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7764 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_compression_astc, )
  RETVAL = GLEW_OES_texture_compression_astc;
  OGLM_CHECK_ERR(GLEW_OES_texture_compression_astc, )
#line 22397 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_cube_map); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_cube_map)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7774 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_cube_map, )
  RETVAL = GLEW_OES_texture_cube_map;
  OGLM_CHECK_ERR(GLEW_OES_texture_cube_map, )
#line 22419 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_cube_map_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_cube_map_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7784 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_cube_map_array, )
  RETVAL = GLEW_OES_texture_cube_map_array;
  OGLM_CHECK_ERR(GLEW_OES_texture_cube_map_array, )
#line 22441 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_env_crossbar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_env_crossbar)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7794 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_env_crossbar, )
  RETVAL = GLEW_OES_texture_env_crossbar;
  OGLM_CHECK_ERR(GLEW_OES_texture_env_crossbar, )
#line 22463 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_mirrored_repeat); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_mirrored_repeat)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7804 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_mirrored_repeat, )
  RETVAL = GLEW_OES_texture_mirrored_repeat;
  OGLM_CHECK_ERR(GLEW_OES_texture_mirrored_repeat, )
#line 22485 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_npot); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_npot)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7814 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_npot, )
  RETVAL = GLEW_OES_texture_npot;
  OGLM_CHECK_ERR(GLEW_OES_texture_npot, )
#line 22507 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_stencil8); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_stencil8)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7824 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_stencil8, )
  RETVAL = GLEW_OES_texture_stencil8;
  OGLM_CHECK_ERR(GLEW_OES_texture_stencil8, )
#line 22529 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_storage_multisample_2d_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_storage_multisample_2d_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7834 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_storage_multisample_2d_array, )
  RETVAL = GLEW_OES_texture_storage_multisample_2d_array;
  OGLM_CHECK_ERR(GLEW_OES_texture_storage_multisample_2d_array, )
#line 22551 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_view); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_texture_view)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7844 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_view, )
  RETVAL = GLEW_OES_texture_view;
  OGLM_CHECK_ERR(GLEW_OES_texture_view, )
#line 22573 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_vertex_array_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_vertex_array_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7854 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_vertex_array_object, )
  RETVAL = GLEW_OES_vertex_array_object;
  OGLM_CHECK_ERR(GLEW_OES_vertex_array_object, )
#line 22595 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_vertex_half_float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_vertex_half_float)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7864 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_vertex_half_float, )
  RETVAL = GLEW_OES_vertex_half_float;
  OGLM_CHECK_ERR(GLEW_OES_vertex_half_float, )
#line 22617 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_vertex_type_10_10_10_2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OES_vertex_type_10_10_10_2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7874 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_vertex_type_10_10_10_2, )
  RETVAL = GLEW_OES_vertex_type_10_10_10_2;
  OGLM_CHECK_ERR(GLEW_OES_vertex_type_10_10_10_2, )
#line 22639 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OML_interlace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OML_interlace)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7884 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OML_interlace, )
  RETVAL = GLEW_OML_interlace;
  OGLM_CHECK_ERR(GLEW_OML_interlace, )
#line 22661 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OML_resample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OML_resample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7894 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OML_resample, )
  RETVAL = GLEW_OML_resample;
  OGLM_CHECK_ERR(GLEW_OML_resample, )
#line 22683 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OML_subsample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OML_subsample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7904 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OML_subsample, )
  RETVAL = GLEW_OML_subsample;
  OGLM_CHECK_ERR(GLEW_OML_subsample, )
#line 22705 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OVR_multiview); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OVR_multiview)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7914 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OVR_multiview, )
  RETVAL = GLEW_OVR_multiview;
  OGLM_CHECK_ERR(GLEW_OVR_multiview, )
#line 22727 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OVR_multiview2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OVR_multiview2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7924 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OVR_multiview2, )
  RETVAL = GLEW_OVR_multiview2;
  OGLM_CHECK_ERR(GLEW_OVR_multiview2, )
#line 22749 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_OVR_multiview_multisampled_render_to_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_OVR_multiview_multisampled_render_to_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7934 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OVR_multiview_multisampled_render_to_texture, )
  RETVAL = GLEW_OVR_multiview_multisampled_render_to_texture;
  OGLM_CHECK_ERR(GLEW_OVR_multiview_multisampled_render_to_texture, )
#line 22771 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_PGI_misc_hints); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_PGI_misc_hints)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7944 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_PGI_misc_hints, )
  RETVAL = GLEW_PGI_misc_hints;
  OGLM_CHECK_ERR(GLEW_PGI_misc_hints, )
#line 22793 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_PGI_vertex_hints); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_PGI_vertex_hints)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7954 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_PGI_vertex_hints, )
  RETVAL = GLEW_PGI_vertex_hints;
  OGLM_CHECK_ERR(GLEW_PGI_vertex_hints, )
#line 22815 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_YUV_texture_gather); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_YUV_texture_gather)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7964 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_YUV_texture_gather, )
  RETVAL = GLEW_QCOM_YUV_texture_gather;
  OGLM_CHECK_ERR(GLEW_QCOM_YUV_texture_gather, )
#line 22837 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_alpha_test); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_alpha_test)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7974 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_alpha_test, )
  RETVAL = GLEW_QCOM_alpha_test;
  OGLM_CHECK_ERR(GLEW_QCOM_alpha_test, )
#line 22859 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_binning_control); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_binning_control)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7984 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_binning_control, )
  RETVAL = GLEW_QCOM_binning_control;
  OGLM_CHECK_ERR(GLEW_QCOM_binning_control, )
#line 22881 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_driver_control); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_driver_control)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 7994 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_driver_control, )
  RETVAL = GLEW_QCOM_driver_control;
  OGLM_CHECK_ERR(GLEW_QCOM_driver_control, )
#line 22903 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_extended_get); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_extended_get)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8004 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_extended_get, )
  RETVAL = GLEW_QCOM_extended_get;
  OGLM_CHECK_ERR(GLEW_QCOM_extended_get, )
#line 22925 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_extended_get2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_extended_get2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8014 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_extended_get2, )
  RETVAL = GLEW_QCOM_extended_get2;
  OGLM_CHECK_ERR(GLEW_QCOM_extended_get2, )
#line 22947 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_frame_extrapolation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_frame_extrapolation)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8024 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_frame_extrapolation, )
  RETVAL = GLEW_QCOM_frame_extrapolation;
  OGLM_CHECK_ERR(GLEW_QCOM_frame_extrapolation, )
#line 22969 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_framebuffer_foveated); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_framebuffer_foveated)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8034 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_framebuffer_foveated, )
  RETVAL = GLEW_QCOM_framebuffer_foveated;
  OGLM_CHECK_ERR(GLEW_QCOM_framebuffer_foveated, )
#line 22991 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_motion_estimation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_motion_estimation)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8044 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_motion_estimation, )
  RETVAL = GLEW_QCOM_motion_estimation;
  OGLM_CHECK_ERR(GLEW_QCOM_motion_estimation, )
#line 23013 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_perfmon_global_mode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_perfmon_global_mode)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8054 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_perfmon_global_mode, )
  RETVAL = GLEW_QCOM_perfmon_global_mode;
  OGLM_CHECK_ERR(GLEW_QCOM_perfmon_global_mode, )
#line 23035 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_render_sRGB_R8_RG8); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_render_sRGB_R8_RG8)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8064 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_render_sRGB_R8_RG8, )
  RETVAL = GLEW_QCOM_render_sRGB_R8_RG8;
  OGLM_CHECK_ERR(GLEW_QCOM_render_sRGB_R8_RG8, )
#line 23057 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_render_shared_exponent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_render_shared_exponent)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8074 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_render_shared_exponent, )
  RETVAL = GLEW_QCOM_render_shared_exponent;
  OGLM_CHECK_ERR(GLEW_QCOM_render_shared_exponent, )
#line 23079 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_shader_framebuffer_fetch_noncoherent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_shader_framebuffer_fetch_noncoherent)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8084 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_shader_framebuffer_fetch_noncoherent, )
  RETVAL = GLEW_QCOM_shader_framebuffer_fetch_noncoherent;
  OGLM_CHECK_ERR(GLEW_QCOM_shader_framebuffer_fetch_noncoherent, )
#line 23101 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_shader_framebuffer_fetch_rate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_shader_framebuffer_fetch_rate)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8094 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_shader_framebuffer_fetch_rate, )
  RETVAL = GLEW_QCOM_shader_framebuffer_fetch_rate;
  OGLM_CHECK_ERR(GLEW_QCOM_shader_framebuffer_fetch_rate, )
#line 23123 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_shading_rate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_shading_rate)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8104 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_shading_rate, )
  RETVAL = GLEW_QCOM_shading_rate;
  OGLM_CHECK_ERR(GLEW_QCOM_shading_rate, )
#line 23145 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_texture_foveated); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_texture_foveated)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8114 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated, )
  RETVAL = GLEW_QCOM_texture_foveated;
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated, )
#line 23167 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_texture_foveated2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_texture_foveated2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8124 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated2, )
  RETVAL = GLEW_QCOM_texture_foveated2;
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated2, )
#line 23189 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_texture_foveated_subsampled_layout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_texture_foveated_subsampled_layout)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8134 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated_subsampled_layout, )
  RETVAL = GLEW_QCOM_texture_foveated_subsampled_layout;
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated_subsampled_layout, )
#line 23211 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_texture_lod_bias); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_texture_lod_bias)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8144 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_texture_lod_bias, )
  RETVAL = GLEW_QCOM_texture_lod_bias;
  OGLM_CHECK_ERR(GLEW_QCOM_texture_lod_bias, )
#line 23233 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_tiled_rendering); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_tiled_rendering)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8154 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_tiled_rendering, )
  RETVAL = GLEW_QCOM_tiled_rendering;
  OGLM_CHECK_ERR(GLEW_QCOM_tiled_rendering, )
#line 23255 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_writeonly_rendering); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_writeonly_rendering)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8164 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_writeonly_rendering, )
  RETVAL = GLEW_QCOM_writeonly_rendering;
  OGLM_CHECK_ERR(GLEW_QCOM_writeonly_rendering, )
#line 23277 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_ycbcr_degamma); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_QCOM_ycbcr_degamma)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8174 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_ycbcr_degamma, )
  RETVAL = GLEW_QCOM_ycbcr_degamma;
  OGLM_CHECK_ERR(GLEW_QCOM_ycbcr_degamma, )
#line 23299 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_ES1_0_compatibility); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_ES1_0_compatibility)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8184 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_ES1_0_compatibility, )
  RETVAL = GLEW_REGAL_ES1_0_compatibility;
  OGLM_CHECK_ERR(GLEW_REGAL_ES1_0_compatibility, )
#line 23321 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_ES1_1_compatibility); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_ES1_1_compatibility)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8194 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_ES1_1_compatibility, )
  RETVAL = GLEW_REGAL_ES1_1_compatibility;
  OGLM_CHECK_ERR(GLEW_REGAL_ES1_1_compatibility, )
#line 23343 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_enable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_enable)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8204 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_enable, )
  RETVAL = GLEW_REGAL_enable;
  OGLM_CHECK_ERR(GLEW_REGAL_enable, )
#line 23365 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_error_string); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_error_string)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8214 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_error_string, )
  RETVAL = GLEW_REGAL_error_string;
  OGLM_CHECK_ERR(GLEW_REGAL_error_string, )
#line 23387 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_extension_query); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_extension_query)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8224 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_extension_query, )
  RETVAL = GLEW_REGAL_extension_query;
  OGLM_CHECK_ERR(GLEW_REGAL_extension_query, )
#line 23409 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_log); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_log)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8234 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_log, )
  RETVAL = GLEW_REGAL_log;
  OGLM_CHECK_ERR(GLEW_REGAL_log, )
#line 23431 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_proc_address); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_REGAL_proc_address)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8244 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_proc_address, )
  RETVAL = GLEW_REGAL_proc_address;
  OGLM_CHECK_ERR(GLEW_REGAL_proc_address, )
#line 23453 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_REND_screen_coordinates); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_REND_screen_coordinates)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8254 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REND_screen_coordinates, )
  RETVAL = GLEW_REND_screen_coordinates;
  OGLM_CHECK_ERR(GLEW_REND_screen_coordinates, )
#line 23475 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_S3_s3tc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_S3_s3tc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8264 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_S3_s3tc, )
  RETVAL = GLEW_S3_s3tc;
  OGLM_CHECK_ERR(GLEW_S3_s3tc, )
#line 23497 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_clip_band_hint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_clip_band_hint)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8274 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_clip_band_hint, )
  RETVAL = GLEW_SGIS_clip_band_hint;
  OGLM_CHECK_ERR(GLEW_SGIS_clip_band_hint, )
#line 23519 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_color_range); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_color_range)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8284 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_color_range, )
  RETVAL = GLEW_SGIS_color_range;
  OGLM_CHECK_ERR(GLEW_SGIS_color_range, )
#line 23541 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_detail_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_detail_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8294 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_detail_texture, )
  RETVAL = GLEW_SGIS_detail_texture;
  OGLM_CHECK_ERR(GLEW_SGIS_detail_texture, )
#line 23563 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_fog_function); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_fog_function)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8304 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_fog_function, )
  RETVAL = GLEW_SGIS_fog_function;
  OGLM_CHECK_ERR(GLEW_SGIS_fog_function, )
#line 23585 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_generate_mipmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_generate_mipmap)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8314 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_generate_mipmap, )
  RETVAL = GLEW_SGIS_generate_mipmap;
  OGLM_CHECK_ERR(GLEW_SGIS_generate_mipmap, )
#line 23607 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_line_texgen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_line_texgen)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8324 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_line_texgen, )
  RETVAL = GLEW_SGIS_line_texgen;
  OGLM_CHECK_ERR(GLEW_SGIS_line_texgen, )
#line 23629 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8334 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_multisample, )
  RETVAL = GLEW_SGIS_multisample;
  OGLM_CHECK_ERR(GLEW_SGIS_multisample, )
#line 23651 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_multitexture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_multitexture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8344 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_multitexture, )
  RETVAL = GLEW_SGIS_multitexture;
  OGLM_CHECK_ERR(GLEW_SGIS_multitexture, )
#line 23673 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_pixel_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_pixel_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8354 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_pixel_texture, )
  RETVAL = GLEW_SGIS_pixel_texture;
  OGLM_CHECK_ERR(GLEW_SGIS_pixel_texture, )
#line 23695 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_point_line_texgen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_point_line_texgen)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8364 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_point_line_texgen, )
  RETVAL = GLEW_SGIS_point_line_texgen;
  OGLM_CHECK_ERR(GLEW_SGIS_point_line_texgen, )
#line 23717 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_shared_multisample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_shared_multisample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8374 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_shared_multisample, )
  RETVAL = GLEW_SGIS_shared_multisample;
  OGLM_CHECK_ERR(GLEW_SGIS_shared_multisample, )
#line 23739 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_sharpen_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_sharpen_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8384 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_sharpen_texture, )
  RETVAL = GLEW_SGIS_sharpen_texture;
  OGLM_CHECK_ERR(GLEW_SGIS_sharpen_texture, )
#line 23761 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture4D); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture4D)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8394 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture4D, )
  RETVAL = GLEW_SGIS_texture4D;
  OGLM_CHECK_ERR(GLEW_SGIS_texture4D, )
#line 23783 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture_border_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture_border_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8404 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture_border_clamp, )
  RETVAL = GLEW_SGIS_texture_border_clamp;
  OGLM_CHECK_ERR(GLEW_SGIS_texture_border_clamp, )
#line 23805 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture_edge_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture_edge_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8414 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture_edge_clamp, )
  RETVAL = GLEW_SGIS_texture_edge_clamp;
  OGLM_CHECK_ERR(GLEW_SGIS_texture_edge_clamp, )
#line 23827 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture_filter4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture_filter4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8424 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture_filter4, )
  RETVAL = GLEW_SGIS_texture_filter4;
  OGLM_CHECK_ERR(GLEW_SGIS_texture_filter4, )
#line 23849 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture_lod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture_lod)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8434 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture_lod, )
  RETVAL = GLEW_SGIS_texture_lod;
  OGLM_CHECK_ERR(GLEW_SGIS_texture_lod, )
#line 23871 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture_select); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIS_texture_select)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8444 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture_select, )
  RETVAL = GLEW_SGIS_texture_select;
  OGLM_CHECK_ERR(GLEW_SGIS_texture_select, )
#line 23893 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_async); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_async)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8454 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_async, )
  RETVAL = GLEW_SGIX_async;
  OGLM_CHECK_ERR(GLEW_SGIX_async, )
#line 23915 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_async_histogram); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_async_histogram)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8464 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_async_histogram, )
  RETVAL = GLEW_SGIX_async_histogram;
  OGLM_CHECK_ERR(GLEW_SGIX_async_histogram, )
#line 23937 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_async_pixel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_async_pixel)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8474 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_async_pixel, )
  RETVAL = GLEW_SGIX_async_pixel;
  OGLM_CHECK_ERR(GLEW_SGIX_async_pixel, )
#line 23959 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_bali_g_instruments); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_bali_g_instruments)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8484 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_bali_g_instruments, )
  RETVAL = GLEW_SGIX_bali_g_instruments;
  OGLM_CHECK_ERR(GLEW_SGIX_bali_g_instruments, )
#line 23981 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_bali_r_instruments); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_bali_r_instruments)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8494 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_bali_r_instruments, )
  RETVAL = GLEW_SGIX_bali_r_instruments;
  OGLM_CHECK_ERR(GLEW_SGIX_bali_r_instruments, )
#line 24003 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_bali_timer_instruments); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_bali_timer_instruments)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8504 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_bali_timer_instruments, )
  RETVAL = GLEW_SGIX_bali_timer_instruments;
  OGLM_CHECK_ERR(GLEW_SGIX_bali_timer_instruments, )
#line 24025 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_blend_alpha_minmax); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_blend_alpha_minmax)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8514 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_blend_alpha_minmax, )
  RETVAL = GLEW_SGIX_blend_alpha_minmax;
  OGLM_CHECK_ERR(GLEW_SGIX_blend_alpha_minmax, )
#line 24047 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_blend_cadd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_blend_cadd)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8524 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_blend_cadd, )
  RETVAL = GLEW_SGIX_blend_cadd;
  OGLM_CHECK_ERR(GLEW_SGIX_blend_cadd, )
#line 24069 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_blend_cmultiply); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_blend_cmultiply)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8534 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_blend_cmultiply, )
  RETVAL = GLEW_SGIX_blend_cmultiply;
  OGLM_CHECK_ERR(GLEW_SGIX_blend_cmultiply, )
#line 24091 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_calligraphic_fragment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_calligraphic_fragment)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8544 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_calligraphic_fragment, )
  RETVAL = GLEW_SGIX_calligraphic_fragment;
  OGLM_CHECK_ERR(GLEW_SGIX_calligraphic_fragment, )
#line 24113 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_clipmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_clipmap)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8554 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_clipmap, )
  RETVAL = GLEW_SGIX_clipmap;
  OGLM_CHECK_ERR(GLEW_SGIX_clipmap, )
#line 24135 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_color_matrix_accuracy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_color_matrix_accuracy)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8564 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_color_matrix_accuracy, )
  RETVAL = GLEW_SGIX_color_matrix_accuracy;
  OGLM_CHECK_ERR(GLEW_SGIX_color_matrix_accuracy, )
#line 24157 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_color_table_index_mode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_color_table_index_mode)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8574 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_color_table_index_mode, )
  RETVAL = GLEW_SGIX_color_table_index_mode;
  OGLM_CHECK_ERR(GLEW_SGIX_color_table_index_mode, )
#line 24179 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_complex_polar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_complex_polar)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8584 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_complex_polar, )
  RETVAL = GLEW_SGIX_complex_polar;
  OGLM_CHECK_ERR(GLEW_SGIX_complex_polar, )
#line 24201 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_convolution_accuracy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_convolution_accuracy)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8594 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_convolution_accuracy, )
  RETVAL = GLEW_SGIX_convolution_accuracy;
  OGLM_CHECK_ERR(GLEW_SGIX_convolution_accuracy, )
#line 24223 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_cube_map); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_cube_map)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8604 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_cube_map, )
  RETVAL = GLEW_SGIX_cube_map;
  OGLM_CHECK_ERR(GLEW_SGIX_cube_map, )
#line 24245 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_cylinder_texgen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_cylinder_texgen)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8614 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_cylinder_texgen, )
  RETVAL = GLEW_SGIX_cylinder_texgen;
  OGLM_CHECK_ERR(GLEW_SGIX_cylinder_texgen, )
#line 24267 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_datapipe); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_datapipe)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8624 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_datapipe, )
  RETVAL = GLEW_SGIX_datapipe;
  OGLM_CHECK_ERR(GLEW_SGIX_datapipe, )
#line 24289 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_decimation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_decimation)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8634 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_decimation, )
  RETVAL = GLEW_SGIX_decimation;
  OGLM_CHECK_ERR(GLEW_SGIX_decimation, )
#line 24311 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_depth_pass_instrument); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_depth_pass_instrument)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8644 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_depth_pass_instrument, )
  RETVAL = GLEW_SGIX_depth_pass_instrument;
  OGLM_CHECK_ERR(GLEW_SGIX_depth_pass_instrument, )
#line 24333 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_depth_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_depth_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8654 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_depth_texture, )
  RETVAL = GLEW_SGIX_depth_texture;
  OGLM_CHECK_ERR(GLEW_SGIX_depth_texture, )
#line 24355 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_dvc); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_dvc)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8664 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_dvc, )
  RETVAL = GLEW_SGIX_dvc;
  OGLM_CHECK_ERR(GLEW_SGIX_dvc, )
#line 24377 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_flush_raster); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_flush_raster)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8674 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_flush_raster, )
  RETVAL = GLEW_SGIX_flush_raster;
  OGLM_CHECK_ERR(GLEW_SGIX_flush_raster, )
#line 24399 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_blend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_blend)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8684 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_blend, )
  RETVAL = GLEW_SGIX_fog_blend;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_blend, )
#line 24421 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_factor_to_alpha); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_factor_to_alpha)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8694 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_factor_to_alpha, )
  RETVAL = GLEW_SGIX_fog_factor_to_alpha;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_factor_to_alpha, )
#line 24443 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_layers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_layers)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8704 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_layers, )
  RETVAL = GLEW_SGIX_fog_layers;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_layers, )
#line 24465 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_offset); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_offset)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8714 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_offset, )
  RETVAL = GLEW_SGIX_fog_offset;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_offset, )
#line 24487 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_patchy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_patchy)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8724 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_patchy, )
  RETVAL = GLEW_SGIX_fog_patchy;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_patchy, )
#line 24509 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_scale); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_scale)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8734 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_scale, )
  RETVAL = GLEW_SGIX_fog_scale;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_scale, )
#line 24531 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fog_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8744 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_texture, )
  RETVAL = GLEW_SGIX_fog_texture;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_texture, )
#line 24553 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fragment_lighting_space); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fragment_lighting_space)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8754 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fragment_lighting_space, )
  RETVAL = GLEW_SGIX_fragment_lighting_space;
  OGLM_CHECK_ERR(GLEW_SGIX_fragment_lighting_space, )
#line 24575 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fragment_specular_lighting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fragment_specular_lighting)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8764 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fragment_specular_lighting, )
  RETVAL = GLEW_SGIX_fragment_specular_lighting;
  OGLM_CHECK_ERR(GLEW_SGIX_fragment_specular_lighting, )
#line 24597 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fragments_instrument); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_fragments_instrument)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8774 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fragments_instrument, )
  RETVAL = GLEW_SGIX_fragments_instrument;
  OGLM_CHECK_ERR(GLEW_SGIX_fragments_instrument, )
#line 24619 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_framezoom); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_framezoom)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8784 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_framezoom, )
  RETVAL = GLEW_SGIX_framezoom;
  OGLM_CHECK_ERR(GLEW_SGIX_framezoom, )
#line 24641 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_icc_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_icc_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8794 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_icc_texture, )
  RETVAL = GLEW_SGIX_icc_texture;
  OGLM_CHECK_ERR(GLEW_SGIX_icc_texture, )
#line 24663 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_igloo_interface); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_igloo_interface)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8804 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_igloo_interface, )
  RETVAL = GLEW_SGIX_igloo_interface;
  OGLM_CHECK_ERR(GLEW_SGIX_igloo_interface, )
#line 24685 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_image_compression); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_image_compression)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8814 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_image_compression, )
  RETVAL = GLEW_SGIX_image_compression;
  OGLM_CHECK_ERR(GLEW_SGIX_image_compression, )
#line 24707 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_impact_pixel_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_impact_pixel_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8824 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_impact_pixel_texture, )
  RETVAL = GLEW_SGIX_impact_pixel_texture;
  OGLM_CHECK_ERR(GLEW_SGIX_impact_pixel_texture, )
#line 24729 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_instrument_error); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_instrument_error)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8834 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_instrument_error, )
  RETVAL = GLEW_SGIX_instrument_error;
  OGLM_CHECK_ERR(GLEW_SGIX_instrument_error, )
#line 24751 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_interlace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_interlace)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8844 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_interlace, )
  RETVAL = GLEW_SGIX_interlace;
  OGLM_CHECK_ERR(GLEW_SGIX_interlace, )
#line 24773 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_ir_instrument1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_ir_instrument1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8854 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_ir_instrument1, )
  RETVAL = GLEW_SGIX_ir_instrument1;
  OGLM_CHECK_ERR(GLEW_SGIX_ir_instrument1, )
#line 24795 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_line_quality_hint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_line_quality_hint)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8864 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_line_quality_hint, )
  RETVAL = GLEW_SGIX_line_quality_hint;
  OGLM_CHECK_ERR(GLEW_SGIX_line_quality_hint, )
#line 24817 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_list_priority); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_list_priority)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8874 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_list_priority, )
  RETVAL = GLEW_SGIX_list_priority;
  OGLM_CHECK_ERR(GLEW_SGIX_list_priority, )
#line 24839 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_mpeg1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_mpeg1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8884 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_mpeg1, )
  RETVAL = GLEW_SGIX_mpeg1;
  OGLM_CHECK_ERR(GLEW_SGIX_mpeg1, )
#line 24861 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_mpeg2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_mpeg2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8894 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_mpeg2, )
  RETVAL = GLEW_SGIX_mpeg2;
  OGLM_CHECK_ERR(GLEW_SGIX_mpeg2, )
#line 24883 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_nonlinear_lighting_pervertex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_nonlinear_lighting_pervertex)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8904 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_nonlinear_lighting_pervertex, )
  RETVAL = GLEW_SGIX_nonlinear_lighting_pervertex;
  OGLM_CHECK_ERR(GLEW_SGIX_nonlinear_lighting_pervertex, )
#line 24905 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_nurbs_eval); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_nurbs_eval)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8914 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_nurbs_eval, )
  RETVAL = GLEW_SGIX_nurbs_eval;
  OGLM_CHECK_ERR(GLEW_SGIX_nurbs_eval, )
#line 24927 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_occlusion_instrument); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_occlusion_instrument)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8924 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_occlusion_instrument, )
  RETVAL = GLEW_SGIX_occlusion_instrument;
  OGLM_CHECK_ERR(GLEW_SGIX_occlusion_instrument, )
#line 24949 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_packed_6bytes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_packed_6bytes)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8934 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_packed_6bytes, )
  RETVAL = GLEW_SGIX_packed_6bytes;
  OGLM_CHECK_ERR(GLEW_SGIX_packed_6bytes, )
#line 24971 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_pixel_texture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_pixel_texture)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8944 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture, )
  RETVAL = GLEW_SGIX_pixel_texture;
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture, )
#line 24993 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_pixel_texture_bits); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_pixel_texture_bits)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8954 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture_bits, )
  RETVAL = GLEW_SGIX_pixel_texture_bits;
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture_bits, )
#line 25015 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_pixel_texture_lod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_pixel_texture_lod)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8964 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture_lod, )
  RETVAL = GLEW_SGIX_pixel_texture_lod;
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture_lod, )
#line 25037 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_pixel_tiles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_pixel_tiles)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8974 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_tiles, )
  RETVAL = GLEW_SGIX_pixel_tiles;
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_tiles, )
#line 25059 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_polynomial_ffd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_polynomial_ffd)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8984 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_polynomial_ffd, )
  RETVAL = GLEW_SGIX_polynomial_ffd;
  OGLM_CHECK_ERR(GLEW_SGIX_polynomial_ffd, )
#line 25081 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_quad_mesh); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_quad_mesh)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 8994 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_quad_mesh, )
  RETVAL = GLEW_SGIX_quad_mesh;
  OGLM_CHECK_ERR(GLEW_SGIX_quad_mesh, )
#line 25103 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_reference_plane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_reference_plane)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9004 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_reference_plane, )
  RETVAL = GLEW_SGIX_reference_plane;
  OGLM_CHECK_ERR(GLEW_SGIX_reference_plane, )
#line 25125 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_resample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_resample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9014 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_resample, )
  RETVAL = GLEW_SGIX_resample;
  OGLM_CHECK_ERR(GLEW_SGIX_resample, )
#line 25147 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_scalebias_hint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_scalebias_hint)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9024 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_scalebias_hint, )
  RETVAL = GLEW_SGIX_scalebias_hint;
  OGLM_CHECK_ERR(GLEW_SGIX_scalebias_hint, )
#line 25169 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_shadow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_shadow)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9034 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_shadow, )
  RETVAL = GLEW_SGIX_shadow;
  OGLM_CHECK_ERR(GLEW_SGIX_shadow, )
#line 25191 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_shadow_ambient); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_shadow_ambient)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9044 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_shadow_ambient, )
  RETVAL = GLEW_SGIX_shadow_ambient;
  OGLM_CHECK_ERR(GLEW_SGIX_shadow_ambient, )
#line 25213 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_slim); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_slim)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9054 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_slim, )
  RETVAL = GLEW_SGIX_slim;
  OGLM_CHECK_ERR(GLEW_SGIX_slim, )
#line 25235 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_spotlight_cutoff); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_spotlight_cutoff)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9064 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_spotlight_cutoff, )
  RETVAL = GLEW_SGIX_spotlight_cutoff;
  OGLM_CHECK_ERR(GLEW_SGIX_spotlight_cutoff, )
#line 25257 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_sprite); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_sprite)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9074 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_sprite, )
  RETVAL = GLEW_SGIX_sprite;
  OGLM_CHECK_ERR(GLEW_SGIX_sprite, )
#line 25279 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_subdiv_patch); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_subdiv_patch)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9084 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_subdiv_patch, )
  RETVAL = GLEW_SGIX_subdiv_patch;
  OGLM_CHECK_ERR(GLEW_SGIX_subdiv_patch, )
#line 25301 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_subsample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_subsample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9094 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_subsample, )
  RETVAL = GLEW_SGIX_subsample;
  OGLM_CHECK_ERR(GLEW_SGIX_subsample, )
#line 25323 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_tag_sample_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_tag_sample_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9104 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_tag_sample_buffer, )
  RETVAL = GLEW_SGIX_tag_sample_buffer;
  OGLM_CHECK_ERR(GLEW_SGIX_tag_sample_buffer, )
#line 25345 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_add_env); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_add_env)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9114 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_add_env, )
  RETVAL = GLEW_SGIX_texture_add_env;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_add_env, )
#line 25367 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_coordinate_clamp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_coordinate_clamp)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9124 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_coordinate_clamp, )
  RETVAL = GLEW_SGIX_texture_coordinate_clamp;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_coordinate_clamp, )
#line 25389 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_lod_bias); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_lod_bias)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9134 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_lod_bias, )
  RETVAL = GLEW_SGIX_texture_lod_bias;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_lod_bias, )
#line 25411 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_mipmap_anisotropic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_mipmap_anisotropic)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9144 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_mipmap_anisotropic, )
  RETVAL = GLEW_SGIX_texture_mipmap_anisotropic;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_mipmap_anisotropic, )
#line 25433 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_multi_buffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_multi_buffer)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9154 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_multi_buffer, )
  RETVAL = GLEW_SGIX_texture_multi_buffer;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_multi_buffer, )
#line 25455 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_phase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_phase)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9164 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_phase, )
  RETVAL = GLEW_SGIX_texture_phase;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_phase, )
#line 25477 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_range); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_range)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9174 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_range, )
  RETVAL = GLEW_SGIX_texture_range;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_range, )
#line 25499 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_scale_bias); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_scale_bias)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9184 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_scale_bias, )
  RETVAL = GLEW_SGIX_texture_scale_bias;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_scale_bias, )
#line 25521 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_supersample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_texture_supersample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9194 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_supersample, )
  RETVAL = GLEW_SGIX_texture_supersample;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_supersample, )
#line 25543 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_vector_ops); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_vector_ops)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9204 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_vector_ops, )
  RETVAL = GLEW_SGIX_vector_ops;
  OGLM_CHECK_ERR(GLEW_SGIX_vector_ops, )
#line 25565 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_vertex_array_object); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_vertex_array_object)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9214 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_array_object, )
  RETVAL = GLEW_SGIX_vertex_array_object;
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_array_object, )
#line 25587 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_vertex_preclip); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_vertex_preclip)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9224 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_preclip, )
  RETVAL = GLEW_SGIX_vertex_preclip;
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_preclip, )
#line 25609 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_vertex_preclip_hint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_vertex_preclip_hint)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9234 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_preclip_hint, )
  RETVAL = GLEW_SGIX_vertex_preclip_hint;
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_preclip_hint, )
#line 25631 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_ycrcb); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_ycrcb)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9244 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcb, )
  RETVAL = GLEW_SGIX_ycrcb;
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcb, )
#line 25653 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_ycrcb_subsample); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_ycrcb_subsample)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9254 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcb_subsample, )
  RETVAL = GLEW_SGIX_ycrcb_subsample;
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcb_subsample, )
#line 25675 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_ycrcba); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGIX_ycrcba)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9264 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcba, )
  RETVAL = GLEW_SGIX_ycrcba;
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcba, )
#line 25697 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_color_matrix); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_color_matrix)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9274 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_color_matrix, )
  RETVAL = GLEW_SGI_color_matrix;
  OGLM_CHECK_ERR(GLEW_SGI_color_matrix, )
#line 25719 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_color_table); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_color_table)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9284 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_color_table, )
  RETVAL = GLEW_SGI_color_table;
  OGLM_CHECK_ERR(GLEW_SGI_color_table, )
#line 25741 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_complex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_complex)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9294 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_complex, )
  RETVAL = GLEW_SGI_complex;
  OGLM_CHECK_ERR(GLEW_SGI_complex, )
#line 25763 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_complex_type); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_complex_type)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9304 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_complex_type, )
  RETVAL = GLEW_SGI_complex_type;
  OGLM_CHECK_ERR(GLEW_SGI_complex_type, )
#line 25785 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_fft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_fft)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9314 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_fft, )
  RETVAL = GLEW_SGI_fft;
  OGLM_CHECK_ERR(GLEW_SGI_fft, )
#line 25807 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_texture_color_table); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SGI_texture_color_table)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9324 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_texture_color_table, )
  RETVAL = GLEW_SGI_texture_color_table;
  OGLM_CHECK_ERR(GLEW_SGI_texture_color_table, )
#line 25829 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SUNX_constant_data); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SUNX_constant_data)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9334 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUNX_constant_data, )
  RETVAL = GLEW_SUNX_constant_data;
  OGLM_CHECK_ERR(GLEW_SUNX_constant_data, )
#line 25851 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_convolution_border_modes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_convolution_border_modes)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9344 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_convolution_border_modes, )
  RETVAL = GLEW_SUN_convolution_border_modes;
  OGLM_CHECK_ERR(GLEW_SUN_convolution_border_modes, )
#line 25873 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_global_alpha); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_global_alpha)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9354 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_global_alpha, )
  RETVAL = GLEW_SUN_global_alpha;
  OGLM_CHECK_ERR(GLEW_SUN_global_alpha, )
#line 25895 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_mesh_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_mesh_array)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9364 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_mesh_array, )
  RETVAL = GLEW_SUN_mesh_array;
  OGLM_CHECK_ERR(GLEW_SUN_mesh_array, )
#line 25917 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_read_video_pixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_read_video_pixels)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9374 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_read_video_pixels, )
  RETVAL = GLEW_SUN_read_video_pixels;
  OGLM_CHECK_ERR(GLEW_SUN_read_video_pixels, )
#line 25939 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_slice_accum); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_slice_accum)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9384 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_slice_accum, )
  RETVAL = GLEW_SUN_slice_accum;
  OGLM_CHECK_ERR(GLEW_SUN_slice_accum, )
#line 25961 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_triangle_list); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_triangle_list)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9394 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_triangle_list, )
  RETVAL = GLEW_SUN_triangle_list;
  OGLM_CHECK_ERR(GLEW_SUN_triangle_list, )
#line 25983 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_vertex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_SUN_vertex)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9404 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_vertex, )
  RETVAL = GLEW_SUN_vertex;
  OGLM_CHECK_ERR(GLEW_SUN_vertex, )
#line 26005 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9414 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_1, )
  RETVAL = GLEW_VERSION_1_1;
  OGLM_CHECK_ERR(GLEW_VERSION_1_1, )
#line 26027 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9424 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_2, )
  RETVAL = GLEW_VERSION_1_2;
  OGLM_CHECK_ERR(GLEW_VERSION_1_2, )
#line 26049 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_2_1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_2_1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9434 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_2_1, )
  RETVAL = GLEW_VERSION_1_2_1;
  OGLM_CHECK_ERR(GLEW_VERSION_1_2_1, )
#line 26071 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9444 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_3, )
  RETVAL = GLEW_VERSION_1_3;
  OGLM_CHECK_ERR(GLEW_VERSION_1_3, )
#line 26093 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9454 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_4, )
  RETVAL = GLEW_VERSION_1_4;
  OGLM_CHECK_ERR(GLEW_VERSION_1_4, )
#line 26115 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_5); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_1_5)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9464 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_5, )
  RETVAL = GLEW_VERSION_1_5;
  OGLM_CHECK_ERR(GLEW_VERSION_1_5, )
#line 26137 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_2_0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_2_0)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9474 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_2_0, )
  RETVAL = GLEW_VERSION_2_0;
  OGLM_CHECK_ERR(GLEW_VERSION_2_0, )
#line 26159 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_2_1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_2_1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9484 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_2_1, )
  RETVAL = GLEW_VERSION_2_1;
  OGLM_CHECK_ERR(GLEW_VERSION_2_1, )
#line 26181 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_3_0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_3_0)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9494 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_3_0, )
  RETVAL = GLEW_VERSION_3_0;
  OGLM_CHECK_ERR(GLEW_VERSION_3_0, )
#line 26203 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_3_1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_3_1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9504 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_3_1, )
  RETVAL = GLEW_VERSION_3_1;
  OGLM_CHECK_ERR(GLEW_VERSION_3_1, )
#line 26225 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_3_2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_3_2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9514 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_3_2, )
  RETVAL = GLEW_VERSION_3_2;
  OGLM_CHECK_ERR(GLEW_VERSION_3_2, )
#line 26247 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_3_3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_3_3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9524 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_3_3, )
  RETVAL = GLEW_VERSION_3_3;
  OGLM_CHECK_ERR(GLEW_VERSION_3_3, )
#line 26269 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_0)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9534 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_0, )
  RETVAL = GLEW_VERSION_4_0;
  OGLM_CHECK_ERR(GLEW_VERSION_4_0, )
#line 26291 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_1)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9544 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_1, )
  RETVAL = GLEW_VERSION_4_1;
  OGLM_CHECK_ERR(GLEW_VERSION_4_1, )
#line 26313 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_2)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9554 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_2, )
  RETVAL = GLEW_VERSION_4_2;
  OGLM_CHECK_ERR(GLEW_VERSION_4_2, )
#line 26335 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_3); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_3)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9564 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_3, )
  RETVAL = GLEW_VERSION_4_3;
  OGLM_CHECK_ERR(GLEW_VERSION_4_3, )
#line 26357 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_4); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_4)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9574 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_4, )
  RETVAL = GLEW_VERSION_4_4;
  OGLM_CHECK_ERR(GLEW_VERSION_4_4, )
#line 26379 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_5); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_5)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9584 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_5, )
  RETVAL = GLEW_VERSION_4_5;
  OGLM_CHECK_ERR(GLEW_VERSION_4_5, )
#line 26401 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_6); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VERSION_4_6)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9594 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_6, )
  RETVAL = GLEW_VERSION_4_6;
  OGLM_CHECK_ERR(GLEW_VERSION_4_6, )
#line 26423 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_VIV_shader_binary); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_VIV_shader_binary)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9604 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VIV_shader_binary, )
  RETVAL = GLEW_VIV_shader_binary;
  OGLM_CHECK_ERR(GLEW_VIV_shader_binary, )
#line 26445 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_WIN_phong_shading); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_WIN_phong_shading)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9614 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_WIN_phong_shading, )
  RETVAL = GLEW_WIN_phong_shading;
  OGLM_CHECK_ERR(GLEW_WIN_phong_shading, )
#line 26467 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_WIN_scene_markerXXX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_WIN_scene_markerXXX)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9624 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_WIN_scene_markerXXX, )
  RETVAL = GLEW_WIN_scene_markerXXX;
  OGLM_CHECK_ERR(GLEW_WIN_scene_markerXXX, )
#line 26489 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_WIN_specular_fog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_WIN_specular_fog)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9634 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_WIN_specular_fog, )
  RETVAL = GLEW_WIN_specular_fog;
  OGLM_CHECK_ERR(GLEW_WIN_specular_fog, )
#line 26511 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_OpenGL__Modern_GLEW_WIN_swap_hint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_OpenGL__Modern_GLEW_WIN_swap_hint)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	GLboolean	RETVAL;
	dXSTARG;
#line 9644 "lib/OpenGL/Modern/../../../auto-xs-var.inc"
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_WIN_swap_hint, )
  RETVAL = GLEW_WIN_swap_hint;
  OGLM_CHECK_ERR(GLEW_WIN_swap_hint, )
#line 26533 "lib/OpenGL/Modern/Const.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Const.xs' from '../../../auto-xs-var.inc' */

#ifdef __cplusplus
extern "C" {
#endif
XS_EXTERNAL(boot_OpenGL__Modern__Const); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_OpenGL__Modern__Const)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

        newXS_deffile("OpenGL::Modern::enum2name", XS_OpenGL__Modern_enum2name);
        newXS_deffile("OpenGL::Modern::GLEW_3DFX_multisample", XS_OpenGL__Modern_GLEW_3DFX_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_3DFX_tbuffer", XS_OpenGL__Modern_GLEW_3DFX_tbuffer);
        newXS_deffile("OpenGL::Modern::GLEW_3DFX_texture_compression_FXT1", XS_OpenGL__Modern_GLEW_3DFX_texture_compression_FXT1);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_blend_minmax_factor", XS_OpenGL__Modern_GLEW_AMD_blend_minmax_factor);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_compressed_3DC_texture", XS_OpenGL__Modern_GLEW_AMD_compressed_3DC_texture);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_compressed_ATC_texture", XS_OpenGL__Modern_GLEW_AMD_compressed_ATC_texture);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_conservative_depth", XS_OpenGL__Modern_GLEW_AMD_conservative_depth);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_debug_output", XS_OpenGL__Modern_GLEW_AMD_debug_output);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_depth_clamp_separate", XS_OpenGL__Modern_GLEW_AMD_depth_clamp_separate);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_draw_buffers_blend", XS_OpenGL__Modern_GLEW_AMD_draw_buffers_blend);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_framebuffer_multisample_advanced", XS_OpenGL__Modern_GLEW_AMD_framebuffer_multisample_advanced);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_framebuffer_sample_positions", XS_OpenGL__Modern_GLEW_AMD_framebuffer_sample_positions);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_gcn_shader", XS_OpenGL__Modern_GLEW_AMD_gcn_shader);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_gpu_shader_half_float", XS_OpenGL__Modern_GLEW_AMD_gpu_shader_half_float);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_gpu_shader_half_float_fetch", XS_OpenGL__Modern_GLEW_AMD_gpu_shader_half_float_fetch);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_gpu_shader_int16", XS_OpenGL__Modern_GLEW_AMD_gpu_shader_int16);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_gpu_shader_int64", XS_OpenGL__Modern_GLEW_AMD_gpu_shader_int64);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_interleaved_elements", XS_OpenGL__Modern_GLEW_AMD_interleaved_elements);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_multi_draw_indirect", XS_OpenGL__Modern_GLEW_AMD_multi_draw_indirect);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_name_gen_delete", XS_OpenGL__Modern_GLEW_AMD_name_gen_delete);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_occlusion_query_event", XS_OpenGL__Modern_GLEW_AMD_occlusion_query_event);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_performance_monitor", XS_OpenGL__Modern_GLEW_AMD_performance_monitor);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_pinned_memory", XS_OpenGL__Modern_GLEW_AMD_pinned_memory);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_program_binary_Z400", XS_OpenGL__Modern_GLEW_AMD_program_binary_Z400);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_query_buffer_object", XS_OpenGL__Modern_GLEW_AMD_query_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_sample_positions", XS_OpenGL__Modern_GLEW_AMD_sample_positions);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_seamless_cubemap_per_texture", XS_OpenGL__Modern_GLEW_AMD_seamless_cubemap_per_texture);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_shader_atomic_counter_ops", XS_OpenGL__Modern_GLEW_AMD_shader_atomic_counter_ops);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_shader_ballot", XS_OpenGL__Modern_GLEW_AMD_shader_ballot);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_shader_explicit_vertex_parameter", XS_OpenGL__Modern_GLEW_AMD_shader_explicit_vertex_parameter);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_shader_image_load_store_lod", XS_OpenGL__Modern_GLEW_AMD_shader_image_load_store_lod);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_shader_stencil_export", XS_OpenGL__Modern_GLEW_AMD_shader_stencil_export);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_shader_stencil_value_export", XS_OpenGL__Modern_GLEW_AMD_shader_stencil_value_export);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_shader_trinary_minmax", XS_OpenGL__Modern_GLEW_AMD_shader_trinary_minmax);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_sparse_texture", XS_OpenGL__Modern_GLEW_AMD_sparse_texture);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_stencil_operation_extended", XS_OpenGL__Modern_GLEW_AMD_stencil_operation_extended);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_texture_gather_bias_lod", XS_OpenGL__Modern_GLEW_AMD_texture_gather_bias_lod);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_texture_texture4", XS_OpenGL__Modern_GLEW_AMD_texture_texture4);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_transform_feedback3_lines_triangles", XS_OpenGL__Modern_GLEW_AMD_transform_feedback3_lines_triangles);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_transform_feedback4", XS_OpenGL__Modern_GLEW_AMD_transform_feedback4);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_vertex_shader_layer", XS_OpenGL__Modern_GLEW_AMD_vertex_shader_layer);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_vertex_shader_tessellator", XS_OpenGL__Modern_GLEW_AMD_vertex_shader_tessellator);
        newXS_deffile("OpenGL::Modern::GLEW_AMD_vertex_shader_viewport_index", XS_OpenGL__Modern_GLEW_AMD_vertex_shader_viewport_index);
        newXS_deffile("OpenGL::Modern::GLEW_ANDROID_extension_pack_es31a", XS_OpenGL__Modern_GLEW_ANDROID_extension_pack_es31a);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_depth_texture", XS_OpenGL__Modern_GLEW_ANGLE_depth_texture);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_framebuffer_blit", XS_OpenGL__Modern_GLEW_ANGLE_framebuffer_blit);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_framebuffer_multisample", XS_OpenGL__Modern_GLEW_ANGLE_framebuffer_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_instanced_arrays", XS_OpenGL__Modern_GLEW_ANGLE_instanced_arrays);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_pack_reverse_row_order", XS_OpenGL__Modern_GLEW_ANGLE_pack_reverse_row_order);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_program_binary", XS_OpenGL__Modern_GLEW_ANGLE_program_binary);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_texture_compression_dxt1", XS_OpenGL__Modern_GLEW_ANGLE_texture_compression_dxt1);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_texture_compression_dxt3", XS_OpenGL__Modern_GLEW_ANGLE_texture_compression_dxt3);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_texture_compression_dxt5", XS_OpenGL__Modern_GLEW_ANGLE_texture_compression_dxt5);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_texture_usage", XS_OpenGL__Modern_GLEW_ANGLE_texture_usage);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_timer_query", XS_OpenGL__Modern_GLEW_ANGLE_timer_query);
        newXS_deffile("OpenGL::Modern::GLEW_ANGLE_translated_shader_source", XS_OpenGL__Modern_GLEW_ANGLE_translated_shader_source);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_aux_depth_stencil", XS_OpenGL__Modern_GLEW_APPLE_aux_depth_stencil);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_client_storage", XS_OpenGL__Modern_GLEW_APPLE_client_storage);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_clip_distance", XS_OpenGL__Modern_GLEW_APPLE_clip_distance);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_color_buffer_packed_float", XS_OpenGL__Modern_GLEW_APPLE_color_buffer_packed_float);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_copy_texture_levels", XS_OpenGL__Modern_GLEW_APPLE_copy_texture_levels);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_element_array", XS_OpenGL__Modern_GLEW_APPLE_element_array);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_fence", XS_OpenGL__Modern_GLEW_APPLE_fence);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_float_pixels", XS_OpenGL__Modern_GLEW_APPLE_float_pixels);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_flush_buffer_range", XS_OpenGL__Modern_GLEW_APPLE_flush_buffer_range);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_framebuffer_multisample", XS_OpenGL__Modern_GLEW_APPLE_framebuffer_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_object_purgeable", XS_OpenGL__Modern_GLEW_APPLE_object_purgeable);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_pixel_buffer", XS_OpenGL__Modern_GLEW_APPLE_pixel_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_rgb_422", XS_OpenGL__Modern_GLEW_APPLE_rgb_422);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_row_bytes", XS_OpenGL__Modern_GLEW_APPLE_row_bytes);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_specular_vector", XS_OpenGL__Modern_GLEW_APPLE_specular_vector);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_sync", XS_OpenGL__Modern_GLEW_APPLE_sync);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_texture_2D_limited_npot", XS_OpenGL__Modern_GLEW_APPLE_texture_2D_limited_npot);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_texture_format_BGRA8888", XS_OpenGL__Modern_GLEW_APPLE_texture_format_BGRA8888);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_texture_max_level", XS_OpenGL__Modern_GLEW_APPLE_texture_max_level);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_texture_packed_float", XS_OpenGL__Modern_GLEW_APPLE_texture_packed_float);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_texture_range", XS_OpenGL__Modern_GLEW_APPLE_texture_range);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_transform_hint", XS_OpenGL__Modern_GLEW_APPLE_transform_hint);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_vertex_array_object", XS_OpenGL__Modern_GLEW_APPLE_vertex_array_object);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_vertex_array_range", XS_OpenGL__Modern_GLEW_APPLE_vertex_array_range);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_vertex_program_evaluators", XS_OpenGL__Modern_GLEW_APPLE_vertex_program_evaluators);
        newXS_deffile("OpenGL::Modern::GLEW_APPLE_ycbcr_422", XS_OpenGL__Modern_GLEW_APPLE_ycbcr_422);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_ES2_compatibility", XS_OpenGL__Modern_GLEW_ARB_ES2_compatibility);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_ES3_1_compatibility", XS_OpenGL__Modern_GLEW_ARB_ES3_1_compatibility);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_ES3_2_compatibility", XS_OpenGL__Modern_GLEW_ARB_ES3_2_compatibility);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_ES3_compatibility", XS_OpenGL__Modern_GLEW_ARB_ES3_compatibility);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_arrays_of_arrays", XS_OpenGL__Modern_GLEW_ARB_arrays_of_arrays);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_base_instance", XS_OpenGL__Modern_GLEW_ARB_base_instance);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_bindless_texture", XS_OpenGL__Modern_GLEW_ARB_bindless_texture);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_blend_func_extended", XS_OpenGL__Modern_GLEW_ARB_blend_func_extended);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_buffer_storage", XS_OpenGL__Modern_GLEW_ARB_buffer_storage);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_cl_event", XS_OpenGL__Modern_GLEW_ARB_cl_event);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_clear_buffer_object", XS_OpenGL__Modern_GLEW_ARB_clear_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_clear_texture", XS_OpenGL__Modern_GLEW_ARB_clear_texture);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_clip_control", XS_OpenGL__Modern_GLEW_ARB_clip_control);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_color_buffer_float", XS_OpenGL__Modern_GLEW_ARB_color_buffer_float);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_compatibility", XS_OpenGL__Modern_GLEW_ARB_compatibility);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_compressed_texture_pixel_storage", XS_OpenGL__Modern_GLEW_ARB_compressed_texture_pixel_storage);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_compute_shader", XS_OpenGL__Modern_GLEW_ARB_compute_shader);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_compute_variable_group_size", XS_OpenGL__Modern_GLEW_ARB_compute_variable_group_size);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_conditional_render_inverted", XS_OpenGL__Modern_GLEW_ARB_conditional_render_inverted);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_conservative_depth", XS_OpenGL__Modern_GLEW_ARB_conservative_depth);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_copy_buffer", XS_OpenGL__Modern_GLEW_ARB_copy_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_copy_image", XS_OpenGL__Modern_GLEW_ARB_copy_image);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_cull_distance", XS_OpenGL__Modern_GLEW_ARB_cull_distance);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_debug_output", XS_OpenGL__Modern_GLEW_ARB_debug_output);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_depth_buffer_float", XS_OpenGL__Modern_GLEW_ARB_depth_buffer_float);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_depth_clamp", XS_OpenGL__Modern_GLEW_ARB_depth_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_depth_texture", XS_OpenGL__Modern_GLEW_ARB_depth_texture);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_derivative_control", XS_OpenGL__Modern_GLEW_ARB_derivative_control);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_direct_state_access", XS_OpenGL__Modern_GLEW_ARB_direct_state_access);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_draw_buffers", XS_OpenGL__Modern_GLEW_ARB_draw_buffers);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_draw_buffers_blend", XS_OpenGL__Modern_GLEW_ARB_draw_buffers_blend);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_draw_elements_base_vertex", XS_OpenGL__Modern_GLEW_ARB_draw_elements_base_vertex);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_draw_indirect", XS_OpenGL__Modern_GLEW_ARB_draw_indirect);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_draw_instanced", XS_OpenGL__Modern_GLEW_ARB_draw_instanced);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_enhanced_layouts", XS_OpenGL__Modern_GLEW_ARB_enhanced_layouts);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_explicit_attrib_location", XS_OpenGL__Modern_GLEW_ARB_explicit_attrib_location);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_explicit_uniform_location", XS_OpenGL__Modern_GLEW_ARB_explicit_uniform_location);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_fragment_coord_conventions", XS_OpenGL__Modern_GLEW_ARB_fragment_coord_conventions);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_fragment_layer_viewport", XS_OpenGL__Modern_GLEW_ARB_fragment_layer_viewport);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_fragment_program", XS_OpenGL__Modern_GLEW_ARB_fragment_program);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_fragment_program_shadow", XS_OpenGL__Modern_GLEW_ARB_fragment_program_shadow);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_fragment_shader", XS_OpenGL__Modern_GLEW_ARB_fragment_shader);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_fragment_shader_interlock", XS_OpenGL__Modern_GLEW_ARB_fragment_shader_interlock);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_framebuffer_no_attachments", XS_OpenGL__Modern_GLEW_ARB_framebuffer_no_attachments);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_framebuffer_object", XS_OpenGL__Modern_GLEW_ARB_framebuffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_framebuffer_sRGB", XS_OpenGL__Modern_GLEW_ARB_framebuffer_sRGB);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_geometry_shader4", XS_OpenGL__Modern_GLEW_ARB_geometry_shader4);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_get_program_binary", XS_OpenGL__Modern_GLEW_ARB_get_program_binary);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_get_texture_sub_image", XS_OpenGL__Modern_GLEW_ARB_get_texture_sub_image);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_gl_spirv", XS_OpenGL__Modern_GLEW_ARB_gl_spirv);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_gpu_shader5", XS_OpenGL__Modern_GLEW_ARB_gpu_shader5);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_gpu_shader_fp64", XS_OpenGL__Modern_GLEW_ARB_gpu_shader_fp64);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_gpu_shader_int64", XS_OpenGL__Modern_GLEW_ARB_gpu_shader_int64);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_half_float_pixel", XS_OpenGL__Modern_GLEW_ARB_half_float_pixel);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_half_float_vertex", XS_OpenGL__Modern_GLEW_ARB_half_float_vertex);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_imaging", XS_OpenGL__Modern_GLEW_ARB_imaging);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_indirect_parameters", XS_OpenGL__Modern_GLEW_ARB_indirect_parameters);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_instanced_arrays", XS_OpenGL__Modern_GLEW_ARB_instanced_arrays);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_internalformat_query", XS_OpenGL__Modern_GLEW_ARB_internalformat_query);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_internalformat_query2", XS_OpenGL__Modern_GLEW_ARB_internalformat_query2);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_invalidate_subdata", XS_OpenGL__Modern_GLEW_ARB_invalidate_subdata);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_map_buffer_alignment", XS_OpenGL__Modern_GLEW_ARB_map_buffer_alignment);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_map_buffer_range", XS_OpenGL__Modern_GLEW_ARB_map_buffer_range);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_matrix_palette", XS_OpenGL__Modern_GLEW_ARB_matrix_palette);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_multi_bind", XS_OpenGL__Modern_GLEW_ARB_multi_bind);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_multi_draw_indirect", XS_OpenGL__Modern_GLEW_ARB_multi_draw_indirect);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_multisample", XS_OpenGL__Modern_GLEW_ARB_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_multitexture", XS_OpenGL__Modern_GLEW_ARB_multitexture);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_occlusion_query", XS_OpenGL__Modern_GLEW_ARB_occlusion_query);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_occlusion_query2", XS_OpenGL__Modern_GLEW_ARB_occlusion_query2);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_parallel_shader_compile", XS_OpenGL__Modern_GLEW_ARB_parallel_shader_compile);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_pipeline_statistics_query", XS_OpenGL__Modern_GLEW_ARB_pipeline_statistics_query);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_pixel_buffer_object", XS_OpenGL__Modern_GLEW_ARB_pixel_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_point_parameters", XS_OpenGL__Modern_GLEW_ARB_point_parameters);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_point_sprite", XS_OpenGL__Modern_GLEW_ARB_point_sprite);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_polygon_offset_clamp", XS_OpenGL__Modern_GLEW_ARB_polygon_offset_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_post_depth_coverage", XS_OpenGL__Modern_GLEW_ARB_post_depth_coverage);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_program_interface_query", XS_OpenGL__Modern_GLEW_ARB_program_interface_query);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_provoking_vertex", XS_OpenGL__Modern_GLEW_ARB_provoking_vertex);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_query_buffer_object", XS_OpenGL__Modern_GLEW_ARB_query_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_robust_buffer_access_behavior", XS_OpenGL__Modern_GLEW_ARB_robust_buffer_access_behavior);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_robustness", XS_OpenGL__Modern_GLEW_ARB_robustness);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_robustness_application_isolation", XS_OpenGL__Modern_GLEW_ARB_robustness_application_isolation);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_robustness_share_group_isolation", XS_OpenGL__Modern_GLEW_ARB_robustness_share_group_isolation);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_sample_locations", XS_OpenGL__Modern_GLEW_ARB_sample_locations);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_sample_shading", XS_OpenGL__Modern_GLEW_ARB_sample_shading);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_sampler_objects", XS_OpenGL__Modern_GLEW_ARB_sampler_objects);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_seamless_cube_map", XS_OpenGL__Modern_GLEW_ARB_seamless_cube_map);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_seamless_cubemap_per_texture", XS_OpenGL__Modern_GLEW_ARB_seamless_cubemap_per_texture);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_separate_shader_objects", XS_OpenGL__Modern_GLEW_ARB_separate_shader_objects);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_atomic_counter_ops", XS_OpenGL__Modern_GLEW_ARB_shader_atomic_counter_ops);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_atomic_counters", XS_OpenGL__Modern_GLEW_ARB_shader_atomic_counters);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_ballot", XS_OpenGL__Modern_GLEW_ARB_shader_ballot);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_bit_encoding", XS_OpenGL__Modern_GLEW_ARB_shader_bit_encoding);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_clock", XS_OpenGL__Modern_GLEW_ARB_shader_clock);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_draw_parameters", XS_OpenGL__Modern_GLEW_ARB_shader_draw_parameters);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_group_vote", XS_OpenGL__Modern_GLEW_ARB_shader_group_vote);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_image_load_store", XS_OpenGL__Modern_GLEW_ARB_shader_image_load_store);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_image_size", XS_OpenGL__Modern_GLEW_ARB_shader_image_size);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_objects", XS_OpenGL__Modern_GLEW_ARB_shader_objects);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_precision", XS_OpenGL__Modern_GLEW_ARB_shader_precision);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_stencil_export", XS_OpenGL__Modern_GLEW_ARB_shader_stencil_export);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_storage_buffer_object", XS_OpenGL__Modern_GLEW_ARB_shader_storage_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_subroutine", XS_OpenGL__Modern_GLEW_ARB_shader_subroutine);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_texture_image_samples", XS_OpenGL__Modern_GLEW_ARB_shader_texture_image_samples);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_texture_lod", XS_OpenGL__Modern_GLEW_ARB_shader_texture_lod);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shader_viewport_layer_array", XS_OpenGL__Modern_GLEW_ARB_shader_viewport_layer_array);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shading_language_100", XS_OpenGL__Modern_GLEW_ARB_shading_language_100);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shading_language_420pack", XS_OpenGL__Modern_GLEW_ARB_shading_language_420pack);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shading_language_include", XS_OpenGL__Modern_GLEW_ARB_shading_language_include);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shading_language_packing", XS_OpenGL__Modern_GLEW_ARB_shading_language_packing);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shadow", XS_OpenGL__Modern_GLEW_ARB_shadow);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_shadow_ambient", XS_OpenGL__Modern_GLEW_ARB_shadow_ambient);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_sparse_buffer", XS_OpenGL__Modern_GLEW_ARB_sparse_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_sparse_texture", XS_OpenGL__Modern_GLEW_ARB_sparse_texture);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_sparse_texture2", XS_OpenGL__Modern_GLEW_ARB_sparse_texture2);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_sparse_texture_clamp", XS_OpenGL__Modern_GLEW_ARB_sparse_texture_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_spirv_extensions", XS_OpenGL__Modern_GLEW_ARB_spirv_extensions);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_stencil_texturing", XS_OpenGL__Modern_GLEW_ARB_stencil_texturing);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_sync", XS_OpenGL__Modern_GLEW_ARB_sync);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_tessellation_shader", XS_OpenGL__Modern_GLEW_ARB_tessellation_shader);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_barrier", XS_OpenGL__Modern_GLEW_ARB_texture_barrier);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_border_clamp", XS_OpenGL__Modern_GLEW_ARB_texture_border_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_buffer_object", XS_OpenGL__Modern_GLEW_ARB_texture_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_buffer_object_rgb32", XS_OpenGL__Modern_GLEW_ARB_texture_buffer_object_rgb32);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_buffer_range", XS_OpenGL__Modern_GLEW_ARB_texture_buffer_range);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_compression", XS_OpenGL__Modern_GLEW_ARB_texture_compression);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_compression_bptc", XS_OpenGL__Modern_GLEW_ARB_texture_compression_bptc);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_compression_rgtc", XS_OpenGL__Modern_GLEW_ARB_texture_compression_rgtc);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_cube_map", XS_OpenGL__Modern_GLEW_ARB_texture_cube_map);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_cube_map_array", XS_OpenGL__Modern_GLEW_ARB_texture_cube_map_array);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_env_add", XS_OpenGL__Modern_GLEW_ARB_texture_env_add);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_env_combine", XS_OpenGL__Modern_GLEW_ARB_texture_env_combine);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_env_crossbar", XS_OpenGL__Modern_GLEW_ARB_texture_env_crossbar);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_env_dot3", XS_OpenGL__Modern_GLEW_ARB_texture_env_dot3);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_filter_anisotropic", XS_OpenGL__Modern_GLEW_ARB_texture_filter_anisotropic);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_filter_minmax", XS_OpenGL__Modern_GLEW_ARB_texture_filter_minmax);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_float", XS_OpenGL__Modern_GLEW_ARB_texture_float);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_gather", XS_OpenGL__Modern_GLEW_ARB_texture_gather);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_mirror_clamp_to_edge", XS_OpenGL__Modern_GLEW_ARB_texture_mirror_clamp_to_edge);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_mirrored_repeat", XS_OpenGL__Modern_GLEW_ARB_texture_mirrored_repeat);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_multisample", XS_OpenGL__Modern_GLEW_ARB_texture_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_non_power_of_two", XS_OpenGL__Modern_GLEW_ARB_texture_non_power_of_two);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_query_levels", XS_OpenGL__Modern_GLEW_ARB_texture_query_levels);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_query_lod", XS_OpenGL__Modern_GLEW_ARB_texture_query_lod);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_rectangle", XS_OpenGL__Modern_GLEW_ARB_texture_rectangle);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_rg", XS_OpenGL__Modern_GLEW_ARB_texture_rg);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_rgb10_a2ui", XS_OpenGL__Modern_GLEW_ARB_texture_rgb10_a2ui);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_stencil8", XS_OpenGL__Modern_GLEW_ARB_texture_stencil8);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_storage", XS_OpenGL__Modern_GLEW_ARB_texture_storage);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_storage_multisample", XS_OpenGL__Modern_GLEW_ARB_texture_storage_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_swizzle", XS_OpenGL__Modern_GLEW_ARB_texture_swizzle);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_texture_view", XS_OpenGL__Modern_GLEW_ARB_texture_view);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_timer_query", XS_OpenGL__Modern_GLEW_ARB_timer_query);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_transform_feedback2", XS_OpenGL__Modern_GLEW_ARB_transform_feedback2);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_transform_feedback3", XS_OpenGL__Modern_GLEW_ARB_transform_feedback3);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_transform_feedback_instanced", XS_OpenGL__Modern_GLEW_ARB_transform_feedback_instanced);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_transform_feedback_overflow_query", XS_OpenGL__Modern_GLEW_ARB_transform_feedback_overflow_query);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_transpose_matrix", XS_OpenGL__Modern_GLEW_ARB_transpose_matrix);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_uniform_buffer_object", XS_OpenGL__Modern_GLEW_ARB_uniform_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_vertex_array_bgra", XS_OpenGL__Modern_GLEW_ARB_vertex_array_bgra);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_vertex_array_object", XS_OpenGL__Modern_GLEW_ARB_vertex_array_object);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_vertex_attrib_64bit", XS_OpenGL__Modern_GLEW_ARB_vertex_attrib_64bit);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_vertex_attrib_binding", XS_OpenGL__Modern_GLEW_ARB_vertex_attrib_binding);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_vertex_blend", XS_OpenGL__Modern_GLEW_ARB_vertex_blend);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_vertex_buffer_object", XS_OpenGL__Modern_GLEW_ARB_vertex_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_vertex_program", XS_OpenGL__Modern_GLEW_ARB_vertex_program);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_vertex_shader", XS_OpenGL__Modern_GLEW_ARB_vertex_shader);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_vertex_type_10f_11f_11f_rev", XS_OpenGL__Modern_GLEW_ARB_vertex_type_10f_11f_11f_rev);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_vertex_type_2_10_10_10_rev", XS_OpenGL__Modern_GLEW_ARB_vertex_type_2_10_10_10_rev);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_viewport_array", XS_OpenGL__Modern_GLEW_ARB_viewport_array);
        newXS_deffile("OpenGL::Modern::GLEW_ARB_window_pos", XS_OpenGL__Modern_GLEW_ARB_window_pos);
        newXS_deffile("OpenGL::Modern::GLEW_ARM_mali_program_binary", XS_OpenGL__Modern_GLEW_ARM_mali_program_binary);
        newXS_deffile("OpenGL::Modern::GLEW_ARM_mali_shader_binary", XS_OpenGL__Modern_GLEW_ARM_mali_shader_binary);
        newXS_deffile("OpenGL::Modern::GLEW_ARM_rgba8", XS_OpenGL__Modern_GLEW_ARM_rgba8);
        newXS_deffile("OpenGL::Modern::GLEW_ARM_shader_core_properties", XS_OpenGL__Modern_GLEW_ARM_shader_core_properties);
        newXS_deffile("OpenGL::Modern::GLEW_ARM_shader_framebuffer_fetch", XS_OpenGL__Modern_GLEW_ARM_shader_framebuffer_fetch);
        newXS_deffile("OpenGL::Modern::GLEW_ARM_shader_framebuffer_fetch_depth_stencil", XS_OpenGL__Modern_GLEW_ARM_shader_framebuffer_fetch_depth_stencil);
        newXS_deffile("OpenGL::Modern::GLEW_ARM_texture_unnormalized_coordinates", XS_OpenGL__Modern_GLEW_ARM_texture_unnormalized_coordinates);
        newXS_deffile("OpenGL::Modern::GLEW_ATIX_point_sprites", XS_OpenGL__Modern_GLEW_ATIX_point_sprites);
        newXS_deffile("OpenGL::Modern::GLEW_ATIX_texture_env_combine3", XS_OpenGL__Modern_GLEW_ATIX_texture_env_combine3);
        newXS_deffile("OpenGL::Modern::GLEW_ATIX_texture_env_route", XS_OpenGL__Modern_GLEW_ATIX_texture_env_route);
        newXS_deffile("OpenGL::Modern::GLEW_ATIX_vertex_shader_output_point_size", XS_OpenGL__Modern_GLEW_ATIX_vertex_shader_output_point_size);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_draw_buffers", XS_OpenGL__Modern_GLEW_ATI_draw_buffers);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_element_array", XS_OpenGL__Modern_GLEW_ATI_element_array);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_envmap_bumpmap", XS_OpenGL__Modern_GLEW_ATI_envmap_bumpmap);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_fragment_shader", XS_OpenGL__Modern_GLEW_ATI_fragment_shader);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_map_object_buffer", XS_OpenGL__Modern_GLEW_ATI_map_object_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_meminfo", XS_OpenGL__Modern_GLEW_ATI_meminfo);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_pn_triangles", XS_OpenGL__Modern_GLEW_ATI_pn_triangles);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_separate_stencil", XS_OpenGL__Modern_GLEW_ATI_separate_stencil);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_shader_texture_lod", XS_OpenGL__Modern_GLEW_ATI_shader_texture_lod);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_text_fragment_shader", XS_OpenGL__Modern_GLEW_ATI_text_fragment_shader);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_texture_compression_3dc", XS_OpenGL__Modern_GLEW_ATI_texture_compression_3dc);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_texture_env_combine3", XS_OpenGL__Modern_GLEW_ATI_texture_env_combine3);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_texture_float", XS_OpenGL__Modern_GLEW_ATI_texture_float);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_texture_mirror_once", XS_OpenGL__Modern_GLEW_ATI_texture_mirror_once);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_vertex_array_object", XS_OpenGL__Modern_GLEW_ATI_vertex_array_object);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_vertex_attrib_array_object", XS_OpenGL__Modern_GLEW_ATI_vertex_attrib_array_object);
        newXS_deffile("OpenGL::Modern::GLEW_ATI_vertex_streams", XS_OpenGL__Modern_GLEW_ATI_vertex_streams);
        newXS_deffile("OpenGL::Modern::GLEW_DMP_program_binary", XS_OpenGL__Modern_GLEW_DMP_program_binary);
        newXS_deffile("OpenGL::Modern::GLEW_DMP_shader_binary", XS_OpenGL__Modern_GLEW_DMP_shader_binary);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_422_pixels", XS_OpenGL__Modern_GLEW_EXT_422_pixels);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_Cg_shader", XS_OpenGL__Modern_GLEW_EXT_Cg_shader);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_EGL_image_array", XS_OpenGL__Modern_GLEW_EXT_EGL_image_array);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_EGL_image_external_wrap_modes", XS_OpenGL__Modern_GLEW_EXT_EGL_image_external_wrap_modes);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_EGL_image_storage", XS_OpenGL__Modern_GLEW_EXT_EGL_image_storage);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_EGL_image_storage_compression", XS_OpenGL__Modern_GLEW_EXT_EGL_image_storage_compression);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_EGL_sync", XS_OpenGL__Modern_GLEW_EXT_EGL_sync);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_YUV_target", XS_OpenGL__Modern_GLEW_EXT_YUV_target);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_abgr", XS_OpenGL__Modern_GLEW_EXT_abgr);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_base_instance", XS_OpenGL__Modern_GLEW_EXT_base_instance);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_bgra", XS_OpenGL__Modern_GLEW_EXT_bgra);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_bindable_uniform", XS_OpenGL__Modern_GLEW_EXT_bindable_uniform);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_blend_color", XS_OpenGL__Modern_GLEW_EXT_blend_color);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_blend_equation_separate", XS_OpenGL__Modern_GLEW_EXT_blend_equation_separate);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_blend_func_extended", XS_OpenGL__Modern_GLEW_EXT_blend_func_extended);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_blend_func_separate", XS_OpenGL__Modern_GLEW_EXT_blend_func_separate);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_blend_logic_op", XS_OpenGL__Modern_GLEW_EXT_blend_logic_op);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_blend_minmax", XS_OpenGL__Modern_GLEW_EXT_blend_minmax);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_blend_subtract", XS_OpenGL__Modern_GLEW_EXT_blend_subtract);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_buffer_storage", XS_OpenGL__Modern_GLEW_EXT_buffer_storage);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_clear_texture", XS_OpenGL__Modern_GLEW_EXT_clear_texture);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_clip_control", XS_OpenGL__Modern_GLEW_EXT_clip_control);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_clip_cull_distance", XS_OpenGL__Modern_GLEW_EXT_clip_cull_distance);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_clip_volume_hint", XS_OpenGL__Modern_GLEW_EXT_clip_volume_hint);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_cmyka", XS_OpenGL__Modern_GLEW_EXT_cmyka);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_color_buffer_float", XS_OpenGL__Modern_GLEW_EXT_color_buffer_float);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_color_buffer_half_float", XS_OpenGL__Modern_GLEW_EXT_color_buffer_half_float);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_color_subtable", XS_OpenGL__Modern_GLEW_EXT_color_subtable);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_compiled_vertex_array", XS_OpenGL__Modern_GLEW_EXT_compiled_vertex_array);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_compressed_ETC1_RGB8_sub_texture", XS_OpenGL__Modern_GLEW_EXT_compressed_ETC1_RGB8_sub_texture);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_conservative_depth", XS_OpenGL__Modern_GLEW_EXT_conservative_depth);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_convolution", XS_OpenGL__Modern_GLEW_EXT_convolution);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_coordinate_frame", XS_OpenGL__Modern_GLEW_EXT_coordinate_frame);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_copy_image", XS_OpenGL__Modern_GLEW_EXT_copy_image);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_copy_texture", XS_OpenGL__Modern_GLEW_EXT_copy_texture);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_cull_vertex", XS_OpenGL__Modern_GLEW_EXT_cull_vertex);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_debug_label", XS_OpenGL__Modern_GLEW_EXT_debug_label);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_debug_marker", XS_OpenGL__Modern_GLEW_EXT_debug_marker);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_depth_bounds_test", XS_OpenGL__Modern_GLEW_EXT_depth_bounds_test);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_depth_clamp", XS_OpenGL__Modern_GLEW_EXT_depth_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_direct_state_access", XS_OpenGL__Modern_GLEW_EXT_direct_state_access);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_discard_framebuffer", XS_OpenGL__Modern_GLEW_EXT_discard_framebuffer);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_disjoint_timer_query", XS_OpenGL__Modern_GLEW_EXT_disjoint_timer_query);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_draw_buffers", XS_OpenGL__Modern_GLEW_EXT_draw_buffers);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_draw_buffers2", XS_OpenGL__Modern_GLEW_EXT_draw_buffers2);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_draw_buffers_indexed", XS_OpenGL__Modern_GLEW_EXT_draw_buffers_indexed);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_draw_elements_base_vertex", XS_OpenGL__Modern_GLEW_EXT_draw_elements_base_vertex);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_draw_instanced", XS_OpenGL__Modern_GLEW_EXT_draw_instanced);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_draw_range_elements", XS_OpenGL__Modern_GLEW_EXT_draw_range_elements);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_draw_transform_feedback", XS_OpenGL__Modern_GLEW_EXT_draw_transform_feedback);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_external_buffer", XS_OpenGL__Modern_GLEW_EXT_external_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_float_blend", XS_OpenGL__Modern_GLEW_EXT_float_blend);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_fog_coord", XS_OpenGL__Modern_GLEW_EXT_fog_coord);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_frag_depth", XS_OpenGL__Modern_GLEW_EXT_frag_depth);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_fragment_lighting", XS_OpenGL__Modern_GLEW_EXT_fragment_lighting);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_fragment_shading_rate", XS_OpenGL__Modern_GLEW_EXT_fragment_shading_rate);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_fragment_shading_rate_attachment", XS_OpenGL__Modern_GLEW_EXT_fragment_shading_rate_attachment);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_fragment_shading_rate_primitive", XS_OpenGL__Modern_GLEW_EXT_fragment_shading_rate_primitive);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_framebuffer_blit", XS_OpenGL__Modern_GLEW_EXT_framebuffer_blit);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_framebuffer_blit_layers", XS_OpenGL__Modern_GLEW_EXT_framebuffer_blit_layers);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_framebuffer_multisample", XS_OpenGL__Modern_GLEW_EXT_framebuffer_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_framebuffer_multisample_blit_scaled", XS_OpenGL__Modern_GLEW_EXT_framebuffer_multisample_blit_scaled);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_framebuffer_object", XS_OpenGL__Modern_GLEW_EXT_framebuffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_framebuffer_sRGB", XS_OpenGL__Modern_GLEW_EXT_framebuffer_sRGB);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_geometry_point_size", XS_OpenGL__Modern_GLEW_EXT_geometry_point_size);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_geometry_shader", XS_OpenGL__Modern_GLEW_EXT_geometry_shader);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_geometry_shader4", XS_OpenGL__Modern_GLEW_EXT_geometry_shader4);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_gpu_program_parameters", XS_OpenGL__Modern_GLEW_EXT_gpu_program_parameters);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_gpu_shader4", XS_OpenGL__Modern_GLEW_EXT_gpu_shader4);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_gpu_shader5", XS_OpenGL__Modern_GLEW_EXT_gpu_shader5);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_histogram", XS_OpenGL__Modern_GLEW_EXT_histogram);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_index_array_formats", XS_OpenGL__Modern_GLEW_EXT_index_array_formats);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_index_func", XS_OpenGL__Modern_GLEW_EXT_index_func);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_index_material", XS_OpenGL__Modern_GLEW_EXT_index_material);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_index_texture", XS_OpenGL__Modern_GLEW_EXT_index_texture);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_instanced_arrays", XS_OpenGL__Modern_GLEW_EXT_instanced_arrays);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_light_texture", XS_OpenGL__Modern_GLEW_EXT_light_texture);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_map_buffer_range", XS_OpenGL__Modern_GLEW_EXT_map_buffer_range);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_memory_object", XS_OpenGL__Modern_GLEW_EXT_memory_object);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_memory_object_fd", XS_OpenGL__Modern_GLEW_EXT_memory_object_fd);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_memory_object_win32", XS_OpenGL__Modern_GLEW_EXT_memory_object_win32);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_mesh_shader", XS_OpenGL__Modern_GLEW_EXT_mesh_shader);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_misc_attribute", XS_OpenGL__Modern_GLEW_EXT_misc_attribute);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_multi_draw_arrays", XS_OpenGL__Modern_GLEW_EXT_multi_draw_arrays);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_multi_draw_indirect", XS_OpenGL__Modern_GLEW_EXT_multi_draw_indirect);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_multiple_textures", XS_OpenGL__Modern_GLEW_EXT_multiple_textures);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_multisample", XS_OpenGL__Modern_GLEW_EXT_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_multisample_compatibility", XS_OpenGL__Modern_GLEW_EXT_multisample_compatibility);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_multisampled_render_to_texture", XS_OpenGL__Modern_GLEW_EXT_multisampled_render_to_texture);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_multisampled_render_to_texture2", XS_OpenGL__Modern_GLEW_EXT_multisampled_render_to_texture2);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_multiview_draw_buffers", XS_OpenGL__Modern_GLEW_EXT_multiview_draw_buffers);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_multiview_tessellation_geometry_shader", XS_OpenGL__Modern_GLEW_EXT_multiview_tessellation_geometry_shader);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_multiview_texture_multisample", XS_OpenGL__Modern_GLEW_EXT_multiview_texture_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_multiview_timer_query", XS_OpenGL__Modern_GLEW_EXT_multiview_timer_query);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_occlusion_query_boolean", XS_OpenGL__Modern_GLEW_EXT_occlusion_query_boolean);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_packed_depth_stencil", XS_OpenGL__Modern_GLEW_EXT_packed_depth_stencil);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_packed_float", XS_OpenGL__Modern_GLEW_EXT_packed_float);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_packed_pixels", XS_OpenGL__Modern_GLEW_EXT_packed_pixels);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_paletted_texture", XS_OpenGL__Modern_GLEW_EXT_paletted_texture);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_pixel_buffer_object", XS_OpenGL__Modern_GLEW_EXT_pixel_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_pixel_transform", XS_OpenGL__Modern_GLEW_EXT_pixel_transform);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_pixel_transform_color_table", XS_OpenGL__Modern_GLEW_EXT_pixel_transform_color_table);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_point_parameters", XS_OpenGL__Modern_GLEW_EXT_point_parameters);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_polygon_offset", XS_OpenGL__Modern_GLEW_EXT_polygon_offset);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_polygon_offset_clamp", XS_OpenGL__Modern_GLEW_EXT_polygon_offset_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_post_depth_coverage", XS_OpenGL__Modern_GLEW_EXT_post_depth_coverage);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_primitive_bounding_box", XS_OpenGL__Modern_GLEW_EXT_primitive_bounding_box);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_protected_textures", XS_OpenGL__Modern_GLEW_EXT_protected_textures);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_provoking_vertex", XS_OpenGL__Modern_GLEW_EXT_provoking_vertex);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_pvrtc_sRGB", XS_OpenGL__Modern_GLEW_EXT_pvrtc_sRGB);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_raster_multisample", XS_OpenGL__Modern_GLEW_EXT_raster_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_read_format_bgra", XS_OpenGL__Modern_GLEW_EXT_read_format_bgra);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_render_snorm", XS_OpenGL__Modern_GLEW_EXT_render_snorm);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_rescale_normal", XS_OpenGL__Modern_GLEW_EXT_rescale_normal);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_robustness", XS_OpenGL__Modern_GLEW_EXT_robustness);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_sRGB", XS_OpenGL__Modern_GLEW_EXT_sRGB);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_sRGB_write_control", XS_OpenGL__Modern_GLEW_EXT_sRGB_write_control);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_scene_marker", XS_OpenGL__Modern_GLEW_EXT_scene_marker);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_secondary_color", XS_OpenGL__Modern_GLEW_EXT_secondary_color);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_semaphore", XS_OpenGL__Modern_GLEW_EXT_semaphore);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_semaphore_fd", XS_OpenGL__Modern_GLEW_EXT_semaphore_fd);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_semaphore_win32", XS_OpenGL__Modern_GLEW_EXT_semaphore_win32);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_separate_depth_stencil", XS_OpenGL__Modern_GLEW_EXT_separate_depth_stencil);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_separate_shader_objects", XS_OpenGL__Modern_GLEW_EXT_separate_shader_objects);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_separate_specular_color", XS_OpenGL__Modern_GLEW_EXT_separate_specular_color);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_clock", XS_OpenGL__Modern_GLEW_EXT_shader_clock);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_framebuffer_fetch", XS_OpenGL__Modern_GLEW_EXT_shader_framebuffer_fetch);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_framebuffer_fetch_non_coherent", XS_OpenGL__Modern_GLEW_EXT_shader_framebuffer_fetch_non_coherent);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_group_vote", XS_OpenGL__Modern_GLEW_EXT_shader_group_vote);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_image_load_formatted", XS_OpenGL__Modern_GLEW_EXT_shader_image_load_formatted);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_image_load_store", XS_OpenGL__Modern_GLEW_EXT_shader_image_load_store);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_implicit_conversions", XS_OpenGL__Modern_GLEW_EXT_shader_implicit_conversions);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_integer_mix", XS_OpenGL__Modern_GLEW_EXT_shader_integer_mix);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_io_blocks", XS_OpenGL__Modern_GLEW_EXT_shader_io_blocks);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_non_constant_global_initializers", XS_OpenGL__Modern_GLEW_EXT_shader_non_constant_global_initializers);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_pixel_local_storage", XS_OpenGL__Modern_GLEW_EXT_shader_pixel_local_storage);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_pixel_local_storage2", XS_OpenGL__Modern_GLEW_EXT_shader_pixel_local_storage2);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_realtime_clock", XS_OpenGL__Modern_GLEW_EXT_shader_realtime_clock);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_samples_identical", XS_OpenGL__Modern_GLEW_EXT_shader_samples_identical);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_texture_lod", XS_OpenGL__Modern_GLEW_EXT_shader_texture_lod);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shader_texture_samples", XS_OpenGL__Modern_GLEW_EXT_shader_texture_samples);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shadow_funcs", XS_OpenGL__Modern_GLEW_EXT_shadow_funcs);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shadow_samplers", XS_OpenGL__Modern_GLEW_EXT_shadow_samplers);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_shared_texture_palette", XS_OpenGL__Modern_GLEW_EXT_shared_texture_palette);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_sparse_texture", XS_OpenGL__Modern_GLEW_EXT_sparse_texture);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_sparse_texture2", XS_OpenGL__Modern_GLEW_EXT_sparse_texture2);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_static_vertex_array", XS_OpenGL__Modern_GLEW_EXT_static_vertex_array);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_stencil_clear_tag", XS_OpenGL__Modern_GLEW_EXT_stencil_clear_tag);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_stencil_two_side", XS_OpenGL__Modern_GLEW_EXT_stencil_two_side);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_stencil_wrap", XS_OpenGL__Modern_GLEW_EXT_stencil_wrap);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_subtexture", XS_OpenGL__Modern_GLEW_EXT_subtexture);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_tessellation_point_size", XS_OpenGL__Modern_GLEW_EXT_tessellation_point_size);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_tessellation_shader", XS_OpenGL__Modern_GLEW_EXT_tessellation_shader);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture", XS_OpenGL__Modern_GLEW_EXT_texture);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture3D", XS_OpenGL__Modern_GLEW_EXT_texture3D);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_array", XS_OpenGL__Modern_GLEW_EXT_texture_array);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_border_clamp", XS_OpenGL__Modern_GLEW_EXT_texture_border_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_buffer", XS_OpenGL__Modern_GLEW_EXT_texture_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_buffer_object", XS_OpenGL__Modern_GLEW_EXT_texture_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_compression_astc_decode_mode", XS_OpenGL__Modern_GLEW_EXT_texture_compression_astc_decode_mode);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_compression_astc_decode_mode_rgb9e5", XS_OpenGL__Modern_GLEW_EXT_texture_compression_astc_decode_mode_rgb9e5);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_compression_bptc", XS_OpenGL__Modern_GLEW_EXT_texture_compression_bptc);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_compression_dxt1", XS_OpenGL__Modern_GLEW_EXT_texture_compression_dxt1);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_compression_latc", XS_OpenGL__Modern_GLEW_EXT_texture_compression_latc);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_compression_rgtc", XS_OpenGL__Modern_GLEW_EXT_texture_compression_rgtc);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_compression_s3tc", XS_OpenGL__Modern_GLEW_EXT_texture_compression_s3tc);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_compression_s3tc_srgb", XS_OpenGL__Modern_GLEW_EXT_texture_compression_s3tc_srgb);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_cube_map", XS_OpenGL__Modern_GLEW_EXT_texture_cube_map);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_cube_map_array", XS_OpenGL__Modern_GLEW_EXT_texture_cube_map_array);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_edge_clamp", XS_OpenGL__Modern_GLEW_EXT_texture_edge_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_env", XS_OpenGL__Modern_GLEW_EXT_texture_env);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_env_add", XS_OpenGL__Modern_GLEW_EXT_texture_env_add);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_env_combine", XS_OpenGL__Modern_GLEW_EXT_texture_env_combine);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_env_dot3", XS_OpenGL__Modern_GLEW_EXT_texture_env_dot3);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_filter_anisotropic", XS_OpenGL__Modern_GLEW_EXT_texture_filter_anisotropic);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_filter_minmax", XS_OpenGL__Modern_GLEW_EXT_texture_filter_minmax);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_format_BGRA8888", XS_OpenGL__Modern_GLEW_EXT_texture_format_BGRA8888);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_format_sRGB_override", XS_OpenGL__Modern_GLEW_EXT_texture_format_sRGB_override);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_integer", XS_OpenGL__Modern_GLEW_EXT_texture_integer);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_lod_bias", XS_OpenGL__Modern_GLEW_EXT_texture_lod_bias);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_mirror_clamp", XS_OpenGL__Modern_GLEW_EXT_texture_mirror_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_mirror_clamp_to_edge", XS_OpenGL__Modern_GLEW_EXT_texture_mirror_clamp_to_edge);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_norm16", XS_OpenGL__Modern_GLEW_EXT_texture_norm16);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_object", XS_OpenGL__Modern_GLEW_EXT_texture_object);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_perturb_normal", XS_OpenGL__Modern_GLEW_EXT_texture_perturb_normal);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_query_lod", XS_OpenGL__Modern_GLEW_EXT_texture_query_lod);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_rectangle", XS_OpenGL__Modern_GLEW_EXT_texture_rectangle);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_rg", XS_OpenGL__Modern_GLEW_EXT_texture_rg);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_sRGB", XS_OpenGL__Modern_GLEW_EXT_texture_sRGB);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_sRGB_R8", XS_OpenGL__Modern_GLEW_EXT_texture_sRGB_R8);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_sRGB_RG8", XS_OpenGL__Modern_GLEW_EXT_texture_sRGB_RG8);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_sRGB_decode", XS_OpenGL__Modern_GLEW_EXT_texture_sRGB_decode);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_shadow_lod", XS_OpenGL__Modern_GLEW_EXT_texture_shadow_lod);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_shared_exponent", XS_OpenGL__Modern_GLEW_EXT_texture_shared_exponent);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_snorm", XS_OpenGL__Modern_GLEW_EXT_texture_snorm);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_storage", XS_OpenGL__Modern_GLEW_EXT_texture_storage);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_storage_compression", XS_OpenGL__Modern_GLEW_EXT_texture_storage_compression);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_swizzle", XS_OpenGL__Modern_GLEW_EXT_texture_swizzle);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_type_2_10_10_10_REV", XS_OpenGL__Modern_GLEW_EXT_texture_type_2_10_10_10_REV);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_texture_view", XS_OpenGL__Modern_GLEW_EXT_texture_view);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_timer_query", XS_OpenGL__Modern_GLEW_EXT_timer_query);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_transform_feedback", XS_OpenGL__Modern_GLEW_EXT_transform_feedback);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_unpack_subimage", XS_OpenGL__Modern_GLEW_EXT_unpack_subimage);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_vertex_array", XS_OpenGL__Modern_GLEW_EXT_vertex_array);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_vertex_array_bgra", XS_OpenGL__Modern_GLEW_EXT_vertex_array_bgra);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_vertex_array_setXXX", XS_OpenGL__Modern_GLEW_EXT_vertex_array_setXXX);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_vertex_attrib_64bit", XS_OpenGL__Modern_GLEW_EXT_vertex_attrib_64bit);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_vertex_shader", XS_OpenGL__Modern_GLEW_EXT_vertex_shader);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_vertex_weighting", XS_OpenGL__Modern_GLEW_EXT_vertex_weighting);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_win32_keyed_mutex", XS_OpenGL__Modern_GLEW_EXT_win32_keyed_mutex);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_window_rectangles", XS_OpenGL__Modern_GLEW_EXT_window_rectangles);
        newXS_deffile("OpenGL::Modern::GLEW_EXT_x11_sync_object", XS_OpenGL__Modern_GLEW_EXT_x11_sync_object);
        newXS_deffile("OpenGL::Modern::GLEW_FJ_shader_binary_GCCSO", XS_OpenGL__Modern_GLEW_FJ_shader_binary_GCCSO);
        newXS_deffile("OpenGL::Modern::GLEW_GREMEDY_frame_terminator", XS_OpenGL__Modern_GLEW_GREMEDY_frame_terminator);
        newXS_deffile("OpenGL::Modern::GLEW_GREMEDY_string_marker", XS_OpenGL__Modern_GLEW_GREMEDY_string_marker);
        newXS_deffile("OpenGL::Modern::GLEW_HP_convolution_border_modes", XS_OpenGL__Modern_GLEW_HP_convolution_border_modes);
        newXS_deffile("OpenGL::Modern::GLEW_HP_image_transform", XS_OpenGL__Modern_GLEW_HP_image_transform);
        newXS_deffile("OpenGL::Modern::GLEW_HP_occlusion_test", XS_OpenGL__Modern_GLEW_HP_occlusion_test);
        newXS_deffile("OpenGL::Modern::GLEW_HP_texture_lighting", XS_OpenGL__Modern_GLEW_HP_texture_lighting);
        newXS_deffile("OpenGL::Modern::GLEW_HUAWEI_program_binary", XS_OpenGL__Modern_GLEW_HUAWEI_program_binary);
        newXS_deffile("OpenGL::Modern::GLEW_HUAWEI_shader_binary", XS_OpenGL__Modern_GLEW_HUAWEI_shader_binary);
        newXS_deffile("OpenGL::Modern::GLEW_IBM_cull_vertex", XS_OpenGL__Modern_GLEW_IBM_cull_vertex);
        newXS_deffile("OpenGL::Modern::GLEW_IBM_multimode_draw_arrays", XS_OpenGL__Modern_GLEW_IBM_multimode_draw_arrays);
        newXS_deffile("OpenGL::Modern::GLEW_IBM_rasterpos_clip", XS_OpenGL__Modern_GLEW_IBM_rasterpos_clip);
        newXS_deffile("OpenGL::Modern::GLEW_IBM_static_data", XS_OpenGL__Modern_GLEW_IBM_static_data);
        newXS_deffile("OpenGL::Modern::GLEW_IBM_texture_mirrored_repeat", XS_OpenGL__Modern_GLEW_IBM_texture_mirrored_repeat);
        newXS_deffile("OpenGL::Modern::GLEW_IBM_vertex_array_lists", XS_OpenGL__Modern_GLEW_IBM_vertex_array_lists);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_bindless_texture", XS_OpenGL__Modern_GLEW_IMG_bindless_texture);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_framebuffer_downsample", XS_OpenGL__Modern_GLEW_IMG_framebuffer_downsample);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_multisampled_render_to_texture", XS_OpenGL__Modern_GLEW_IMG_multisampled_render_to_texture);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_program_binary", XS_OpenGL__Modern_GLEW_IMG_program_binary);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_pvric_end_to_end_signature", XS_OpenGL__Modern_GLEW_IMG_pvric_end_to_end_signature);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_read_format", XS_OpenGL__Modern_GLEW_IMG_read_format);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_shader_binary", XS_OpenGL__Modern_GLEW_IMG_shader_binary);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_texture_compression_pvrtc", XS_OpenGL__Modern_GLEW_IMG_texture_compression_pvrtc);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_texture_compression_pvrtc2", XS_OpenGL__Modern_GLEW_IMG_texture_compression_pvrtc2);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_texture_env_enhanced_fixed_function", XS_OpenGL__Modern_GLEW_IMG_texture_env_enhanced_fixed_function);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_texture_filter_cubic", XS_OpenGL__Modern_GLEW_IMG_texture_filter_cubic);
        newXS_deffile("OpenGL::Modern::GLEW_IMG_tile_region_protection", XS_OpenGL__Modern_GLEW_IMG_tile_region_protection);
        newXS_deffile("OpenGL::Modern::GLEW_INGR_color_clamp", XS_OpenGL__Modern_GLEW_INGR_color_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_INGR_interlace_read", XS_OpenGL__Modern_GLEW_INGR_interlace_read);
        newXS_deffile("OpenGL::Modern::GLEW_INTEL_blackhole_render", XS_OpenGL__Modern_GLEW_INTEL_blackhole_render);
        newXS_deffile("OpenGL::Modern::GLEW_INTEL_conservative_rasterization", XS_OpenGL__Modern_GLEW_INTEL_conservative_rasterization);
        newXS_deffile("OpenGL::Modern::GLEW_INTEL_fragment_shader_ordering", XS_OpenGL__Modern_GLEW_INTEL_fragment_shader_ordering);
        newXS_deffile("OpenGL::Modern::GLEW_INTEL_framebuffer_CMAA", XS_OpenGL__Modern_GLEW_INTEL_framebuffer_CMAA);
        newXS_deffile("OpenGL::Modern::GLEW_INTEL_map_texture", XS_OpenGL__Modern_GLEW_INTEL_map_texture);
        newXS_deffile("OpenGL::Modern::GLEW_INTEL_parallel_arrays", XS_OpenGL__Modern_GLEW_INTEL_parallel_arrays);
        newXS_deffile("OpenGL::Modern::GLEW_INTEL_performance_query", XS_OpenGL__Modern_GLEW_INTEL_performance_query);
        newXS_deffile("OpenGL::Modern::GLEW_INTEL_shader_integer_functions2", XS_OpenGL__Modern_GLEW_INTEL_shader_integer_functions2);
        newXS_deffile("OpenGL::Modern::GLEW_INTEL_texture_scissor", XS_OpenGL__Modern_GLEW_INTEL_texture_scissor);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_blend_equation_advanced", XS_OpenGL__Modern_GLEW_KHR_blend_equation_advanced);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_blend_equation_advanced_coherent", XS_OpenGL__Modern_GLEW_KHR_blend_equation_advanced_coherent);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_context_flush_control", XS_OpenGL__Modern_GLEW_KHR_context_flush_control);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_debug", XS_OpenGL__Modern_GLEW_KHR_debug);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_no_error", XS_OpenGL__Modern_GLEW_KHR_no_error);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_parallel_shader_compile", XS_OpenGL__Modern_GLEW_KHR_parallel_shader_compile);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_robust_buffer_access_behavior", XS_OpenGL__Modern_GLEW_KHR_robust_buffer_access_behavior);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_robustness", XS_OpenGL__Modern_GLEW_KHR_robustness);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_shader_subgroup", XS_OpenGL__Modern_GLEW_KHR_shader_subgroup);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_texture_compression_astc_hdr", XS_OpenGL__Modern_GLEW_KHR_texture_compression_astc_hdr);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_texture_compression_astc_ldr", XS_OpenGL__Modern_GLEW_KHR_texture_compression_astc_ldr);
        newXS_deffile("OpenGL::Modern::GLEW_KHR_texture_compression_astc_sliced_3d", XS_OpenGL__Modern_GLEW_KHR_texture_compression_astc_sliced_3d);
        newXS_deffile("OpenGL::Modern::GLEW_KTX_buffer_region", XS_OpenGL__Modern_GLEW_KTX_buffer_region);
        newXS_deffile("OpenGL::Modern::GLEW_MESAX_texture_stack", XS_OpenGL__Modern_GLEW_MESAX_texture_stack);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_bgra", XS_OpenGL__Modern_GLEW_MESA_bgra);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_framebuffer_flip_x", XS_OpenGL__Modern_GLEW_MESA_framebuffer_flip_x);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_framebuffer_flip_y", XS_OpenGL__Modern_GLEW_MESA_framebuffer_flip_y);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_framebuffer_swap_xy", XS_OpenGL__Modern_GLEW_MESA_framebuffer_swap_xy);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_pack_invert", XS_OpenGL__Modern_GLEW_MESA_pack_invert);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_program_binary_formats", XS_OpenGL__Modern_GLEW_MESA_program_binary_formats);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_resize_buffers", XS_OpenGL__Modern_GLEW_MESA_resize_buffers);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_shader_integer_functions", XS_OpenGL__Modern_GLEW_MESA_shader_integer_functions);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_texture_const_bandwidth", XS_OpenGL__Modern_GLEW_MESA_texture_const_bandwidth);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_tile_raster_order", XS_OpenGL__Modern_GLEW_MESA_tile_raster_order);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_window_pos", XS_OpenGL__Modern_GLEW_MESA_window_pos);
        newXS_deffile("OpenGL::Modern::GLEW_MESA_ycbcr_texture", XS_OpenGL__Modern_GLEW_MESA_ycbcr_texture);
        newXS_deffile("OpenGL::Modern::GLEW_NVX_blend_equation_advanced_multi_draw_buffers", XS_OpenGL__Modern_GLEW_NVX_blend_equation_advanced_multi_draw_buffers);
        newXS_deffile("OpenGL::Modern::GLEW_NVX_conditional_render", XS_OpenGL__Modern_GLEW_NVX_conditional_render);
        newXS_deffile("OpenGL::Modern::GLEW_NVX_gpu_memory_info", XS_OpenGL__Modern_GLEW_NVX_gpu_memory_info);
        newXS_deffile("OpenGL::Modern::GLEW_NVX_gpu_multicast2", XS_OpenGL__Modern_GLEW_NVX_gpu_multicast2);
        newXS_deffile("OpenGL::Modern::GLEW_NVX_linked_gpu_multicast", XS_OpenGL__Modern_GLEW_NVX_linked_gpu_multicast);
        newXS_deffile("OpenGL::Modern::GLEW_NVX_progress_fence", XS_OpenGL__Modern_GLEW_NVX_progress_fence);
        newXS_deffile("OpenGL::Modern::GLEW_NV_3dvision_settings", XS_OpenGL__Modern_GLEW_NV_3dvision_settings);
        newXS_deffile("OpenGL::Modern::GLEW_NV_EGL_stream_consumer_external", XS_OpenGL__Modern_GLEW_NV_EGL_stream_consumer_external);
        newXS_deffile("OpenGL::Modern::GLEW_NV_alpha_to_coverage_dither_control", XS_OpenGL__Modern_GLEW_NV_alpha_to_coverage_dither_control);
        newXS_deffile("OpenGL::Modern::GLEW_NV_bgr", XS_OpenGL__Modern_GLEW_NV_bgr);
        newXS_deffile("OpenGL::Modern::GLEW_NV_bindless_multi_draw_indirect", XS_OpenGL__Modern_GLEW_NV_bindless_multi_draw_indirect);
        newXS_deffile("OpenGL::Modern::GLEW_NV_bindless_multi_draw_indirect_count", XS_OpenGL__Modern_GLEW_NV_bindless_multi_draw_indirect_count);
        newXS_deffile("OpenGL::Modern::GLEW_NV_bindless_texture", XS_OpenGL__Modern_GLEW_NV_bindless_texture);
        newXS_deffile("OpenGL::Modern::GLEW_NV_blend_equation_advanced", XS_OpenGL__Modern_GLEW_NV_blend_equation_advanced);
        newXS_deffile("OpenGL::Modern::GLEW_NV_blend_equation_advanced_coherent", XS_OpenGL__Modern_GLEW_NV_blend_equation_advanced_coherent);
        newXS_deffile("OpenGL::Modern::GLEW_NV_blend_minmax_factor", XS_OpenGL__Modern_GLEW_NV_blend_minmax_factor);
        newXS_deffile("OpenGL::Modern::GLEW_NV_blend_square", XS_OpenGL__Modern_GLEW_NV_blend_square);
        newXS_deffile("OpenGL::Modern::GLEW_NV_clip_space_w_scaling", XS_OpenGL__Modern_GLEW_NV_clip_space_w_scaling);
        newXS_deffile("OpenGL::Modern::GLEW_NV_command_list", XS_OpenGL__Modern_GLEW_NV_command_list);
        newXS_deffile("OpenGL::Modern::GLEW_NV_compute_program5", XS_OpenGL__Modern_GLEW_NV_compute_program5);
        newXS_deffile("OpenGL::Modern::GLEW_NV_compute_shader_derivatives", XS_OpenGL__Modern_GLEW_NV_compute_shader_derivatives);
        newXS_deffile("OpenGL::Modern::GLEW_NV_conditional_render", XS_OpenGL__Modern_GLEW_NV_conditional_render);
        newXS_deffile("OpenGL::Modern::GLEW_NV_conservative_raster", XS_OpenGL__Modern_GLEW_NV_conservative_raster);
        newXS_deffile("OpenGL::Modern::GLEW_NV_conservative_raster_dilate", XS_OpenGL__Modern_GLEW_NV_conservative_raster_dilate);
        newXS_deffile("OpenGL::Modern::GLEW_NV_conservative_raster_pre_snap", XS_OpenGL__Modern_GLEW_NV_conservative_raster_pre_snap);
        newXS_deffile("OpenGL::Modern::GLEW_NV_conservative_raster_pre_snap_triangles", XS_OpenGL__Modern_GLEW_NV_conservative_raster_pre_snap_triangles);
        newXS_deffile("OpenGL::Modern::GLEW_NV_conservative_raster_underestimation", XS_OpenGL__Modern_GLEW_NV_conservative_raster_underestimation);
        newXS_deffile("OpenGL::Modern::GLEW_NV_copy_buffer", XS_OpenGL__Modern_GLEW_NV_copy_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_NV_copy_depth_to_color", XS_OpenGL__Modern_GLEW_NV_copy_depth_to_color);
        newXS_deffile("OpenGL::Modern::GLEW_NV_copy_image", XS_OpenGL__Modern_GLEW_NV_copy_image);
        newXS_deffile("OpenGL::Modern::GLEW_NV_deep_texture3D", XS_OpenGL__Modern_GLEW_NV_deep_texture3D);
        newXS_deffile("OpenGL::Modern::GLEW_NV_depth_buffer_float", XS_OpenGL__Modern_GLEW_NV_depth_buffer_float);
        newXS_deffile("OpenGL::Modern::GLEW_NV_depth_clamp", XS_OpenGL__Modern_GLEW_NV_depth_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_NV_depth_nonlinear", XS_OpenGL__Modern_GLEW_NV_depth_nonlinear);
        newXS_deffile("OpenGL::Modern::GLEW_NV_depth_range_unclamped", XS_OpenGL__Modern_GLEW_NV_depth_range_unclamped);
        newXS_deffile("OpenGL::Modern::GLEW_NV_draw_buffers", XS_OpenGL__Modern_GLEW_NV_draw_buffers);
        newXS_deffile("OpenGL::Modern::GLEW_NV_draw_instanced", XS_OpenGL__Modern_GLEW_NV_draw_instanced);
        newXS_deffile("OpenGL::Modern::GLEW_NV_draw_texture", XS_OpenGL__Modern_GLEW_NV_draw_texture);
        newXS_deffile("OpenGL::Modern::GLEW_NV_draw_vulkan_image", XS_OpenGL__Modern_GLEW_NV_draw_vulkan_image);
        newXS_deffile("OpenGL::Modern::GLEW_NV_evaluators", XS_OpenGL__Modern_GLEW_NV_evaluators);
        newXS_deffile("OpenGL::Modern::GLEW_NV_explicit_attrib_location", XS_OpenGL__Modern_GLEW_NV_explicit_attrib_location);
        newXS_deffile("OpenGL::Modern::GLEW_NV_explicit_multisample", XS_OpenGL__Modern_GLEW_NV_explicit_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_NV_fbo_color_attachments", XS_OpenGL__Modern_GLEW_NV_fbo_color_attachments);
        newXS_deffile("OpenGL::Modern::GLEW_NV_fence", XS_OpenGL__Modern_GLEW_NV_fence);
        newXS_deffile("OpenGL::Modern::GLEW_NV_fill_rectangle", XS_OpenGL__Modern_GLEW_NV_fill_rectangle);
        newXS_deffile("OpenGL::Modern::GLEW_NV_float_buffer", XS_OpenGL__Modern_GLEW_NV_float_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_NV_fog_distance", XS_OpenGL__Modern_GLEW_NV_fog_distance);
        newXS_deffile("OpenGL::Modern::GLEW_NV_fragment_coverage_to_color", XS_OpenGL__Modern_GLEW_NV_fragment_coverage_to_color);
        newXS_deffile("OpenGL::Modern::GLEW_NV_fragment_program", XS_OpenGL__Modern_GLEW_NV_fragment_program);
        newXS_deffile("OpenGL::Modern::GLEW_NV_fragment_program2", XS_OpenGL__Modern_GLEW_NV_fragment_program2);
        newXS_deffile("OpenGL::Modern::GLEW_NV_fragment_program4", XS_OpenGL__Modern_GLEW_NV_fragment_program4);
        newXS_deffile("OpenGL::Modern::GLEW_NV_fragment_program_option", XS_OpenGL__Modern_GLEW_NV_fragment_program_option);
        newXS_deffile("OpenGL::Modern::GLEW_NV_fragment_shader_barycentric", XS_OpenGL__Modern_GLEW_NV_fragment_shader_barycentric);
        newXS_deffile("OpenGL::Modern::GLEW_NV_fragment_shader_interlock", XS_OpenGL__Modern_GLEW_NV_fragment_shader_interlock);
        newXS_deffile("OpenGL::Modern::GLEW_NV_framebuffer_blit", XS_OpenGL__Modern_GLEW_NV_framebuffer_blit);
        newXS_deffile("OpenGL::Modern::GLEW_NV_framebuffer_mixed_samples", XS_OpenGL__Modern_GLEW_NV_framebuffer_mixed_samples);
        newXS_deffile("OpenGL::Modern::GLEW_NV_framebuffer_multisample", XS_OpenGL__Modern_GLEW_NV_framebuffer_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_NV_framebuffer_multisample_coverage", XS_OpenGL__Modern_GLEW_NV_framebuffer_multisample_coverage);
        newXS_deffile("OpenGL::Modern::GLEW_NV_generate_mipmap_sRGB", XS_OpenGL__Modern_GLEW_NV_generate_mipmap_sRGB);
        newXS_deffile("OpenGL::Modern::GLEW_NV_geometry_program4", XS_OpenGL__Modern_GLEW_NV_geometry_program4);
        newXS_deffile("OpenGL::Modern::GLEW_NV_geometry_shader4", XS_OpenGL__Modern_GLEW_NV_geometry_shader4);
        newXS_deffile("OpenGL::Modern::GLEW_NV_geometry_shader_passthrough", XS_OpenGL__Modern_GLEW_NV_geometry_shader_passthrough);
        newXS_deffile("OpenGL::Modern::GLEW_NV_gpu_multicast", XS_OpenGL__Modern_GLEW_NV_gpu_multicast);
        newXS_deffile("OpenGL::Modern::GLEW_NV_gpu_program4", XS_OpenGL__Modern_GLEW_NV_gpu_program4);
        newXS_deffile("OpenGL::Modern::GLEW_NV_gpu_program5", XS_OpenGL__Modern_GLEW_NV_gpu_program5);
        newXS_deffile("OpenGL::Modern::GLEW_NV_gpu_program5_mem_extended", XS_OpenGL__Modern_GLEW_NV_gpu_program5_mem_extended);
        newXS_deffile("OpenGL::Modern::GLEW_NV_gpu_program_fp64", XS_OpenGL__Modern_GLEW_NV_gpu_program_fp64);
        newXS_deffile("OpenGL::Modern::GLEW_NV_gpu_shader5", XS_OpenGL__Modern_GLEW_NV_gpu_shader5);
        newXS_deffile("OpenGL::Modern::GLEW_NV_half_float", XS_OpenGL__Modern_GLEW_NV_half_float);
        newXS_deffile("OpenGL::Modern::GLEW_NV_image_formats", XS_OpenGL__Modern_GLEW_NV_image_formats);
        newXS_deffile("OpenGL::Modern::GLEW_NV_instanced_arrays", XS_OpenGL__Modern_GLEW_NV_instanced_arrays);
        newXS_deffile("OpenGL::Modern::GLEW_NV_internalformat_sample_query", XS_OpenGL__Modern_GLEW_NV_internalformat_sample_query);
        newXS_deffile("OpenGL::Modern::GLEW_NV_light_max_exponent", XS_OpenGL__Modern_GLEW_NV_light_max_exponent);
        newXS_deffile("OpenGL::Modern::GLEW_NV_memory_attachment", XS_OpenGL__Modern_GLEW_NV_memory_attachment);
        newXS_deffile("OpenGL::Modern::GLEW_NV_memory_object_sparse", XS_OpenGL__Modern_GLEW_NV_memory_object_sparse);
        newXS_deffile("OpenGL::Modern::GLEW_NV_mesh_shader", XS_OpenGL__Modern_GLEW_NV_mesh_shader);
        newXS_deffile("OpenGL::Modern::GLEW_NV_multisample_coverage", XS_OpenGL__Modern_GLEW_NV_multisample_coverage);
        newXS_deffile("OpenGL::Modern::GLEW_NV_multisample_filter_hint", XS_OpenGL__Modern_GLEW_NV_multisample_filter_hint);
        newXS_deffile("OpenGL::Modern::GLEW_NV_non_square_matrices", XS_OpenGL__Modern_GLEW_NV_non_square_matrices);
        newXS_deffile("OpenGL::Modern::GLEW_NV_occlusion_query", XS_OpenGL__Modern_GLEW_NV_occlusion_query);
        newXS_deffile("OpenGL::Modern::GLEW_NV_pack_subimage", XS_OpenGL__Modern_GLEW_NV_pack_subimage);
        newXS_deffile("OpenGL::Modern::GLEW_NV_packed_depth_stencil", XS_OpenGL__Modern_GLEW_NV_packed_depth_stencil);
        newXS_deffile("OpenGL::Modern::GLEW_NV_packed_float", XS_OpenGL__Modern_GLEW_NV_packed_float);
        newXS_deffile("OpenGL::Modern::GLEW_NV_packed_float_linear", XS_OpenGL__Modern_GLEW_NV_packed_float_linear);
        newXS_deffile("OpenGL::Modern::GLEW_NV_parameter_buffer_object", XS_OpenGL__Modern_GLEW_NV_parameter_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_NV_parameter_buffer_object2", XS_OpenGL__Modern_GLEW_NV_parameter_buffer_object2);
        newXS_deffile("OpenGL::Modern::GLEW_NV_path_rendering", XS_OpenGL__Modern_GLEW_NV_path_rendering);
        newXS_deffile("OpenGL::Modern::GLEW_NV_path_rendering_shared_edge", XS_OpenGL__Modern_GLEW_NV_path_rendering_shared_edge);
        newXS_deffile("OpenGL::Modern::GLEW_NV_pixel_buffer_object", XS_OpenGL__Modern_GLEW_NV_pixel_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_NV_pixel_data_range", XS_OpenGL__Modern_GLEW_NV_pixel_data_range);
        newXS_deffile("OpenGL::Modern::GLEW_NV_platform_binary", XS_OpenGL__Modern_GLEW_NV_platform_binary);
        newXS_deffile("OpenGL::Modern::GLEW_NV_point_sprite", XS_OpenGL__Modern_GLEW_NV_point_sprite);
        newXS_deffile("OpenGL::Modern::GLEW_NV_polygon_mode", XS_OpenGL__Modern_GLEW_NV_polygon_mode);
        newXS_deffile("OpenGL::Modern::GLEW_NV_present_video", XS_OpenGL__Modern_GLEW_NV_present_video);
        newXS_deffile("OpenGL::Modern::GLEW_NV_primitive_restart", XS_OpenGL__Modern_GLEW_NV_primitive_restart);
        newXS_deffile("OpenGL::Modern::GLEW_NV_primitive_shading_rate", XS_OpenGL__Modern_GLEW_NV_primitive_shading_rate);
        newXS_deffile("OpenGL::Modern::GLEW_NV_query_resource_tag", XS_OpenGL__Modern_GLEW_NV_query_resource_tag);
        newXS_deffile("OpenGL::Modern::GLEW_NV_read_buffer", XS_OpenGL__Modern_GLEW_NV_read_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_NV_read_buffer_front", XS_OpenGL__Modern_GLEW_NV_read_buffer_front);
        newXS_deffile("OpenGL::Modern::GLEW_NV_read_depth", XS_OpenGL__Modern_GLEW_NV_read_depth);
        newXS_deffile("OpenGL::Modern::GLEW_NV_read_depth_stencil", XS_OpenGL__Modern_GLEW_NV_read_depth_stencil);
        newXS_deffile("OpenGL::Modern::GLEW_NV_read_stencil", XS_OpenGL__Modern_GLEW_NV_read_stencil);
        newXS_deffile("OpenGL::Modern::GLEW_NV_register_combiners", XS_OpenGL__Modern_GLEW_NV_register_combiners);
        newXS_deffile("OpenGL::Modern::GLEW_NV_register_combiners2", XS_OpenGL__Modern_GLEW_NV_register_combiners2);
        newXS_deffile("OpenGL::Modern::GLEW_NV_representative_fragment_test", XS_OpenGL__Modern_GLEW_NV_representative_fragment_test);
        newXS_deffile("OpenGL::Modern::GLEW_NV_robustness_video_memory_purge", XS_OpenGL__Modern_GLEW_NV_robustness_video_memory_purge);
        newXS_deffile("OpenGL::Modern::GLEW_NV_sRGB_formats", XS_OpenGL__Modern_GLEW_NV_sRGB_formats);
        newXS_deffile("OpenGL::Modern::GLEW_NV_sample_locations", XS_OpenGL__Modern_GLEW_NV_sample_locations);
        newXS_deffile("OpenGL::Modern::GLEW_NV_sample_mask_override_coverage", XS_OpenGL__Modern_GLEW_NV_sample_mask_override_coverage);
        newXS_deffile("OpenGL::Modern::GLEW_NV_scissor_exclusive", XS_OpenGL__Modern_GLEW_NV_scissor_exclusive);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_atomic_counters", XS_OpenGL__Modern_GLEW_NV_shader_atomic_counters);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_atomic_float", XS_OpenGL__Modern_GLEW_NV_shader_atomic_float);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_atomic_float64", XS_OpenGL__Modern_GLEW_NV_shader_atomic_float64);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_atomic_fp16_vector", XS_OpenGL__Modern_GLEW_NV_shader_atomic_fp16_vector);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_atomic_int64", XS_OpenGL__Modern_GLEW_NV_shader_atomic_int64);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_buffer_load", XS_OpenGL__Modern_GLEW_NV_shader_buffer_load);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_noperspective_interpolation", XS_OpenGL__Modern_GLEW_NV_shader_noperspective_interpolation);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_storage_buffer_object", XS_OpenGL__Modern_GLEW_NV_shader_storage_buffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_subgroup_partitioned", XS_OpenGL__Modern_GLEW_NV_shader_subgroup_partitioned);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_texture_footprint", XS_OpenGL__Modern_GLEW_NV_shader_texture_footprint);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_thread_group", XS_OpenGL__Modern_GLEW_NV_shader_thread_group);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shader_thread_shuffle", XS_OpenGL__Modern_GLEW_NV_shader_thread_shuffle);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shading_rate_image", XS_OpenGL__Modern_GLEW_NV_shading_rate_image);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shadow_samplers_array", XS_OpenGL__Modern_GLEW_NV_shadow_samplers_array);
        newXS_deffile("OpenGL::Modern::GLEW_NV_shadow_samplers_cube", XS_OpenGL__Modern_GLEW_NV_shadow_samplers_cube);
        newXS_deffile("OpenGL::Modern::GLEW_NV_stereo_view_rendering", XS_OpenGL__Modern_GLEW_NV_stereo_view_rendering);
        newXS_deffile("OpenGL::Modern::GLEW_NV_tessellation_program5", XS_OpenGL__Modern_GLEW_NV_tessellation_program5);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texgen_emboss", XS_OpenGL__Modern_GLEW_NV_texgen_emboss);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texgen_reflection", XS_OpenGL__Modern_GLEW_NV_texgen_reflection);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_array", XS_OpenGL__Modern_GLEW_NV_texture_array);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_barrier", XS_OpenGL__Modern_GLEW_NV_texture_barrier);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_border_clamp", XS_OpenGL__Modern_GLEW_NV_texture_border_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_compression_latc", XS_OpenGL__Modern_GLEW_NV_texture_compression_latc);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_compression_s3tc", XS_OpenGL__Modern_GLEW_NV_texture_compression_s3tc);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_compression_s3tc_update", XS_OpenGL__Modern_GLEW_NV_texture_compression_s3tc_update);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_compression_vtc", XS_OpenGL__Modern_GLEW_NV_texture_compression_vtc);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_env_combine4", XS_OpenGL__Modern_GLEW_NV_texture_env_combine4);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_expand_normal", XS_OpenGL__Modern_GLEW_NV_texture_expand_normal);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_multisample", XS_OpenGL__Modern_GLEW_NV_texture_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_npot_2D_mipmap", XS_OpenGL__Modern_GLEW_NV_texture_npot_2D_mipmap);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_rectangle", XS_OpenGL__Modern_GLEW_NV_texture_rectangle);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_rectangle_compressed", XS_OpenGL__Modern_GLEW_NV_texture_rectangle_compressed);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_shader", XS_OpenGL__Modern_GLEW_NV_texture_shader);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_shader2", XS_OpenGL__Modern_GLEW_NV_texture_shader2);
        newXS_deffile("OpenGL::Modern::GLEW_NV_texture_shader3", XS_OpenGL__Modern_GLEW_NV_texture_shader3);
        newXS_deffile("OpenGL::Modern::GLEW_NV_timeline_semaphore", XS_OpenGL__Modern_GLEW_NV_timeline_semaphore);
        newXS_deffile("OpenGL::Modern::GLEW_NV_transform_feedback", XS_OpenGL__Modern_GLEW_NV_transform_feedback);
        newXS_deffile("OpenGL::Modern::GLEW_NV_transform_feedback2", XS_OpenGL__Modern_GLEW_NV_transform_feedback2);
        newXS_deffile("OpenGL::Modern::GLEW_NV_uniform_buffer_std430_layout", XS_OpenGL__Modern_GLEW_NV_uniform_buffer_std430_layout);
        newXS_deffile("OpenGL::Modern::GLEW_NV_uniform_buffer_unified_memory", XS_OpenGL__Modern_GLEW_NV_uniform_buffer_unified_memory);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vdpau_interop", XS_OpenGL__Modern_GLEW_NV_vdpau_interop);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vdpau_interop2", XS_OpenGL__Modern_GLEW_NV_vdpau_interop2);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vertex_array_range", XS_OpenGL__Modern_GLEW_NV_vertex_array_range);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vertex_array_range2", XS_OpenGL__Modern_GLEW_NV_vertex_array_range2);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vertex_attrib_integer_64bit", XS_OpenGL__Modern_GLEW_NV_vertex_attrib_integer_64bit);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vertex_buffer_unified_memory", XS_OpenGL__Modern_GLEW_NV_vertex_buffer_unified_memory);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vertex_program", XS_OpenGL__Modern_GLEW_NV_vertex_program);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vertex_program1_1", XS_OpenGL__Modern_GLEW_NV_vertex_program1_1);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vertex_program2", XS_OpenGL__Modern_GLEW_NV_vertex_program2);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vertex_program2_option", XS_OpenGL__Modern_GLEW_NV_vertex_program2_option);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vertex_program3", XS_OpenGL__Modern_GLEW_NV_vertex_program3);
        newXS_deffile("OpenGL::Modern::GLEW_NV_vertex_program4", XS_OpenGL__Modern_GLEW_NV_vertex_program4);
        newXS_deffile("OpenGL::Modern::GLEW_NV_video_capture", XS_OpenGL__Modern_GLEW_NV_video_capture);
        newXS_deffile("OpenGL::Modern::GLEW_NV_viewport_array", XS_OpenGL__Modern_GLEW_NV_viewport_array);
        newXS_deffile("OpenGL::Modern::GLEW_NV_viewport_array2", XS_OpenGL__Modern_GLEW_NV_viewport_array2);
        newXS_deffile("OpenGL::Modern::GLEW_NV_viewport_swizzle", XS_OpenGL__Modern_GLEW_NV_viewport_swizzle);
        newXS_deffile("OpenGL::Modern::GLEW_OES_EGL_image", XS_OpenGL__Modern_GLEW_OES_EGL_image);
        newXS_deffile("OpenGL::Modern::GLEW_OES_EGL_image_external", XS_OpenGL__Modern_GLEW_OES_EGL_image_external);
        newXS_deffile("OpenGL::Modern::GLEW_OES_EGL_image_external_essl3", XS_OpenGL__Modern_GLEW_OES_EGL_image_external_essl3);
        newXS_deffile("OpenGL::Modern::GLEW_OES_blend_equation_separate", XS_OpenGL__Modern_GLEW_OES_blend_equation_separate);
        newXS_deffile("OpenGL::Modern::GLEW_OES_blend_func_separate", XS_OpenGL__Modern_GLEW_OES_blend_func_separate);
        newXS_deffile("OpenGL::Modern::GLEW_OES_blend_subtract", XS_OpenGL__Modern_GLEW_OES_blend_subtract);
        newXS_deffile("OpenGL::Modern::GLEW_OES_byte_coordinates", XS_OpenGL__Modern_GLEW_OES_byte_coordinates);
        newXS_deffile("OpenGL::Modern::GLEW_OES_compressed_ETC1_RGB8_texture", XS_OpenGL__Modern_GLEW_OES_compressed_ETC1_RGB8_texture);
        newXS_deffile("OpenGL::Modern::GLEW_OES_compressed_paletted_texture", XS_OpenGL__Modern_GLEW_OES_compressed_paletted_texture);
        newXS_deffile("OpenGL::Modern::GLEW_OES_copy_image", XS_OpenGL__Modern_GLEW_OES_copy_image);
        newXS_deffile("OpenGL::Modern::GLEW_OES_depth24", XS_OpenGL__Modern_GLEW_OES_depth24);
        newXS_deffile("OpenGL::Modern::GLEW_OES_depth32", XS_OpenGL__Modern_GLEW_OES_depth32);
        newXS_deffile("OpenGL::Modern::GLEW_OES_depth_texture", XS_OpenGL__Modern_GLEW_OES_depth_texture);
        newXS_deffile("OpenGL::Modern::GLEW_OES_depth_texture_cube_map", XS_OpenGL__Modern_GLEW_OES_depth_texture_cube_map);
        newXS_deffile("OpenGL::Modern::GLEW_OES_draw_buffers_indexed", XS_OpenGL__Modern_GLEW_OES_draw_buffers_indexed);
        newXS_deffile("OpenGL::Modern::GLEW_OES_draw_texture", XS_OpenGL__Modern_GLEW_OES_draw_texture);
        newXS_deffile("OpenGL::Modern::GLEW_OES_element_index_uint", XS_OpenGL__Modern_GLEW_OES_element_index_uint);
        newXS_deffile("OpenGL::Modern::GLEW_OES_extended_matrix_palette", XS_OpenGL__Modern_GLEW_OES_extended_matrix_palette);
        newXS_deffile("OpenGL::Modern::GLEW_OES_fbo_render_mipmap", XS_OpenGL__Modern_GLEW_OES_fbo_render_mipmap);
        newXS_deffile("OpenGL::Modern::GLEW_OES_fragment_precision_high", XS_OpenGL__Modern_GLEW_OES_fragment_precision_high);
        newXS_deffile("OpenGL::Modern::GLEW_OES_framebuffer_object", XS_OpenGL__Modern_GLEW_OES_framebuffer_object);
        newXS_deffile("OpenGL::Modern::GLEW_OES_geometry_point_size", XS_OpenGL__Modern_GLEW_OES_geometry_point_size);
        newXS_deffile("OpenGL::Modern::GLEW_OES_geometry_shader", XS_OpenGL__Modern_GLEW_OES_geometry_shader);
        newXS_deffile("OpenGL::Modern::GLEW_OES_get_program_binary", XS_OpenGL__Modern_GLEW_OES_get_program_binary);
        newXS_deffile("OpenGL::Modern::GLEW_OES_gpu_shader5", XS_OpenGL__Modern_GLEW_OES_gpu_shader5);
        newXS_deffile("OpenGL::Modern::GLEW_OES_mapbuffer", XS_OpenGL__Modern_GLEW_OES_mapbuffer);
        newXS_deffile("OpenGL::Modern::GLEW_OES_matrix_get", XS_OpenGL__Modern_GLEW_OES_matrix_get);
        newXS_deffile("OpenGL::Modern::GLEW_OES_matrix_palette", XS_OpenGL__Modern_GLEW_OES_matrix_palette);
        newXS_deffile("OpenGL::Modern::GLEW_OES_packed_depth_stencil", XS_OpenGL__Modern_GLEW_OES_packed_depth_stencil);
        newXS_deffile("OpenGL::Modern::GLEW_OES_point_size_array", XS_OpenGL__Modern_GLEW_OES_point_size_array);
        newXS_deffile("OpenGL::Modern::GLEW_OES_point_sprite", XS_OpenGL__Modern_GLEW_OES_point_sprite);
        newXS_deffile("OpenGL::Modern::GLEW_OES_read_format", XS_OpenGL__Modern_GLEW_OES_read_format);
        newXS_deffile("OpenGL::Modern::GLEW_OES_required_internalformat", XS_OpenGL__Modern_GLEW_OES_required_internalformat);
        newXS_deffile("OpenGL::Modern::GLEW_OES_rgb8_rgba8", XS_OpenGL__Modern_GLEW_OES_rgb8_rgba8);
        newXS_deffile("OpenGL::Modern::GLEW_OES_sample_shading", XS_OpenGL__Modern_GLEW_OES_sample_shading);
        newXS_deffile("OpenGL::Modern::GLEW_OES_sample_variables", XS_OpenGL__Modern_GLEW_OES_sample_variables);
        newXS_deffile("OpenGL::Modern::GLEW_OES_shader_image_atomic", XS_OpenGL__Modern_GLEW_OES_shader_image_atomic);
        newXS_deffile("OpenGL::Modern::GLEW_OES_shader_io_blocks", XS_OpenGL__Modern_GLEW_OES_shader_io_blocks);
        newXS_deffile("OpenGL::Modern::GLEW_OES_shader_multisample_interpolation", XS_OpenGL__Modern_GLEW_OES_shader_multisample_interpolation);
        newXS_deffile("OpenGL::Modern::GLEW_OES_single_precision", XS_OpenGL__Modern_GLEW_OES_single_precision);
        newXS_deffile("OpenGL::Modern::GLEW_OES_standard_derivatives", XS_OpenGL__Modern_GLEW_OES_standard_derivatives);
        newXS_deffile("OpenGL::Modern::GLEW_OES_stencil1", XS_OpenGL__Modern_GLEW_OES_stencil1);
        newXS_deffile("OpenGL::Modern::GLEW_OES_stencil4", XS_OpenGL__Modern_GLEW_OES_stencil4);
        newXS_deffile("OpenGL::Modern::GLEW_OES_stencil8", XS_OpenGL__Modern_GLEW_OES_stencil8);
        newXS_deffile("OpenGL::Modern::GLEW_OES_surfaceless_context", XS_OpenGL__Modern_GLEW_OES_surfaceless_context);
        newXS_deffile("OpenGL::Modern::GLEW_OES_tessellation_point_size", XS_OpenGL__Modern_GLEW_OES_tessellation_point_size);
        newXS_deffile("OpenGL::Modern::GLEW_OES_tessellation_shader", XS_OpenGL__Modern_GLEW_OES_tessellation_shader);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_3D", XS_OpenGL__Modern_GLEW_OES_texture_3D);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_border_clamp", XS_OpenGL__Modern_GLEW_OES_texture_border_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_buffer", XS_OpenGL__Modern_GLEW_OES_texture_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_compression_astc", XS_OpenGL__Modern_GLEW_OES_texture_compression_astc);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_cube_map", XS_OpenGL__Modern_GLEW_OES_texture_cube_map);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_cube_map_array", XS_OpenGL__Modern_GLEW_OES_texture_cube_map_array);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_env_crossbar", XS_OpenGL__Modern_GLEW_OES_texture_env_crossbar);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_mirrored_repeat", XS_OpenGL__Modern_GLEW_OES_texture_mirrored_repeat);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_npot", XS_OpenGL__Modern_GLEW_OES_texture_npot);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_stencil8", XS_OpenGL__Modern_GLEW_OES_texture_stencil8);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_storage_multisample_2d_array", XS_OpenGL__Modern_GLEW_OES_texture_storage_multisample_2d_array);
        newXS_deffile("OpenGL::Modern::GLEW_OES_texture_view", XS_OpenGL__Modern_GLEW_OES_texture_view);
        newXS_deffile("OpenGL::Modern::GLEW_OES_vertex_array_object", XS_OpenGL__Modern_GLEW_OES_vertex_array_object);
        newXS_deffile("OpenGL::Modern::GLEW_OES_vertex_half_float", XS_OpenGL__Modern_GLEW_OES_vertex_half_float);
        newXS_deffile("OpenGL::Modern::GLEW_OES_vertex_type_10_10_10_2", XS_OpenGL__Modern_GLEW_OES_vertex_type_10_10_10_2);
        newXS_deffile("OpenGL::Modern::GLEW_OML_interlace", XS_OpenGL__Modern_GLEW_OML_interlace);
        newXS_deffile("OpenGL::Modern::GLEW_OML_resample", XS_OpenGL__Modern_GLEW_OML_resample);
        newXS_deffile("OpenGL::Modern::GLEW_OML_subsample", XS_OpenGL__Modern_GLEW_OML_subsample);
        newXS_deffile("OpenGL::Modern::GLEW_OVR_multiview", XS_OpenGL__Modern_GLEW_OVR_multiview);
        newXS_deffile("OpenGL::Modern::GLEW_OVR_multiview2", XS_OpenGL__Modern_GLEW_OVR_multiview2);
        newXS_deffile("OpenGL::Modern::GLEW_OVR_multiview_multisampled_render_to_texture", XS_OpenGL__Modern_GLEW_OVR_multiview_multisampled_render_to_texture);
        newXS_deffile("OpenGL::Modern::GLEW_PGI_misc_hints", XS_OpenGL__Modern_GLEW_PGI_misc_hints);
        newXS_deffile("OpenGL::Modern::GLEW_PGI_vertex_hints", XS_OpenGL__Modern_GLEW_PGI_vertex_hints);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_YUV_texture_gather", XS_OpenGL__Modern_GLEW_QCOM_YUV_texture_gather);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_alpha_test", XS_OpenGL__Modern_GLEW_QCOM_alpha_test);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_binning_control", XS_OpenGL__Modern_GLEW_QCOM_binning_control);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_driver_control", XS_OpenGL__Modern_GLEW_QCOM_driver_control);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_extended_get", XS_OpenGL__Modern_GLEW_QCOM_extended_get);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_extended_get2", XS_OpenGL__Modern_GLEW_QCOM_extended_get2);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_frame_extrapolation", XS_OpenGL__Modern_GLEW_QCOM_frame_extrapolation);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_framebuffer_foveated", XS_OpenGL__Modern_GLEW_QCOM_framebuffer_foveated);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_motion_estimation", XS_OpenGL__Modern_GLEW_QCOM_motion_estimation);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_perfmon_global_mode", XS_OpenGL__Modern_GLEW_QCOM_perfmon_global_mode);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_render_sRGB_R8_RG8", XS_OpenGL__Modern_GLEW_QCOM_render_sRGB_R8_RG8);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_render_shared_exponent", XS_OpenGL__Modern_GLEW_QCOM_render_shared_exponent);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_shader_framebuffer_fetch_noncoherent", XS_OpenGL__Modern_GLEW_QCOM_shader_framebuffer_fetch_noncoherent);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_shader_framebuffer_fetch_rate", XS_OpenGL__Modern_GLEW_QCOM_shader_framebuffer_fetch_rate);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_shading_rate", XS_OpenGL__Modern_GLEW_QCOM_shading_rate);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_texture_foveated", XS_OpenGL__Modern_GLEW_QCOM_texture_foveated);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_texture_foveated2", XS_OpenGL__Modern_GLEW_QCOM_texture_foveated2);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_texture_foveated_subsampled_layout", XS_OpenGL__Modern_GLEW_QCOM_texture_foveated_subsampled_layout);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_texture_lod_bias", XS_OpenGL__Modern_GLEW_QCOM_texture_lod_bias);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_tiled_rendering", XS_OpenGL__Modern_GLEW_QCOM_tiled_rendering);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_writeonly_rendering", XS_OpenGL__Modern_GLEW_QCOM_writeonly_rendering);
        newXS_deffile("OpenGL::Modern::GLEW_QCOM_ycbcr_degamma", XS_OpenGL__Modern_GLEW_QCOM_ycbcr_degamma);
        newXS_deffile("OpenGL::Modern::GLEW_REGAL_ES1_0_compatibility", XS_OpenGL__Modern_GLEW_REGAL_ES1_0_compatibility);
        newXS_deffile("OpenGL::Modern::GLEW_REGAL_ES1_1_compatibility", XS_OpenGL__Modern_GLEW_REGAL_ES1_1_compatibility);
        newXS_deffile("OpenGL::Modern::GLEW_REGAL_enable", XS_OpenGL__Modern_GLEW_REGAL_enable);
        newXS_deffile("OpenGL::Modern::GLEW_REGAL_error_string", XS_OpenGL__Modern_GLEW_REGAL_error_string);
        newXS_deffile("OpenGL::Modern::GLEW_REGAL_extension_query", XS_OpenGL__Modern_GLEW_REGAL_extension_query);
        newXS_deffile("OpenGL::Modern::GLEW_REGAL_log", XS_OpenGL__Modern_GLEW_REGAL_log);
        newXS_deffile("OpenGL::Modern::GLEW_REGAL_proc_address", XS_OpenGL__Modern_GLEW_REGAL_proc_address);
        newXS_deffile("OpenGL::Modern::GLEW_REND_screen_coordinates", XS_OpenGL__Modern_GLEW_REND_screen_coordinates);
        newXS_deffile("OpenGL::Modern::GLEW_S3_s3tc", XS_OpenGL__Modern_GLEW_S3_s3tc);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_clip_band_hint", XS_OpenGL__Modern_GLEW_SGIS_clip_band_hint);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_color_range", XS_OpenGL__Modern_GLEW_SGIS_color_range);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_detail_texture", XS_OpenGL__Modern_GLEW_SGIS_detail_texture);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_fog_function", XS_OpenGL__Modern_GLEW_SGIS_fog_function);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_generate_mipmap", XS_OpenGL__Modern_GLEW_SGIS_generate_mipmap);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_line_texgen", XS_OpenGL__Modern_GLEW_SGIS_line_texgen);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_multisample", XS_OpenGL__Modern_GLEW_SGIS_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_multitexture", XS_OpenGL__Modern_GLEW_SGIS_multitexture);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_pixel_texture", XS_OpenGL__Modern_GLEW_SGIS_pixel_texture);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_point_line_texgen", XS_OpenGL__Modern_GLEW_SGIS_point_line_texgen);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_shared_multisample", XS_OpenGL__Modern_GLEW_SGIS_shared_multisample);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_sharpen_texture", XS_OpenGL__Modern_GLEW_SGIS_sharpen_texture);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_texture4D", XS_OpenGL__Modern_GLEW_SGIS_texture4D);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_texture_border_clamp", XS_OpenGL__Modern_GLEW_SGIS_texture_border_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_texture_edge_clamp", XS_OpenGL__Modern_GLEW_SGIS_texture_edge_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_texture_filter4", XS_OpenGL__Modern_GLEW_SGIS_texture_filter4);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_texture_lod", XS_OpenGL__Modern_GLEW_SGIS_texture_lod);
        newXS_deffile("OpenGL::Modern::GLEW_SGIS_texture_select", XS_OpenGL__Modern_GLEW_SGIS_texture_select);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_async", XS_OpenGL__Modern_GLEW_SGIX_async);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_async_histogram", XS_OpenGL__Modern_GLEW_SGIX_async_histogram);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_async_pixel", XS_OpenGL__Modern_GLEW_SGIX_async_pixel);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_bali_g_instruments", XS_OpenGL__Modern_GLEW_SGIX_bali_g_instruments);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_bali_r_instruments", XS_OpenGL__Modern_GLEW_SGIX_bali_r_instruments);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_bali_timer_instruments", XS_OpenGL__Modern_GLEW_SGIX_bali_timer_instruments);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_blend_alpha_minmax", XS_OpenGL__Modern_GLEW_SGIX_blend_alpha_minmax);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_blend_cadd", XS_OpenGL__Modern_GLEW_SGIX_blend_cadd);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_blend_cmultiply", XS_OpenGL__Modern_GLEW_SGIX_blend_cmultiply);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_calligraphic_fragment", XS_OpenGL__Modern_GLEW_SGIX_calligraphic_fragment);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_clipmap", XS_OpenGL__Modern_GLEW_SGIX_clipmap);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_color_matrix_accuracy", XS_OpenGL__Modern_GLEW_SGIX_color_matrix_accuracy);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_color_table_index_mode", XS_OpenGL__Modern_GLEW_SGIX_color_table_index_mode);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_complex_polar", XS_OpenGL__Modern_GLEW_SGIX_complex_polar);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_convolution_accuracy", XS_OpenGL__Modern_GLEW_SGIX_convolution_accuracy);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_cube_map", XS_OpenGL__Modern_GLEW_SGIX_cube_map);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_cylinder_texgen", XS_OpenGL__Modern_GLEW_SGIX_cylinder_texgen);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_datapipe", XS_OpenGL__Modern_GLEW_SGIX_datapipe);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_decimation", XS_OpenGL__Modern_GLEW_SGIX_decimation);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_depth_pass_instrument", XS_OpenGL__Modern_GLEW_SGIX_depth_pass_instrument);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_depth_texture", XS_OpenGL__Modern_GLEW_SGIX_depth_texture);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_dvc", XS_OpenGL__Modern_GLEW_SGIX_dvc);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_flush_raster", XS_OpenGL__Modern_GLEW_SGIX_flush_raster);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_fog_blend", XS_OpenGL__Modern_GLEW_SGIX_fog_blend);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_fog_factor_to_alpha", XS_OpenGL__Modern_GLEW_SGIX_fog_factor_to_alpha);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_fog_layers", XS_OpenGL__Modern_GLEW_SGIX_fog_layers);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_fog_offset", XS_OpenGL__Modern_GLEW_SGIX_fog_offset);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_fog_patchy", XS_OpenGL__Modern_GLEW_SGIX_fog_patchy);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_fog_scale", XS_OpenGL__Modern_GLEW_SGIX_fog_scale);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_fog_texture", XS_OpenGL__Modern_GLEW_SGIX_fog_texture);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_fragment_lighting_space", XS_OpenGL__Modern_GLEW_SGIX_fragment_lighting_space);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_fragment_specular_lighting", XS_OpenGL__Modern_GLEW_SGIX_fragment_specular_lighting);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_fragments_instrument", XS_OpenGL__Modern_GLEW_SGIX_fragments_instrument);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_framezoom", XS_OpenGL__Modern_GLEW_SGIX_framezoom);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_icc_texture", XS_OpenGL__Modern_GLEW_SGIX_icc_texture);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_igloo_interface", XS_OpenGL__Modern_GLEW_SGIX_igloo_interface);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_image_compression", XS_OpenGL__Modern_GLEW_SGIX_image_compression);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_impact_pixel_texture", XS_OpenGL__Modern_GLEW_SGIX_impact_pixel_texture);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_instrument_error", XS_OpenGL__Modern_GLEW_SGIX_instrument_error);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_interlace", XS_OpenGL__Modern_GLEW_SGIX_interlace);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_ir_instrument1", XS_OpenGL__Modern_GLEW_SGIX_ir_instrument1);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_line_quality_hint", XS_OpenGL__Modern_GLEW_SGIX_line_quality_hint);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_list_priority", XS_OpenGL__Modern_GLEW_SGIX_list_priority);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_mpeg1", XS_OpenGL__Modern_GLEW_SGIX_mpeg1);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_mpeg2", XS_OpenGL__Modern_GLEW_SGIX_mpeg2);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_nonlinear_lighting_pervertex", XS_OpenGL__Modern_GLEW_SGIX_nonlinear_lighting_pervertex);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_nurbs_eval", XS_OpenGL__Modern_GLEW_SGIX_nurbs_eval);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_occlusion_instrument", XS_OpenGL__Modern_GLEW_SGIX_occlusion_instrument);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_packed_6bytes", XS_OpenGL__Modern_GLEW_SGIX_packed_6bytes);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_pixel_texture", XS_OpenGL__Modern_GLEW_SGIX_pixel_texture);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_pixel_texture_bits", XS_OpenGL__Modern_GLEW_SGIX_pixel_texture_bits);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_pixel_texture_lod", XS_OpenGL__Modern_GLEW_SGIX_pixel_texture_lod);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_pixel_tiles", XS_OpenGL__Modern_GLEW_SGIX_pixel_tiles);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_polynomial_ffd", XS_OpenGL__Modern_GLEW_SGIX_polynomial_ffd);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_quad_mesh", XS_OpenGL__Modern_GLEW_SGIX_quad_mesh);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_reference_plane", XS_OpenGL__Modern_GLEW_SGIX_reference_plane);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_resample", XS_OpenGL__Modern_GLEW_SGIX_resample);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_scalebias_hint", XS_OpenGL__Modern_GLEW_SGIX_scalebias_hint);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_shadow", XS_OpenGL__Modern_GLEW_SGIX_shadow);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_shadow_ambient", XS_OpenGL__Modern_GLEW_SGIX_shadow_ambient);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_slim", XS_OpenGL__Modern_GLEW_SGIX_slim);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_spotlight_cutoff", XS_OpenGL__Modern_GLEW_SGIX_spotlight_cutoff);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_sprite", XS_OpenGL__Modern_GLEW_SGIX_sprite);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_subdiv_patch", XS_OpenGL__Modern_GLEW_SGIX_subdiv_patch);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_subsample", XS_OpenGL__Modern_GLEW_SGIX_subsample);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_tag_sample_buffer", XS_OpenGL__Modern_GLEW_SGIX_tag_sample_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_texture_add_env", XS_OpenGL__Modern_GLEW_SGIX_texture_add_env);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_texture_coordinate_clamp", XS_OpenGL__Modern_GLEW_SGIX_texture_coordinate_clamp);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_texture_lod_bias", XS_OpenGL__Modern_GLEW_SGIX_texture_lod_bias);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_texture_mipmap_anisotropic", XS_OpenGL__Modern_GLEW_SGIX_texture_mipmap_anisotropic);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_texture_multi_buffer", XS_OpenGL__Modern_GLEW_SGIX_texture_multi_buffer);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_texture_phase", XS_OpenGL__Modern_GLEW_SGIX_texture_phase);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_texture_range", XS_OpenGL__Modern_GLEW_SGIX_texture_range);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_texture_scale_bias", XS_OpenGL__Modern_GLEW_SGIX_texture_scale_bias);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_texture_supersample", XS_OpenGL__Modern_GLEW_SGIX_texture_supersample);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_vector_ops", XS_OpenGL__Modern_GLEW_SGIX_vector_ops);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_vertex_array_object", XS_OpenGL__Modern_GLEW_SGIX_vertex_array_object);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_vertex_preclip", XS_OpenGL__Modern_GLEW_SGIX_vertex_preclip);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_vertex_preclip_hint", XS_OpenGL__Modern_GLEW_SGIX_vertex_preclip_hint);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_ycrcb", XS_OpenGL__Modern_GLEW_SGIX_ycrcb);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_ycrcb_subsample", XS_OpenGL__Modern_GLEW_SGIX_ycrcb_subsample);
        newXS_deffile("OpenGL::Modern::GLEW_SGIX_ycrcba", XS_OpenGL__Modern_GLEW_SGIX_ycrcba);
        newXS_deffile("OpenGL::Modern::GLEW_SGI_color_matrix", XS_OpenGL__Modern_GLEW_SGI_color_matrix);
        newXS_deffile("OpenGL::Modern::GLEW_SGI_color_table", XS_OpenGL__Modern_GLEW_SGI_color_table);
        newXS_deffile("OpenGL::Modern::GLEW_SGI_complex", XS_OpenGL__Modern_GLEW_SGI_complex);
        newXS_deffile("OpenGL::Modern::GLEW_SGI_complex_type", XS_OpenGL__Modern_GLEW_SGI_complex_type);
        newXS_deffile("OpenGL::Modern::GLEW_SGI_fft", XS_OpenGL__Modern_GLEW_SGI_fft);
        newXS_deffile("OpenGL::Modern::GLEW_SGI_texture_color_table", XS_OpenGL__Modern_GLEW_SGI_texture_color_table);
        newXS_deffile("OpenGL::Modern::GLEW_SUNX_constant_data", XS_OpenGL__Modern_GLEW_SUNX_constant_data);
        newXS_deffile("OpenGL::Modern::GLEW_SUN_convolution_border_modes", XS_OpenGL__Modern_GLEW_SUN_convolution_border_modes);
        newXS_deffile("OpenGL::Modern::GLEW_SUN_global_alpha", XS_OpenGL__Modern_GLEW_SUN_global_alpha);
        newXS_deffile("OpenGL::Modern::GLEW_SUN_mesh_array", XS_OpenGL__Modern_GLEW_SUN_mesh_array);
        newXS_deffile("OpenGL::Modern::GLEW_SUN_read_video_pixels", XS_OpenGL__Modern_GLEW_SUN_read_video_pixels);
        newXS_deffile("OpenGL::Modern::GLEW_SUN_slice_accum", XS_OpenGL__Modern_GLEW_SUN_slice_accum);
        newXS_deffile("OpenGL::Modern::GLEW_SUN_triangle_list", XS_OpenGL__Modern_GLEW_SUN_triangle_list);
        newXS_deffile("OpenGL::Modern::GLEW_SUN_vertex", XS_OpenGL__Modern_GLEW_SUN_vertex);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_1_1", XS_OpenGL__Modern_GLEW_VERSION_1_1);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_1_2", XS_OpenGL__Modern_GLEW_VERSION_1_2);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_1_2_1", XS_OpenGL__Modern_GLEW_VERSION_1_2_1);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_1_3", XS_OpenGL__Modern_GLEW_VERSION_1_3);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_1_4", XS_OpenGL__Modern_GLEW_VERSION_1_4);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_1_5", XS_OpenGL__Modern_GLEW_VERSION_1_5);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_2_0", XS_OpenGL__Modern_GLEW_VERSION_2_0);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_2_1", XS_OpenGL__Modern_GLEW_VERSION_2_1);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_3_0", XS_OpenGL__Modern_GLEW_VERSION_3_0);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_3_1", XS_OpenGL__Modern_GLEW_VERSION_3_1);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_3_2", XS_OpenGL__Modern_GLEW_VERSION_3_2);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_3_3", XS_OpenGL__Modern_GLEW_VERSION_3_3);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_4_0", XS_OpenGL__Modern_GLEW_VERSION_4_0);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_4_1", XS_OpenGL__Modern_GLEW_VERSION_4_1);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_4_2", XS_OpenGL__Modern_GLEW_VERSION_4_2);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_4_3", XS_OpenGL__Modern_GLEW_VERSION_4_3);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_4_4", XS_OpenGL__Modern_GLEW_VERSION_4_4);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_4_5", XS_OpenGL__Modern_GLEW_VERSION_4_5);
        newXS_deffile("OpenGL::Modern::GLEW_VERSION_4_6", XS_OpenGL__Modern_GLEW_VERSION_4_6);
        newXS_deffile("OpenGL::Modern::GLEW_VIV_shader_binary", XS_OpenGL__Modern_GLEW_VIV_shader_binary);
        newXS_deffile("OpenGL::Modern::GLEW_WIN_phong_shading", XS_OpenGL__Modern_GLEW_WIN_phong_shading);
        newXS_deffile("OpenGL::Modern::GLEW_WIN_scene_markerXXX", XS_OpenGL__Modern_GLEW_WIN_scene_markerXXX);
        newXS_deffile("OpenGL::Modern::GLEW_WIN_specular_fog", XS_OpenGL__Modern_GLEW_WIN_specular_fog);
        newXS_deffile("OpenGL::Modern::GLEW_WIN_swap_hint", XS_OpenGL__Modern_GLEW_WIN_swap_hint);

    /* Initialisation Section */

#line 22 "lib/OpenGL/Modern/Const.xs"
  HV *stash = gv_stashpvn("OpenGL::Modern", strlen("OpenGL::Modern"), TRUE);
#include "const.h"

#line 27544 "lib/OpenGL/Modern/Const.c"

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

#ifdef __cplusplus
}
#endif
