GLboolean
GLEW_3DFX_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_3DFX_multisample, )
  RETVAL = GLEW_3DFX_multisample;
  OGLM_CHECK_ERR(GLEW_3DFX_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_3DFX_tbuffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_3DFX_tbuffer, )
  RETVAL = GLEW_3DFX_tbuffer;
  OGLM_CHECK_ERR(GLEW_3DFX_tbuffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_3DFX_texture_compression_FXT1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_3DFX_texture_compression_FXT1, )
  RETVAL = GLEW_3DFX_texture_compression_FXT1;
  OGLM_CHECK_ERR(GLEW_3DFX_texture_compression_FXT1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_blend_minmax_factor()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_blend_minmax_factor, )
  RETVAL = GLEW_AMD_blend_minmax_factor;
  OGLM_CHECK_ERR(GLEW_AMD_blend_minmax_factor, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_compressed_3DC_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_compressed_3DC_texture, )
  RETVAL = GLEW_AMD_compressed_3DC_texture;
  OGLM_CHECK_ERR(GLEW_AMD_compressed_3DC_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_compressed_ATC_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_compressed_ATC_texture, )
  RETVAL = GLEW_AMD_compressed_ATC_texture;
  OGLM_CHECK_ERR(GLEW_AMD_compressed_ATC_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_conservative_depth()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_conservative_depth, )
  RETVAL = GLEW_AMD_conservative_depth;
  OGLM_CHECK_ERR(GLEW_AMD_conservative_depth, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_debug_output()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_debug_output, )
  RETVAL = GLEW_AMD_debug_output;
  OGLM_CHECK_ERR(GLEW_AMD_debug_output, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_depth_clamp_separate()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_depth_clamp_separate, )
  RETVAL = GLEW_AMD_depth_clamp_separate;
  OGLM_CHECK_ERR(GLEW_AMD_depth_clamp_separate, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_draw_buffers_blend()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_draw_buffers_blend, )
  RETVAL = GLEW_AMD_draw_buffers_blend;
  OGLM_CHECK_ERR(GLEW_AMD_draw_buffers_blend, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_framebuffer_multisample_advanced()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_framebuffer_multisample_advanced, )
  RETVAL = GLEW_AMD_framebuffer_multisample_advanced;
  OGLM_CHECK_ERR(GLEW_AMD_framebuffer_multisample_advanced, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_framebuffer_sample_positions()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_framebuffer_sample_positions, )
  RETVAL = GLEW_AMD_framebuffer_sample_positions;
  OGLM_CHECK_ERR(GLEW_AMD_framebuffer_sample_positions, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_gcn_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_gcn_shader, )
  RETVAL = GLEW_AMD_gcn_shader;
  OGLM_CHECK_ERR(GLEW_AMD_gcn_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_gpu_shader_half_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_half_float, )
  RETVAL = GLEW_AMD_gpu_shader_half_float;
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_half_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_gpu_shader_half_float_fetch()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_half_float_fetch, )
  RETVAL = GLEW_AMD_gpu_shader_half_float_fetch;
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_half_float_fetch, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_gpu_shader_int16()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_int16, )
  RETVAL = GLEW_AMD_gpu_shader_int16;
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_int16, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_gpu_shader_int64()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_int64, )
  RETVAL = GLEW_AMD_gpu_shader_int64;
  OGLM_CHECK_ERR(GLEW_AMD_gpu_shader_int64, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_interleaved_elements()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_interleaved_elements, )
  RETVAL = GLEW_AMD_interleaved_elements;
  OGLM_CHECK_ERR(GLEW_AMD_interleaved_elements, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_multi_draw_indirect()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_multi_draw_indirect, )
  RETVAL = GLEW_AMD_multi_draw_indirect;
  OGLM_CHECK_ERR(GLEW_AMD_multi_draw_indirect, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_name_gen_delete()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_name_gen_delete, )
  RETVAL = GLEW_AMD_name_gen_delete;
  OGLM_CHECK_ERR(GLEW_AMD_name_gen_delete, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_occlusion_query_event()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_occlusion_query_event, )
  RETVAL = GLEW_AMD_occlusion_query_event;
  OGLM_CHECK_ERR(GLEW_AMD_occlusion_query_event, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_performance_monitor()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_performance_monitor, )
  RETVAL = GLEW_AMD_performance_monitor;
  OGLM_CHECK_ERR(GLEW_AMD_performance_monitor, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_pinned_memory()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_pinned_memory, )
  RETVAL = GLEW_AMD_pinned_memory;
  OGLM_CHECK_ERR(GLEW_AMD_pinned_memory, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_program_binary_Z400()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_program_binary_Z400, )
  RETVAL = GLEW_AMD_program_binary_Z400;
  OGLM_CHECK_ERR(GLEW_AMD_program_binary_Z400, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_query_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_query_buffer_object, )
  RETVAL = GLEW_AMD_query_buffer_object;
  OGLM_CHECK_ERR(GLEW_AMD_query_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_sample_positions()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_sample_positions, )
  RETVAL = GLEW_AMD_sample_positions;
  OGLM_CHECK_ERR(GLEW_AMD_sample_positions, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_seamless_cubemap_per_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_seamless_cubemap_per_texture, )
  RETVAL = GLEW_AMD_seamless_cubemap_per_texture;
  OGLM_CHECK_ERR(GLEW_AMD_seamless_cubemap_per_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_shader_atomic_counter_ops()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_atomic_counter_ops, )
  RETVAL = GLEW_AMD_shader_atomic_counter_ops;
  OGLM_CHECK_ERR(GLEW_AMD_shader_atomic_counter_ops, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_shader_ballot()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_ballot, )
  RETVAL = GLEW_AMD_shader_ballot;
  OGLM_CHECK_ERR(GLEW_AMD_shader_ballot, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_shader_explicit_vertex_parameter()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_explicit_vertex_parameter, )
  RETVAL = GLEW_AMD_shader_explicit_vertex_parameter;
  OGLM_CHECK_ERR(GLEW_AMD_shader_explicit_vertex_parameter, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_shader_image_load_store_lod()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_image_load_store_lod, )
  RETVAL = GLEW_AMD_shader_image_load_store_lod;
  OGLM_CHECK_ERR(GLEW_AMD_shader_image_load_store_lod, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_shader_stencil_export()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_stencil_export, )
  RETVAL = GLEW_AMD_shader_stencil_export;
  OGLM_CHECK_ERR(GLEW_AMD_shader_stencil_export, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_shader_stencil_value_export()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_stencil_value_export, )
  RETVAL = GLEW_AMD_shader_stencil_value_export;
  OGLM_CHECK_ERR(GLEW_AMD_shader_stencil_value_export, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_shader_trinary_minmax()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_shader_trinary_minmax, )
  RETVAL = GLEW_AMD_shader_trinary_minmax;
  OGLM_CHECK_ERR(GLEW_AMD_shader_trinary_minmax, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_sparse_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_sparse_texture, )
  RETVAL = GLEW_AMD_sparse_texture;
  OGLM_CHECK_ERR(GLEW_AMD_sparse_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_stencil_operation_extended()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_stencil_operation_extended, )
  RETVAL = GLEW_AMD_stencil_operation_extended;
  OGLM_CHECK_ERR(GLEW_AMD_stencil_operation_extended, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_texture_gather_bias_lod()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_texture_gather_bias_lod, )
  RETVAL = GLEW_AMD_texture_gather_bias_lod;
  OGLM_CHECK_ERR(GLEW_AMD_texture_gather_bias_lod, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_texture_texture4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_texture_texture4, )
  RETVAL = GLEW_AMD_texture_texture4;
  OGLM_CHECK_ERR(GLEW_AMD_texture_texture4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_transform_feedback3_lines_triangles()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_transform_feedback3_lines_triangles, )
  RETVAL = GLEW_AMD_transform_feedback3_lines_triangles;
  OGLM_CHECK_ERR(GLEW_AMD_transform_feedback3_lines_triangles, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_transform_feedback4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_transform_feedback4, )
  RETVAL = GLEW_AMD_transform_feedback4;
  OGLM_CHECK_ERR(GLEW_AMD_transform_feedback4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_vertex_shader_layer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_layer, )
  RETVAL = GLEW_AMD_vertex_shader_layer;
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_layer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_vertex_shader_tessellator()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_tessellator, )
  RETVAL = GLEW_AMD_vertex_shader_tessellator;
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_tessellator, )
OUTPUT:
  RETVAL

GLboolean
GLEW_AMD_vertex_shader_viewport_index()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_viewport_index, )
  RETVAL = GLEW_AMD_vertex_shader_viewport_index;
  OGLM_CHECK_ERR(GLEW_AMD_vertex_shader_viewport_index, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANDROID_extension_pack_es31a()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANDROID_extension_pack_es31a, )
  RETVAL = GLEW_ANDROID_extension_pack_es31a;
  OGLM_CHECK_ERR(GLEW_ANDROID_extension_pack_es31a, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_depth_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_depth_texture, )
  RETVAL = GLEW_ANGLE_depth_texture;
  OGLM_CHECK_ERR(GLEW_ANGLE_depth_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_framebuffer_blit()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_framebuffer_blit, )
  RETVAL = GLEW_ANGLE_framebuffer_blit;
  OGLM_CHECK_ERR(GLEW_ANGLE_framebuffer_blit, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_framebuffer_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_framebuffer_multisample, )
  RETVAL = GLEW_ANGLE_framebuffer_multisample;
  OGLM_CHECK_ERR(GLEW_ANGLE_framebuffer_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_instanced_arrays()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_instanced_arrays, )
  RETVAL = GLEW_ANGLE_instanced_arrays;
  OGLM_CHECK_ERR(GLEW_ANGLE_instanced_arrays, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_pack_reverse_row_order()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_pack_reverse_row_order, )
  RETVAL = GLEW_ANGLE_pack_reverse_row_order;
  OGLM_CHECK_ERR(GLEW_ANGLE_pack_reverse_row_order, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_program_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_program_binary, )
  RETVAL = GLEW_ANGLE_program_binary;
  OGLM_CHECK_ERR(GLEW_ANGLE_program_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_texture_compression_dxt1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt1, )
  RETVAL = GLEW_ANGLE_texture_compression_dxt1;
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_texture_compression_dxt3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt3, )
  RETVAL = GLEW_ANGLE_texture_compression_dxt3;
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_texture_compression_dxt5()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt5, )
  RETVAL = GLEW_ANGLE_texture_compression_dxt5;
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_compression_dxt5, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_texture_usage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_usage, )
  RETVAL = GLEW_ANGLE_texture_usage;
  OGLM_CHECK_ERR(GLEW_ANGLE_texture_usage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_timer_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_timer_query, )
  RETVAL = GLEW_ANGLE_timer_query;
  OGLM_CHECK_ERR(GLEW_ANGLE_timer_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ANGLE_translated_shader_source()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ANGLE_translated_shader_source, )
  RETVAL = GLEW_ANGLE_translated_shader_source;
  OGLM_CHECK_ERR(GLEW_ANGLE_translated_shader_source, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_aux_depth_stencil()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_aux_depth_stencil, )
  RETVAL = GLEW_APPLE_aux_depth_stencil;
  OGLM_CHECK_ERR(GLEW_APPLE_aux_depth_stencil, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_client_storage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_client_storage, )
  RETVAL = GLEW_APPLE_client_storage;
  OGLM_CHECK_ERR(GLEW_APPLE_client_storage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_clip_distance()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_clip_distance, )
  RETVAL = GLEW_APPLE_clip_distance;
  OGLM_CHECK_ERR(GLEW_APPLE_clip_distance, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_color_buffer_packed_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_color_buffer_packed_float, )
  RETVAL = GLEW_APPLE_color_buffer_packed_float;
  OGLM_CHECK_ERR(GLEW_APPLE_color_buffer_packed_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_copy_texture_levels()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_copy_texture_levels, )
  RETVAL = GLEW_APPLE_copy_texture_levels;
  OGLM_CHECK_ERR(GLEW_APPLE_copy_texture_levels, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_element_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_element_array, )
  RETVAL = GLEW_APPLE_element_array;
  OGLM_CHECK_ERR(GLEW_APPLE_element_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_fence()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_fence, )
  RETVAL = GLEW_APPLE_fence;
  OGLM_CHECK_ERR(GLEW_APPLE_fence, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_float_pixels()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_float_pixels, )
  RETVAL = GLEW_APPLE_float_pixels;
  OGLM_CHECK_ERR(GLEW_APPLE_float_pixels, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_flush_buffer_range()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_flush_buffer_range, )
  RETVAL = GLEW_APPLE_flush_buffer_range;
  OGLM_CHECK_ERR(GLEW_APPLE_flush_buffer_range, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_framebuffer_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_framebuffer_multisample, )
  RETVAL = GLEW_APPLE_framebuffer_multisample;
  OGLM_CHECK_ERR(GLEW_APPLE_framebuffer_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_object_purgeable()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_object_purgeable, )
  RETVAL = GLEW_APPLE_object_purgeable;
  OGLM_CHECK_ERR(GLEW_APPLE_object_purgeable, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_pixel_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_pixel_buffer, )
  RETVAL = GLEW_APPLE_pixel_buffer;
  OGLM_CHECK_ERR(GLEW_APPLE_pixel_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_rgb_422()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_rgb_422, )
  RETVAL = GLEW_APPLE_rgb_422;
  OGLM_CHECK_ERR(GLEW_APPLE_rgb_422, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_row_bytes()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_row_bytes, )
  RETVAL = GLEW_APPLE_row_bytes;
  OGLM_CHECK_ERR(GLEW_APPLE_row_bytes, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_specular_vector()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_specular_vector, )
  RETVAL = GLEW_APPLE_specular_vector;
  OGLM_CHECK_ERR(GLEW_APPLE_specular_vector, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_sync()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_sync, )
  RETVAL = GLEW_APPLE_sync;
  OGLM_CHECK_ERR(GLEW_APPLE_sync, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_texture_2D_limited_npot()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_texture_2D_limited_npot, )
  RETVAL = GLEW_APPLE_texture_2D_limited_npot;
  OGLM_CHECK_ERR(GLEW_APPLE_texture_2D_limited_npot, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_texture_format_BGRA8888()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_texture_format_BGRA8888, )
  RETVAL = GLEW_APPLE_texture_format_BGRA8888;
  OGLM_CHECK_ERR(GLEW_APPLE_texture_format_BGRA8888, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_texture_max_level()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_texture_max_level, )
  RETVAL = GLEW_APPLE_texture_max_level;
  OGLM_CHECK_ERR(GLEW_APPLE_texture_max_level, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_texture_packed_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_texture_packed_float, )
  RETVAL = GLEW_APPLE_texture_packed_float;
  OGLM_CHECK_ERR(GLEW_APPLE_texture_packed_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_texture_range()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_texture_range, )
  RETVAL = GLEW_APPLE_texture_range;
  OGLM_CHECK_ERR(GLEW_APPLE_texture_range, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_transform_hint()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_transform_hint, )
  RETVAL = GLEW_APPLE_transform_hint;
  OGLM_CHECK_ERR(GLEW_APPLE_transform_hint, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_vertex_array_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_array_object, )
  RETVAL = GLEW_APPLE_vertex_array_object;
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_array_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_vertex_array_range()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_array_range, )
  RETVAL = GLEW_APPLE_vertex_array_range;
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_array_range, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_vertex_program_evaluators()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_program_evaluators, )
  RETVAL = GLEW_APPLE_vertex_program_evaluators;
  OGLM_CHECK_ERR(GLEW_APPLE_vertex_program_evaluators, )
OUTPUT:
  RETVAL

GLboolean
GLEW_APPLE_ycbcr_422()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_APPLE_ycbcr_422, )
  RETVAL = GLEW_APPLE_ycbcr_422;
  OGLM_CHECK_ERR(GLEW_APPLE_ycbcr_422, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_ES2_compatibility()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_ES2_compatibility, )
  RETVAL = GLEW_ARB_ES2_compatibility;
  OGLM_CHECK_ERR(GLEW_ARB_ES2_compatibility, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_ES3_1_compatibility()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_ES3_1_compatibility, )
  RETVAL = GLEW_ARB_ES3_1_compatibility;
  OGLM_CHECK_ERR(GLEW_ARB_ES3_1_compatibility, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_ES3_2_compatibility()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_ES3_2_compatibility, )
  RETVAL = GLEW_ARB_ES3_2_compatibility;
  OGLM_CHECK_ERR(GLEW_ARB_ES3_2_compatibility, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_ES3_compatibility()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_ES3_compatibility, )
  RETVAL = GLEW_ARB_ES3_compatibility;
  OGLM_CHECK_ERR(GLEW_ARB_ES3_compatibility, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_arrays_of_arrays()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_arrays_of_arrays, )
  RETVAL = GLEW_ARB_arrays_of_arrays;
  OGLM_CHECK_ERR(GLEW_ARB_arrays_of_arrays, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_base_instance()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_base_instance, )
  RETVAL = GLEW_ARB_base_instance;
  OGLM_CHECK_ERR(GLEW_ARB_base_instance, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_bindless_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_bindless_texture, )
  RETVAL = GLEW_ARB_bindless_texture;
  OGLM_CHECK_ERR(GLEW_ARB_bindless_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_blend_func_extended()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_blend_func_extended, )
  RETVAL = GLEW_ARB_blend_func_extended;
  OGLM_CHECK_ERR(GLEW_ARB_blend_func_extended, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_buffer_storage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_buffer_storage, )
  RETVAL = GLEW_ARB_buffer_storage;
  OGLM_CHECK_ERR(GLEW_ARB_buffer_storage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_cl_event()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_cl_event, )
  RETVAL = GLEW_ARB_cl_event;
  OGLM_CHECK_ERR(GLEW_ARB_cl_event, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_clear_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_clear_buffer_object, )
  RETVAL = GLEW_ARB_clear_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_clear_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_clear_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_clear_texture, )
  RETVAL = GLEW_ARB_clear_texture;
  OGLM_CHECK_ERR(GLEW_ARB_clear_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_clip_control()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_clip_control, )
  RETVAL = GLEW_ARB_clip_control;
  OGLM_CHECK_ERR(GLEW_ARB_clip_control, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_color_buffer_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_color_buffer_float, )
  RETVAL = GLEW_ARB_color_buffer_float;
  OGLM_CHECK_ERR(GLEW_ARB_color_buffer_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_compatibility()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_compatibility, )
  RETVAL = GLEW_ARB_compatibility;
  OGLM_CHECK_ERR(GLEW_ARB_compatibility, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_compressed_texture_pixel_storage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_compressed_texture_pixel_storage, )
  RETVAL = GLEW_ARB_compressed_texture_pixel_storage;
  OGLM_CHECK_ERR(GLEW_ARB_compressed_texture_pixel_storage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_compute_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_compute_shader, )
  RETVAL = GLEW_ARB_compute_shader;
  OGLM_CHECK_ERR(GLEW_ARB_compute_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_compute_variable_group_size()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_compute_variable_group_size, )
  RETVAL = GLEW_ARB_compute_variable_group_size;
  OGLM_CHECK_ERR(GLEW_ARB_compute_variable_group_size, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_conditional_render_inverted()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_conditional_render_inverted, )
  RETVAL = GLEW_ARB_conditional_render_inverted;
  OGLM_CHECK_ERR(GLEW_ARB_conditional_render_inverted, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_conservative_depth()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_conservative_depth, )
  RETVAL = GLEW_ARB_conservative_depth;
  OGLM_CHECK_ERR(GLEW_ARB_conservative_depth, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_copy_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_copy_buffer, )
  RETVAL = GLEW_ARB_copy_buffer;
  OGLM_CHECK_ERR(GLEW_ARB_copy_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_copy_image()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_copy_image, )
  RETVAL = GLEW_ARB_copy_image;
  OGLM_CHECK_ERR(GLEW_ARB_copy_image, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_cull_distance()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_cull_distance, )
  RETVAL = GLEW_ARB_cull_distance;
  OGLM_CHECK_ERR(GLEW_ARB_cull_distance, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_debug_output()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_debug_output, )
  RETVAL = GLEW_ARB_debug_output;
  OGLM_CHECK_ERR(GLEW_ARB_debug_output, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_depth_buffer_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_depth_buffer_float, )
  RETVAL = GLEW_ARB_depth_buffer_float;
  OGLM_CHECK_ERR(GLEW_ARB_depth_buffer_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_depth_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_depth_clamp, )
  RETVAL = GLEW_ARB_depth_clamp;
  OGLM_CHECK_ERR(GLEW_ARB_depth_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_depth_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_depth_texture, )
  RETVAL = GLEW_ARB_depth_texture;
  OGLM_CHECK_ERR(GLEW_ARB_depth_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_derivative_control()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_derivative_control, )
  RETVAL = GLEW_ARB_derivative_control;
  OGLM_CHECK_ERR(GLEW_ARB_derivative_control, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_direct_state_access()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_direct_state_access, )
  RETVAL = GLEW_ARB_direct_state_access;
  OGLM_CHECK_ERR(GLEW_ARB_direct_state_access, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_draw_buffers()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_draw_buffers, )
  RETVAL = GLEW_ARB_draw_buffers;
  OGLM_CHECK_ERR(GLEW_ARB_draw_buffers, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_draw_buffers_blend()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_draw_buffers_blend, )
  RETVAL = GLEW_ARB_draw_buffers_blend;
  OGLM_CHECK_ERR(GLEW_ARB_draw_buffers_blend, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_draw_elements_base_vertex()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_draw_elements_base_vertex, )
  RETVAL = GLEW_ARB_draw_elements_base_vertex;
  OGLM_CHECK_ERR(GLEW_ARB_draw_elements_base_vertex, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_draw_indirect()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_draw_indirect, )
  RETVAL = GLEW_ARB_draw_indirect;
  OGLM_CHECK_ERR(GLEW_ARB_draw_indirect, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_draw_instanced()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_draw_instanced, )
  RETVAL = GLEW_ARB_draw_instanced;
  OGLM_CHECK_ERR(GLEW_ARB_draw_instanced, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_enhanced_layouts()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_enhanced_layouts, )
  RETVAL = GLEW_ARB_enhanced_layouts;
  OGLM_CHECK_ERR(GLEW_ARB_enhanced_layouts, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_explicit_attrib_location()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_explicit_attrib_location, )
  RETVAL = GLEW_ARB_explicit_attrib_location;
  OGLM_CHECK_ERR(GLEW_ARB_explicit_attrib_location, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_explicit_uniform_location()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_explicit_uniform_location, )
  RETVAL = GLEW_ARB_explicit_uniform_location;
  OGLM_CHECK_ERR(GLEW_ARB_explicit_uniform_location, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_fragment_coord_conventions()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_coord_conventions, )
  RETVAL = GLEW_ARB_fragment_coord_conventions;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_coord_conventions, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_fragment_layer_viewport()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_layer_viewport, )
  RETVAL = GLEW_ARB_fragment_layer_viewport;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_layer_viewport, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_fragment_program()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_program, )
  RETVAL = GLEW_ARB_fragment_program;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_program, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_fragment_program_shadow()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_program_shadow, )
  RETVAL = GLEW_ARB_fragment_program_shadow;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_program_shadow, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_fragment_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_shader, )
  RETVAL = GLEW_ARB_fragment_shader;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_fragment_shader_interlock()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_fragment_shader_interlock, )
  RETVAL = GLEW_ARB_fragment_shader_interlock;
  OGLM_CHECK_ERR(GLEW_ARB_fragment_shader_interlock, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_framebuffer_no_attachments()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_no_attachments, )
  RETVAL = GLEW_ARB_framebuffer_no_attachments;
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_no_attachments, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_framebuffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_object, )
  RETVAL = GLEW_ARB_framebuffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_framebuffer_sRGB()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_sRGB, )
  RETVAL = GLEW_ARB_framebuffer_sRGB;
  OGLM_CHECK_ERR(GLEW_ARB_framebuffer_sRGB, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_geometry_shader4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_geometry_shader4, )
  RETVAL = GLEW_ARB_geometry_shader4;
  OGLM_CHECK_ERR(GLEW_ARB_geometry_shader4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_get_program_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_get_program_binary, )
  RETVAL = GLEW_ARB_get_program_binary;
  OGLM_CHECK_ERR(GLEW_ARB_get_program_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_get_texture_sub_image()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_get_texture_sub_image, )
  RETVAL = GLEW_ARB_get_texture_sub_image;
  OGLM_CHECK_ERR(GLEW_ARB_get_texture_sub_image, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_gl_spirv()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_gl_spirv, )
  RETVAL = GLEW_ARB_gl_spirv;
  OGLM_CHECK_ERR(GLEW_ARB_gl_spirv, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_gpu_shader5()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader5, )
  RETVAL = GLEW_ARB_gpu_shader5;
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader5, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_gpu_shader_fp64()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader_fp64, )
  RETVAL = GLEW_ARB_gpu_shader_fp64;
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader_fp64, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_gpu_shader_int64()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader_int64, )
  RETVAL = GLEW_ARB_gpu_shader_int64;
  OGLM_CHECK_ERR(GLEW_ARB_gpu_shader_int64, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_half_float_pixel()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_half_float_pixel, )
  RETVAL = GLEW_ARB_half_float_pixel;
  OGLM_CHECK_ERR(GLEW_ARB_half_float_pixel, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_half_float_vertex()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_half_float_vertex, )
  RETVAL = GLEW_ARB_half_float_vertex;
  OGLM_CHECK_ERR(GLEW_ARB_half_float_vertex, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_imaging()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_imaging, )
  RETVAL = GLEW_ARB_imaging;
  OGLM_CHECK_ERR(GLEW_ARB_imaging, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_indirect_parameters()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_indirect_parameters, )
  RETVAL = GLEW_ARB_indirect_parameters;
  OGLM_CHECK_ERR(GLEW_ARB_indirect_parameters, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_instanced_arrays()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_instanced_arrays, )
  RETVAL = GLEW_ARB_instanced_arrays;
  OGLM_CHECK_ERR(GLEW_ARB_instanced_arrays, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_internalformat_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_internalformat_query, )
  RETVAL = GLEW_ARB_internalformat_query;
  OGLM_CHECK_ERR(GLEW_ARB_internalformat_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_internalformat_query2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_internalformat_query2, )
  RETVAL = GLEW_ARB_internalformat_query2;
  OGLM_CHECK_ERR(GLEW_ARB_internalformat_query2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_invalidate_subdata()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_invalidate_subdata, )
  RETVAL = GLEW_ARB_invalidate_subdata;
  OGLM_CHECK_ERR(GLEW_ARB_invalidate_subdata, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_map_buffer_alignment()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_map_buffer_alignment, )
  RETVAL = GLEW_ARB_map_buffer_alignment;
  OGLM_CHECK_ERR(GLEW_ARB_map_buffer_alignment, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_map_buffer_range()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_map_buffer_range, )
  RETVAL = GLEW_ARB_map_buffer_range;
  OGLM_CHECK_ERR(GLEW_ARB_map_buffer_range, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_matrix_palette()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_matrix_palette, )
  RETVAL = GLEW_ARB_matrix_palette;
  OGLM_CHECK_ERR(GLEW_ARB_matrix_palette, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_multi_bind()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_multi_bind, )
  RETVAL = GLEW_ARB_multi_bind;
  OGLM_CHECK_ERR(GLEW_ARB_multi_bind, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_multi_draw_indirect()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_multi_draw_indirect, )
  RETVAL = GLEW_ARB_multi_draw_indirect;
  OGLM_CHECK_ERR(GLEW_ARB_multi_draw_indirect, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_multisample, )
  RETVAL = GLEW_ARB_multisample;
  OGLM_CHECK_ERR(GLEW_ARB_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_multitexture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_multitexture, )
  RETVAL = GLEW_ARB_multitexture;
  OGLM_CHECK_ERR(GLEW_ARB_multitexture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_occlusion_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_occlusion_query, )
  RETVAL = GLEW_ARB_occlusion_query;
  OGLM_CHECK_ERR(GLEW_ARB_occlusion_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_occlusion_query2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_occlusion_query2, )
  RETVAL = GLEW_ARB_occlusion_query2;
  OGLM_CHECK_ERR(GLEW_ARB_occlusion_query2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_parallel_shader_compile()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_parallel_shader_compile, )
  RETVAL = GLEW_ARB_parallel_shader_compile;
  OGLM_CHECK_ERR(GLEW_ARB_parallel_shader_compile, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_pipeline_statistics_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_pipeline_statistics_query, )
  RETVAL = GLEW_ARB_pipeline_statistics_query;
  OGLM_CHECK_ERR(GLEW_ARB_pipeline_statistics_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_pixel_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_pixel_buffer_object, )
  RETVAL = GLEW_ARB_pixel_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_pixel_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_point_parameters()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_point_parameters, )
  RETVAL = GLEW_ARB_point_parameters;
  OGLM_CHECK_ERR(GLEW_ARB_point_parameters, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_point_sprite()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_point_sprite, )
  RETVAL = GLEW_ARB_point_sprite;
  OGLM_CHECK_ERR(GLEW_ARB_point_sprite, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_polygon_offset_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_polygon_offset_clamp, )
  RETVAL = GLEW_ARB_polygon_offset_clamp;
  OGLM_CHECK_ERR(GLEW_ARB_polygon_offset_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_post_depth_coverage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_post_depth_coverage, )
  RETVAL = GLEW_ARB_post_depth_coverage;
  OGLM_CHECK_ERR(GLEW_ARB_post_depth_coverage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_program_interface_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_program_interface_query, )
  RETVAL = GLEW_ARB_program_interface_query;
  OGLM_CHECK_ERR(GLEW_ARB_program_interface_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_provoking_vertex()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_provoking_vertex, )
  RETVAL = GLEW_ARB_provoking_vertex;
  OGLM_CHECK_ERR(GLEW_ARB_provoking_vertex, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_query_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_query_buffer_object, )
  RETVAL = GLEW_ARB_query_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_query_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_robust_buffer_access_behavior()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_robust_buffer_access_behavior, )
  RETVAL = GLEW_ARB_robust_buffer_access_behavior;
  OGLM_CHECK_ERR(GLEW_ARB_robust_buffer_access_behavior, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_robustness()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_robustness, )
  RETVAL = GLEW_ARB_robustness;
  OGLM_CHECK_ERR(GLEW_ARB_robustness, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_robustness_application_isolation()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_robustness_application_isolation, )
  RETVAL = GLEW_ARB_robustness_application_isolation;
  OGLM_CHECK_ERR(GLEW_ARB_robustness_application_isolation, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_robustness_share_group_isolation()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_robustness_share_group_isolation, )
  RETVAL = GLEW_ARB_robustness_share_group_isolation;
  OGLM_CHECK_ERR(GLEW_ARB_robustness_share_group_isolation, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_sample_locations()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sample_locations, )
  RETVAL = GLEW_ARB_sample_locations;
  OGLM_CHECK_ERR(GLEW_ARB_sample_locations, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_sample_shading()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sample_shading, )
  RETVAL = GLEW_ARB_sample_shading;
  OGLM_CHECK_ERR(GLEW_ARB_sample_shading, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_sampler_objects()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sampler_objects, )
  RETVAL = GLEW_ARB_sampler_objects;
  OGLM_CHECK_ERR(GLEW_ARB_sampler_objects, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_seamless_cube_map()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_seamless_cube_map, )
  RETVAL = GLEW_ARB_seamless_cube_map;
  OGLM_CHECK_ERR(GLEW_ARB_seamless_cube_map, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_seamless_cubemap_per_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_seamless_cubemap_per_texture, )
  RETVAL = GLEW_ARB_seamless_cubemap_per_texture;
  OGLM_CHECK_ERR(GLEW_ARB_seamless_cubemap_per_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_separate_shader_objects()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_separate_shader_objects, )
  RETVAL = GLEW_ARB_separate_shader_objects;
  OGLM_CHECK_ERR(GLEW_ARB_separate_shader_objects, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_atomic_counter_ops()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_atomic_counter_ops, )
  RETVAL = GLEW_ARB_shader_atomic_counter_ops;
  OGLM_CHECK_ERR(GLEW_ARB_shader_atomic_counter_ops, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_atomic_counters()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_atomic_counters, )
  RETVAL = GLEW_ARB_shader_atomic_counters;
  OGLM_CHECK_ERR(GLEW_ARB_shader_atomic_counters, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_ballot()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_ballot, )
  RETVAL = GLEW_ARB_shader_ballot;
  OGLM_CHECK_ERR(GLEW_ARB_shader_ballot, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_bit_encoding()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_bit_encoding, )
  RETVAL = GLEW_ARB_shader_bit_encoding;
  OGLM_CHECK_ERR(GLEW_ARB_shader_bit_encoding, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_clock()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_clock, )
  RETVAL = GLEW_ARB_shader_clock;
  OGLM_CHECK_ERR(GLEW_ARB_shader_clock, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_draw_parameters()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_draw_parameters, )
  RETVAL = GLEW_ARB_shader_draw_parameters;
  OGLM_CHECK_ERR(GLEW_ARB_shader_draw_parameters, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_group_vote()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_group_vote, )
  RETVAL = GLEW_ARB_shader_group_vote;
  OGLM_CHECK_ERR(GLEW_ARB_shader_group_vote, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_image_load_store()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_image_load_store, )
  RETVAL = GLEW_ARB_shader_image_load_store;
  OGLM_CHECK_ERR(GLEW_ARB_shader_image_load_store, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_image_size()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_image_size, )
  RETVAL = GLEW_ARB_shader_image_size;
  OGLM_CHECK_ERR(GLEW_ARB_shader_image_size, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_objects()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_objects, )
  RETVAL = GLEW_ARB_shader_objects;
  OGLM_CHECK_ERR(GLEW_ARB_shader_objects, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_precision()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_precision, )
  RETVAL = GLEW_ARB_shader_precision;
  OGLM_CHECK_ERR(GLEW_ARB_shader_precision, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_stencil_export()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_stencil_export, )
  RETVAL = GLEW_ARB_shader_stencil_export;
  OGLM_CHECK_ERR(GLEW_ARB_shader_stencil_export, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_storage_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_storage_buffer_object, )
  RETVAL = GLEW_ARB_shader_storage_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_shader_storage_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_subroutine()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_subroutine, )
  RETVAL = GLEW_ARB_shader_subroutine;
  OGLM_CHECK_ERR(GLEW_ARB_shader_subroutine, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_texture_image_samples()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_texture_image_samples, )
  RETVAL = GLEW_ARB_shader_texture_image_samples;
  OGLM_CHECK_ERR(GLEW_ARB_shader_texture_image_samples, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_texture_lod()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_texture_lod, )
  RETVAL = GLEW_ARB_shader_texture_lod;
  OGLM_CHECK_ERR(GLEW_ARB_shader_texture_lod, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shader_viewport_layer_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shader_viewport_layer_array, )
  RETVAL = GLEW_ARB_shader_viewport_layer_array;
  OGLM_CHECK_ERR(GLEW_ARB_shader_viewport_layer_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shading_language_100()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_100, )
  RETVAL = GLEW_ARB_shading_language_100;
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_100, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shading_language_420pack()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_420pack, )
  RETVAL = GLEW_ARB_shading_language_420pack;
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_420pack, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shading_language_include()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_include, )
  RETVAL = GLEW_ARB_shading_language_include;
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_include, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shading_language_packing()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_packing, )
  RETVAL = GLEW_ARB_shading_language_packing;
  OGLM_CHECK_ERR(GLEW_ARB_shading_language_packing, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shadow()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shadow, )
  RETVAL = GLEW_ARB_shadow;
  OGLM_CHECK_ERR(GLEW_ARB_shadow, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_shadow_ambient()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_shadow_ambient, )
  RETVAL = GLEW_ARB_shadow_ambient;
  OGLM_CHECK_ERR(GLEW_ARB_shadow_ambient, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_sparse_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sparse_buffer, )
  RETVAL = GLEW_ARB_sparse_buffer;
  OGLM_CHECK_ERR(GLEW_ARB_sparse_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_sparse_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture, )
  RETVAL = GLEW_ARB_sparse_texture;
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_sparse_texture2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture2, )
  RETVAL = GLEW_ARB_sparse_texture2;
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_sparse_texture_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture_clamp, )
  RETVAL = GLEW_ARB_sparse_texture_clamp;
  OGLM_CHECK_ERR(GLEW_ARB_sparse_texture_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_spirv_extensions()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_spirv_extensions, )
  RETVAL = GLEW_ARB_spirv_extensions;
  OGLM_CHECK_ERR(GLEW_ARB_spirv_extensions, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_stencil_texturing()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_stencil_texturing, )
  RETVAL = GLEW_ARB_stencil_texturing;
  OGLM_CHECK_ERR(GLEW_ARB_stencil_texturing, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_sync()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_sync, )
  RETVAL = GLEW_ARB_sync;
  OGLM_CHECK_ERR(GLEW_ARB_sync, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_tessellation_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_tessellation_shader, )
  RETVAL = GLEW_ARB_tessellation_shader;
  OGLM_CHECK_ERR(GLEW_ARB_tessellation_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_barrier()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_barrier, )
  RETVAL = GLEW_ARB_texture_barrier;
  OGLM_CHECK_ERR(GLEW_ARB_texture_barrier, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_border_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_border_clamp, )
  RETVAL = GLEW_ARB_texture_border_clamp;
  OGLM_CHECK_ERR(GLEW_ARB_texture_border_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_object, )
  RETVAL = GLEW_ARB_texture_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_buffer_object_rgb32()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_object_rgb32, )
  RETVAL = GLEW_ARB_texture_buffer_object_rgb32;
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_object_rgb32, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_buffer_range()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_range, )
  RETVAL = GLEW_ARB_texture_buffer_range;
  OGLM_CHECK_ERR(GLEW_ARB_texture_buffer_range, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_compression()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression, )
  RETVAL = GLEW_ARB_texture_compression;
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_compression_bptc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression_bptc, )
  RETVAL = GLEW_ARB_texture_compression_bptc;
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression_bptc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_compression_rgtc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression_rgtc, )
  RETVAL = GLEW_ARB_texture_compression_rgtc;
  OGLM_CHECK_ERR(GLEW_ARB_texture_compression_rgtc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_cube_map()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_cube_map, )
  RETVAL = GLEW_ARB_texture_cube_map;
  OGLM_CHECK_ERR(GLEW_ARB_texture_cube_map, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_cube_map_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_cube_map_array, )
  RETVAL = GLEW_ARB_texture_cube_map_array;
  OGLM_CHECK_ERR(GLEW_ARB_texture_cube_map_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_env_add()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_add, )
  RETVAL = GLEW_ARB_texture_env_add;
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_add, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_env_combine()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_combine, )
  RETVAL = GLEW_ARB_texture_env_combine;
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_combine, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_env_crossbar()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_crossbar, )
  RETVAL = GLEW_ARB_texture_env_crossbar;
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_crossbar, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_env_dot3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_dot3, )
  RETVAL = GLEW_ARB_texture_env_dot3;
  OGLM_CHECK_ERR(GLEW_ARB_texture_env_dot3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_filter_anisotropic()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_filter_anisotropic, )
  RETVAL = GLEW_ARB_texture_filter_anisotropic;
  OGLM_CHECK_ERR(GLEW_ARB_texture_filter_anisotropic, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_filter_minmax()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_filter_minmax, )
  RETVAL = GLEW_ARB_texture_filter_minmax;
  OGLM_CHECK_ERR(GLEW_ARB_texture_filter_minmax, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_float, )
  RETVAL = GLEW_ARB_texture_float;
  OGLM_CHECK_ERR(GLEW_ARB_texture_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_gather()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_gather, )
  RETVAL = GLEW_ARB_texture_gather;
  OGLM_CHECK_ERR(GLEW_ARB_texture_gather, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_mirror_clamp_to_edge()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_mirror_clamp_to_edge, )
  RETVAL = GLEW_ARB_texture_mirror_clamp_to_edge;
  OGLM_CHECK_ERR(GLEW_ARB_texture_mirror_clamp_to_edge, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_mirrored_repeat()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_mirrored_repeat, )
  RETVAL = GLEW_ARB_texture_mirrored_repeat;
  OGLM_CHECK_ERR(GLEW_ARB_texture_mirrored_repeat, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_multisample, )
  RETVAL = GLEW_ARB_texture_multisample;
  OGLM_CHECK_ERR(GLEW_ARB_texture_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_non_power_of_two()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_non_power_of_two, )
  RETVAL = GLEW_ARB_texture_non_power_of_two;
  OGLM_CHECK_ERR(GLEW_ARB_texture_non_power_of_two, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_query_levels()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_query_levels, )
  RETVAL = GLEW_ARB_texture_query_levels;
  OGLM_CHECK_ERR(GLEW_ARB_texture_query_levels, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_query_lod()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_query_lod, )
  RETVAL = GLEW_ARB_texture_query_lod;
  OGLM_CHECK_ERR(GLEW_ARB_texture_query_lod, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_rectangle()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_rectangle, )
  RETVAL = GLEW_ARB_texture_rectangle;
  OGLM_CHECK_ERR(GLEW_ARB_texture_rectangle, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_rg()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_rg, )
  RETVAL = GLEW_ARB_texture_rg;
  OGLM_CHECK_ERR(GLEW_ARB_texture_rg, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_rgb10_a2ui()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_rgb10_a2ui, )
  RETVAL = GLEW_ARB_texture_rgb10_a2ui;
  OGLM_CHECK_ERR(GLEW_ARB_texture_rgb10_a2ui, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_stencil8()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_stencil8, )
  RETVAL = GLEW_ARB_texture_stencil8;
  OGLM_CHECK_ERR(GLEW_ARB_texture_stencil8, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_storage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_storage, )
  RETVAL = GLEW_ARB_texture_storage;
  OGLM_CHECK_ERR(GLEW_ARB_texture_storage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_storage_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_storage_multisample, )
  RETVAL = GLEW_ARB_texture_storage_multisample;
  OGLM_CHECK_ERR(GLEW_ARB_texture_storage_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_swizzle()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_swizzle, )
  RETVAL = GLEW_ARB_texture_swizzle;
  OGLM_CHECK_ERR(GLEW_ARB_texture_swizzle, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_texture_view()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_texture_view, )
  RETVAL = GLEW_ARB_texture_view;
  OGLM_CHECK_ERR(GLEW_ARB_texture_view, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_timer_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_timer_query, )
  RETVAL = GLEW_ARB_timer_query;
  OGLM_CHECK_ERR(GLEW_ARB_timer_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_transform_feedback2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback2, )
  RETVAL = GLEW_ARB_transform_feedback2;
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_transform_feedback3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback3, )
  RETVAL = GLEW_ARB_transform_feedback3;
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_transform_feedback_instanced()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback_instanced, )
  RETVAL = GLEW_ARB_transform_feedback_instanced;
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback_instanced, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_transform_feedback_overflow_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback_overflow_query, )
  RETVAL = GLEW_ARB_transform_feedback_overflow_query;
  OGLM_CHECK_ERR(GLEW_ARB_transform_feedback_overflow_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_transpose_matrix()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_transpose_matrix, )
  RETVAL = GLEW_ARB_transpose_matrix;
  OGLM_CHECK_ERR(GLEW_ARB_transpose_matrix, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_uniform_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_uniform_buffer_object, )
  RETVAL = GLEW_ARB_uniform_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_uniform_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_vertex_array_bgra()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_array_bgra, )
  RETVAL = GLEW_ARB_vertex_array_bgra;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_array_bgra, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_vertex_array_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_array_object, )
  RETVAL = GLEW_ARB_vertex_array_object;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_array_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_vertex_attrib_64bit()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_attrib_64bit, )
  RETVAL = GLEW_ARB_vertex_attrib_64bit;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_attrib_64bit, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_vertex_attrib_binding()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_attrib_binding, )
  RETVAL = GLEW_ARB_vertex_attrib_binding;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_attrib_binding, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_vertex_blend()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_blend, )
  RETVAL = GLEW_ARB_vertex_blend;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_blend, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_vertex_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_buffer_object, )
  RETVAL = GLEW_ARB_vertex_buffer_object;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_vertex_program()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_program, )
  RETVAL = GLEW_ARB_vertex_program;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_program, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_vertex_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_shader, )
  RETVAL = GLEW_ARB_vertex_shader;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_vertex_type_10f_11f_11f_rev()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_type_10f_11f_11f_rev, )
  RETVAL = GLEW_ARB_vertex_type_10f_11f_11f_rev;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_type_10f_11f_11f_rev, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_vertex_type_2_10_10_10_rev()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_vertex_type_2_10_10_10_rev, )
  RETVAL = GLEW_ARB_vertex_type_2_10_10_10_rev;
  OGLM_CHECK_ERR(GLEW_ARB_vertex_type_2_10_10_10_rev, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_viewport_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_viewport_array, )
  RETVAL = GLEW_ARB_viewport_array;
  OGLM_CHECK_ERR(GLEW_ARB_viewport_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARB_window_pos()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARB_window_pos, )
  RETVAL = GLEW_ARB_window_pos;
  OGLM_CHECK_ERR(GLEW_ARB_window_pos, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARM_mali_program_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_mali_program_binary, )
  RETVAL = GLEW_ARM_mali_program_binary;
  OGLM_CHECK_ERR(GLEW_ARM_mali_program_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARM_mali_shader_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_mali_shader_binary, )
  RETVAL = GLEW_ARM_mali_shader_binary;
  OGLM_CHECK_ERR(GLEW_ARM_mali_shader_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARM_rgba8()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_rgba8, )
  RETVAL = GLEW_ARM_rgba8;
  OGLM_CHECK_ERR(GLEW_ARM_rgba8, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARM_shader_core_properties()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_shader_core_properties, )
  RETVAL = GLEW_ARM_shader_core_properties;
  OGLM_CHECK_ERR(GLEW_ARM_shader_core_properties, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARM_shader_framebuffer_fetch()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_shader_framebuffer_fetch, )
  RETVAL = GLEW_ARM_shader_framebuffer_fetch;
  OGLM_CHECK_ERR(GLEW_ARM_shader_framebuffer_fetch, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARM_shader_framebuffer_fetch_depth_stencil()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_shader_framebuffer_fetch_depth_stencil, )
  RETVAL = GLEW_ARM_shader_framebuffer_fetch_depth_stencil;
  OGLM_CHECK_ERR(GLEW_ARM_shader_framebuffer_fetch_depth_stencil, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ARM_texture_unnormalized_coordinates()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ARM_texture_unnormalized_coordinates, )
  RETVAL = GLEW_ARM_texture_unnormalized_coordinates;
  OGLM_CHECK_ERR(GLEW_ARM_texture_unnormalized_coordinates, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATIX_point_sprites()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATIX_point_sprites, )
  RETVAL = GLEW_ATIX_point_sprites;
  OGLM_CHECK_ERR(GLEW_ATIX_point_sprites, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATIX_texture_env_combine3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATIX_texture_env_combine3, )
  RETVAL = GLEW_ATIX_texture_env_combine3;
  OGLM_CHECK_ERR(GLEW_ATIX_texture_env_combine3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATIX_texture_env_route()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATIX_texture_env_route, )
  RETVAL = GLEW_ATIX_texture_env_route;
  OGLM_CHECK_ERR(GLEW_ATIX_texture_env_route, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATIX_vertex_shader_output_point_size()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATIX_vertex_shader_output_point_size, )
  RETVAL = GLEW_ATIX_vertex_shader_output_point_size;
  OGLM_CHECK_ERR(GLEW_ATIX_vertex_shader_output_point_size, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_draw_buffers()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_draw_buffers, )
  RETVAL = GLEW_ATI_draw_buffers;
  OGLM_CHECK_ERR(GLEW_ATI_draw_buffers, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_element_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_element_array, )
  RETVAL = GLEW_ATI_element_array;
  OGLM_CHECK_ERR(GLEW_ATI_element_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_envmap_bumpmap()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_envmap_bumpmap, )
  RETVAL = GLEW_ATI_envmap_bumpmap;
  OGLM_CHECK_ERR(GLEW_ATI_envmap_bumpmap, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_fragment_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_fragment_shader, )
  RETVAL = GLEW_ATI_fragment_shader;
  OGLM_CHECK_ERR(GLEW_ATI_fragment_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_map_object_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_map_object_buffer, )
  RETVAL = GLEW_ATI_map_object_buffer;
  OGLM_CHECK_ERR(GLEW_ATI_map_object_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_meminfo()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_meminfo, )
  RETVAL = GLEW_ATI_meminfo;
  OGLM_CHECK_ERR(GLEW_ATI_meminfo, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_pn_triangles()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_pn_triangles, )
  RETVAL = GLEW_ATI_pn_triangles;
  OGLM_CHECK_ERR(GLEW_ATI_pn_triangles, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_separate_stencil()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_separate_stencil, )
  RETVAL = GLEW_ATI_separate_stencil;
  OGLM_CHECK_ERR(GLEW_ATI_separate_stencil, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_shader_texture_lod()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_shader_texture_lod, )
  RETVAL = GLEW_ATI_shader_texture_lod;
  OGLM_CHECK_ERR(GLEW_ATI_shader_texture_lod, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_text_fragment_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_text_fragment_shader, )
  RETVAL = GLEW_ATI_text_fragment_shader;
  OGLM_CHECK_ERR(GLEW_ATI_text_fragment_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_texture_compression_3dc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_texture_compression_3dc, )
  RETVAL = GLEW_ATI_texture_compression_3dc;
  OGLM_CHECK_ERR(GLEW_ATI_texture_compression_3dc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_texture_env_combine3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_texture_env_combine3, )
  RETVAL = GLEW_ATI_texture_env_combine3;
  OGLM_CHECK_ERR(GLEW_ATI_texture_env_combine3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_texture_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_texture_float, )
  RETVAL = GLEW_ATI_texture_float;
  OGLM_CHECK_ERR(GLEW_ATI_texture_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_texture_mirror_once()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_texture_mirror_once, )
  RETVAL = GLEW_ATI_texture_mirror_once;
  OGLM_CHECK_ERR(GLEW_ATI_texture_mirror_once, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_vertex_array_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_vertex_array_object, )
  RETVAL = GLEW_ATI_vertex_array_object;
  OGLM_CHECK_ERR(GLEW_ATI_vertex_array_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_vertex_attrib_array_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_vertex_attrib_array_object, )
  RETVAL = GLEW_ATI_vertex_attrib_array_object;
  OGLM_CHECK_ERR(GLEW_ATI_vertex_attrib_array_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_ATI_vertex_streams()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_ATI_vertex_streams, )
  RETVAL = GLEW_ATI_vertex_streams;
  OGLM_CHECK_ERR(GLEW_ATI_vertex_streams, )
OUTPUT:
  RETVAL

GLboolean
GLEW_DMP_program_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_DMP_program_binary, )
  RETVAL = GLEW_DMP_program_binary;
  OGLM_CHECK_ERR(GLEW_DMP_program_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_DMP_shader_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_DMP_shader_binary, )
  RETVAL = GLEW_DMP_shader_binary;
  OGLM_CHECK_ERR(GLEW_DMP_shader_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_422_pixels()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_422_pixels, )
  RETVAL = GLEW_EXT_422_pixels;
  OGLM_CHECK_ERR(GLEW_EXT_422_pixels, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_Cg_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_Cg_shader, )
  RETVAL = GLEW_EXT_Cg_shader;
  OGLM_CHECK_ERR(GLEW_EXT_Cg_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_EGL_image_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_array, )
  RETVAL = GLEW_EXT_EGL_image_array;
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_EGL_image_external_wrap_modes()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_external_wrap_modes, )
  RETVAL = GLEW_EXT_EGL_image_external_wrap_modes;
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_external_wrap_modes, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_EGL_image_storage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_storage, )
  RETVAL = GLEW_EXT_EGL_image_storage;
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_storage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_EGL_image_storage_compression()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_storage_compression, )
  RETVAL = GLEW_EXT_EGL_image_storage_compression;
  OGLM_CHECK_ERR(GLEW_EXT_EGL_image_storage_compression, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_EGL_sync()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_EGL_sync, )
  RETVAL = GLEW_EXT_EGL_sync;
  OGLM_CHECK_ERR(GLEW_EXT_EGL_sync, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_YUV_target()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_YUV_target, )
  RETVAL = GLEW_EXT_YUV_target;
  OGLM_CHECK_ERR(GLEW_EXT_YUV_target, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_abgr()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_abgr, )
  RETVAL = GLEW_EXT_abgr;
  OGLM_CHECK_ERR(GLEW_EXT_abgr, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_base_instance()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_base_instance, )
  RETVAL = GLEW_EXT_base_instance;
  OGLM_CHECK_ERR(GLEW_EXT_base_instance, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_bgra()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_bgra, )
  RETVAL = GLEW_EXT_bgra;
  OGLM_CHECK_ERR(GLEW_EXT_bgra, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_bindable_uniform()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_bindable_uniform, )
  RETVAL = GLEW_EXT_bindable_uniform;
  OGLM_CHECK_ERR(GLEW_EXT_bindable_uniform, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_blend_color()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_color, )
  RETVAL = GLEW_EXT_blend_color;
  OGLM_CHECK_ERR(GLEW_EXT_blend_color, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_blend_equation_separate()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_equation_separate, )
  RETVAL = GLEW_EXT_blend_equation_separate;
  OGLM_CHECK_ERR(GLEW_EXT_blend_equation_separate, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_blend_func_extended()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_func_extended, )
  RETVAL = GLEW_EXT_blend_func_extended;
  OGLM_CHECK_ERR(GLEW_EXT_blend_func_extended, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_blend_func_separate()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_func_separate, )
  RETVAL = GLEW_EXT_blend_func_separate;
  OGLM_CHECK_ERR(GLEW_EXT_blend_func_separate, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_blend_logic_op()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_logic_op, )
  RETVAL = GLEW_EXT_blend_logic_op;
  OGLM_CHECK_ERR(GLEW_EXT_blend_logic_op, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_blend_minmax()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_minmax, )
  RETVAL = GLEW_EXT_blend_minmax;
  OGLM_CHECK_ERR(GLEW_EXT_blend_minmax, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_blend_subtract()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_blend_subtract, )
  RETVAL = GLEW_EXT_blend_subtract;
  OGLM_CHECK_ERR(GLEW_EXT_blend_subtract, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_buffer_storage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_buffer_storage, )
  RETVAL = GLEW_EXT_buffer_storage;
  OGLM_CHECK_ERR(GLEW_EXT_buffer_storage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_clear_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_clear_texture, )
  RETVAL = GLEW_EXT_clear_texture;
  OGLM_CHECK_ERR(GLEW_EXT_clear_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_clip_control()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_clip_control, )
  RETVAL = GLEW_EXT_clip_control;
  OGLM_CHECK_ERR(GLEW_EXT_clip_control, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_clip_cull_distance()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_clip_cull_distance, )
  RETVAL = GLEW_EXT_clip_cull_distance;
  OGLM_CHECK_ERR(GLEW_EXT_clip_cull_distance, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_clip_volume_hint()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_clip_volume_hint, )
  RETVAL = GLEW_EXT_clip_volume_hint;
  OGLM_CHECK_ERR(GLEW_EXT_clip_volume_hint, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_cmyka()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_cmyka, )
  RETVAL = GLEW_EXT_cmyka;
  OGLM_CHECK_ERR(GLEW_EXT_cmyka, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_color_buffer_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_color_buffer_float, )
  RETVAL = GLEW_EXT_color_buffer_float;
  OGLM_CHECK_ERR(GLEW_EXT_color_buffer_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_color_buffer_half_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_color_buffer_half_float, )
  RETVAL = GLEW_EXT_color_buffer_half_float;
  OGLM_CHECK_ERR(GLEW_EXT_color_buffer_half_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_color_subtable()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_color_subtable, )
  RETVAL = GLEW_EXT_color_subtable;
  OGLM_CHECK_ERR(GLEW_EXT_color_subtable, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_compiled_vertex_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_compiled_vertex_array, )
  RETVAL = GLEW_EXT_compiled_vertex_array;
  OGLM_CHECK_ERR(GLEW_EXT_compiled_vertex_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_compressed_ETC1_RGB8_sub_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_compressed_ETC1_RGB8_sub_texture, )
  RETVAL = GLEW_EXT_compressed_ETC1_RGB8_sub_texture;
  OGLM_CHECK_ERR(GLEW_EXT_compressed_ETC1_RGB8_sub_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_conservative_depth()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_conservative_depth, )
  RETVAL = GLEW_EXT_conservative_depth;
  OGLM_CHECK_ERR(GLEW_EXT_conservative_depth, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_convolution()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_convolution, )
  RETVAL = GLEW_EXT_convolution;
  OGLM_CHECK_ERR(GLEW_EXT_convolution, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_coordinate_frame()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_coordinate_frame, )
  RETVAL = GLEW_EXT_coordinate_frame;
  OGLM_CHECK_ERR(GLEW_EXT_coordinate_frame, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_copy_image()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_copy_image, )
  RETVAL = GLEW_EXT_copy_image;
  OGLM_CHECK_ERR(GLEW_EXT_copy_image, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_copy_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_copy_texture, )
  RETVAL = GLEW_EXT_copy_texture;
  OGLM_CHECK_ERR(GLEW_EXT_copy_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_cull_vertex()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_cull_vertex, )
  RETVAL = GLEW_EXT_cull_vertex;
  OGLM_CHECK_ERR(GLEW_EXT_cull_vertex, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_debug_label()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_debug_label, )
  RETVAL = GLEW_EXT_debug_label;
  OGLM_CHECK_ERR(GLEW_EXT_debug_label, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_debug_marker()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_debug_marker, )
  RETVAL = GLEW_EXT_debug_marker;
  OGLM_CHECK_ERR(GLEW_EXT_debug_marker, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_depth_bounds_test()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_depth_bounds_test, )
  RETVAL = GLEW_EXT_depth_bounds_test;
  OGLM_CHECK_ERR(GLEW_EXT_depth_bounds_test, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_depth_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_depth_clamp, )
  RETVAL = GLEW_EXT_depth_clamp;
  OGLM_CHECK_ERR(GLEW_EXT_depth_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_direct_state_access()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_direct_state_access, )
  RETVAL = GLEW_EXT_direct_state_access;
  OGLM_CHECK_ERR(GLEW_EXT_direct_state_access, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_discard_framebuffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_discard_framebuffer, )
  RETVAL = GLEW_EXT_discard_framebuffer;
  OGLM_CHECK_ERR(GLEW_EXT_discard_framebuffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_disjoint_timer_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_disjoint_timer_query, )
  RETVAL = GLEW_EXT_disjoint_timer_query;
  OGLM_CHECK_ERR(GLEW_EXT_disjoint_timer_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_draw_buffers()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers, )
  RETVAL = GLEW_EXT_draw_buffers;
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_draw_buffers2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers2, )
  RETVAL = GLEW_EXT_draw_buffers2;
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_draw_buffers_indexed()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers_indexed, )
  RETVAL = GLEW_EXT_draw_buffers_indexed;
  OGLM_CHECK_ERR(GLEW_EXT_draw_buffers_indexed, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_draw_elements_base_vertex()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_elements_base_vertex, )
  RETVAL = GLEW_EXT_draw_elements_base_vertex;
  OGLM_CHECK_ERR(GLEW_EXT_draw_elements_base_vertex, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_draw_instanced()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_instanced, )
  RETVAL = GLEW_EXT_draw_instanced;
  OGLM_CHECK_ERR(GLEW_EXT_draw_instanced, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_draw_range_elements()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_range_elements, )
  RETVAL = GLEW_EXT_draw_range_elements;
  OGLM_CHECK_ERR(GLEW_EXT_draw_range_elements, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_draw_transform_feedback()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_draw_transform_feedback, )
  RETVAL = GLEW_EXT_draw_transform_feedback;
  OGLM_CHECK_ERR(GLEW_EXT_draw_transform_feedback, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_external_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_external_buffer, )
  RETVAL = GLEW_EXT_external_buffer;
  OGLM_CHECK_ERR(GLEW_EXT_external_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_float_blend()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_float_blend, )
  RETVAL = GLEW_EXT_float_blend;
  OGLM_CHECK_ERR(GLEW_EXT_float_blend, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_fog_coord()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_fog_coord, )
  RETVAL = GLEW_EXT_fog_coord;
  OGLM_CHECK_ERR(GLEW_EXT_fog_coord, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_frag_depth()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_frag_depth, )
  RETVAL = GLEW_EXT_frag_depth;
  OGLM_CHECK_ERR(GLEW_EXT_frag_depth, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_fragment_lighting()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_fragment_lighting, )
  RETVAL = GLEW_EXT_fragment_lighting;
  OGLM_CHECK_ERR(GLEW_EXT_fragment_lighting, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_fragment_shading_rate()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate, )
  RETVAL = GLEW_EXT_fragment_shading_rate;
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_fragment_shading_rate_attachment()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate_attachment, )
  RETVAL = GLEW_EXT_fragment_shading_rate_attachment;
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate_attachment, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_fragment_shading_rate_primitive()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate_primitive, )
  RETVAL = GLEW_EXT_fragment_shading_rate_primitive;
  OGLM_CHECK_ERR(GLEW_EXT_fragment_shading_rate_primitive, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_framebuffer_blit()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_blit, )
  RETVAL = GLEW_EXT_framebuffer_blit;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_blit, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_framebuffer_blit_layers()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_blit_layers, )
  RETVAL = GLEW_EXT_framebuffer_blit_layers;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_blit_layers, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_framebuffer_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_multisample, )
  RETVAL = GLEW_EXT_framebuffer_multisample;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_framebuffer_multisample_blit_scaled()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_multisample_blit_scaled, )
  RETVAL = GLEW_EXT_framebuffer_multisample_blit_scaled;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_multisample_blit_scaled, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_framebuffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_object, )
  RETVAL = GLEW_EXT_framebuffer_object;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_framebuffer_sRGB()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_sRGB, )
  RETVAL = GLEW_EXT_framebuffer_sRGB;
  OGLM_CHECK_ERR(GLEW_EXT_framebuffer_sRGB, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_geometry_point_size()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_geometry_point_size, )
  RETVAL = GLEW_EXT_geometry_point_size;
  OGLM_CHECK_ERR(GLEW_EXT_geometry_point_size, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_geometry_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_geometry_shader, )
  RETVAL = GLEW_EXT_geometry_shader;
  OGLM_CHECK_ERR(GLEW_EXT_geometry_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_geometry_shader4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_geometry_shader4, )
  RETVAL = GLEW_EXT_geometry_shader4;
  OGLM_CHECK_ERR(GLEW_EXT_geometry_shader4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_gpu_program_parameters()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_gpu_program_parameters, )
  RETVAL = GLEW_EXT_gpu_program_parameters;
  OGLM_CHECK_ERR(GLEW_EXT_gpu_program_parameters, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_gpu_shader4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_gpu_shader4, )
  RETVAL = GLEW_EXT_gpu_shader4;
  OGLM_CHECK_ERR(GLEW_EXT_gpu_shader4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_gpu_shader5()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_gpu_shader5, )
  RETVAL = GLEW_EXT_gpu_shader5;
  OGLM_CHECK_ERR(GLEW_EXT_gpu_shader5, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_histogram()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_histogram, )
  RETVAL = GLEW_EXT_histogram;
  OGLM_CHECK_ERR(GLEW_EXT_histogram, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_index_array_formats()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_index_array_formats, )
  RETVAL = GLEW_EXT_index_array_formats;
  OGLM_CHECK_ERR(GLEW_EXT_index_array_formats, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_index_func()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_index_func, )
  RETVAL = GLEW_EXT_index_func;
  OGLM_CHECK_ERR(GLEW_EXT_index_func, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_index_material()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_index_material, )
  RETVAL = GLEW_EXT_index_material;
  OGLM_CHECK_ERR(GLEW_EXT_index_material, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_index_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_index_texture, )
  RETVAL = GLEW_EXT_index_texture;
  OGLM_CHECK_ERR(GLEW_EXT_index_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_instanced_arrays()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_instanced_arrays, )
  RETVAL = GLEW_EXT_instanced_arrays;
  OGLM_CHECK_ERR(GLEW_EXT_instanced_arrays, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_light_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_light_texture, )
  RETVAL = GLEW_EXT_light_texture;
  OGLM_CHECK_ERR(GLEW_EXT_light_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_map_buffer_range()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_map_buffer_range, )
  RETVAL = GLEW_EXT_map_buffer_range;
  OGLM_CHECK_ERR(GLEW_EXT_map_buffer_range, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_memory_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_memory_object, )
  RETVAL = GLEW_EXT_memory_object;
  OGLM_CHECK_ERR(GLEW_EXT_memory_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_memory_object_fd()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_memory_object_fd, )
  RETVAL = GLEW_EXT_memory_object_fd;
  OGLM_CHECK_ERR(GLEW_EXT_memory_object_fd, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_memory_object_win32()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_memory_object_win32, )
  RETVAL = GLEW_EXT_memory_object_win32;
  OGLM_CHECK_ERR(GLEW_EXT_memory_object_win32, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_mesh_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_mesh_shader, )
  RETVAL = GLEW_EXT_mesh_shader;
  OGLM_CHECK_ERR(GLEW_EXT_mesh_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_misc_attribute()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_misc_attribute, )
  RETVAL = GLEW_EXT_misc_attribute;
  OGLM_CHECK_ERR(GLEW_EXT_misc_attribute, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_multi_draw_arrays()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multi_draw_arrays, )
  RETVAL = GLEW_EXT_multi_draw_arrays;
  OGLM_CHECK_ERR(GLEW_EXT_multi_draw_arrays, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_multi_draw_indirect()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multi_draw_indirect, )
  RETVAL = GLEW_EXT_multi_draw_indirect;
  OGLM_CHECK_ERR(GLEW_EXT_multi_draw_indirect, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_multiple_textures()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multiple_textures, )
  RETVAL = GLEW_EXT_multiple_textures;
  OGLM_CHECK_ERR(GLEW_EXT_multiple_textures, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multisample, )
  RETVAL = GLEW_EXT_multisample;
  OGLM_CHECK_ERR(GLEW_EXT_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_multisample_compatibility()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multisample_compatibility, )
  RETVAL = GLEW_EXT_multisample_compatibility;
  OGLM_CHECK_ERR(GLEW_EXT_multisample_compatibility, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_multisampled_render_to_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multisampled_render_to_texture, )
  RETVAL = GLEW_EXT_multisampled_render_to_texture;
  OGLM_CHECK_ERR(GLEW_EXT_multisampled_render_to_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_multisampled_render_to_texture2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multisampled_render_to_texture2, )
  RETVAL = GLEW_EXT_multisampled_render_to_texture2;
  OGLM_CHECK_ERR(GLEW_EXT_multisampled_render_to_texture2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_multiview_draw_buffers()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multiview_draw_buffers, )
  RETVAL = GLEW_EXT_multiview_draw_buffers;
  OGLM_CHECK_ERR(GLEW_EXT_multiview_draw_buffers, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_multiview_tessellation_geometry_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multiview_tessellation_geometry_shader, )
  RETVAL = GLEW_EXT_multiview_tessellation_geometry_shader;
  OGLM_CHECK_ERR(GLEW_EXT_multiview_tessellation_geometry_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_multiview_texture_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multiview_texture_multisample, )
  RETVAL = GLEW_EXT_multiview_texture_multisample;
  OGLM_CHECK_ERR(GLEW_EXT_multiview_texture_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_multiview_timer_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_multiview_timer_query, )
  RETVAL = GLEW_EXT_multiview_timer_query;
  OGLM_CHECK_ERR(GLEW_EXT_multiview_timer_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_occlusion_query_boolean()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_occlusion_query_boolean, )
  RETVAL = GLEW_EXT_occlusion_query_boolean;
  OGLM_CHECK_ERR(GLEW_EXT_occlusion_query_boolean, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_packed_depth_stencil()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_packed_depth_stencil, )
  RETVAL = GLEW_EXT_packed_depth_stencil;
  OGLM_CHECK_ERR(GLEW_EXT_packed_depth_stencil, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_packed_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_packed_float, )
  RETVAL = GLEW_EXT_packed_float;
  OGLM_CHECK_ERR(GLEW_EXT_packed_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_packed_pixels()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_packed_pixels, )
  RETVAL = GLEW_EXT_packed_pixels;
  OGLM_CHECK_ERR(GLEW_EXT_packed_pixels, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_paletted_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_paletted_texture, )
  RETVAL = GLEW_EXT_paletted_texture;
  OGLM_CHECK_ERR(GLEW_EXT_paletted_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_pixel_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_pixel_buffer_object, )
  RETVAL = GLEW_EXT_pixel_buffer_object;
  OGLM_CHECK_ERR(GLEW_EXT_pixel_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_pixel_transform()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_pixel_transform, )
  RETVAL = GLEW_EXT_pixel_transform;
  OGLM_CHECK_ERR(GLEW_EXT_pixel_transform, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_pixel_transform_color_table()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_pixel_transform_color_table, )
  RETVAL = GLEW_EXT_pixel_transform_color_table;
  OGLM_CHECK_ERR(GLEW_EXT_pixel_transform_color_table, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_point_parameters()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_point_parameters, )
  RETVAL = GLEW_EXT_point_parameters;
  OGLM_CHECK_ERR(GLEW_EXT_point_parameters, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_polygon_offset()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_polygon_offset, )
  RETVAL = GLEW_EXT_polygon_offset;
  OGLM_CHECK_ERR(GLEW_EXT_polygon_offset, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_polygon_offset_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_polygon_offset_clamp, )
  RETVAL = GLEW_EXT_polygon_offset_clamp;
  OGLM_CHECK_ERR(GLEW_EXT_polygon_offset_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_post_depth_coverage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_post_depth_coverage, )
  RETVAL = GLEW_EXT_post_depth_coverage;
  OGLM_CHECK_ERR(GLEW_EXT_post_depth_coverage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_primitive_bounding_box()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_primitive_bounding_box, )
  RETVAL = GLEW_EXT_primitive_bounding_box;
  OGLM_CHECK_ERR(GLEW_EXT_primitive_bounding_box, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_protected_textures()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_protected_textures, )
  RETVAL = GLEW_EXT_protected_textures;
  OGLM_CHECK_ERR(GLEW_EXT_protected_textures, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_provoking_vertex()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_provoking_vertex, )
  RETVAL = GLEW_EXT_provoking_vertex;
  OGLM_CHECK_ERR(GLEW_EXT_provoking_vertex, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_pvrtc_sRGB()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_pvrtc_sRGB, )
  RETVAL = GLEW_EXT_pvrtc_sRGB;
  OGLM_CHECK_ERR(GLEW_EXT_pvrtc_sRGB, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_raster_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_raster_multisample, )
  RETVAL = GLEW_EXT_raster_multisample;
  OGLM_CHECK_ERR(GLEW_EXT_raster_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_read_format_bgra()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_read_format_bgra, )
  RETVAL = GLEW_EXT_read_format_bgra;
  OGLM_CHECK_ERR(GLEW_EXT_read_format_bgra, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_render_snorm()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_render_snorm, )
  RETVAL = GLEW_EXT_render_snorm;
  OGLM_CHECK_ERR(GLEW_EXT_render_snorm, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_rescale_normal()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_rescale_normal, )
  RETVAL = GLEW_EXT_rescale_normal;
  OGLM_CHECK_ERR(GLEW_EXT_rescale_normal, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_robustness()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_robustness, )
  RETVAL = GLEW_EXT_robustness;
  OGLM_CHECK_ERR(GLEW_EXT_robustness, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_sRGB()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_sRGB, )
  RETVAL = GLEW_EXT_sRGB;
  OGLM_CHECK_ERR(GLEW_EXT_sRGB, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_sRGB_write_control()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_sRGB_write_control, )
  RETVAL = GLEW_EXT_sRGB_write_control;
  OGLM_CHECK_ERR(GLEW_EXT_sRGB_write_control, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_scene_marker()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_scene_marker, )
  RETVAL = GLEW_EXT_scene_marker;
  OGLM_CHECK_ERR(GLEW_EXT_scene_marker, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_secondary_color()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_secondary_color, )
  RETVAL = GLEW_EXT_secondary_color;
  OGLM_CHECK_ERR(GLEW_EXT_secondary_color, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_semaphore()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_semaphore, )
  RETVAL = GLEW_EXT_semaphore;
  OGLM_CHECK_ERR(GLEW_EXT_semaphore, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_semaphore_fd()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_semaphore_fd, )
  RETVAL = GLEW_EXT_semaphore_fd;
  OGLM_CHECK_ERR(GLEW_EXT_semaphore_fd, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_semaphore_win32()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_semaphore_win32, )
  RETVAL = GLEW_EXT_semaphore_win32;
  OGLM_CHECK_ERR(GLEW_EXT_semaphore_win32, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_separate_depth_stencil()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_separate_depth_stencil, )
  RETVAL = GLEW_EXT_separate_depth_stencil;
  OGLM_CHECK_ERR(GLEW_EXT_separate_depth_stencil, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_separate_shader_objects()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_separate_shader_objects, )
  RETVAL = GLEW_EXT_separate_shader_objects;
  OGLM_CHECK_ERR(GLEW_EXT_separate_shader_objects, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_separate_specular_color()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_separate_specular_color, )
  RETVAL = GLEW_EXT_separate_specular_color;
  OGLM_CHECK_ERR(GLEW_EXT_separate_specular_color, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_clock()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_clock, )
  RETVAL = GLEW_EXT_shader_clock;
  OGLM_CHECK_ERR(GLEW_EXT_shader_clock, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_framebuffer_fetch()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_framebuffer_fetch, )
  RETVAL = GLEW_EXT_shader_framebuffer_fetch;
  OGLM_CHECK_ERR(GLEW_EXT_shader_framebuffer_fetch, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_framebuffer_fetch_non_coherent()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_framebuffer_fetch_non_coherent, )
  RETVAL = GLEW_EXT_shader_framebuffer_fetch_non_coherent;
  OGLM_CHECK_ERR(GLEW_EXT_shader_framebuffer_fetch_non_coherent, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_group_vote()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_group_vote, )
  RETVAL = GLEW_EXT_shader_group_vote;
  OGLM_CHECK_ERR(GLEW_EXT_shader_group_vote, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_image_load_formatted()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_image_load_formatted, )
  RETVAL = GLEW_EXT_shader_image_load_formatted;
  OGLM_CHECK_ERR(GLEW_EXT_shader_image_load_formatted, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_image_load_store()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_image_load_store, )
  RETVAL = GLEW_EXT_shader_image_load_store;
  OGLM_CHECK_ERR(GLEW_EXT_shader_image_load_store, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_implicit_conversions()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_implicit_conversions, )
  RETVAL = GLEW_EXT_shader_implicit_conversions;
  OGLM_CHECK_ERR(GLEW_EXT_shader_implicit_conversions, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_integer_mix()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_integer_mix, )
  RETVAL = GLEW_EXT_shader_integer_mix;
  OGLM_CHECK_ERR(GLEW_EXT_shader_integer_mix, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_io_blocks()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_io_blocks, )
  RETVAL = GLEW_EXT_shader_io_blocks;
  OGLM_CHECK_ERR(GLEW_EXT_shader_io_blocks, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_non_constant_global_initializers()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_non_constant_global_initializers, )
  RETVAL = GLEW_EXT_shader_non_constant_global_initializers;
  OGLM_CHECK_ERR(GLEW_EXT_shader_non_constant_global_initializers, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_pixel_local_storage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_pixel_local_storage, )
  RETVAL = GLEW_EXT_shader_pixel_local_storage;
  OGLM_CHECK_ERR(GLEW_EXT_shader_pixel_local_storage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_pixel_local_storage2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_pixel_local_storage2, )
  RETVAL = GLEW_EXT_shader_pixel_local_storage2;
  OGLM_CHECK_ERR(GLEW_EXT_shader_pixel_local_storage2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_realtime_clock()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_realtime_clock, )
  RETVAL = GLEW_EXT_shader_realtime_clock;
  OGLM_CHECK_ERR(GLEW_EXT_shader_realtime_clock, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_samples_identical()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_samples_identical, )
  RETVAL = GLEW_EXT_shader_samples_identical;
  OGLM_CHECK_ERR(GLEW_EXT_shader_samples_identical, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_texture_lod()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_texture_lod, )
  RETVAL = GLEW_EXT_shader_texture_lod;
  OGLM_CHECK_ERR(GLEW_EXT_shader_texture_lod, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shader_texture_samples()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shader_texture_samples, )
  RETVAL = GLEW_EXT_shader_texture_samples;
  OGLM_CHECK_ERR(GLEW_EXT_shader_texture_samples, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shadow_funcs()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shadow_funcs, )
  RETVAL = GLEW_EXT_shadow_funcs;
  OGLM_CHECK_ERR(GLEW_EXT_shadow_funcs, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shadow_samplers()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shadow_samplers, )
  RETVAL = GLEW_EXT_shadow_samplers;
  OGLM_CHECK_ERR(GLEW_EXT_shadow_samplers, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_shared_texture_palette()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_shared_texture_palette, )
  RETVAL = GLEW_EXT_shared_texture_palette;
  OGLM_CHECK_ERR(GLEW_EXT_shared_texture_palette, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_sparse_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_sparse_texture, )
  RETVAL = GLEW_EXT_sparse_texture;
  OGLM_CHECK_ERR(GLEW_EXT_sparse_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_sparse_texture2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_sparse_texture2, )
  RETVAL = GLEW_EXT_sparse_texture2;
  OGLM_CHECK_ERR(GLEW_EXT_sparse_texture2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_static_vertex_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_static_vertex_array, )
  RETVAL = GLEW_EXT_static_vertex_array;
  OGLM_CHECK_ERR(GLEW_EXT_static_vertex_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_stencil_clear_tag()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_stencil_clear_tag, )
  RETVAL = GLEW_EXT_stencil_clear_tag;
  OGLM_CHECK_ERR(GLEW_EXT_stencil_clear_tag, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_stencil_two_side()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_stencil_two_side, )
  RETVAL = GLEW_EXT_stencil_two_side;
  OGLM_CHECK_ERR(GLEW_EXT_stencil_two_side, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_stencil_wrap()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_stencil_wrap, )
  RETVAL = GLEW_EXT_stencil_wrap;
  OGLM_CHECK_ERR(GLEW_EXT_stencil_wrap, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_subtexture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_subtexture, )
  RETVAL = GLEW_EXT_subtexture;
  OGLM_CHECK_ERR(GLEW_EXT_subtexture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_tessellation_point_size()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_tessellation_point_size, )
  RETVAL = GLEW_EXT_tessellation_point_size;
  OGLM_CHECK_ERR(GLEW_EXT_tessellation_point_size, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_tessellation_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_tessellation_shader, )
  RETVAL = GLEW_EXT_tessellation_shader;
  OGLM_CHECK_ERR(GLEW_EXT_tessellation_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture, )
  RETVAL = GLEW_EXT_texture;
  OGLM_CHECK_ERR(GLEW_EXT_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture3D()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture3D, )
  RETVAL = GLEW_EXT_texture3D;
  OGLM_CHECK_ERR(GLEW_EXT_texture3D, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_array, )
  RETVAL = GLEW_EXT_texture_array;
  OGLM_CHECK_ERR(GLEW_EXT_texture_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_border_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_border_clamp, )
  RETVAL = GLEW_EXT_texture_border_clamp;
  OGLM_CHECK_ERR(GLEW_EXT_texture_border_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_buffer, )
  RETVAL = GLEW_EXT_texture_buffer;
  OGLM_CHECK_ERR(GLEW_EXT_texture_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_buffer_object, )
  RETVAL = GLEW_EXT_texture_buffer_object;
  OGLM_CHECK_ERR(GLEW_EXT_texture_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_compression_astc_decode_mode()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_astc_decode_mode, )
  RETVAL = GLEW_EXT_texture_compression_astc_decode_mode;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_astc_decode_mode, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_compression_astc_decode_mode_rgb9e5()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_astc_decode_mode_rgb9e5, )
  RETVAL = GLEW_EXT_texture_compression_astc_decode_mode_rgb9e5;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_astc_decode_mode_rgb9e5, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_compression_bptc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_bptc, )
  RETVAL = GLEW_EXT_texture_compression_bptc;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_bptc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_compression_dxt1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_dxt1, )
  RETVAL = GLEW_EXT_texture_compression_dxt1;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_dxt1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_compression_latc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_latc, )
  RETVAL = GLEW_EXT_texture_compression_latc;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_latc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_compression_rgtc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_rgtc, )
  RETVAL = GLEW_EXT_texture_compression_rgtc;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_rgtc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_compression_s3tc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_s3tc, )
  RETVAL = GLEW_EXT_texture_compression_s3tc;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_s3tc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_compression_s3tc_srgb()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_s3tc_srgb, )
  RETVAL = GLEW_EXT_texture_compression_s3tc_srgb;
  OGLM_CHECK_ERR(GLEW_EXT_texture_compression_s3tc_srgb, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_cube_map()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_cube_map, )
  RETVAL = GLEW_EXT_texture_cube_map;
  OGLM_CHECK_ERR(GLEW_EXT_texture_cube_map, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_cube_map_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_cube_map_array, )
  RETVAL = GLEW_EXT_texture_cube_map_array;
  OGLM_CHECK_ERR(GLEW_EXT_texture_cube_map_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_edge_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_edge_clamp, )
  RETVAL = GLEW_EXT_texture_edge_clamp;
  OGLM_CHECK_ERR(GLEW_EXT_texture_edge_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_env()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_env, )
  RETVAL = GLEW_EXT_texture_env;
  OGLM_CHECK_ERR(GLEW_EXT_texture_env, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_env_add()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_add, )
  RETVAL = GLEW_EXT_texture_env_add;
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_add, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_env_combine()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_combine, )
  RETVAL = GLEW_EXT_texture_env_combine;
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_combine, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_env_dot3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_dot3, )
  RETVAL = GLEW_EXT_texture_env_dot3;
  OGLM_CHECK_ERR(GLEW_EXT_texture_env_dot3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_filter_anisotropic()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_filter_anisotropic, )
  RETVAL = GLEW_EXT_texture_filter_anisotropic;
  OGLM_CHECK_ERR(GLEW_EXT_texture_filter_anisotropic, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_filter_minmax()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_filter_minmax, )
  RETVAL = GLEW_EXT_texture_filter_minmax;
  OGLM_CHECK_ERR(GLEW_EXT_texture_filter_minmax, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_format_BGRA8888()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_format_BGRA8888, )
  RETVAL = GLEW_EXT_texture_format_BGRA8888;
  OGLM_CHECK_ERR(GLEW_EXT_texture_format_BGRA8888, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_format_sRGB_override()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_format_sRGB_override, )
  RETVAL = GLEW_EXT_texture_format_sRGB_override;
  OGLM_CHECK_ERR(GLEW_EXT_texture_format_sRGB_override, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_integer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_integer, )
  RETVAL = GLEW_EXT_texture_integer;
  OGLM_CHECK_ERR(GLEW_EXT_texture_integer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_lod_bias()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_lod_bias, )
  RETVAL = GLEW_EXT_texture_lod_bias;
  OGLM_CHECK_ERR(GLEW_EXT_texture_lod_bias, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_mirror_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_mirror_clamp, )
  RETVAL = GLEW_EXT_texture_mirror_clamp;
  OGLM_CHECK_ERR(GLEW_EXT_texture_mirror_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_mirror_clamp_to_edge()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_mirror_clamp_to_edge, )
  RETVAL = GLEW_EXT_texture_mirror_clamp_to_edge;
  OGLM_CHECK_ERR(GLEW_EXT_texture_mirror_clamp_to_edge, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_norm16()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_norm16, )
  RETVAL = GLEW_EXT_texture_norm16;
  OGLM_CHECK_ERR(GLEW_EXT_texture_norm16, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_object, )
  RETVAL = GLEW_EXT_texture_object;
  OGLM_CHECK_ERR(GLEW_EXT_texture_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_perturb_normal()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_perturb_normal, )
  RETVAL = GLEW_EXT_texture_perturb_normal;
  OGLM_CHECK_ERR(GLEW_EXT_texture_perturb_normal, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_query_lod()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_query_lod, )
  RETVAL = GLEW_EXT_texture_query_lod;
  OGLM_CHECK_ERR(GLEW_EXT_texture_query_lod, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_rectangle()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_rectangle, )
  RETVAL = GLEW_EXT_texture_rectangle;
  OGLM_CHECK_ERR(GLEW_EXT_texture_rectangle, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_rg()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_rg, )
  RETVAL = GLEW_EXT_texture_rg;
  OGLM_CHECK_ERR(GLEW_EXT_texture_rg, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_sRGB()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB, )
  RETVAL = GLEW_EXT_texture_sRGB;
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_sRGB_R8()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_R8, )
  RETVAL = GLEW_EXT_texture_sRGB_R8;
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_R8, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_sRGB_RG8()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_RG8, )
  RETVAL = GLEW_EXT_texture_sRGB_RG8;
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_RG8, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_sRGB_decode()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_decode, )
  RETVAL = GLEW_EXT_texture_sRGB_decode;
  OGLM_CHECK_ERR(GLEW_EXT_texture_sRGB_decode, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_shadow_lod()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_shadow_lod, )
  RETVAL = GLEW_EXT_texture_shadow_lod;
  OGLM_CHECK_ERR(GLEW_EXT_texture_shadow_lod, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_shared_exponent()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_shared_exponent, )
  RETVAL = GLEW_EXT_texture_shared_exponent;
  OGLM_CHECK_ERR(GLEW_EXT_texture_shared_exponent, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_snorm()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_snorm, )
  RETVAL = GLEW_EXT_texture_snorm;
  OGLM_CHECK_ERR(GLEW_EXT_texture_snorm, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_storage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_storage, )
  RETVAL = GLEW_EXT_texture_storage;
  OGLM_CHECK_ERR(GLEW_EXT_texture_storage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_storage_compression()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_storage_compression, )
  RETVAL = GLEW_EXT_texture_storage_compression;
  OGLM_CHECK_ERR(GLEW_EXT_texture_storage_compression, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_swizzle()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_swizzle, )
  RETVAL = GLEW_EXT_texture_swizzle;
  OGLM_CHECK_ERR(GLEW_EXT_texture_swizzle, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_type_2_10_10_10_REV()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_type_2_10_10_10_REV, )
  RETVAL = GLEW_EXT_texture_type_2_10_10_10_REV;
  OGLM_CHECK_ERR(GLEW_EXT_texture_type_2_10_10_10_REV, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_texture_view()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_texture_view, )
  RETVAL = GLEW_EXT_texture_view;
  OGLM_CHECK_ERR(GLEW_EXT_texture_view, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_timer_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_timer_query, )
  RETVAL = GLEW_EXT_timer_query;
  OGLM_CHECK_ERR(GLEW_EXT_timer_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_transform_feedback()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_transform_feedback, )
  RETVAL = GLEW_EXT_transform_feedback;
  OGLM_CHECK_ERR(GLEW_EXT_transform_feedback, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_unpack_subimage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_unpack_subimage, )
  RETVAL = GLEW_EXT_unpack_subimage;
  OGLM_CHECK_ERR(GLEW_EXT_unpack_subimage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_vertex_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array, )
  RETVAL = GLEW_EXT_vertex_array;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_vertex_array_bgra()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array_bgra, )
  RETVAL = GLEW_EXT_vertex_array_bgra;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array_bgra, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_vertex_array_setXXX()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array_setXXX, )
  RETVAL = GLEW_EXT_vertex_array_setXXX;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_array_setXXX, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_vertex_attrib_64bit()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_attrib_64bit, )
  RETVAL = GLEW_EXT_vertex_attrib_64bit;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_attrib_64bit, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_vertex_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_shader, )
  RETVAL = GLEW_EXT_vertex_shader;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_vertex_weighting()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_vertex_weighting, )
  RETVAL = GLEW_EXT_vertex_weighting;
  OGLM_CHECK_ERR(GLEW_EXT_vertex_weighting, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_win32_keyed_mutex()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_win32_keyed_mutex, )
  RETVAL = GLEW_EXT_win32_keyed_mutex;
  OGLM_CHECK_ERR(GLEW_EXT_win32_keyed_mutex, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_window_rectangles()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_window_rectangles, )
  RETVAL = GLEW_EXT_window_rectangles;
  OGLM_CHECK_ERR(GLEW_EXT_window_rectangles, )
OUTPUT:
  RETVAL

GLboolean
GLEW_EXT_x11_sync_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_EXT_x11_sync_object, )
  RETVAL = GLEW_EXT_x11_sync_object;
  OGLM_CHECK_ERR(GLEW_EXT_x11_sync_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_FJ_shader_binary_GCCSO()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_FJ_shader_binary_GCCSO, )
  RETVAL = GLEW_FJ_shader_binary_GCCSO;
  OGLM_CHECK_ERR(GLEW_FJ_shader_binary_GCCSO, )
OUTPUT:
  RETVAL

GLboolean
GLEW_GREMEDY_frame_terminator()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_GREMEDY_frame_terminator, )
  RETVAL = GLEW_GREMEDY_frame_terminator;
  OGLM_CHECK_ERR(GLEW_GREMEDY_frame_terminator, )
OUTPUT:
  RETVAL

GLboolean
GLEW_GREMEDY_string_marker()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_GREMEDY_string_marker, )
  RETVAL = GLEW_GREMEDY_string_marker;
  OGLM_CHECK_ERR(GLEW_GREMEDY_string_marker, )
OUTPUT:
  RETVAL

GLboolean
GLEW_HP_convolution_border_modes()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HP_convolution_border_modes, )
  RETVAL = GLEW_HP_convolution_border_modes;
  OGLM_CHECK_ERR(GLEW_HP_convolution_border_modes, )
OUTPUT:
  RETVAL

GLboolean
GLEW_HP_image_transform()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HP_image_transform, )
  RETVAL = GLEW_HP_image_transform;
  OGLM_CHECK_ERR(GLEW_HP_image_transform, )
OUTPUT:
  RETVAL

GLboolean
GLEW_HP_occlusion_test()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HP_occlusion_test, )
  RETVAL = GLEW_HP_occlusion_test;
  OGLM_CHECK_ERR(GLEW_HP_occlusion_test, )
OUTPUT:
  RETVAL

GLboolean
GLEW_HP_texture_lighting()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HP_texture_lighting, )
  RETVAL = GLEW_HP_texture_lighting;
  OGLM_CHECK_ERR(GLEW_HP_texture_lighting, )
OUTPUT:
  RETVAL

GLboolean
GLEW_HUAWEI_program_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HUAWEI_program_binary, )
  RETVAL = GLEW_HUAWEI_program_binary;
  OGLM_CHECK_ERR(GLEW_HUAWEI_program_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_HUAWEI_shader_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_HUAWEI_shader_binary, )
  RETVAL = GLEW_HUAWEI_shader_binary;
  OGLM_CHECK_ERR(GLEW_HUAWEI_shader_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IBM_cull_vertex()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_cull_vertex, )
  RETVAL = GLEW_IBM_cull_vertex;
  OGLM_CHECK_ERR(GLEW_IBM_cull_vertex, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IBM_multimode_draw_arrays()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_multimode_draw_arrays, )
  RETVAL = GLEW_IBM_multimode_draw_arrays;
  OGLM_CHECK_ERR(GLEW_IBM_multimode_draw_arrays, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IBM_rasterpos_clip()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_rasterpos_clip, )
  RETVAL = GLEW_IBM_rasterpos_clip;
  OGLM_CHECK_ERR(GLEW_IBM_rasterpos_clip, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IBM_static_data()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_static_data, )
  RETVAL = GLEW_IBM_static_data;
  OGLM_CHECK_ERR(GLEW_IBM_static_data, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IBM_texture_mirrored_repeat()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_texture_mirrored_repeat, )
  RETVAL = GLEW_IBM_texture_mirrored_repeat;
  OGLM_CHECK_ERR(GLEW_IBM_texture_mirrored_repeat, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IBM_vertex_array_lists()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IBM_vertex_array_lists, )
  RETVAL = GLEW_IBM_vertex_array_lists;
  OGLM_CHECK_ERR(GLEW_IBM_vertex_array_lists, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_bindless_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_bindless_texture, )
  RETVAL = GLEW_IMG_bindless_texture;
  OGLM_CHECK_ERR(GLEW_IMG_bindless_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_framebuffer_downsample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_framebuffer_downsample, )
  RETVAL = GLEW_IMG_framebuffer_downsample;
  OGLM_CHECK_ERR(GLEW_IMG_framebuffer_downsample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_multisampled_render_to_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_multisampled_render_to_texture, )
  RETVAL = GLEW_IMG_multisampled_render_to_texture;
  OGLM_CHECK_ERR(GLEW_IMG_multisampled_render_to_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_program_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_program_binary, )
  RETVAL = GLEW_IMG_program_binary;
  OGLM_CHECK_ERR(GLEW_IMG_program_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_pvric_end_to_end_signature()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_pvric_end_to_end_signature, )
  RETVAL = GLEW_IMG_pvric_end_to_end_signature;
  OGLM_CHECK_ERR(GLEW_IMG_pvric_end_to_end_signature, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_read_format()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_read_format, )
  RETVAL = GLEW_IMG_read_format;
  OGLM_CHECK_ERR(GLEW_IMG_read_format, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_shader_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_shader_binary, )
  RETVAL = GLEW_IMG_shader_binary;
  OGLM_CHECK_ERR(GLEW_IMG_shader_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_texture_compression_pvrtc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_texture_compression_pvrtc, )
  RETVAL = GLEW_IMG_texture_compression_pvrtc;
  OGLM_CHECK_ERR(GLEW_IMG_texture_compression_pvrtc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_texture_compression_pvrtc2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_texture_compression_pvrtc2, )
  RETVAL = GLEW_IMG_texture_compression_pvrtc2;
  OGLM_CHECK_ERR(GLEW_IMG_texture_compression_pvrtc2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_texture_env_enhanced_fixed_function()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_texture_env_enhanced_fixed_function, )
  RETVAL = GLEW_IMG_texture_env_enhanced_fixed_function;
  OGLM_CHECK_ERR(GLEW_IMG_texture_env_enhanced_fixed_function, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_texture_filter_cubic()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_texture_filter_cubic, )
  RETVAL = GLEW_IMG_texture_filter_cubic;
  OGLM_CHECK_ERR(GLEW_IMG_texture_filter_cubic, )
OUTPUT:
  RETVAL

GLboolean
GLEW_IMG_tile_region_protection()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_IMG_tile_region_protection, )
  RETVAL = GLEW_IMG_tile_region_protection;
  OGLM_CHECK_ERR(GLEW_IMG_tile_region_protection, )
OUTPUT:
  RETVAL

GLboolean
GLEW_INGR_color_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INGR_color_clamp, )
  RETVAL = GLEW_INGR_color_clamp;
  OGLM_CHECK_ERR(GLEW_INGR_color_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_INGR_interlace_read()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INGR_interlace_read, )
  RETVAL = GLEW_INGR_interlace_read;
  OGLM_CHECK_ERR(GLEW_INGR_interlace_read, )
OUTPUT:
  RETVAL

GLboolean
GLEW_INTEL_blackhole_render()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_blackhole_render, )
  RETVAL = GLEW_INTEL_blackhole_render;
  OGLM_CHECK_ERR(GLEW_INTEL_blackhole_render, )
OUTPUT:
  RETVAL

GLboolean
GLEW_INTEL_conservative_rasterization()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_conservative_rasterization, )
  RETVAL = GLEW_INTEL_conservative_rasterization;
  OGLM_CHECK_ERR(GLEW_INTEL_conservative_rasterization, )
OUTPUT:
  RETVAL

GLboolean
GLEW_INTEL_fragment_shader_ordering()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_fragment_shader_ordering, )
  RETVAL = GLEW_INTEL_fragment_shader_ordering;
  OGLM_CHECK_ERR(GLEW_INTEL_fragment_shader_ordering, )
OUTPUT:
  RETVAL

GLboolean
GLEW_INTEL_framebuffer_CMAA()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_framebuffer_CMAA, )
  RETVAL = GLEW_INTEL_framebuffer_CMAA;
  OGLM_CHECK_ERR(GLEW_INTEL_framebuffer_CMAA, )
OUTPUT:
  RETVAL

GLboolean
GLEW_INTEL_map_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_map_texture, )
  RETVAL = GLEW_INTEL_map_texture;
  OGLM_CHECK_ERR(GLEW_INTEL_map_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_INTEL_parallel_arrays()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_parallel_arrays, )
  RETVAL = GLEW_INTEL_parallel_arrays;
  OGLM_CHECK_ERR(GLEW_INTEL_parallel_arrays, )
OUTPUT:
  RETVAL

GLboolean
GLEW_INTEL_performance_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_performance_query, )
  RETVAL = GLEW_INTEL_performance_query;
  OGLM_CHECK_ERR(GLEW_INTEL_performance_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_INTEL_shader_integer_functions2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_shader_integer_functions2, )
  RETVAL = GLEW_INTEL_shader_integer_functions2;
  OGLM_CHECK_ERR(GLEW_INTEL_shader_integer_functions2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_INTEL_texture_scissor()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_INTEL_texture_scissor, )
  RETVAL = GLEW_INTEL_texture_scissor;
  OGLM_CHECK_ERR(GLEW_INTEL_texture_scissor, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_blend_equation_advanced()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_blend_equation_advanced, )
  RETVAL = GLEW_KHR_blend_equation_advanced;
  OGLM_CHECK_ERR(GLEW_KHR_blend_equation_advanced, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_blend_equation_advanced_coherent()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_blend_equation_advanced_coherent, )
  RETVAL = GLEW_KHR_blend_equation_advanced_coherent;
  OGLM_CHECK_ERR(GLEW_KHR_blend_equation_advanced_coherent, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_context_flush_control()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_context_flush_control, )
  RETVAL = GLEW_KHR_context_flush_control;
  OGLM_CHECK_ERR(GLEW_KHR_context_flush_control, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_debug()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_debug, )
  RETVAL = GLEW_KHR_debug;
  OGLM_CHECK_ERR(GLEW_KHR_debug, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_no_error()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_no_error, )
  RETVAL = GLEW_KHR_no_error;
  OGLM_CHECK_ERR(GLEW_KHR_no_error, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_parallel_shader_compile()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_parallel_shader_compile, )
  RETVAL = GLEW_KHR_parallel_shader_compile;
  OGLM_CHECK_ERR(GLEW_KHR_parallel_shader_compile, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_robust_buffer_access_behavior()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_robust_buffer_access_behavior, )
  RETVAL = GLEW_KHR_robust_buffer_access_behavior;
  OGLM_CHECK_ERR(GLEW_KHR_robust_buffer_access_behavior, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_robustness()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_robustness, )
  RETVAL = GLEW_KHR_robustness;
  OGLM_CHECK_ERR(GLEW_KHR_robustness, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_shader_subgroup()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_shader_subgroup, )
  RETVAL = GLEW_KHR_shader_subgroup;
  OGLM_CHECK_ERR(GLEW_KHR_shader_subgroup, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_texture_compression_astc_hdr()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_hdr, )
  RETVAL = GLEW_KHR_texture_compression_astc_hdr;
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_hdr, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_texture_compression_astc_ldr()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_ldr, )
  RETVAL = GLEW_KHR_texture_compression_astc_ldr;
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_ldr, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KHR_texture_compression_astc_sliced_3d()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_sliced_3d, )
  RETVAL = GLEW_KHR_texture_compression_astc_sliced_3d;
  OGLM_CHECK_ERR(GLEW_KHR_texture_compression_astc_sliced_3d, )
OUTPUT:
  RETVAL

GLboolean
GLEW_KTX_buffer_region()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_KTX_buffer_region, )
  RETVAL = GLEW_KTX_buffer_region;
  OGLM_CHECK_ERR(GLEW_KTX_buffer_region, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESAX_texture_stack()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESAX_texture_stack, )
  RETVAL = GLEW_MESAX_texture_stack;
  OGLM_CHECK_ERR(GLEW_MESAX_texture_stack, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_bgra()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_bgra, )
  RETVAL = GLEW_MESA_bgra;
  OGLM_CHECK_ERR(GLEW_MESA_bgra, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_framebuffer_flip_x()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_flip_x, )
  RETVAL = GLEW_MESA_framebuffer_flip_x;
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_flip_x, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_framebuffer_flip_y()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_flip_y, )
  RETVAL = GLEW_MESA_framebuffer_flip_y;
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_flip_y, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_framebuffer_swap_xy()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_swap_xy, )
  RETVAL = GLEW_MESA_framebuffer_swap_xy;
  OGLM_CHECK_ERR(GLEW_MESA_framebuffer_swap_xy, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_pack_invert()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_pack_invert, )
  RETVAL = GLEW_MESA_pack_invert;
  OGLM_CHECK_ERR(GLEW_MESA_pack_invert, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_program_binary_formats()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_program_binary_formats, )
  RETVAL = GLEW_MESA_program_binary_formats;
  OGLM_CHECK_ERR(GLEW_MESA_program_binary_formats, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_resize_buffers()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_resize_buffers, )
  RETVAL = GLEW_MESA_resize_buffers;
  OGLM_CHECK_ERR(GLEW_MESA_resize_buffers, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_shader_integer_functions()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_shader_integer_functions, )
  RETVAL = GLEW_MESA_shader_integer_functions;
  OGLM_CHECK_ERR(GLEW_MESA_shader_integer_functions, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_texture_const_bandwidth()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_texture_const_bandwidth, )
  RETVAL = GLEW_MESA_texture_const_bandwidth;
  OGLM_CHECK_ERR(GLEW_MESA_texture_const_bandwidth, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_tile_raster_order()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_tile_raster_order, )
  RETVAL = GLEW_MESA_tile_raster_order;
  OGLM_CHECK_ERR(GLEW_MESA_tile_raster_order, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_window_pos()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_window_pos, )
  RETVAL = GLEW_MESA_window_pos;
  OGLM_CHECK_ERR(GLEW_MESA_window_pos, )
OUTPUT:
  RETVAL

GLboolean
GLEW_MESA_ycbcr_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_MESA_ycbcr_texture, )
  RETVAL = GLEW_MESA_ycbcr_texture;
  OGLM_CHECK_ERR(GLEW_MESA_ycbcr_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NVX_blend_equation_advanced_multi_draw_buffers()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_blend_equation_advanced_multi_draw_buffers, )
  RETVAL = GLEW_NVX_blend_equation_advanced_multi_draw_buffers;
  OGLM_CHECK_ERR(GLEW_NVX_blend_equation_advanced_multi_draw_buffers, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NVX_conditional_render()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_conditional_render, )
  RETVAL = GLEW_NVX_conditional_render;
  OGLM_CHECK_ERR(GLEW_NVX_conditional_render, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NVX_gpu_memory_info()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_gpu_memory_info, )
  RETVAL = GLEW_NVX_gpu_memory_info;
  OGLM_CHECK_ERR(GLEW_NVX_gpu_memory_info, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NVX_gpu_multicast2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_gpu_multicast2, )
  RETVAL = GLEW_NVX_gpu_multicast2;
  OGLM_CHECK_ERR(GLEW_NVX_gpu_multicast2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NVX_linked_gpu_multicast()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_linked_gpu_multicast, )
  RETVAL = GLEW_NVX_linked_gpu_multicast;
  OGLM_CHECK_ERR(GLEW_NVX_linked_gpu_multicast, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NVX_progress_fence()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NVX_progress_fence, )
  RETVAL = GLEW_NVX_progress_fence;
  OGLM_CHECK_ERR(GLEW_NVX_progress_fence, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_3dvision_settings()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_3dvision_settings, )
  RETVAL = GLEW_NV_3dvision_settings;
  OGLM_CHECK_ERR(GLEW_NV_3dvision_settings, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_EGL_stream_consumer_external()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_EGL_stream_consumer_external, )
  RETVAL = GLEW_NV_EGL_stream_consumer_external;
  OGLM_CHECK_ERR(GLEW_NV_EGL_stream_consumer_external, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_alpha_to_coverage_dither_control()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_alpha_to_coverage_dither_control, )
  RETVAL = GLEW_NV_alpha_to_coverage_dither_control;
  OGLM_CHECK_ERR(GLEW_NV_alpha_to_coverage_dither_control, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_bgr()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_bgr, )
  RETVAL = GLEW_NV_bgr;
  OGLM_CHECK_ERR(GLEW_NV_bgr, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_bindless_multi_draw_indirect()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_bindless_multi_draw_indirect, )
  RETVAL = GLEW_NV_bindless_multi_draw_indirect;
  OGLM_CHECK_ERR(GLEW_NV_bindless_multi_draw_indirect, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_bindless_multi_draw_indirect_count()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_bindless_multi_draw_indirect_count, )
  RETVAL = GLEW_NV_bindless_multi_draw_indirect_count;
  OGLM_CHECK_ERR(GLEW_NV_bindless_multi_draw_indirect_count, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_bindless_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_bindless_texture, )
  RETVAL = GLEW_NV_bindless_texture;
  OGLM_CHECK_ERR(GLEW_NV_bindless_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_blend_equation_advanced()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_blend_equation_advanced, )
  RETVAL = GLEW_NV_blend_equation_advanced;
  OGLM_CHECK_ERR(GLEW_NV_blend_equation_advanced, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_blend_equation_advanced_coherent()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_blend_equation_advanced_coherent, )
  RETVAL = GLEW_NV_blend_equation_advanced_coherent;
  OGLM_CHECK_ERR(GLEW_NV_blend_equation_advanced_coherent, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_blend_minmax_factor()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_blend_minmax_factor, )
  RETVAL = GLEW_NV_blend_minmax_factor;
  OGLM_CHECK_ERR(GLEW_NV_blend_minmax_factor, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_blend_square()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_blend_square, )
  RETVAL = GLEW_NV_blend_square;
  OGLM_CHECK_ERR(GLEW_NV_blend_square, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_clip_space_w_scaling()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_clip_space_w_scaling, )
  RETVAL = GLEW_NV_clip_space_w_scaling;
  OGLM_CHECK_ERR(GLEW_NV_clip_space_w_scaling, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_command_list()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_command_list, )
  RETVAL = GLEW_NV_command_list;
  OGLM_CHECK_ERR(GLEW_NV_command_list, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_compute_program5()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_compute_program5, )
  RETVAL = GLEW_NV_compute_program5;
  OGLM_CHECK_ERR(GLEW_NV_compute_program5, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_compute_shader_derivatives()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_compute_shader_derivatives, )
  RETVAL = GLEW_NV_compute_shader_derivatives;
  OGLM_CHECK_ERR(GLEW_NV_compute_shader_derivatives, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_conditional_render()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conditional_render, )
  RETVAL = GLEW_NV_conditional_render;
  OGLM_CHECK_ERR(GLEW_NV_conditional_render, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_conservative_raster()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster, )
  RETVAL = GLEW_NV_conservative_raster;
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_conservative_raster_dilate()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_dilate, )
  RETVAL = GLEW_NV_conservative_raster_dilate;
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_dilate, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_conservative_raster_pre_snap()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_pre_snap, )
  RETVAL = GLEW_NV_conservative_raster_pre_snap;
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_pre_snap, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_conservative_raster_pre_snap_triangles()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_pre_snap_triangles, )
  RETVAL = GLEW_NV_conservative_raster_pre_snap_triangles;
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_pre_snap_triangles, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_conservative_raster_underestimation()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_underestimation, )
  RETVAL = GLEW_NV_conservative_raster_underestimation;
  OGLM_CHECK_ERR(GLEW_NV_conservative_raster_underestimation, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_copy_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_copy_buffer, )
  RETVAL = GLEW_NV_copy_buffer;
  OGLM_CHECK_ERR(GLEW_NV_copy_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_copy_depth_to_color()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_copy_depth_to_color, )
  RETVAL = GLEW_NV_copy_depth_to_color;
  OGLM_CHECK_ERR(GLEW_NV_copy_depth_to_color, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_copy_image()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_copy_image, )
  RETVAL = GLEW_NV_copy_image;
  OGLM_CHECK_ERR(GLEW_NV_copy_image, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_deep_texture3D()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_deep_texture3D, )
  RETVAL = GLEW_NV_deep_texture3D;
  OGLM_CHECK_ERR(GLEW_NV_deep_texture3D, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_depth_buffer_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_depth_buffer_float, )
  RETVAL = GLEW_NV_depth_buffer_float;
  OGLM_CHECK_ERR(GLEW_NV_depth_buffer_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_depth_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_depth_clamp, )
  RETVAL = GLEW_NV_depth_clamp;
  OGLM_CHECK_ERR(GLEW_NV_depth_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_depth_nonlinear()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_depth_nonlinear, )
  RETVAL = GLEW_NV_depth_nonlinear;
  OGLM_CHECK_ERR(GLEW_NV_depth_nonlinear, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_depth_range_unclamped()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_depth_range_unclamped, )
  RETVAL = GLEW_NV_depth_range_unclamped;
  OGLM_CHECK_ERR(GLEW_NV_depth_range_unclamped, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_draw_buffers()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_draw_buffers, )
  RETVAL = GLEW_NV_draw_buffers;
  OGLM_CHECK_ERR(GLEW_NV_draw_buffers, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_draw_instanced()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_draw_instanced, )
  RETVAL = GLEW_NV_draw_instanced;
  OGLM_CHECK_ERR(GLEW_NV_draw_instanced, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_draw_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_draw_texture, )
  RETVAL = GLEW_NV_draw_texture;
  OGLM_CHECK_ERR(GLEW_NV_draw_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_draw_vulkan_image()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_draw_vulkan_image, )
  RETVAL = GLEW_NV_draw_vulkan_image;
  OGLM_CHECK_ERR(GLEW_NV_draw_vulkan_image, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_evaluators()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_evaluators, )
  RETVAL = GLEW_NV_evaluators;
  OGLM_CHECK_ERR(GLEW_NV_evaluators, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_explicit_attrib_location()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_explicit_attrib_location, )
  RETVAL = GLEW_NV_explicit_attrib_location;
  OGLM_CHECK_ERR(GLEW_NV_explicit_attrib_location, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_explicit_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_explicit_multisample, )
  RETVAL = GLEW_NV_explicit_multisample;
  OGLM_CHECK_ERR(GLEW_NV_explicit_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_fbo_color_attachments()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fbo_color_attachments, )
  RETVAL = GLEW_NV_fbo_color_attachments;
  OGLM_CHECK_ERR(GLEW_NV_fbo_color_attachments, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_fence()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fence, )
  RETVAL = GLEW_NV_fence;
  OGLM_CHECK_ERR(GLEW_NV_fence, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_fill_rectangle()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fill_rectangle, )
  RETVAL = GLEW_NV_fill_rectangle;
  OGLM_CHECK_ERR(GLEW_NV_fill_rectangle, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_float_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_float_buffer, )
  RETVAL = GLEW_NV_float_buffer;
  OGLM_CHECK_ERR(GLEW_NV_float_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_fog_distance()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fog_distance, )
  RETVAL = GLEW_NV_fog_distance;
  OGLM_CHECK_ERR(GLEW_NV_fog_distance, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_fragment_coverage_to_color()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_coverage_to_color, )
  RETVAL = GLEW_NV_fragment_coverage_to_color;
  OGLM_CHECK_ERR(GLEW_NV_fragment_coverage_to_color, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_fragment_program()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_program, )
  RETVAL = GLEW_NV_fragment_program;
  OGLM_CHECK_ERR(GLEW_NV_fragment_program, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_fragment_program2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_program2, )
  RETVAL = GLEW_NV_fragment_program2;
  OGLM_CHECK_ERR(GLEW_NV_fragment_program2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_fragment_program4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_program4, )
  RETVAL = GLEW_NV_fragment_program4;
  OGLM_CHECK_ERR(GLEW_NV_fragment_program4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_fragment_program_option()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_program_option, )
  RETVAL = GLEW_NV_fragment_program_option;
  OGLM_CHECK_ERR(GLEW_NV_fragment_program_option, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_fragment_shader_barycentric()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_shader_barycentric, )
  RETVAL = GLEW_NV_fragment_shader_barycentric;
  OGLM_CHECK_ERR(GLEW_NV_fragment_shader_barycentric, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_fragment_shader_interlock()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_fragment_shader_interlock, )
  RETVAL = GLEW_NV_fragment_shader_interlock;
  OGLM_CHECK_ERR(GLEW_NV_fragment_shader_interlock, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_framebuffer_blit()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_blit, )
  RETVAL = GLEW_NV_framebuffer_blit;
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_blit, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_framebuffer_mixed_samples()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_mixed_samples, )
  RETVAL = GLEW_NV_framebuffer_mixed_samples;
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_mixed_samples, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_framebuffer_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_multisample, )
  RETVAL = GLEW_NV_framebuffer_multisample;
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_framebuffer_multisample_coverage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_multisample_coverage, )
  RETVAL = GLEW_NV_framebuffer_multisample_coverage;
  OGLM_CHECK_ERR(GLEW_NV_framebuffer_multisample_coverage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_generate_mipmap_sRGB()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_generate_mipmap_sRGB, )
  RETVAL = GLEW_NV_generate_mipmap_sRGB;
  OGLM_CHECK_ERR(GLEW_NV_generate_mipmap_sRGB, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_geometry_program4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_geometry_program4, )
  RETVAL = GLEW_NV_geometry_program4;
  OGLM_CHECK_ERR(GLEW_NV_geometry_program4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_geometry_shader4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_geometry_shader4, )
  RETVAL = GLEW_NV_geometry_shader4;
  OGLM_CHECK_ERR(GLEW_NV_geometry_shader4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_geometry_shader_passthrough()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_geometry_shader_passthrough, )
  RETVAL = GLEW_NV_geometry_shader_passthrough;
  OGLM_CHECK_ERR(GLEW_NV_geometry_shader_passthrough, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_gpu_multicast()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_multicast, )
  RETVAL = GLEW_NV_gpu_multicast;
  OGLM_CHECK_ERR(GLEW_NV_gpu_multicast, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_gpu_program4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_program4, )
  RETVAL = GLEW_NV_gpu_program4;
  OGLM_CHECK_ERR(GLEW_NV_gpu_program4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_gpu_program5()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_program5, )
  RETVAL = GLEW_NV_gpu_program5;
  OGLM_CHECK_ERR(GLEW_NV_gpu_program5, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_gpu_program5_mem_extended()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_program5_mem_extended, )
  RETVAL = GLEW_NV_gpu_program5_mem_extended;
  OGLM_CHECK_ERR(GLEW_NV_gpu_program5_mem_extended, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_gpu_program_fp64()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_program_fp64, )
  RETVAL = GLEW_NV_gpu_program_fp64;
  OGLM_CHECK_ERR(GLEW_NV_gpu_program_fp64, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_gpu_shader5()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_gpu_shader5, )
  RETVAL = GLEW_NV_gpu_shader5;
  OGLM_CHECK_ERR(GLEW_NV_gpu_shader5, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_half_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_half_float, )
  RETVAL = GLEW_NV_half_float;
  OGLM_CHECK_ERR(GLEW_NV_half_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_image_formats()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_image_formats, )
  RETVAL = GLEW_NV_image_formats;
  OGLM_CHECK_ERR(GLEW_NV_image_formats, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_instanced_arrays()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_instanced_arrays, )
  RETVAL = GLEW_NV_instanced_arrays;
  OGLM_CHECK_ERR(GLEW_NV_instanced_arrays, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_internalformat_sample_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_internalformat_sample_query, )
  RETVAL = GLEW_NV_internalformat_sample_query;
  OGLM_CHECK_ERR(GLEW_NV_internalformat_sample_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_light_max_exponent()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_light_max_exponent, )
  RETVAL = GLEW_NV_light_max_exponent;
  OGLM_CHECK_ERR(GLEW_NV_light_max_exponent, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_memory_attachment()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_memory_attachment, )
  RETVAL = GLEW_NV_memory_attachment;
  OGLM_CHECK_ERR(GLEW_NV_memory_attachment, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_memory_object_sparse()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_memory_object_sparse, )
  RETVAL = GLEW_NV_memory_object_sparse;
  OGLM_CHECK_ERR(GLEW_NV_memory_object_sparse, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_mesh_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_mesh_shader, )
  RETVAL = GLEW_NV_mesh_shader;
  OGLM_CHECK_ERR(GLEW_NV_mesh_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_multisample_coverage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_multisample_coverage, )
  RETVAL = GLEW_NV_multisample_coverage;
  OGLM_CHECK_ERR(GLEW_NV_multisample_coverage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_multisample_filter_hint()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_multisample_filter_hint, )
  RETVAL = GLEW_NV_multisample_filter_hint;
  OGLM_CHECK_ERR(GLEW_NV_multisample_filter_hint, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_non_square_matrices()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_non_square_matrices, )
  RETVAL = GLEW_NV_non_square_matrices;
  OGLM_CHECK_ERR(GLEW_NV_non_square_matrices, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_occlusion_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_occlusion_query, )
  RETVAL = GLEW_NV_occlusion_query;
  OGLM_CHECK_ERR(GLEW_NV_occlusion_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_pack_subimage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_pack_subimage, )
  RETVAL = GLEW_NV_pack_subimage;
  OGLM_CHECK_ERR(GLEW_NV_pack_subimage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_packed_depth_stencil()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_packed_depth_stencil, )
  RETVAL = GLEW_NV_packed_depth_stencil;
  OGLM_CHECK_ERR(GLEW_NV_packed_depth_stencil, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_packed_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_packed_float, )
  RETVAL = GLEW_NV_packed_float;
  OGLM_CHECK_ERR(GLEW_NV_packed_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_packed_float_linear()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_packed_float_linear, )
  RETVAL = GLEW_NV_packed_float_linear;
  OGLM_CHECK_ERR(GLEW_NV_packed_float_linear, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_parameter_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_parameter_buffer_object, )
  RETVAL = GLEW_NV_parameter_buffer_object;
  OGLM_CHECK_ERR(GLEW_NV_parameter_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_parameter_buffer_object2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_parameter_buffer_object2, )
  RETVAL = GLEW_NV_parameter_buffer_object2;
  OGLM_CHECK_ERR(GLEW_NV_parameter_buffer_object2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_path_rendering()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_path_rendering, )
  RETVAL = GLEW_NV_path_rendering;
  OGLM_CHECK_ERR(GLEW_NV_path_rendering, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_path_rendering_shared_edge()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_path_rendering_shared_edge, )
  RETVAL = GLEW_NV_path_rendering_shared_edge;
  OGLM_CHECK_ERR(GLEW_NV_path_rendering_shared_edge, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_pixel_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_pixel_buffer_object, )
  RETVAL = GLEW_NV_pixel_buffer_object;
  OGLM_CHECK_ERR(GLEW_NV_pixel_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_pixel_data_range()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_pixel_data_range, )
  RETVAL = GLEW_NV_pixel_data_range;
  OGLM_CHECK_ERR(GLEW_NV_pixel_data_range, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_platform_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_platform_binary, )
  RETVAL = GLEW_NV_platform_binary;
  OGLM_CHECK_ERR(GLEW_NV_platform_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_point_sprite()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_point_sprite, )
  RETVAL = GLEW_NV_point_sprite;
  OGLM_CHECK_ERR(GLEW_NV_point_sprite, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_polygon_mode()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_polygon_mode, )
  RETVAL = GLEW_NV_polygon_mode;
  OGLM_CHECK_ERR(GLEW_NV_polygon_mode, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_present_video()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_present_video, )
  RETVAL = GLEW_NV_present_video;
  OGLM_CHECK_ERR(GLEW_NV_present_video, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_primitive_restart()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_primitive_restart, )
  RETVAL = GLEW_NV_primitive_restart;
  OGLM_CHECK_ERR(GLEW_NV_primitive_restart, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_primitive_shading_rate()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_primitive_shading_rate, )
  RETVAL = GLEW_NV_primitive_shading_rate;
  OGLM_CHECK_ERR(GLEW_NV_primitive_shading_rate, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_query_resource_tag()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_query_resource_tag, )
  RETVAL = GLEW_NV_query_resource_tag;
  OGLM_CHECK_ERR(GLEW_NV_query_resource_tag, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_read_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_read_buffer, )
  RETVAL = GLEW_NV_read_buffer;
  OGLM_CHECK_ERR(GLEW_NV_read_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_read_buffer_front()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_read_buffer_front, )
  RETVAL = GLEW_NV_read_buffer_front;
  OGLM_CHECK_ERR(GLEW_NV_read_buffer_front, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_read_depth()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_read_depth, )
  RETVAL = GLEW_NV_read_depth;
  OGLM_CHECK_ERR(GLEW_NV_read_depth, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_read_depth_stencil()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_read_depth_stencil, )
  RETVAL = GLEW_NV_read_depth_stencil;
  OGLM_CHECK_ERR(GLEW_NV_read_depth_stencil, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_read_stencil()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_read_stencil, )
  RETVAL = GLEW_NV_read_stencil;
  OGLM_CHECK_ERR(GLEW_NV_read_stencil, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_register_combiners()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_register_combiners, )
  RETVAL = GLEW_NV_register_combiners;
  OGLM_CHECK_ERR(GLEW_NV_register_combiners, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_register_combiners2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_register_combiners2, )
  RETVAL = GLEW_NV_register_combiners2;
  OGLM_CHECK_ERR(GLEW_NV_register_combiners2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_representative_fragment_test()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_representative_fragment_test, )
  RETVAL = GLEW_NV_representative_fragment_test;
  OGLM_CHECK_ERR(GLEW_NV_representative_fragment_test, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_robustness_video_memory_purge()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_robustness_video_memory_purge, )
  RETVAL = GLEW_NV_robustness_video_memory_purge;
  OGLM_CHECK_ERR(GLEW_NV_robustness_video_memory_purge, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_sRGB_formats()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_sRGB_formats, )
  RETVAL = GLEW_NV_sRGB_formats;
  OGLM_CHECK_ERR(GLEW_NV_sRGB_formats, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_sample_locations()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_sample_locations, )
  RETVAL = GLEW_NV_sample_locations;
  OGLM_CHECK_ERR(GLEW_NV_sample_locations, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_sample_mask_override_coverage()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_sample_mask_override_coverage, )
  RETVAL = GLEW_NV_sample_mask_override_coverage;
  OGLM_CHECK_ERR(GLEW_NV_sample_mask_override_coverage, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_scissor_exclusive()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_scissor_exclusive, )
  RETVAL = GLEW_NV_scissor_exclusive;
  OGLM_CHECK_ERR(GLEW_NV_scissor_exclusive, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_atomic_counters()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_counters, )
  RETVAL = GLEW_NV_shader_atomic_counters;
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_counters, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_atomic_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_float, )
  RETVAL = GLEW_NV_shader_atomic_float;
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_atomic_float64()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_float64, )
  RETVAL = GLEW_NV_shader_atomic_float64;
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_float64, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_atomic_fp16_vector()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_fp16_vector, )
  RETVAL = GLEW_NV_shader_atomic_fp16_vector;
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_fp16_vector, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_atomic_int64()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_int64, )
  RETVAL = GLEW_NV_shader_atomic_int64;
  OGLM_CHECK_ERR(GLEW_NV_shader_atomic_int64, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_buffer_load()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_buffer_load, )
  RETVAL = GLEW_NV_shader_buffer_load;
  OGLM_CHECK_ERR(GLEW_NV_shader_buffer_load, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_noperspective_interpolation()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_noperspective_interpolation, )
  RETVAL = GLEW_NV_shader_noperspective_interpolation;
  OGLM_CHECK_ERR(GLEW_NV_shader_noperspective_interpolation, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_storage_buffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_storage_buffer_object, )
  RETVAL = GLEW_NV_shader_storage_buffer_object;
  OGLM_CHECK_ERR(GLEW_NV_shader_storage_buffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_subgroup_partitioned()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_subgroup_partitioned, )
  RETVAL = GLEW_NV_shader_subgroup_partitioned;
  OGLM_CHECK_ERR(GLEW_NV_shader_subgroup_partitioned, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_texture_footprint()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_texture_footprint, )
  RETVAL = GLEW_NV_shader_texture_footprint;
  OGLM_CHECK_ERR(GLEW_NV_shader_texture_footprint, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_thread_group()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_thread_group, )
  RETVAL = GLEW_NV_shader_thread_group;
  OGLM_CHECK_ERR(GLEW_NV_shader_thread_group, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shader_thread_shuffle()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shader_thread_shuffle, )
  RETVAL = GLEW_NV_shader_thread_shuffle;
  OGLM_CHECK_ERR(GLEW_NV_shader_thread_shuffle, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shading_rate_image()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shading_rate_image, )
  RETVAL = GLEW_NV_shading_rate_image;
  OGLM_CHECK_ERR(GLEW_NV_shading_rate_image, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shadow_samplers_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shadow_samplers_array, )
  RETVAL = GLEW_NV_shadow_samplers_array;
  OGLM_CHECK_ERR(GLEW_NV_shadow_samplers_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_shadow_samplers_cube()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_shadow_samplers_cube, )
  RETVAL = GLEW_NV_shadow_samplers_cube;
  OGLM_CHECK_ERR(GLEW_NV_shadow_samplers_cube, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_stereo_view_rendering()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_stereo_view_rendering, )
  RETVAL = GLEW_NV_stereo_view_rendering;
  OGLM_CHECK_ERR(GLEW_NV_stereo_view_rendering, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_tessellation_program5()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_tessellation_program5, )
  RETVAL = GLEW_NV_tessellation_program5;
  OGLM_CHECK_ERR(GLEW_NV_tessellation_program5, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texgen_emboss()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texgen_emboss, )
  RETVAL = GLEW_NV_texgen_emboss;
  OGLM_CHECK_ERR(GLEW_NV_texgen_emboss, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texgen_reflection()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texgen_reflection, )
  RETVAL = GLEW_NV_texgen_reflection;
  OGLM_CHECK_ERR(GLEW_NV_texgen_reflection, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_array, )
  RETVAL = GLEW_NV_texture_array;
  OGLM_CHECK_ERR(GLEW_NV_texture_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_barrier()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_barrier, )
  RETVAL = GLEW_NV_texture_barrier;
  OGLM_CHECK_ERR(GLEW_NV_texture_barrier, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_border_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_border_clamp, )
  RETVAL = GLEW_NV_texture_border_clamp;
  OGLM_CHECK_ERR(GLEW_NV_texture_border_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_compression_latc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_latc, )
  RETVAL = GLEW_NV_texture_compression_latc;
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_latc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_compression_s3tc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_s3tc, )
  RETVAL = GLEW_NV_texture_compression_s3tc;
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_s3tc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_compression_s3tc_update()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_s3tc_update, )
  RETVAL = GLEW_NV_texture_compression_s3tc_update;
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_s3tc_update, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_compression_vtc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_vtc, )
  RETVAL = GLEW_NV_texture_compression_vtc;
  OGLM_CHECK_ERR(GLEW_NV_texture_compression_vtc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_env_combine4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_env_combine4, )
  RETVAL = GLEW_NV_texture_env_combine4;
  OGLM_CHECK_ERR(GLEW_NV_texture_env_combine4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_expand_normal()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_expand_normal, )
  RETVAL = GLEW_NV_texture_expand_normal;
  OGLM_CHECK_ERR(GLEW_NV_texture_expand_normal, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_multisample, )
  RETVAL = GLEW_NV_texture_multisample;
  OGLM_CHECK_ERR(GLEW_NV_texture_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_npot_2D_mipmap()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_npot_2D_mipmap, )
  RETVAL = GLEW_NV_texture_npot_2D_mipmap;
  OGLM_CHECK_ERR(GLEW_NV_texture_npot_2D_mipmap, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_rectangle()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_rectangle, )
  RETVAL = GLEW_NV_texture_rectangle;
  OGLM_CHECK_ERR(GLEW_NV_texture_rectangle, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_rectangle_compressed()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_rectangle_compressed, )
  RETVAL = GLEW_NV_texture_rectangle_compressed;
  OGLM_CHECK_ERR(GLEW_NV_texture_rectangle_compressed, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_shader, )
  RETVAL = GLEW_NV_texture_shader;
  OGLM_CHECK_ERR(GLEW_NV_texture_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_shader2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_shader2, )
  RETVAL = GLEW_NV_texture_shader2;
  OGLM_CHECK_ERR(GLEW_NV_texture_shader2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_texture_shader3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_texture_shader3, )
  RETVAL = GLEW_NV_texture_shader3;
  OGLM_CHECK_ERR(GLEW_NV_texture_shader3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_timeline_semaphore()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_timeline_semaphore, )
  RETVAL = GLEW_NV_timeline_semaphore;
  OGLM_CHECK_ERR(GLEW_NV_timeline_semaphore, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_transform_feedback()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_transform_feedback, )
  RETVAL = GLEW_NV_transform_feedback;
  OGLM_CHECK_ERR(GLEW_NV_transform_feedback, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_transform_feedback2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_transform_feedback2, )
  RETVAL = GLEW_NV_transform_feedback2;
  OGLM_CHECK_ERR(GLEW_NV_transform_feedback2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_uniform_buffer_std430_layout()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_uniform_buffer_std430_layout, )
  RETVAL = GLEW_NV_uniform_buffer_std430_layout;
  OGLM_CHECK_ERR(GLEW_NV_uniform_buffer_std430_layout, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_uniform_buffer_unified_memory()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_uniform_buffer_unified_memory, )
  RETVAL = GLEW_NV_uniform_buffer_unified_memory;
  OGLM_CHECK_ERR(GLEW_NV_uniform_buffer_unified_memory, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vdpau_interop()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vdpau_interop, )
  RETVAL = GLEW_NV_vdpau_interop;
  OGLM_CHECK_ERR(GLEW_NV_vdpau_interop, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vdpau_interop2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vdpau_interop2, )
  RETVAL = GLEW_NV_vdpau_interop2;
  OGLM_CHECK_ERR(GLEW_NV_vdpau_interop2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vertex_array_range()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_array_range, )
  RETVAL = GLEW_NV_vertex_array_range;
  OGLM_CHECK_ERR(GLEW_NV_vertex_array_range, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vertex_array_range2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_array_range2, )
  RETVAL = GLEW_NV_vertex_array_range2;
  OGLM_CHECK_ERR(GLEW_NV_vertex_array_range2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vertex_attrib_integer_64bit()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_attrib_integer_64bit, )
  RETVAL = GLEW_NV_vertex_attrib_integer_64bit;
  OGLM_CHECK_ERR(GLEW_NV_vertex_attrib_integer_64bit, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vertex_buffer_unified_memory()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_buffer_unified_memory, )
  RETVAL = GLEW_NV_vertex_buffer_unified_memory;
  OGLM_CHECK_ERR(GLEW_NV_vertex_buffer_unified_memory, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vertex_program()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program, )
  RETVAL = GLEW_NV_vertex_program;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vertex_program1_1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program1_1, )
  RETVAL = GLEW_NV_vertex_program1_1;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program1_1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vertex_program2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program2, )
  RETVAL = GLEW_NV_vertex_program2;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vertex_program2_option()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program2_option, )
  RETVAL = GLEW_NV_vertex_program2_option;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program2_option, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vertex_program3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program3, )
  RETVAL = GLEW_NV_vertex_program3;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_vertex_program4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_vertex_program4, )
  RETVAL = GLEW_NV_vertex_program4;
  OGLM_CHECK_ERR(GLEW_NV_vertex_program4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_video_capture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_video_capture, )
  RETVAL = GLEW_NV_video_capture;
  OGLM_CHECK_ERR(GLEW_NV_video_capture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_viewport_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_viewport_array, )
  RETVAL = GLEW_NV_viewport_array;
  OGLM_CHECK_ERR(GLEW_NV_viewport_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_viewport_array2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_viewport_array2, )
  RETVAL = GLEW_NV_viewport_array2;
  OGLM_CHECK_ERR(GLEW_NV_viewport_array2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_NV_viewport_swizzle()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_NV_viewport_swizzle, )
  RETVAL = GLEW_NV_viewport_swizzle;
  OGLM_CHECK_ERR(GLEW_NV_viewport_swizzle, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_EGL_image()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_EGL_image, )
  RETVAL = GLEW_OES_EGL_image;
  OGLM_CHECK_ERR(GLEW_OES_EGL_image, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_EGL_image_external()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_EGL_image_external, )
  RETVAL = GLEW_OES_EGL_image_external;
  OGLM_CHECK_ERR(GLEW_OES_EGL_image_external, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_EGL_image_external_essl3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_EGL_image_external_essl3, )
  RETVAL = GLEW_OES_EGL_image_external_essl3;
  OGLM_CHECK_ERR(GLEW_OES_EGL_image_external_essl3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_blend_equation_separate()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_blend_equation_separate, )
  RETVAL = GLEW_OES_blend_equation_separate;
  OGLM_CHECK_ERR(GLEW_OES_blend_equation_separate, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_blend_func_separate()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_blend_func_separate, )
  RETVAL = GLEW_OES_blend_func_separate;
  OGLM_CHECK_ERR(GLEW_OES_blend_func_separate, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_blend_subtract()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_blend_subtract, )
  RETVAL = GLEW_OES_blend_subtract;
  OGLM_CHECK_ERR(GLEW_OES_blend_subtract, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_byte_coordinates()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_byte_coordinates, )
  RETVAL = GLEW_OES_byte_coordinates;
  OGLM_CHECK_ERR(GLEW_OES_byte_coordinates, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_compressed_ETC1_RGB8_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_compressed_ETC1_RGB8_texture, )
  RETVAL = GLEW_OES_compressed_ETC1_RGB8_texture;
  OGLM_CHECK_ERR(GLEW_OES_compressed_ETC1_RGB8_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_compressed_paletted_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_compressed_paletted_texture, )
  RETVAL = GLEW_OES_compressed_paletted_texture;
  OGLM_CHECK_ERR(GLEW_OES_compressed_paletted_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_copy_image()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_copy_image, )
  RETVAL = GLEW_OES_copy_image;
  OGLM_CHECK_ERR(GLEW_OES_copy_image, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_depth24()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_depth24, )
  RETVAL = GLEW_OES_depth24;
  OGLM_CHECK_ERR(GLEW_OES_depth24, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_depth32()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_depth32, )
  RETVAL = GLEW_OES_depth32;
  OGLM_CHECK_ERR(GLEW_OES_depth32, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_depth_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_depth_texture, )
  RETVAL = GLEW_OES_depth_texture;
  OGLM_CHECK_ERR(GLEW_OES_depth_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_depth_texture_cube_map()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_depth_texture_cube_map, )
  RETVAL = GLEW_OES_depth_texture_cube_map;
  OGLM_CHECK_ERR(GLEW_OES_depth_texture_cube_map, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_draw_buffers_indexed()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_draw_buffers_indexed, )
  RETVAL = GLEW_OES_draw_buffers_indexed;
  OGLM_CHECK_ERR(GLEW_OES_draw_buffers_indexed, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_draw_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_draw_texture, )
  RETVAL = GLEW_OES_draw_texture;
  OGLM_CHECK_ERR(GLEW_OES_draw_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_element_index_uint()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_element_index_uint, )
  RETVAL = GLEW_OES_element_index_uint;
  OGLM_CHECK_ERR(GLEW_OES_element_index_uint, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_extended_matrix_palette()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_extended_matrix_palette, )
  RETVAL = GLEW_OES_extended_matrix_palette;
  OGLM_CHECK_ERR(GLEW_OES_extended_matrix_palette, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_fbo_render_mipmap()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_fbo_render_mipmap, )
  RETVAL = GLEW_OES_fbo_render_mipmap;
  OGLM_CHECK_ERR(GLEW_OES_fbo_render_mipmap, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_fragment_precision_high()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_fragment_precision_high, )
  RETVAL = GLEW_OES_fragment_precision_high;
  OGLM_CHECK_ERR(GLEW_OES_fragment_precision_high, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_framebuffer_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_framebuffer_object, )
  RETVAL = GLEW_OES_framebuffer_object;
  OGLM_CHECK_ERR(GLEW_OES_framebuffer_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_geometry_point_size()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_geometry_point_size, )
  RETVAL = GLEW_OES_geometry_point_size;
  OGLM_CHECK_ERR(GLEW_OES_geometry_point_size, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_geometry_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_geometry_shader, )
  RETVAL = GLEW_OES_geometry_shader;
  OGLM_CHECK_ERR(GLEW_OES_geometry_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_get_program_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_get_program_binary, )
  RETVAL = GLEW_OES_get_program_binary;
  OGLM_CHECK_ERR(GLEW_OES_get_program_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_gpu_shader5()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_gpu_shader5, )
  RETVAL = GLEW_OES_gpu_shader5;
  OGLM_CHECK_ERR(GLEW_OES_gpu_shader5, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_mapbuffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_mapbuffer, )
  RETVAL = GLEW_OES_mapbuffer;
  OGLM_CHECK_ERR(GLEW_OES_mapbuffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_matrix_get()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_matrix_get, )
  RETVAL = GLEW_OES_matrix_get;
  OGLM_CHECK_ERR(GLEW_OES_matrix_get, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_matrix_palette()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_matrix_palette, )
  RETVAL = GLEW_OES_matrix_palette;
  OGLM_CHECK_ERR(GLEW_OES_matrix_palette, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_packed_depth_stencil()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_packed_depth_stencil, )
  RETVAL = GLEW_OES_packed_depth_stencil;
  OGLM_CHECK_ERR(GLEW_OES_packed_depth_stencil, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_point_size_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_point_size_array, )
  RETVAL = GLEW_OES_point_size_array;
  OGLM_CHECK_ERR(GLEW_OES_point_size_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_point_sprite()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_point_sprite, )
  RETVAL = GLEW_OES_point_sprite;
  OGLM_CHECK_ERR(GLEW_OES_point_sprite, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_read_format()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_read_format, )
  RETVAL = GLEW_OES_read_format;
  OGLM_CHECK_ERR(GLEW_OES_read_format, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_required_internalformat()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_required_internalformat, )
  RETVAL = GLEW_OES_required_internalformat;
  OGLM_CHECK_ERR(GLEW_OES_required_internalformat, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_rgb8_rgba8()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_rgb8_rgba8, )
  RETVAL = GLEW_OES_rgb8_rgba8;
  OGLM_CHECK_ERR(GLEW_OES_rgb8_rgba8, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_sample_shading()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_sample_shading, )
  RETVAL = GLEW_OES_sample_shading;
  OGLM_CHECK_ERR(GLEW_OES_sample_shading, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_sample_variables()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_sample_variables, )
  RETVAL = GLEW_OES_sample_variables;
  OGLM_CHECK_ERR(GLEW_OES_sample_variables, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_shader_image_atomic()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_shader_image_atomic, )
  RETVAL = GLEW_OES_shader_image_atomic;
  OGLM_CHECK_ERR(GLEW_OES_shader_image_atomic, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_shader_io_blocks()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_shader_io_blocks, )
  RETVAL = GLEW_OES_shader_io_blocks;
  OGLM_CHECK_ERR(GLEW_OES_shader_io_blocks, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_shader_multisample_interpolation()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_shader_multisample_interpolation, )
  RETVAL = GLEW_OES_shader_multisample_interpolation;
  OGLM_CHECK_ERR(GLEW_OES_shader_multisample_interpolation, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_single_precision()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_single_precision, )
  RETVAL = GLEW_OES_single_precision;
  OGLM_CHECK_ERR(GLEW_OES_single_precision, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_standard_derivatives()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_standard_derivatives, )
  RETVAL = GLEW_OES_standard_derivatives;
  OGLM_CHECK_ERR(GLEW_OES_standard_derivatives, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_stencil1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_stencil1, )
  RETVAL = GLEW_OES_stencil1;
  OGLM_CHECK_ERR(GLEW_OES_stencil1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_stencil4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_stencil4, )
  RETVAL = GLEW_OES_stencil4;
  OGLM_CHECK_ERR(GLEW_OES_stencil4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_stencil8()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_stencil8, )
  RETVAL = GLEW_OES_stencil8;
  OGLM_CHECK_ERR(GLEW_OES_stencil8, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_surfaceless_context()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_surfaceless_context, )
  RETVAL = GLEW_OES_surfaceless_context;
  OGLM_CHECK_ERR(GLEW_OES_surfaceless_context, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_tessellation_point_size()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_tessellation_point_size, )
  RETVAL = GLEW_OES_tessellation_point_size;
  OGLM_CHECK_ERR(GLEW_OES_tessellation_point_size, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_tessellation_shader()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_tessellation_shader, )
  RETVAL = GLEW_OES_tessellation_shader;
  OGLM_CHECK_ERR(GLEW_OES_tessellation_shader, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_3D()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_3D, )
  RETVAL = GLEW_OES_texture_3D;
  OGLM_CHECK_ERR(GLEW_OES_texture_3D, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_border_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_border_clamp, )
  RETVAL = GLEW_OES_texture_border_clamp;
  OGLM_CHECK_ERR(GLEW_OES_texture_border_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_buffer, )
  RETVAL = GLEW_OES_texture_buffer;
  OGLM_CHECK_ERR(GLEW_OES_texture_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_compression_astc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_compression_astc, )
  RETVAL = GLEW_OES_texture_compression_astc;
  OGLM_CHECK_ERR(GLEW_OES_texture_compression_astc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_cube_map()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_cube_map, )
  RETVAL = GLEW_OES_texture_cube_map;
  OGLM_CHECK_ERR(GLEW_OES_texture_cube_map, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_cube_map_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_cube_map_array, )
  RETVAL = GLEW_OES_texture_cube_map_array;
  OGLM_CHECK_ERR(GLEW_OES_texture_cube_map_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_env_crossbar()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_env_crossbar, )
  RETVAL = GLEW_OES_texture_env_crossbar;
  OGLM_CHECK_ERR(GLEW_OES_texture_env_crossbar, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_mirrored_repeat()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_mirrored_repeat, )
  RETVAL = GLEW_OES_texture_mirrored_repeat;
  OGLM_CHECK_ERR(GLEW_OES_texture_mirrored_repeat, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_npot()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_npot, )
  RETVAL = GLEW_OES_texture_npot;
  OGLM_CHECK_ERR(GLEW_OES_texture_npot, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_stencil8()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_stencil8, )
  RETVAL = GLEW_OES_texture_stencil8;
  OGLM_CHECK_ERR(GLEW_OES_texture_stencil8, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_storage_multisample_2d_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_storage_multisample_2d_array, )
  RETVAL = GLEW_OES_texture_storage_multisample_2d_array;
  OGLM_CHECK_ERR(GLEW_OES_texture_storage_multisample_2d_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_texture_view()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_texture_view, )
  RETVAL = GLEW_OES_texture_view;
  OGLM_CHECK_ERR(GLEW_OES_texture_view, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_vertex_array_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_vertex_array_object, )
  RETVAL = GLEW_OES_vertex_array_object;
  OGLM_CHECK_ERR(GLEW_OES_vertex_array_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_vertex_half_float()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_vertex_half_float, )
  RETVAL = GLEW_OES_vertex_half_float;
  OGLM_CHECK_ERR(GLEW_OES_vertex_half_float, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OES_vertex_type_10_10_10_2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OES_vertex_type_10_10_10_2, )
  RETVAL = GLEW_OES_vertex_type_10_10_10_2;
  OGLM_CHECK_ERR(GLEW_OES_vertex_type_10_10_10_2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OML_interlace()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OML_interlace, )
  RETVAL = GLEW_OML_interlace;
  OGLM_CHECK_ERR(GLEW_OML_interlace, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OML_resample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OML_resample, )
  RETVAL = GLEW_OML_resample;
  OGLM_CHECK_ERR(GLEW_OML_resample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OML_subsample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OML_subsample, )
  RETVAL = GLEW_OML_subsample;
  OGLM_CHECK_ERR(GLEW_OML_subsample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OVR_multiview()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OVR_multiview, )
  RETVAL = GLEW_OVR_multiview;
  OGLM_CHECK_ERR(GLEW_OVR_multiview, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OVR_multiview2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OVR_multiview2, )
  RETVAL = GLEW_OVR_multiview2;
  OGLM_CHECK_ERR(GLEW_OVR_multiview2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_OVR_multiview_multisampled_render_to_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_OVR_multiview_multisampled_render_to_texture, )
  RETVAL = GLEW_OVR_multiview_multisampled_render_to_texture;
  OGLM_CHECK_ERR(GLEW_OVR_multiview_multisampled_render_to_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_PGI_misc_hints()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_PGI_misc_hints, )
  RETVAL = GLEW_PGI_misc_hints;
  OGLM_CHECK_ERR(GLEW_PGI_misc_hints, )
OUTPUT:
  RETVAL

GLboolean
GLEW_PGI_vertex_hints()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_PGI_vertex_hints, )
  RETVAL = GLEW_PGI_vertex_hints;
  OGLM_CHECK_ERR(GLEW_PGI_vertex_hints, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_YUV_texture_gather()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_YUV_texture_gather, )
  RETVAL = GLEW_QCOM_YUV_texture_gather;
  OGLM_CHECK_ERR(GLEW_QCOM_YUV_texture_gather, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_alpha_test()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_alpha_test, )
  RETVAL = GLEW_QCOM_alpha_test;
  OGLM_CHECK_ERR(GLEW_QCOM_alpha_test, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_binning_control()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_binning_control, )
  RETVAL = GLEW_QCOM_binning_control;
  OGLM_CHECK_ERR(GLEW_QCOM_binning_control, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_driver_control()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_driver_control, )
  RETVAL = GLEW_QCOM_driver_control;
  OGLM_CHECK_ERR(GLEW_QCOM_driver_control, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_extended_get()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_extended_get, )
  RETVAL = GLEW_QCOM_extended_get;
  OGLM_CHECK_ERR(GLEW_QCOM_extended_get, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_extended_get2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_extended_get2, )
  RETVAL = GLEW_QCOM_extended_get2;
  OGLM_CHECK_ERR(GLEW_QCOM_extended_get2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_frame_extrapolation()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_frame_extrapolation, )
  RETVAL = GLEW_QCOM_frame_extrapolation;
  OGLM_CHECK_ERR(GLEW_QCOM_frame_extrapolation, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_framebuffer_foveated()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_framebuffer_foveated, )
  RETVAL = GLEW_QCOM_framebuffer_foveated;
  OGLM_CHECK_ERR(GLEW_QCOM_framebuffer_foveated, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_motion_estimation()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_motion_estimation, )
  RETVAL = GLEW_QCOM_motion_estimation;
  OGLM_CHECK_ERR(GLEW_QCOM_motion_estimation, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_perfmon_global_mode()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_perfmon_global_mode, )
  RETVAL = GLEW_QCOM_perfmon_global_mode;
  OGLM_CHECK_ERR(GLEW_QCOM_perfmon_global_mode, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_render_sRGB_R8_RG8()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_render_sRGB_R8_RG8, )
  RETVAL = GLEW_QCOM_render_sRGB_R8_RG8;
  OGLM_CHECK_ERR(GLEW_QCOM_render_sRGB_R8_RG8, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_render_shared_exponent()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_render_shared_exponent, )
  RETVAL = GLEW_QCOM_render_shared_exponent;
  OGLM_CHECK_ERR(GLEW_QCOM_render_shared_exponent, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_shader_framebuffer_fetch_noncoherent()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_shader_framebuffer_fetch_noncoherent, )
  RETVAL = GLEW_QCOM_shader_framebuffer_fetch_noncoherent;
  OGLM_CHECK_ERR(GLEW_QCOM_shader_framebuffer_fetch_noncoherent, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_shader_framebuffer_fetch_rate()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_shader_framebuffer_fetch_rate, )
  RETVAL = GLEW_QCOM_shader_framebuffer_fetch_rate;
  OGLM_CHECK_ERR(GLEW_QCOM_shader_framebuffer_fetch_rate, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_shading_rate()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_shading_rate, )
  RETVAL = GLEW_QCOM_shading_rate;
  OGLM_CHECK_ERR(GLEW_QCOM_shading_rate, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_texture_foveated()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated, )
  RETVAL = GLEW_QCOM_texture_foveated;
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_texture_foveated2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated2, )
  RETVAL = GLEW_QCOM_texture_foveated2;
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_texture_foveated_subsampled_layout()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated_subsampled_layout, )
  RETVAL = GLEW_QCOM_texture_foveated_subsampled_layout;
  OGLM_CHECK_ERR(GLEW_QCOM_texture_foveated_subsampled_layout, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_texture_lod_bias()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_texture_lod_bias, )
  RETVAL = GLEW_QCOM_texture_lod_bias;
  OGLM_CHECK_ERR(GLEW_QCOM_texture_lod_bias, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_tiled_rendering()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_tiled_rendering, )
  RETVAL = GLEW_QCOM_tiled_rendering;
  OGLM_CHECK_ERR(GLEW_QCOM_tiled_rendering, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_writeonly_rendering()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_writeonly_rendering, )
  RETVAL = GLEW_QCOM_writeonly_rendering;
  OGLM_CHECK_ERR(GLEW_QCOM_writeonly_rendering, )
OUTPUT:
  RETVAL

GLboolean
GLEW_QCOM_ycbcr_degamma()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_QCOM_ycbcr_degamma, )
  RETVAL = GLEW_QCOM_ycbcr_degamma;
  OGLM_CHECK_ERR(GLEW_QCOM_ycbcr_degamma, )
OUTPUT:
  RETVAL

GLboolean
GLEW_REGAL_ES1_0_compatibility()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_ES1_0_compatibility, )
  RETVAL = GLEW_REGAL_ES1_0_compatibility;
  OGLM_CHECK_ERR(GLEW_REGAL_ES1_0_compatibility, )
OUTPUT:
  RETVAL

GLboolean
GLEW_REGAL_ES1_1_compatibility()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_ES1_1_compatibility, )
  RETVAL = GLEW_REGAL_ES1_1_compatibility;
  OGLM_CHECK_ERR(GLEW_REGAL_ES1_1_compatibility, )
OUTPUT:
  RETVAL

GLboolean
GLEW_REGAL_enable()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_enable, )
  RETVAL = GLEW_REGAL_enable;
  OGLM_CHECK_ERR(GLEW_REGAL_enable, )
OUTPUT:
  RETVAL

GLboolean
GLEW_REGAL_error_string()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_error_string, )
  RETVAL = GLEW_REGAL_error_string;
  OGLM_CHECK_ERR(GLEW_REGAL_error_string, )
OUTPUT:
  RETVAL

GLboolean
GLEW_REGAL_extension_query()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_extension_query, )
  RETVAL = GLEW_REGAL_extension_query;
  OGLM_CHECK_ERR(GLEW_REGAL_extension_query, )
OUTPUT:
  RETVAL

GLboolean
GLEW_REGAL_log()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_log, )
  RETVAL = GLEW_REGAL_log;
  OGLM_CHECK_ERR(GLEW_REGAL_log, )
OUTPUT:
  RETVAL

GLboolean
GLEW_REGAL_proc_address()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REGAL_proc_address, )
  RETVAL = GLEW_REGAL_proc_address;
  OGLM_CHECK_ERR(GLEW_REGAL_proc_address, )
OUTPUT:
  RETVAL

GLboolean
GLEW_REND_screen_coordinates()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_REND_screen_coordinates, )
  RETVAL = GLEW_REND_screen_coordinates;
  OGLM_CHECK_ERR(GLEW_REND_screen_coordinates, )
OUTPUT:
  RETVAL

GLboolean
GLEW_S3_s3tc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_S3_s3tc, )
  RETVAL = GLEW_S3_s3tc;
  OGLM_CHECK_ERR(GLEW_S3_s3tc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_clip_band_hint()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_clip_band_hint, )
  RETVAL = GLEW_SGIS_clip_band_hint;
  OGLM_CHECK_ERR(GLEW_SGIS_clip_band_hint, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_color_range()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_color_range, )
  RETVAL = GLEW_SGIS_color_range;
  OGLM_CHECK_ERR(GLEW_SGIS_color_range, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_detail_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_detail_texture, )
  RETVAL = GLEW_SGIS_detail_texture;
  OGLM_CHECK_ERR(GLEW_SGIS_detail_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_fog_function()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_fog_function, )
  RETVAL = GLEW_SGIS_fog_function;
  OGLM_CHECK_ERR(GLEW_SGIS_fog_function, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_generate_mipmap()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_generate_mipmap, )
  RETVAL = GLEW_SGIS_generate_mipmap;
  OGLM_CHECK_ERR(GLEW_SGIS_generate_mipmap, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_line_texgen()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_line_texgen, )
  RETVAL = GLEW_SGIS_line_texgen;
  OGLM_CHECK_ERR(GLEW_SGIS_line_texgen, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_multisample, )
  RETVAL = GLEW_SGIS_multisample;
  OGLM_CHECK_ERR(GLEW_SGIS_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_multitexture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_multitexture, )
  RETVAL = GLEW_SGIS_multitexture;
  OGLM_CHECK_ERR(GLEW_SGIS_multitexture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_pixel_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_pixel_texture, )
  RETVAL = GLEW_SGIS_pixel_texture;
  OGLM_CHECK_ERR(GLEW_SGIS_pixel_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_point_line_texgen()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_point_line_texgen, )
  RETVAL = GLEW_SGIS_point_line_texgen;
  OGLM_CHECK_ERR(GLEW_SGIS_point_line_texgen, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_shared_multisample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_shared_multisample, )
  RETVAL = GLEW_SGIS_shared_multisample;
  OGLM_CHECK_ERR(GLEW_SGIS_shared_multisample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_sharpen_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_sharpen_texture, )
  RETVAL = GLEW_SGIS_sharpen_texture;
  OGLM_CHECK_ERR(GLEW_SGIS_sharpen_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_texture4D()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture4D, )
  RETVAL = GLEW_SGIS_texture4D;
  OGLM_CHECK_ERR(GLEW_SGIS_texture4D, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_texture_border_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture_border_clamp, )
  RETVAL = GLEW_SGIS_texture_border_clamp;
  OGLM_CHECK_ERR(GLEW_SGIS_texture_border_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_texture_edge_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture_edge_clamp, )
  RETVAL = GLEW_SGIS_texture_edge_clamp;
  OGLM_CHECK_ERR(GLEW_SGIS_texture_edge_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_texture_filter4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture_filter4, )
  RETVAL = GLEW_SGIS_texture_filter4;
  OGLM_CHECK_ERR(GLEW_SGIS_texture_filter4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_texture_lod()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture_lod, )
  RETVAL = GLEW_SGIS_texture_lod;
  OGLM_CHECK_ERR(GLEW_SGIS_texture_lod, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIS_texture_select()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIS_texture_select, )
  RETVAL = GLEW_SGIS_texture_select;
  OGLM_CHECK_ERR(GLEW_SGIS_texture_select, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_async()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_async, )
  RETVAL = GLEW_SGIX_async;
  OGLM_CHECK_ERR(GLEW_SGIX_async, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_async_histogram()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_async_histogram, )
  RETVAL = GLEW_SGIX_async_histogram;
  OGLM_CHECK_ERR(GLEW_SGIX_async_histogram, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_async_pixel()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_async_pixel, )
  RETVAL = GLEW_SGIX_async_pixel;
  OGLM_CHECK_ERR(GLEW_SGIX_async_pixel, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_bali_g_instruments()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_bali_g_instruments, )
  RETVAL = GLEW_SGIX_bali_g_instruments;
  OGLM_CHECK_ERR(GLEW_SGIX_bali_g_instruments, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_bali_r_instruments()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_bali_r_instruments, )
  RETVAL = GLEW_SGIX_bali_r_instruments;
  OGLM_CHECK_ERR(GLEW_SGIX_bali_r_instruments, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_bali_timer_instruments()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_bali_timer_instruments, )
  RETVAL = GLEW_SGIX_bali_timer_instruments;
  OGLM_CHECK_ERR(GLEW_SGIX_bali_timer_instruments, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_blend_alpha_minmax()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_blend_alpha_minmax, )
  RETVAL = GLEW_SGIX_blend_alpha_minmax;
  OGLM_CHECK_ERR(GLEW_SGIX_blend_alpha_minmax, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_blend_cadd()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_blend_cadd, )
  RETVAL = GLEW_SGIX_blend_cadd;
  OGLM_CHECK_ERR(GLEW_SGIX_blend_cadd, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_blend_cmultiply()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_blend_cmultiply, )
  RETVAL = GLEW_SGIX_blend_cmultiply;
  OGLM_CHECK_ERR(GLEW_SGIX_blend_cmultiply, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_calligraphic_fragment()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_calligraphic_fragment, )
  RETVAL = GLEW_SGIX_calligraphic_fragment;
  OGLM_CHECK_ERR(GLEW_SGIX_calligraphic_fragment, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_clipmap()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_clipmap, )
  RETVAL = GLEW_SGIX_clipmap;
  OGLM_CHECK_ERR(GLEW_SGIX_clipmap, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_color_matrix_accuracy()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_color_matrix_accuracy, )
  RETVAL = GLEW_SGIX_color_matrix_accuracy;
  OGLM_CHECK_ERR(GLEW_SGIX_color_matrix_accuracy, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_color_table_index_mode()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_color_table_index_mode, )
  RETVAL = GLEW_SGIX_color_table_index_mode;
  OGLM_CHECK_ERR(GLEW_SGIX_color_table_index_mode, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_complex_polar()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_complex_polar, )
  RETVAL = GLEW_SGIX_complex_polar;
  OGLM_CHECK_ERR(GLEW_SGIX_complex_polar, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_convolution_accuracy()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_convolution_accuracy, )
  RETVAL = GLEW_SGIX_convolution_accuracy;
  OGLM_CHECK_ERR(GLEW_SGIX_convolution_accuracy, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_cube_map()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_cube_map, )
  RETVAL = GLEW_SGIX_cube_map;
  OGLM_CHECK_ERR(GLEW_SGIX_cube_map, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_cylinder_texgen()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_cylinder_texgen, )
  RETVAL = GLEW_SGIX_cylinder_texgen;
  OGLM_CHECK_ERR(GLEW_SGIX_cylinder_texgen, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_datapipe()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_datapipe, )
  RETVAL = GLEW_SGIX_datapipe;
  OGLM_CHECK_ERR(GLEW_SGIX_datapipe, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_decimation()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_decimation, )
  RETVAL = GLEW_SGIX_decimation;
  OGLM_CHECK_ERR(GLEW_SGIX_decimation, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_depth_pass_instrument()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_depth_pass_instrument, )
  RETVAL = GLEW_SGIX_depth_pass_instrument;
  OGLM_CHECK_ERR(GLEW_SGIX_depth_pass_instrument, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_depth_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_depth_texture, )
  RETVAL = GLEW_SGIX_depth_texture;
  OGLM_CHECK_ERR(GLEW_SGIX_depth_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_dvc()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_dvc, )
  RETVAL = GLEW_SGIX_dvc;
  OGLM_CHECK_ERR(GLEW_SGIX_dvc, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_flush_raster()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_flush_raster, )
  RETVAL = GLEW_SGIX_flush_raster;
  OGLM_CHECK_ERR(GLEW_SGIX_flush_raster, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_fog_blend()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_blend, )
  RETVAL = GLEW_SGIX_fog_blend;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_blend, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_fog_factor_to_alpha()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_factor_to_alpha, )
  RETVAL = GLEW_SGIX_fog_factor_to_alpha;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_factor_to_alpha, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_fog_layers()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_layers, )
  RETVAL = GLEW_SGIX_fog_layers;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_layers, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_fog_offset()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_offset, )
  RETVAL = GLEW_SGIX_fog_offset;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_offset, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_fog_patchy()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_patchy, )
  RETVAL = GLEW_SGIX_fog_patchy;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_patchy, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_fog_scale()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_scale, )
  RETVAL = GLEW_SGIX_fog_scale;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_scale, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_fog_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fog_texture, )
  RETVAL = GLEW_SGIX_fog_texture;
  OGLM_CHECK_ERR(GLEW_SGIX_fog_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_fragment_lighting_space()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fragment_lighting_space, )
  RETVAL = GLEW_SGIX_fragment_lighting_space;
  OGLM_CHECK_ERR(GLEW_SGIX_fragment_lighting_space, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_fragment_specular_lighting()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fragment_specular_lighting, )
  RETVAL = GLEW_SGIX_fragment_specular_lighting;
  OGLM_CHECK_ERR(GLEW_SGIX_fragment_specular_lighting, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_fragments_instrument()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_fragments_instrument, )
  RETVAL = GLEW_SGIX_fragments_instrument;
  OGLM_CHECK_ERR(GLEW_SGIX_fragments_instrument, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_framezoom()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_framezoom, )
  RETVAL = GLEW_SGIX_framezoom;
  OGLM_CHECK_ERR(GLEW_SGIX_framezoom, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_icc_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_icc_texture, )
  RETVAL = GLEW_SGIX_icc_texture;
  OGLM_CHECK_ERR(GLEW_SGIX_icc_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_igloo_interface()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_igloo_interface, )
  RETVAL = GLEW_SGIX_igloo_interface;
  OGLM_CHECK_ERR(GLEW_SGIX_igloo_interface, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_image_compression()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_image_compression, )
  RETVAL = GLEW_SGIX_image_compression;
  OGLM_CHECK_ERR(GLEW_SGIX_image_compression, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_impact_pixel_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_impact_pixel_texture, )
  RETVAL = GLEW_SGIX_impact_pixel_texture;
  OGLM_CHECK_ERR(GLEW_SGIX_impact_pixel_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_instrument_error()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_instrument_error, )
  RETVAL = GLEW_SGIX_instrument_error;
  OGLM_CHECK_ERR(GLEW_SGIX_instrument_error, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_interlace()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_interlace, )
  RETVAL = GLEW_SGIX_interlace;
  OGLM_CHECK_ERR(GLEW_SGIX_interlace, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_ir_instrument1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_ir_instrument1, )
  RETVAL = GLEW_SGIX_ir_instrument1;
  OGLM_CHECK_ERR(GLEW_SGIX_ir_instrument1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_line_quality_hint()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_line_quality_hint, )
  RETVAL = GLEW_SGIX_line_quality_hint;
  OGLM_CHECK_ERR(GLEW_SGIX_line_quality_hint, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_list_priority()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_list_priority, )
  RETVAL = GLEW_SGIX_list_priority;
  OGLM_CHECK_ERR(GLEW_SGIX_list_priority, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_mpeg1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_mpeg1, )
  RETVAL = GLEW_SGIX_mpeg1;
  OGLM_CHECK_ERR(GLEW_SGIX_mpeg1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_mpeg2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_mpeg2, )
  RETVAL = GLEW_SGIX_mpeg2;
  OGLM_CHECK_ERR(GLEW_SGIX_mpeg2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_nonlinear_lighting_pervertex()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_nonlinear_lighting_pervertex, )
  RETVAL = GLEW_SGIX_nonlinear_lighting_pervertex;
  OGLM_CHECK_ERR(GLEW_SGIX_nonlinear_lighting_pervertex, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_nurbs_eval()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_nurbs_eval, )
  RETVAL = GLEW_SGIX_nurbs_eval;
  OGLM_CHECK_ERR(GLEW_SGIX_nurbs_eval, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_occlusion_instrument()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_occlusion_instrument, )
  RETVAL = GLEW_SGIX_occlusion_instrument;
  OGLM_CHECK_ERR(GLEW_SGIX_occlusion_instrument, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_packed_6bytes()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_packed_6bytes, )
  RETVAL = GLEW_SGIX_packed_6bytes;
  OGLM_CHECK_ERR(GLEW_SGIX_packed_6bytes, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_pixel_texture()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture, )
  RETVAL = GLEW_SGIX_pixel_texture;
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_pixel_texture_bits()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture_bits, )
  RETVAL = GLEW_SGIX_pixel_texture_bits;
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture_bits, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_pixel_texture_lod()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture_lod, )
  RETVAL = GLEW_SGIX_pixel_texture_lod;
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_texture_lod, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_pixel_tiles()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_tiles, )
  RETVAL = GLEW_SGIX_pixel_tiles;
  OGLM_CHECK_ERR(GLEW_SGIX_pixel_tiles, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_polynomial_ffd()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_polynomial_ffd, )
  RETVAL = GLEW_SGIX_polynomial_ffd;
  OGLM_CHECK_ERR(GLEW_SGIX_polynomial_ffd, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_quad_mesh()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_quad_mesh, )
  RETVAL = GLEW_SGIX_quad_mesh;
  OGLM_CHECK_ERR(GLEW_SGIX_quad_mesh, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_reference_plane()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_reference_plane, )
  RETVAL = GLEW_SGIX_reference_plane;
  OGLM_CHECK_ERR(GLEW_SGIX_reference_plane, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_resample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_resample, )
  RETVAL = GLEW_SGIX_resample;
  OGLM_CHECK_ERR(GLEW_SGIX_resample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_scalebias_hint()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_scalebias_hint, )
  RETVAL = GLEW_SGIX_scalebias_hint;
  OGLM_CHECK_ERR(GLEW_SGIX_scalebias_hint, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_shadow()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_shadow, )
  RETVAL = GLEW_SGIX_shadow;
  OGLM_CHECK_ERR(GLEW_SGIX_shadow, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_shadow_ambient()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_shadow_ambient, )
  RETVAL = GLEW_SGIX_shadow_ambient;
  OGLM_CHECK_ERR(GLEW_SGIX_shadow_ambient, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_slim()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_slim, )
  RETVAL = GLEW_SGIX_slim;
  OGLM_CHECK_ERR(GLEW_SGIX_slim, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_spotlight_cutoff()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_spotlight_cutoff, )
  RETVAL = GLEW_SGIX_spotlight_cutoff;
  OGLM_CHECK_ERR(GLEW_SGIX_spotlight_cutoff, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_sprite()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_sprite, )
  RETVAL = GLEW_SGIX_sprite;
  OGLM_CHECK_ERR(GLEW_SGIX_sprite, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_subdiv_patch()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_subdiv_patch, )
  RETVAL = GLEW_SGIX_subdiv_patch;
  OGLM_CHECK_ERR(GLEW_SGIX_subdiv_patch, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_subsample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_subsample, )
  RETVAL = GLEW_SGIX_subsample;
  OGLM_CHECK_ERR(GLEW_SGIX_subsample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_tag_sample_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_tag_sample_buffer, )
  RETVAL = GLEW_SGIX_tag_sample_buffer;
  OGLM_CHECK_ERR(GLEW_SGIX_tag_sample_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_texture_add_env()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_add_env, )
  RETVAL = GLEW_SGIX_texture_add_env;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_add_env, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_texture_coordinate_clamp()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_coordinate_clamp, )
  RETVAL = GLEW_SGIX_texture_coordinate_clamp;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_coordinate_clamp, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_texture_lod_bias()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_lod_bias, )
  RETVAL = GLEW_SGIX_texture_lod_bias;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_lod_bias, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_texture_mipmap_anisotropic()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_mipmap_anisotropic, )
  RETVAL = GLEW_SGIX_texture_mipmap_anisotropic;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_mipmap_anisotropic, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_texture_multi_buffer()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_multi_buffer, )
  RETVAL = GLEW_SGIX_texture_multi_buffer;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_multi_buffer, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_texture_phase()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_phase, )
  RETVAL = GLEW_SGIX_texture_phase;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_phase, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_texture_range()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_range, )
  RETVAL = GLEW_SGIX_texture_range;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_range, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_texture_scale_bias()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_scale_bias, )
  RETVAL = GLEW_SGIX_texture_scale_bias;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_scale_bias, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_texture_supersample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_texture_supersample, )
  RETVAL = GLEW_SGIX_texture_supersample;
  OGLM_CHECK_ERR(GLEW_SGIX_texture_supersample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_vector_ops()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_vector_ops, )
  RETVAL = GLEW_SGIX_vector_ops;
  OGLM_CHECK_ERR(GLEW_SGIX_vector_ops, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_vertex_array_object()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_array_object, )
  RETVAL = GLEW_SGIX_vertex_array_object;
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_array_object, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_vertex_preclip()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_preclip, )
  RETVAL = GLEW_SGIX_vertex_preclip;
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_preclip, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_vertex_preclip_hint()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_preclip_hint, )
  RETVAL = GLEW_SGIX_vertex_preclip_hint;
  OGLM_CHECK_ERR(GLEW_SGIX_vertex_preclip_hint, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_ycrcb()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcb, )
  RETVAL = GLEW_SGIX_ycrcb;
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcb, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_ycrcb_subsample()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcb_subsample, )
  RETVAL = GLEW_SGIX_ycrcb_subsample;
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcb_subsample, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGIX_ycrcba()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcba, )
  RETVAL = GLEW_SGIX_ycrcba;
  OGLM_CHECK_ERR(GLEW_SGIX_ycrcba, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGI_color_matrix()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_color_matrix, )
  RETVAL = GLEW_SGI_color_matrix;
  OGLM_CHECK_ERR(GLEW_SGI_color_matrix, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGI_color_table()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_color_table, )
  RETVAL = GLEW_SGI_color_table;
  OGLM_CHECK_ERR(GLEW_SGI_color_table, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGI_complex()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_complex, )
  RETVAL = GLEW_SGI_complex;
  OGLM_CHECK_ERR(GLEW_SGI_complex, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGI_complex_type()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_complex_type, )
  RETVAL = GLEW_SGI_complex_type;
  OGLM_CHECK_ERR(GLEW_SGI_complex_type, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGI_fft()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_fft, )
  RETVAL = GLEW_SGI_fft;
  OGLM_CHECK_ERR(GLEW_SGI_fft, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SGI_texture_color_table()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SGI_texture_color_table, )
  RETVAL = GLEW_SGI_texture_color_table;
  OGLM_CHECK_ERR(GLEW_SGI_texture_color_table, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SUNX_constant_data()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUNX_constant_data, )
  RETVAL = GLEW_SUNX_constant_data;
  OGLM_CHECK_ERR(GLEW_SUNX_constant_data, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SUN_convolution_border_modes()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_convolution_border_modes, )
  RETVAL = GLEW_SUN_convolution_border_modes;
  OGLM_CHECK_ERR(GLEW_SUN_convolution_border_modes, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SUN_global_alpha()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_global_alpha, )
  RETVAL = GLEW_SUN_global_alpha;
  OGLM_CHECK_ERR(GLEW_SUN_global_alpha, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SUN_mesh_array()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_mesh_array, )
  RETVAL = GLEW_SUN_mesh_array;
  OGLM_CHECK_ERR(GLEW_SUN_mesh_array, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SUN_read_video_pixels()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_read_video_pixels, )
  RETVAL = GLEW_SUN_read_video_pixels;
  OGLM_CHECK_ERR(GLEW_SUN_read_video_pixels, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SUN_slice_accum()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_slice_accum, )
  RETVAL = GLEW_SUN_slice_accum;
  OGLM_CHECK_ERR(GLEW_SUN_slice_accum, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SUN_triangle_list()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_triangle_list, )
  RETVAL = GLEW_SUN_triangle_list;
  OGLM_CHECK_ERR(GLEW_SUN_triangle_list, )
OUTPUT:
  RETVAL

GLboolean
GLEW_SUN_vertex()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_SUN_vertex, )
  RETVAL = GLEW_SUN_vertex;
  OGLM_CHECK_ERR(GLEW_SUN_vertex, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_1_1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_1, )
  RETVAL = GLEW_VERSION_1_1;
  OGLM_CHECK_ERR(GLEW_VERSION_1_1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_1_2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_2, )
  RETVAL = GLEW_VERSION_1_2;
  OGLM_CHECK_ERR(GLEW_VERSION_1_2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_1_2_1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_2_1, )
  RETVAL = GLEW_VERSION_1_2_1;
  OGLM_CHECK_ERR(GLEW_VERSION_1_2_1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_1_3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_3, )
  RETVAL = GLEW_VERSION_1_3;
  OGLM_CHECK_ERR(GLEW_VERSION_1_3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_1_4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_4, )
  RETVAL = GLEW_VERSION_1_4;
  OGLM_CHECK_ERR(GLEW_VERSION_1_4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_1_5()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_1_5, )
  RETVAL = GLEW_VERSION_1_5;
  OGLM_CHECK_ERR(GLEW_VERSION_1_5, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_2_0()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_2_0, )
  RETVAL = GLEW_VERSION_2_0;
  OGLM_CHECK_ERR(GLEW_VERSION_2_0, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_2_1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_2_1, )
  RETVAL = GLEW_VERSION_2_1;
  OGLM_CHECK_ERR(GLEW_VERSION_2_1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_3_0()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_3_0, )
  RETVAL = GLEW_VERSION_3_0;
  OGLM_CHECK_ERR(GLEW_VERSION_3_0, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_3_1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_3_1, )
  RETVAL = GLEW_VERSION_3_1;
  OGLM_CHECK_ERR(GLEW_VERSION_3_1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_3_2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_3_2, )
  RETVAL = GLEW_VERSION_3_2;
  OGLM_CHECK_ERR(GLEW_VERSION_3_2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_3_3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_3_3, )
  RETVAL = GLEW_VERSION_3_3;
  OGLM_CHECK_ERR(GLEW_VERSION_3_3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_4_0()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_0, )
  RETVAL = GLEW_VERSION_4_0;
  OGLM_CHECK_ERR(GLEW_VERSION_4_0, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_4_1()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_1, )
  RETVAL = GLEW_VERSION_4_1;
  OGLM_CHECK_ERR(GLEW_VERSION_4_1, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_4_2()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_2, )
  RETVAL = GLEW_VERSION_4_2;
  OGLM_CHECK_ERR(GLEW_VERSION_4_2, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_4_3()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_3, )
  RETVAL = GLEW_VERSION_4_3;
  OGLM_CHECK_ERR(GLEW_VERSION_4_3, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_4_4()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_4, )
  RETVAL = GLEW_VERSION_4_4;
  OGLM_CHECK_ERR(GLEW_VERSION_4_4, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_4_5()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_5, )
  RETVAL = GLEW_VERSION_4_5;
  OGLM_CHECK_ERR(GLEW_VERSION_4_5, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VERSION_4_6()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VERSION_4_6, )
  RETVAL = GLEW_VERSION_4_6;
  OGLM_CHECK_ERR(GLEW_VERSION_4_6, )
OUTPUT:
  RETVAL

GLboolean
GLEW_VIV_shader_binary()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_VIV_shader_binary, )
  RETVAL = GLEW_VIV_shader_binary;
  OGLM_CHECK_ERR(GLEW_VIV_shader_binary, )
OUTPUT:
  RETVAL

GLboolean
GLEW_WIN_phong_shading()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_WIN_phong_shading, )
  RETVAL = GLEW_WIN_phong_shading;
  OGLM_CHECK_ERR(GLEW_WIN_phong_shading, )
OUTPUT:
  RETVAL

GLboolean
GLEW_WIN_scene_markerXXX()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_WIN_scene_markerXXX, )
  RETVAL = GLEW_WIN_scene_markerXXX;
  OGLM_CHECK_ERR(GLEW_WIN_scene_markerXXX, )
OUTPUT:
  RETVAL

GLboolean
GLEW_WIN_specular_fog()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_WIN_specular_fog, )
  RETVAL = GLEW_WIN_specular_fog;
  OGLM_CHECK_ERR(GLEW_WIN_specular_fog, )
OUTPUT:
  RETVAL

GLboolean
GLEW_WIN_swap_hint()
CODE:
  OGLM_GLEWINIT
  OGLM_CHECK_ERR(GLEW_WIN_swap_hint, )
  RETVAL = GLEW_WIN_swap_hint;
  OGLM_CHECK_ERR(GLEW_WIN_swap_hint, )
OUTPUT:
  RETVAL

